--
-- PostgreSQL database dump
--

SET client_encoding = 'UNICODE';
SET check_function_bodies = false;

SET SESSION AUTHORIZATION 'postgres';

SET search_path = public, pg_catalog;

--
-- TOC entry 100 (OID 17142)
-- Name: plpgsql_call_handler(); Type: FUNC PROCEDURAL LANGUAGE; Schema: public; Owner: postgres
--

CREATE FUNCTION plpgsql_call_handler() RETURNS language_handler
    AS '$libdir/plpgsql', 'plpgsql_call_handler'
    LANGUAGE c;


--
-- TOC entry 101 (OID 17144)
-- Name: plperl_call_handler(); Type: FUNC PROCEDURAL LANGUAGE; Schema: public; Owner: postgres
--

CREATE FUNCTION plperl_call_handler() RETURNS language_handler
    AS '$libdir/plperl', 'plperl_call_handler'
    LANGUAGE c;


SET SESSION AUTHORIZATION DEFAULT;

--
-- TOC entry 97 (OID 17143)
-- Name: plpgsql; Type: PROCEDURAL LANGUAGE; Schema: public; Owner: 
--

CREATE TRUSTED PROCEDURAL LANGUAGE plpgsql HANDLER plpgsql_call_handler;


--
-- TOC entry 98 (OID 17145)
-- Name: plperl; Type: PROCEDURAL LANGUAGE; Schema: public; Owner: 
--

CREATE TRUSTED PROCEDURAL LANGUAGE plperl HANDLER plperl_call_handler;


--
-- TOC entry 99 (OID 17146)
-- Name: plperlu; Type: PROCEDURAL LANGUAGE; Schema: public; Owner: 
--

CREATE PROCEDURAL LANGUAGE plperlu HANDLER plperl_call_handler;


SET SESSION AUTHORIZATION 'postgres';

--
-- TOC entry 4 (OID 2200)
-- Name: public; Type: ACL; Schema: -; Owner: postgres
--

REVOKE ALL ON SCHEMA public FROM PUBLIC;
GRANT ALL ON SCHEMA public TO PUBLIC;


--
-- TOC entry 5 (OID 165765)
-- Name: euro; Type: DOMAIN; Schema: public; Owner: postgres
--

CREATE DOMAIN euro AS numeric;


--
-- TOC entry 102 (OID 165766)
-- Name: firstword(text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION firstword(text) RETURNS text
    AS 'my $text=shift;
$text=~ s/\\s+.*//;
return $text;
'
    LANGUAGE plperl IMMUTABLE STRICT;


--
-- TOC entry 104 (OID 165767)
-- Name: makename(text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION makename(text) RETURNS name
    AS 'my $text=shift;
$text=~ y/A-Za-z0-9/_/c;
return lc($text);
'
    LANGUAGE plperl;


--
-- TOC entry 106 (OID 165768)
-- Name: trunc(timestamp with time zone, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION trunc(timestamp with time zone, text) RETURNS timestamp with time zone
    AS 'my ($ts,$option)=@_;
my $res;
if($ts=~/(\\d\\d\\d\\d)-(\\d\\d)-(\\d\\d)/) {
	if(lc($option) eq "mm") { $res="$1-$2-01"; }
	else { $res="$1-$2-$3"; }
}
return $res;
'
    LANGUAGE plperl;


--
-- TOC entry 107 (OID 165769)
-- Name: trunc(timestamp with time zone); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION trunc(timestamp with time zone) RETURNS timestamp with time zone
    AS 'SELECT trunc($1,''d'') as result'
    LANGUAGE sql;


--
-- TOC entry 108 (OID 165770)
-- Name: ptrue(text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION ptrue(text) RETURNS boolean
    AS 'return($_[0]?"y":"n");'
    LANGUAGE plperl;


--
-- TOC entry 109 (OID 165771)
-- Name: pfalse(text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION pfalse(text) RETURNS boolean
    AS 'return($_[0]?"n":"y");'
    LANGUAGE plperl;


--
-- TOC entry 110 (OID 165772)
-- Name: path_indent(text, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION path_indent(text, text) RETURNS text
    AS 'my ($path,$label)=@_;
my $sep="&nbsp;";

$path=~s|/[^/]*|$sep|g;

return $path.$label;
'
    LANGUAGE plperl;


--
-- TOC entry 112 (OID 165773)
-- Name: path_indent(text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION path_indent(text) RETURNS text
    AS 'my ($path)=@_;
my $sep="&nbsp;"x2;

$path=~s|/[^/]*|$sep|g;

return $path;
'
    LANGUAGE plperl;


--
-- TOC entry 114 (OID 165774)
-- Name: kiki_path_a(text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION kiki_path_a(text) RETURNS text
    AS 'my ($path)=@_;
my $depth=($path=~y|/|/|);
my @pathi=split("/",$path); 
shift @pathi; $depth--;
my @path; my $i;

for $i (0..$#pathi) {
  push @path,
           qq{<a href="}.("../"x($depth-$i-1)).qq{">$pathi[$i]</a>};
};
  
return join(" / ",@path);
'
    LANGUAGE plperl IMMUTABLE STRICT;


--
-- TOC entry 115 (OID 165775)
-- Name: count_substrings(text, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION count_substrings(text, text) RETURNS text
    AS 'my ($str1,$str2)=@_;

my $r=s/$str1/$str2/g;

return "[$r]";
'
    LANGUAGE plperl;


--
-- TOC entry 117 (OID 165776)
-- Name: path_to_depth(text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION path_to_depth(text) RETURNS integer
    AS 'my ($path)=@_;

my $n=($path=~y|/|/|);

$n=($n>1)?($n-2):$n;

return $n;
'
    LANGUAGE plperl;


--
-- TOC entry 118 (OID 165777)
-- Name: if(boolean, text, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION if(boolean, text, text) RETURNS text
    AS 'my ($if1,$then2,$else3)=@_;

if($if1 eq "f") { $if1=0; }
return $if1?$then2:$else3;
'
    LANGUAGE plperl;


--
-- TOC entry 119 (OID 165778)
-- Name: str_repeat(text, integer); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION str_repeat(text, integer) RETURNS text
    AS '
return $_[0]x$_[1];
'
    LANGUAGE plperl;


--
-- TOC entry 121 (OID 165779)
-- Name: preg_replace(text, text, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION preg_replace(text, text, text) RETURNS text
    AS '
  my ($from,$to,$str)=@_;
  $str=~s/$from/$to/g;
  return $str;
'
    LANGUAGE plperl;


--
-- TOC entry 122 (OID 165780)
-- Name: run_add(text, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION run_add(text, text) RETURNS text
    AS '
$kiki::run[$_[0]]+=$_[1];
return $kiki::run[$_[0]];
'
    LANGUAGE plperl;


--
-- TOC entry 124 (OID 165781)
-- Name: run_reset(text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION run_reset(text) RETURNS text
    AS 'SELECT run_add( $1,-run_add( $1,0)::float)'
    LANGUAGE sql;


--
-- TOC entry 125 (OID 165782)
-- Name: kiki_find_node(text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION kiki_find_node(text) RETURNS integer
    AS '
DECLARE
  id1 integer;
  path1 ALIAS for $1;
BEGIN
  SELECT INTO id1
    id
  FROM nodes
  WHERE path=path1;

  RETURN id1;
END;

'
    LANGUAGE plpgsql;


--
-- TOC entry 126 (OID 165783)
-- Name: kiki_stamp(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION kiki_stamp() RETURNS "trigger"
    AS 'DECLARE
  parent nodes%ROWTYPE;

BEGIN 

IF NEW.id = 0 OR NEW.id = 1
THEN
 RETURN NEW;
END IF;

NEW.name := coalesce(nul(NEW.name),makename(NEW.title));

IF NEW.name ISNULL 
THEN RAISE EXCEPTION ''name cannot be NULL value''; 
END IF; 

IF NEW.pid ISNULL 
THEN RAISE EXCEPTION ''cannot have NULL parent''; 
END IF; 

SELECT INTO parent 
 *
FROM nodes
WHERE id=NEW.pid;

NEW.title := coalesce(NEW.title,ucfirst(NEW.name));
NEW.path := parent.path || NEW.name || ''/'';
NEW.depth := path_to_depth(NEW.path);
NEW.idpath := parent.idpath || '','' || NEW.id;
NEW.depth := path_to_depth(NEW.path);
NEW.ordungspath := parent.ordungspath || to_char(parent.ordung,''FM9990999'');
NEW.mtime := ''now''; 
NEW.label := coalesce(NEW.label,ucfirst(NEW.name));
RETURN NEW; 
END; 

'
    LANGUAGE plpgsql;


--
-- TOC entry 128 (OID 165784)
-- Name: kiki_stamp_children(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION kiki_stamp_children() RETURNS "trigger"
    AS 'BEGIN 

IF NEW.id = 0 OR NEW.id=1
THEN
 RETURN NEW;
END IF;

IF OLD.pid != NEW.pid OR OLD.name != NEW.name
THEN
UPDATE nodes SET id=id WHERE pid=NEW.id;
END IF;

RETURN NEW; 
END; 

'
    LANGUAGE plpgsql;


--
-- TOC entry 130 (OID 165785)
-- Name: kiki_insert(text, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION kiki_insert(text, text) RETURNS text
    AS '
DECLARE
  parent_path ALIAS FOR $1;
  new_name ALIAS FOR $2;

BEGIN 

INSERT INTO nodes
 (pid,name)
SELECT
 id,new_name
FROM nodes
WHERE path=parent_path;

RETURN parent_path || new_name;

END; 

'
    LANGUAGE plpgsql;


--
-- TOC entry 132 (OID 165786)
-- Name: sitemap_insert(text, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION sitemap_insert(text, text) RETURNS text
    AS '
DECLARE
  parent_path ALIAS FOR $1;
  new_name ALIAS FOR $2;

BEGIN 

INSERT INTO sitemap
 (pid,name)
SELECT
 id,new_name
FROM nodes
WHERE path=parent_path;

RETURN parent_path || new_name;

END; 

'
    LANGUAGE plpgsql;


--
-- TOC entry 134 (OID 165787)
-- Name: kiki_ordung(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION kiki_ordung() RETURNS opaque
    AS 'DECLARE
  newordung integer;

BEGIN 

SELECT 
 coalesce(max(ordung),0) + 100
INTO newordung
FROM nodes
WHERE pid=NEW.pid;

UPDATE nodes
SET
 ordung=newordung
WHERE
 id=NEW.id;

RETURN NEW;
END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 136 (OID 165788)
-- Name: log_trigger(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION log_trigger() RETURNS "trigger"
    AS '
DECLARE
  tab0 text;
  tab1 text;

BEGIN
  tab0 := wdbi.sql_full_path(TG_RELID);
  tab1 :=tab0 || ''_log'';

EXECUTE ''
INSERT INTO '' || tab1 || ''
SELECT now(), * FROM '' || tab0 || ''
WHERE oid='' || OLD.oid || ''
'';

IF TG_OP = ''DELETE'' THEN
  RETURN OLD;
ELSE
  RETURN NEW;
END IF;

END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 138 (OID 165789)
-- Name: lookup_create(text, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION lookup_create(text, text) RETURNS text
    AS '
DECLARE
  tab0 ALIAS FOR $1;
  tab1 ALIAS FOR $2;
BEGIN
EXECUTE ''
CREATE TABLE "'' || tab1 || ''" (
        "id" integer DEFAULT nextval(''''wdbi_seq'''') PRIMARY KEY,
        "text" text,
        "ordung" real,
        "cat" integer
);

CREATE TABLE "'' || tab0 || ''_'' || tab1 || ''_l" (
        "'' || tab0 ||''_id" integer,
        "'' || tab1 ||''_id" integer
)
'';
RETURN ''lookup_create'';
END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 139 (OID 165790)
-- Name: kiki_subclass(text, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION kiki_subclass(text, text) RETURNS text
    AS '
DECLARE
  tab0 ALIAS FOR $1;
  tab1 ALIAS FOR $2;
BEGIN
EXECUTE ''
CREATE TABLE "'' || tab1 || ''" (
) INHERITS('' || tab0 || '');
''; 
RETURN kiki_add_triggers(tab1);
END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 141 (OID 165791)
-- Name: kiki_add_triggers(text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION kiki_add_triggers(text) RETURNS text
    AS '
DECLARE
  tab ALIAS FOR $1;
BEGIN
EXECUTE ''
CREATE TRIGGER "'' || tab || ''_insert" 
BEFORE INSERT ON "'' || tab || ''"  
FOR EACH ROW 
EXECUTE PROCEDURE "kiki_stamp" ();

CREATE TRIGGER "'' || tab || ''_update" 
BEFORE UPDATE ON "'' || tab || ''"  
FOR EACH ROW 
EXECUTE PROCEDURE "kiki_stamp" ();

CREATE TRIGGER "'' || tab || ''_update_children" 
AFTER UPDATE ON "'' || tab || ''"  
FOR EACH ROW 
EXECUTE PROCEDURE "kiki_stamp_children" ();
'';
RETURN ''Kiki triggers created on table '' || tab;
END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 42 (OID 165917)
-- Name: links; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE links (
    id integer DEFAULT nextval('id_seq'::text),
    url text,
    uptime integer,
    downtime integer
)
INHERITS (ljudmila.items);


--
-- TOC entry 44 (OID 165917)
-- Name: links; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE links FROM PUBLIC;
GRANT SELECT ON TABLE links TO PUBLIC;


--
-- TOC entry 45 (OID 165940)
-- Name: zip; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE zip (
    zip integer NOT NULL,
    city text
);


--
-- TOC entry 47 (OID 165940)
-- Name: zip; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE zip FROM PUBLIC;
GRANT SELECT ON TABLE zip TO PUBLIC;
GRANT ALL ON TABLE zip TO GROUP ljudmila;


--
-- TOC entry 39 (OID 166024)
-- Name: users_id_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE users_id_seq
    INCREMENT BY 1
    NO MAXVALUE
    NO MINVALUE
    CACHE 1;


--
-- TOC entry 143 (OID 166041)
-- Name: wdbi_atom(text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION wdbi_atom(text) RETURNS integer
    AS '
DECLARE
  id1 integer;
  name1 ALIAS for $1;
BEGIN
  SELECT INTO id1
    id
  FROM wdbi_atoms
  WHERE name=name1;

  IF NOT FOUND THEN
	id1 := NEXTVAL(''wdbi_atoms_id_seq'');
	INSERT INTO wdbi_atoms (id,name) VALUES (id1,name1);
  END IF;

  RETURN id1;
END;

'
    LANGUAGE plpgsql;


--
-- TOC entry 145 (OID 166097)
-- Name: trunc(timestamp without time zone, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION trunc(timestamp without time zone, text) RETURNS timestamp without time zone
    AS 'my ($ts,$option)=@_;
my $res;
if($ts=~/(\\d\\d\\d\\d)-(\\d\\d)-(\\d\\d)/) {
	if(lc($option) eq "mm") { $res="$1-$2-01"; }
	else { $res="$1-$2-$3"; }
}
return $res;
'
    LANGUAGE plperl;


--
-- TOC entry 146 (OID 166098)
-- Name: trunc(timestamp without time zone); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION trunc(timestamp without time zone) RETURNS timestamp without time zone
    AS 'SELECT trunc($1,''d'') as result'
    LANGUAGE sql;


--
-- TOC entry 147 (OID 166099)
-- Name: sec_to_time(text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION sec_to_time(text) RETURNS text
    AS '
$sec=$_[0];
if(!defined($sec)) { return undef; }
$dd=int($sec/(60*60*24));
$sec-=$dd*60*60*24;
$hh=int($sec/(60*60));
$sec-=$hh*60*60;
$mi=int($sec/60);
$sec-=$mi*60;

return sprintf("%d %2d:%02d:%02d",$dd,$hh,$mi,$sec);
return $kiki::run[$_[0]];
'
    LANGUAGE plperl IMMUTABLE;


--
-- TOC entry 149 (OID 166100)
-- Name: char(integer); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION "char"(integer) RETURNS text
    AS '
    SELECT chr($1);
'
    LANGUAGE sql;


--
-- TOC entry 150 (OID 166101)
-- Name: insert(text, integer, integer, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION "insert"(text, integer, integer, text) RETURNS text
    AS '
    SELECT substring($1 from 1 for $2 - 1) || $4 || substring($1 from $2 + $3);
'
    LANGUAGE sql;


--
-- TOC entry 151 (OID 166102)
-- Name: left(text, integer); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION "left"(text, integer) RETURNS text
    AS '
    SELECT substring($1 for $2);
'
    LANGUAGE sql;


--
-- TOC entry 152 (OID 166103)
-- Name: locate(text, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION locate(text, text) RETURNS integer
    AS '
    SELECT position($1 in $2);
'
    LANGUAGE sql;


--
-- TOC entry 153 (OID 166104)
-- Name: locate(text, text, integer); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION locate(text, text, integer) RETURNS integer
    AS '
    SELECT position($1 in substring($2 from $3)) + $3 - 1;
'
    LANGUAGE sql;


--
-- TOC entry 154 (OID 166105)
-- Name: right(text, integer); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION "right"(text, integer) RETURNS text
    AS '
    SELECT substring($1 from char_length($1) - $2 + 1);
'
    LANGUAGE sql;


--
-- TOC entry 155 (OID 166106)
-- Name: space(integer); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION space(integer) RETURNS text
    AS '
    SELECT repeat('' '', $1);
'
    LANGUAGE sql;


--
-- TOC entry 156 (OID 166107)
-- Name: ceiling(numeric); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION ceiling(numeric) RETURNS numeric
    AS '
    SELECT ceil($1);
'
    LANGUAGE sql;


--
-- TOC entry 157 (OID 166108)
-- Name: log10(double precision); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION log10(double precision) RETURNS double precision
    AS '
    SELECT log($1);
'
    LANGUAGE sql;


--
-- TOC entry 158 (OID 166109)
-- Name: log10(numeric); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION log10(numeric) RETURNS numeric
    AS '
    SELECT log($1);
'
    LANGUAGE sql;


--
-- TOC entry 159 (OID 166110)
-- Name: power(double precision, double precision); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION power(double precision, double precision) RETURNS double precision
    AS '
    SELECT pow($1, $2);
'
    LANGUAGE sql;


--
-- TOC entry 160 (OID 166111)
-- Name: power(numeric, numeric); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION power(numeric, numeric) RETURNS numeric
    AS '
    SELECT pow($1, $2);
'
    LANGUAGE sql;


--
-- TOC entry 161 (OID 166112)
-- Name: rand(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION rand() RETURNS double precision
    AS '
    SELECT random();
'
    LANGUAGE sql;


--
-- TOC entry 162 (OID 166113)
-- Name: rand(double precision); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION rand(double precision) RETURNS double precision
    AS '
    SELECT setseed($1);
    SELECT random();
'
    LANGUAGE sql;


--
-- TOC entry 163 (OID 166114)
-- Name: truncate(numeric, integer); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION "truncate"(numeric, integer) RETURNS numeric
    AS '
    SELECT trunc($1, $2);
'
    LANGUAGE sql;


--
-- TOC entry 164 (OID 166115)
-- Name: curdate(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION curdate() RETURNS date
    AS 'SELECT current_date;
'
    LANGUAGE sql;


--
-- TOC entry 165 (OID 166116)
-- Name: curtime(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION curtime() RETURNS time with time zone
    AS '
    SELECT current_time;
'
    LANGUAGE sql;


--
-- TOC entry 166 (OID 166117)
-- Name: odbc_timestamp(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION odbc_timestamp() RETURNS timestamp with time zone
    AS '
    SELECT current_timestamp;
'
    LANGUAGE sql;


--
-- TOC entry 167 (OID 166118)
-- Name: dayname(timestamp without time zone); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION dayname(timestamp without time zone) RETURNS text
    AS '
    SELECT to_char($1,''Day'');
'
    LANGUAGE sql;


--
-- TOC entry 168 (OID 166119)
-- Name: dayofmonth(timestamp without time zone); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION dayofmonth(timestamp without time zone) RETURNS integer
    AS '
    SELECT CAST(EXTRACT(day FROM $1) AS integer);
'
    LANGUAGE sql;


--
-- TOC entry 169 (OID 166120)
-- Name: dayofweek(timestamp without time zone); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION dayofweek(timestamp without time zone) RETURNS integer
    AS '
    SELECT CAST(EXTRACT(dow FROM $1) AS integer) + 1;
'
    LANGUAGE sql;


--
-- TOC entry 170 (OID 166121)
-- Name: dayofyear(timestamp without time zone); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION dayofyear(timestamp without time zone) RETURNS integer
    AS '    SELECT CAST(EXTRACT(day FROM $1) AS integer);
'
    LANGUAGE sql;


--
-- TOC entry 171 (OID 166122)
-- Name: hour(timestamp without time zone); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION "hour"(timestamp without time zone) RETURNS integer
    AS '
    SELECT CAST(EXTRACT(hour FROM $1) AS integer);
'
    LANGUAGE sql;


--
-- TOC entry 172 (OID 166123)
-- Name: minute(timestamp without time zone); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION "minute"(timestamp without time zone) RETURNS integer
    AS '
    SELECT CAST(EXTRACT(minute FROM $1) AS integer);
'
    LANGUAGE sql;


--
-- TOC entry 173 (OID 166124)
-- Name: month(timestamp without time zone); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION "month"(timestamp without time zone) RETURNS integer
    AS '
    SELECT CAST(EXTRACT(month FROM $1) AS integer);
'
    LANGUAGE sql;


--
-- TOC entry 174 (OID 166125)
-- Name: monthname(timestamp without time zone); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION monthname(timestamp without time zone) RETURNS text
    AS '
    SELECT to_char($1, ''Month'');
'
    LANGUAGE sql;


--
-- TOC entry 175 (OID 166126)
-- Name: quarter(timestamp without time zone); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION quarter(timestamp without time zone) RETURNS integer
    AS '
    SELECT CAST(EXTRACT(quarter FROM $1) AS integer);
'
    LANGUAGE sql;


--
-- TOC entry 176 (OID 166127)
-- Name: second(timestamp without time zone); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION "second"(timestamp without time zone) RETURNS integer
    AS '
    SELECT CAST(EXTRACT(second FROM $1) AS integer);
'
    LANGUAGE sql;


--
-- TOC entry 177 (OID 166128)
-- Name: week(timestamp without time zone); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION week(timestamp without time zone) RETURNS integer
    AS '
    SELECT CAST(EXTRACT(week FROM $1) AS integer);
'
    LANGUAGE sql;


--
-- TOC entry 178 (OID 166129)
-- Name: year(timestamp without time zone); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION "year"(timestamp without time zone) RETURNS integer
    AS '
    SELECT CAST(EXTRACT(year FROM $1) AS integer);
'
    LANGUAGE sql;


--
-- TOC entry 179 (OID 166130)
-- Name: odbc_user(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION odbc_user() RETURNS text
    AS '
    SELECT CAST(current_user AS TEXT);
'
    LANGUAGE sql;


--
-- TOC entry 180 (OID 166131)
-- Name: odbc_current_user(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION odbc_current_user() RETURNS text
    AS '
    SELECT CAST(current_user AS TEXT);
'
    LANGUAGE sql;


--
-- TOC entry 181 (OID 166132)
-- Name: odbc_session_user(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION odbc_session_user() RETURNS text
    AS '
    SELECT CAST(session_user AS TEXT);
'
    LANGUAGE sql;


--
-- TOC entry 182 (OID 166136)
-- Name: dblink_connect(text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION dblink_connect(text) RETURNS text
    AS '$libdir/dblink', 'dblink_connect'
    LANGUAGE c STRICT;


--
-- TOC entry 183 (OID 166137)
-- Name: dblink_disconnect(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION dblink_disconnect() RETURNS text
    AS '$libdir/dblink', 'dblink_disconnect'
    LANGUAGE c STRICT;


--
-- TOC entry 184 (OID 166138)
-- Name: dblink_open(text, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION dblink_open(text, text) RETURNS text
    AS '$libdir/dblink', 'dblink_open'
    LANGUAGE c STRICT;


--
-- TOC entry 185 (OID 166139)
-- Name: dblink_fetch(text, integer); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION dblink_fetch(text, integer) RETURNS SETOF record
    AS '$libdir/dblink', 'dblink_fetch'
    LANGUAGE c STRICT;


--
-- TOC entry 186 (OID 166140)
-- Name: dblink_close(text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION dblink_close(text) RETURNS text
    AS '$libdir/dblink', 'dblink_close'
    LANGUAGE c STRICT;


--
-- TOC entry 187 (OID 166141)
-- Name: dblink(text, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION dblink(text, text) RETURNS SETOF record
    AS '$libdir/dblink', 'dblink_record'
    LANGUAGE c STRICT;


--
-- TOC entry 188 (OID 166142)
-- Name: dblink(text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION dblink(text) RETURNS SETOF record
    AS '$libdir/dblink', 'dblink_record'
    LANGUAGE c STRICT;


--
-- TOC entry 189 (OID 166143)
-- Name: dblink_exec(text, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION dblink_exec(text, text) RETURNS text
    AS '$libdir/dblink', 'dblink_exec'
    LANGUAGE c STRICT;


--
-- TOC entry 190 (OID 166144)
-- Name: dblink_exec(text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION dblink_exec(text) RETURNS text
    AS '$libdir/dblink', 'dblink_exec'
    LANGUAGE c STRICT;


--
-- TOC entry 7 (OID 166146)
-- Name: dblink_pkey_results; Type: TYPE; Schema: public; Owner: postgres
--

CREATE TYPE dblink_pkey_results AS (
	"position" integer,
	colname text
);


--
-- TOC entry 191 (OID 166147)
-- Name: dblink_get_pkey(text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION dblink_get_pkey(text) RETURNS SETOF dblink_pkey_results
    AS '$libdir/dblink', 'dblink_get_pkey'
    LANGUAGE c STRICT;


--
-- TOC entry 192 (OID 166148)
-- Name: dblink_build_sql_insert(text, int2vector, integer, text[], text[]); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION dblink_build_sql_insert(text, int2vector, integer, text[], text[]) RETURNS text
    AS '$libdir/dblink', 'dblink_build_sql_insert'
    LANGUAGE c STRICT;


--
-- TOC entry 193 (OID 166149)
-- Name: dblink_build_sql_delete(text, int2vector, integer, text[]); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION dblink_build_sql_delete(text, int2vector, integer, text[]) RETURNS text
    AS '$libdir/dblink', 'dblink_build_sql_delete'
    LANGUAGE c STRICT;


--
-- TOC entry 194 (OID 166150)
-- Name: dblink_build_sql_update(text, int2vector, integer, text[], text[]); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION dblink_build_sql_update(text, int2vector, integer, text[], text[]) RETURNS text
    AS '$libdir/dblink', 'dblink_build_sql_update'
    LANGUAGE c STRICT;


--
-- TOC entry 195 (OID 166151)
-- Name: dblink_current_query(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION dblink_current_query() RETURNS text
    AS '$libdir/dblink', 'dblink_current_query'
    LANGUAGE c;


--
-- TOC entry 196 (OID 166178)
-- Name: database_size(name); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION database_size(name) RETURNS bigint
    AS '$libdir/dbsize', 'database_size'
    LANGUAGE c STRICT;


--
-- TOC entry 197 (OID 166179)
-- Name: relation_size(text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION relation_size(text) RETURNS bigint
    AS '$libdir/dbsize', 'relation_size'
    LANGUAGE c STRICT;


--
-- TOC entry 203 (OID 166339)
-- Name: nodes_construct(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION nodes_construct() RETURNS "trigger"
    AS '
BEGIN
 RETURN NEW;
END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 204 (OID 166340)
-- Name: nodes_destruct(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION nodes_destruct() RETURNS "trigger"
    AS '
BEGIN
 RETURN OLD;
END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 205 (OID 166341)
-- Name: nodes_touch(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION nodes_touch() RETURNS "trigger"
    AS '
BEGIN
 RETURN NEW;
END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 206 (OID 166342)
-- Name: zip_construct(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION zip_construct() RETURNS "trigger"
    AS '
BEGIN
 RETURN NEW;
END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 207 (OID 166343)
-- Name: zip_destruct(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION zip_destruct() RETURNS "trigger"
    AS '
BEGIN
 RETURN OLD;
END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 208 (OID 166344)
-- Name: zip_touch(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION zip_touch() RETURNS "trigger"
    AS '
BEGIN
 RETURN NEW;
END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 209 (OID 166345)
-- Name: foo_construct(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION foo_construct() RETURNS "trigger"
    AS '
BEGIN
 RETURN NEW;
END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 210 (OID 166346)
-- Name: foo_destruct(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION foo_destruct() RETURNS "trigger"
    AS '
BEGIN
 RETURN OLD;
END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 211 (OID 166347)
-- Name: foo_touch(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION foo_touch() RETURNS "trigger"
    AS '
BEGIN
 RETURN NEW;
END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 212 (OID 166348)
-- Name: sitemap_construct(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION sitemap_construct() RETURNS "trigger"
    AS '
BEGIN
 RETURN NEW;
END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 213 (OID 166349)
-- Name: sitemap_destruct(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION sitemap_destruct() RETURNS "trigger"
    AS '
BEGIN
 RETURN OLD;
END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 214 (OID 166350)
-- Name: sitemap_touch(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION sitemap_touch() RETURNS "trigger"
    AS '
BEGIN
 RETURN NEW;
END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 215 (OID 166369)
-- Name: foo2_construct(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION foo2_construct() RETURNS "trigger"
    AS '
BEGIN
 RETURN NEW;
END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 216 (OID 166370)
-- Name: foo2_destruct(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION foo2_destruct() RETURNS "trigger"
    AS '
BEGIN
 RETURN OLD;
END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 217 (OID 166371)
-- Name: foo2_touch(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION foo2_touch() RETURNS "trigger"
    AS '
BEGIN
 RETURN NEW;
END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 218 (OID 166374)
-- Name: palette_construct(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION palette_construct() RETURNS "trigger"
    AS '
BEGIN
 RETURN NEW;
END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 219 (OID 166375)
-- Name: palette_destruct(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION palette_destruct() RETURNS "trigger"
    AS '
BEGIN
 RETURN OLD;
END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 220 (OID 166376)
-- Name: palette_touch(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION palette_touch() RETURNS "trigger"
    AS '
BEGIN
 RETURN NEW;
END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 221 (OID 166551)
-- Name: erw_construct(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION erw_construct() RETURNS "trigger"
    AS '
BEGIN
 RETURN NEW;
END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 222 (OID 166552)
-- Name: erw_destruct(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION erw_destruct() RETURNS "trigger"
    AS '
BEGIN
 RETURN OLD;
END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 223 (OID 166553)
-- Name: erw_touch(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION erw_touch() RETURNS "trigger"
    AS '
BEGIN
 RETURN NEW;
END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 224 (OID 166615)
-- Name: costly_items_construct(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION costly_items_construct() RETURNS "trigger"
    AS 'BEGIN

 SELECT INTO NEW.charge
   p.brutto * NEW.amount
 FROM pricelist p
 WHERE p.id=NEW.price_id;

 RETURN NEW;
END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 225 (OID 166616)
-- Name: costly_items_destruct(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION costly_items_destruct() RETURNS "trigger"
    AS '
BEGIN
 RETURN OLD;
END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 226 (OID 166617)
-- Name: costly_items_touch(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION costly_items_touch() RETURNS "trigger"
    AS 'BEGIN
 SELECT INTO NEW.charge
   p.netto * NEW.amount
 FROM pricelist p
 WHERE p.id=NEW.price_id;

 RETURN NEW;
END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 227 (OID 166622)
-- Name: todo_items_construct(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION todo_items_construct() RETURNS "trigger"
    AS '
BEGIN
 RETURN NEW;
END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 228 (OID 166623)
-- Name: todo_items_destruct(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION todo_items_destruct() RETURNS "trigger"
    AS '
BEGIN
 RETURN OLD;
END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 229 (OID 166624)
-- Name: todo_items_touch(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION todo_items_touch() RETURNS "trigger"
    AS 'BEGIN
 SELECT INTO NEW.items_total
   sum(charge)
 FROM costly_items WHERE pid=NEW.id;

 RETURN NEW;
END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 230 (OID 166626)
-- Name: costly_items_update(text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION costly_items_update(text) RETURNS "trigger"
    AS '
BEGIN
 UPDATE todo_items SET id=id WHERE id=OLD.pid;
END
'
    LANGUAGE plpgsql;


--
-- TOC entry 449 (OID 166627)
-- Name: costly_items_update(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION costly_items_update() RETURNS "trigger"
    AS 'BEGIN
 IF TG_OP IN (''UPDATE'',''DELETE'') THEN
   UPDATE todo_items SET id=id WHERE id=OLD.pid;
 END IF;

 IF TG_OP IN (''INSERT'',''UPDATE'') THEN
   UPDATE todo_items SET id=id WHERE id=NEW.pid;
 END IF;

 RETURN NEW;
END
'
    LANGUAGE plpgsql;


--
-- TOC entry 231 (OID 166665)
-- Name: photos_construct(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION photos_construct() RETURNS "trigger"
    AS '
BEGIN
 RETURN NEW;
END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 232 (OID 166666)
-- Name: photos_destruct(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION photos_destruct() RETURNS "trigger"
    AS '
BEGIN
 RETURN OLD;
END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 233 (OID 166667)
-- Name: photos_touch(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION photos_touch() RETURNS "trigger"
    AS '
BEGIN
 RETURN NEW;
END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 234 (OID 166705)
-- Name: wdbi_forms_bootstrap(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION wdbi_forms_bootstrap() RETURNS text
    AS '
BEGIN
----------------------------------------------------------------
-- DATA ljudmila.public.wdbi_forms
-- generated by WDBI on 2003-04-29 08:54:41
----------------------------------------------------------------
SET search_path="public",pg_catalog;
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (''133'',''photos'','' '',''ud'',''photos'',''Fotografije'',''id'','''',''photos.name'','''',''0'','''','''',NULL);
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (''40'',''news'',''0'',''iud'',''news'',''Form news on news'',''id'',NULL,'''',NULL,NULL,''items'',NULL,NULL);
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (''186'',''sitemap'',NULL,''1iudgs'',''sitemap'',''Sitemap'',''id'',NULL,''sitemap.mtime desc'',NULL,''0'',NULL,NULL,NULL);
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (''104'',''queries'',''0'',NULL,''nodes'',''SQL Query'',''id'',NULL,NULL,NULL,NULL,NULL,NULL,NULL);
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (''1004'',''wdbi_forms'',NULL,''uids'',''wdbi_forms'',''WDBI forms'',''name'',NULL,NULL,NULL,''0'',NULL,NULL,NULL);
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (''136'',''catalog_items'',NULL,NULL,''catalog_items'',''Katalog....'',''id'',NULL,''catalog_items.ctime desc'',NULL,NULL,NULL,NULL,NULL);
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (''139'',''kiki_types'',''0'',''uids'',''kiki_types'',''Form types on types'',''id'',NULL,''mime'',NULL,NULL,NULL,NULL,NULL);
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (''144'',''zip'',''0'',''iud'',''zip'',''Form zip on zip'',''zip'',NULL,NULL,NULL,NULL,NULL,NULL,NULL);
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (NULL,''pricelist'',NULL,''1iuds'',''pricelist'',''Price List'',''id'',NULL,''brutto desc'',NULL,NULL,NULL,NULL,NULL);
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (NULL,''users'',NULL,''1uids'',''users'',''Users'',''id'',NULL,NULL,NULL,NULL,NULL,NULL,''cols="40%,60%"'');
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (''14'',''ordung'',''0'',''do'',''nodes'',''Reordering children.'',''id'','''',''ordung'','''',''0'','''','''',NULL);
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (''98'',''kategorije'',''0'',''iud'',''kategorije'',''Form kategorije on kategorije'',''id'','''','''','''',''0'','''','''',NULL);
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (''134'',''kiki_drivers'',''0'',''iudsg'',''kiki_drivers'',''Kiki drivers'',''id'','''','''','''',''0'','''','''',NULL);
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (''143'',''wdbi_fields'',''0'',''iud'',''wdbi_fields'',''Form fields'',''id'','''','''','''',''0'','''','''',NULL);
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (NULL,''costly_items'',NULL,''1iudsgf'',''costly_items'',''Costly items'',''id'',NULL,''costly_items.ctime desc'',NULL,NULL,NULL,NULL,''cols="50%,50%"'');
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (''137'',''contacts'',''1'',''sl'',''contacts'',''Contacts'',''oid'',NULL,''contacts.name'',NULL,NULL,NULL,NULL,NULL);
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (''75'',''links'',NULL,''1iudls'',''links'',''Links'',''id'',NULL,''id desc'',NULL,''0'',NULL,NULL,NULL);
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (NULL,''kiki_properties'',''0'',''iudsg'',''kiki_properties'',''Node properties'',''id'',NULL,NULL,NULL,NULL,NULL,NULL,NULL);
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (NULL,''members'',NULL,''1iudls'',''members'',''Members'',''id'',NULL,''members.ctime desc'',NULL,''0'',NULL,NULL,''cols="50%,50%"'');
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (NULL,''nodes'',NULL,''ulids'',''nodes'',''Form nodes on nodes'',''id'',NULL,''nodes.mtime desc'',NULL,''0'',NULL,NULL,NULL);
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (''1080'',''lamers'',NULL,''iudsg'',''lamers'',''Lamers'',''username'',NULL,NULL,NULL,NULL,NULL,NULL,NULL);
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (NULL,''servers'',NULL,''iud'',''servers'',''Form servers on servers'',''id'',NULL,NULL,NULL,NULL,NULL,NULL,NULL);
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (NULL,''sites'',NULL,''1iudsl'',''sites'',''Sites'',''id'',NULL,''name'',NULL,''0'',NULL,NULL,NULL);
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (NULL,''todo_items'',''1'',''iusgd1'',''todo_items'',''Tasks'',''id'',NULL,''todo_items.ctime desc'',NULL,''0'',NULL,NULL,''cols="50%,50%"'');
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (''1002'',''dns'','' '',''1iudsl'',''dns'',''DNS records'',''id'','''','''','''',''0'','''','''',NULL);
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (''0'',''mail_headers'','' '',''iudgs'',''mail'',''Form mail on mail'',''id'','''',''date desc'','''',''0'','''','''',NULL);
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (NULL,''kikis'',NULL,''1iud'',''kikis'',''Other kikis'',''oid'',NULL,NULL,NULL,NULL,NULL,NULL,NULL);
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (''0'',''mail'','' '',''iud'',''mail'',''Mail messages'',''id'','''','''','''',''0'','''','''',NULL);
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (NULL,''projects'',''1'',''1iudsl'',''projects'',''Projects'',''id'',NULL,''projects.priority desc'',NULL,NULL,NULL,NULL,''rows="40%,60%"'');
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (NULL,''filesets'',NULL,''iud'',''filesets'',''Filesets (autoform)'',''id'',NULL,''filesets.mtime desc'',NULL,NULL,NULL,NULL,NULL);
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (NULL,''files'',NULL,''iud'',''files'',''Form files on files'',''id'',NULL,''ctime desc'',NULL,NULL,NULL,NULL,NULL);
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (''1001'',''pg_stat_activity'','' '',''sg'',''pg_stat_activity'',''DB sessions'',''id'','''','''','''',''0'','''','''',NULL);
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (NULL,''playlists'',NULL,''iud'',''playlists'',''Playlists (autoform)'',''id'',NULL,''playlists.ordung'',NULL,NULL,''sitemap'',NULL,NULL);
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (''1003'',''members1'',NULL,''iudl'',''members'',''Members'',''id'',NULL,''members.mtime desc'',NULL,NULL,NULL,NULL,NULL);
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (''1004'',''wdbi_tables'',NULL,'''',''wdbi_tables'',''Database Tables'',''oid'',NULL,NULL,NULL,NULL,NULL,NULL,NULL);
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (''1005'',''organizations'',NULL,''1iudls'',''organizations'',''Member organizations'',''id'',NULL,''organizations.ctime desc'',NULL,NULL,NULL,NULL,''cols="50%,50%"'');
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (''1009'',''wdbi.triggers'',NULL,''1ius'',''wdbi.triggers'',''Triggers'',''trigger_name'',NULL,NULL,NULL,NULL,NULL,NULL,NULL);
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (''1010'',''wdbi.queries'',NULL,''1iuds'',''wdbi.queries'',''WDBI Queries'',''name'',NULL,NULL,NULL,NULL,NULL,NULL,NULL);
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (''1011'',''wdbi.attr'',NULL,''1iuds'',''wdbi.attr'',''Attributes'',''oid'',NULL,NULL,NULL,NULL,NULL,NULL,NULL);
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (''1012'',''wdbi.enum'',NULL,''1iuds'',''wdbi.enum'',''Enums'',''id'',NULL,NULL,NULL,NULL,NULL,NULL,NULL);
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (''1013'',''wdbi.ent'',NULL,''1iuds'',''wdbi.ent'',''Entities'',''id'',NULL,NULL,NULL,NULL,NULL,NULL,NULL);
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (''1014'',''wdbi.tables'',NULL,''1us'',''wdbi.tables'',''Database Tables'',''sql_path'',NULL,NULL,NULL,NULL,NULL,NULL,NULL);
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (''1015'',''wdbi.db_link'',NULL,''iud'',''wdbi.db_link'',''Database links'',''name'',NULL,NULL,NULL,NULL,NULL,NULL,NULL);
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (''1016'',''wdbi.db_link_protocol'',NULL,''iud'',''wdbi.db_link_protocol'',''Database link protocols'',''name'',NULL,NULL,NULL,NULL,NULL,NULL,NULL);
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (''1017'',''wdbi.columns'',NULL,''iuds'',''wdbi.columns'',''wdbi.columns - WDBI columns '',''id'',NULL,NULL,NULL,NULL,NULL,NULL,NULL);
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (''1018'',''ljudmila.locations'',NULL,''iud'',''ljudmila.locations'',''ljudmila.locations'',''id'',NULL,NULL,NULL,NULL,NULL,NULL,NULL);
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (''1019'',''wdbi.leg'',NULL,''1iuds'',''wdbi.leg'',''Relation Leg'',''oid'',NULL,NULL,NULL,NULL,NULL,NULL,NULL);
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (''1020'',''ljudmila.hosts'',NULL,''iuds'',''ljudmila.hosts'',''ljudmila.hosts - Network hosts (automatic)'',''id'',NULL,NULL,NULL,NULL,NULL,NULL,NULL);
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (''1021'',''ljudmila.contacts'',NULL,''iuds'',''ljudmila.contacts'',''ljudmila.contacts - Human contacts'',''id'',NULL,NULL,NULL,NULL,NULL,NULL,NULL);
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (''1022'',''ljudmila.foo'',NULL,''iuds'',''ljudmila.foo'',''ljudmila.foo (automatic)'',''id'',NULL,NULL,NULL,NULL,NULL,NULL,NULL);
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (''1023'',''ljudmila.x'',NULL,''iuds'',''ljudmila.x'',''ljudmila.x (automatic)'',''id'',NULL,NULL,NULL,NULL,NULL,NULL,NULL);
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (''1024'',''wdbi.ddls'',NULL,''iuds'',''wdbi.ddls'',''wdbi.ddls (automatic)'',''id'',NULL,NULL,NULL,NULL,NULL,NULL,NULL);
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (''1025'',''wdbi.synonims'',NULL,''iuds'',''wdbi.synonims'',''wdbi.synonims - Table synonims (automatic)'',''id'',NULL,NULL,NULL,NULL,NULL,NULL,NULL);
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (''1026'',''wdbi.synonyms'',NULL,''iuds'',''wdbi.synonyms'',''wdbi.synonyms - Table synonyms - views with rules (automatic)'',''name'',NULL,NULL,NULL,NULL,NULL,NULL,NULL);
----------------------------------------------------------------
RETURN ''public.wdbi_forms bootstrapped'';
END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 235 (OID 166707)
-- Name: kiki_explorer_bootstrap(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION kiki_explorer_bootstrap() RETURNS text
    AS '
BEGIN
----------------------------------------------------------------
-- DATA ljudmila.public.kiki_explorer
-- generated by WDBI on 2003-04-29 10:19:13
----------------------------------------------------------------
SET search_path="public",pg_catalog;
<p>ERROR: Attribute "oid" not found </p>
<script>window.status="ERROR: Attribute \\"oid\\" not found ";</script>RETURN ''public.kiki_explorer bootstrapped'';
END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 236 (OID 166728)
-- Name: enum2_construct(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION enum2_construct() RETURNS "trigger"
    AS '
BEGIN
 RETURN NEW;
END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 237 (OID 166729)
-- Name: enum2_destruct(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION enum2_destruct() RETURNS "trigger"
    AS '
BEGIN
 RETURN OLD;
END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 238 (OID 166730)
-- Name: enum2_touch(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION enum2_touch() RETURNS "trigger"
    AS '
BEGIN
 RETURN NEW;
END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 239 (OID 166734)
-- Name: clips_construct(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION clips_construct() RETURNS "trigger"
    AS '
BEGIN
 RETURN NEW;
END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 240 (OID 166735)
-- Name: clips_destruct(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION clips_destruct() RETURNS "trigger"
    AS '
BEGIN
 RETURN OLD;
END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 241 (OID 166736)
-- Name: clips_touch(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION clips_touch() RETURNS "trigger"
    AS '
BEGIN
 RETURN NEW;
END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 242 (OID 167001)
-- Name: catalog_items_bootstrap(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION catalog_items_bootstrap() RETURNS text
    AS '
BEGIN
----------------------------------------------------------------
-- DATA ljudmila.public.catalog_items
-- generated by WDBI on 2003-09-5 08:06:37
----------------------------------------------------------------
SET search_path="public",pg_catalog;
----------------------------------------------------------------
RETURN ''public.catalog_items bootstrapped'';
END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 243 (OID 167006)
-- Name: kiki_types_bootstrap(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION kiki_types_bootstrap() RETURNS text
    AS '
BEGIN
----------------------------------------------------------------
-- DATA ljudmila.public.kiki_types
-- generated by WDBI on 2003-09-6 01:56:32
----------------------------------------------------------------
SET search_path="public",pg_catalog;
----------------------------------------------------------------
INSERT INTO kiki_types
 ("id","mime","name","encoding","driver","form","tablename")
VALUES
 (''0'',''kiki/node'',''node'','''',''kiki.php'',NULL,NULL);
----------------------------------------------------------------
INSERT INTO kiki_types
 ("id","mime","name","encoding","driver","form","tablename")
VALUES
 (''5'',''property/php'',''php expression'',''latin2'','''',NULL,NULL);
----------------------------------------------------------------
INSERT INTO kiki_types
 ("id","mime","name","encoding","driver","form","tablename")
VALUES
 (''6'',''kiki/driver'','''','''','''',NULL,NULL);
----------------------------------------------------------------
INSERT INTO kiki_types
 ("id","mime","name","encoding","driver","form","tablename")
VALUES
 (''100'',''wdbi/driver'','''','''','''',NULL,NULL);
----------------------------------------------------------------
INSERT INTO kiki_types
 ("id","mime","name","encoding","driver","form","tablename")
VALUES
 (''7'',''kiki/query'',''query'',''sql'',''/kiki/query.php'',NULL,NULL);
----------------------------------------------------------------
INSERT INTO kiki_types
 ("id","mime","name","encoding","driver","form","tablename")
VALUES
 (''2'',''kiki/project'',''project'',NULL,''kiki.php/'',''projects'',NULL);
----------------------------------------------------------------
INSERT INTO kiki_types
 ("id","mime","name","encoding","driver","form","tablename")
VALUES
 (''3'',''kiki/page'',''page'',NULL,''kiki.php/'',''sitemap'',NULL);
----------------------------------------------------------------
INSERT INTO kiki_types
 ("id","mime","name","encoding","driver","form","tablename")
VALUES
 (''4'',''property/text'',''literal text'',''latin2'','''',NULL,NULL);
----------------------------------------------------------------
INSERT INTO kiki_types
 ("id","mime","name","encoding","driver","form","tablename")
VALUES
 (''1'',''kiki/server'',''server'',NULL,''/standard'',''servers'',NULL);
----------------------------------------------------------------
INSERT INTO kiki_types
 ("id","mime","name","encoding","driver","form","tablename")
VALUES
 (''102'',''property/css'',''CSS style element'',NULL,NULL,NULL,NULL);
----------------------------------------------------------------
RETURN ''public.kiki_types bootstrapped'';
END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 48 (OID 167301)
-- Name: mime; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE mime (
    "type" text NOT NULL,
    "comment" text,
    registry text,
    aliasfor name
);


--
-- TOC entry 50 (OID 167301)
-- Name: mime; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE mime FROM PUBLIC;
GRANT SELECT ON TABLE mime TO iedc;
GRANT SELECT ON TABLE mime TO PUBLIC;
GRANT ALL ON TABLE mime TO GROUP mime;


--
-- TOC entry 201 (OID 173673)
-- Name: pgxml_parse(text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION pgxml_parse(text) RETURNS boolean
    AS '$libdir/pgxml_dom', 'pgxml_parse'
    LANGUAGE c STRICT;


--
-- TOC entry 202 (OID 173674)
-- Name: pgxml_xpath(text, text, text, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION pgxml_xpath(text, text, text, text) RETURNS text
    AS '$libdir/pgxml_dom', 'pgxml_xpath'
    LANGUAGE c STRICT;


--
-- TOC entry 13 (OID 173676)
-- Name: xml; Type: DOMAIN; Schema: public; Owner: postgres
--

CREATE DOMAIN xml AS text
	CONSTRAINT "validate_XML" CHECK (pgxml_parse(VALUE));


--
-- TOC entry 274 (OID 175276)
-- Name: sms_construct(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION sms_construct() RETURNS "trigger"
    AS 'DECLARE
  res TEXT;

BEGIN 
  IF NEW.msisdn IS NOT NULL AND NEW.text IS NOT NULL THEN
    SELECT INTO NEW.reply public.smsto(NEW.msisdn,NEW.text);
  END IF;

  RETURN NEW;
END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 272 (OID 175283)
-- Name: smsto(text, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION smsto(text, text) RETURNS text
    AS 'my ($msisdn,$text)=@_;

use LWP::Simple;
use WDBI::P;

my $url="https://ziga:bonec1984\\@glasnik.simobil.si/xml/".
        "?msisdn=".esc(''uri'',$msisdn)."&text=".esc(''uri'',$text);

my $response=get($url);
return $response;
'
    LANGUAGE plperlu STABLE;


--
-- TOC entry 198 (OID 182518)
-- Name: test_construct(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION test_construct() RETURNS "trigger"
    AS '
BEGIN
 RETURN NEW;
END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 199 (OID 182519)
-- Name: test_destruct(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION test_destruct() RETURNS "trigger"
    AS '
BEGIN
 RETURN OLD;
END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 200 (OID 182520)
-- Name: test_touch(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION test_touch() RETURNS "trigger"
    AS '
BEGIN
 RETURN NEW;
END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 51 (OID 184698)
-- Name: imp_pref; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE imp_pref (
    username text,
    sig text,
    fullname text,
    replyto text,
    lang character varying(30)
);


--
-- TOC entry 52 (OID 184703)
-- Name: imp_addr; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE imp_addr (
    username text,
    address text,
    nickname text,
    fullname text
);


--
-- TOC entry 53 (OID 184709)
-- Name: turba_objects; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE turba_objects (
    object_id character varying(32) NOT NULL,
    owner_id character varying(255) NOT NULL,
    object_name character varying(255),
    object_alias character varying(32),
    object_email character varying(255),
    object_homeaddress character varying(255),
    object_workaddress character varying(255),
    object_homephone character varying(25),
    object_workphone character varying(25),
    object_cellphone character varying(25),
    object_fax character varying(25),
    object_title character varying(32),
    object_company character varying(32),
    object_notes text
);


--
-- TOC entry 54 (OID 184709)
-- Name: turba_objects; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE turba_objects FROM PUBLIC;
GRANT INSERT,SELECT,UPDATE,DELETE ON TABLE turba_objects TO horde;


--
-- TOC entry 244 (OID 1867129)
-- Name: issn_in(cstring); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION issn_in(cstring) RETURNS issn
    AS '$libdir/isbn_issn', 'issn_in'
    LANGUAGE c;


--
-- TOC entry 245 (OID 1867130)
-- Name: issn_out(issn); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION issn_out(issn) RETURNS cstring
    AS '$libdir/isbn_issn', 'issn_out'
    LANGUAGE c;


--
-- TOC entry 11 (OID 1867128)
-- Name: issn; Type: TYPE; Schema: public; Owner: postgres
--

CREATE TYPE issn (
    INTERNALLENGTH = 16,
    INPUT = issn_in,
    OUTPUT = issn_out,
    ALIGNMENT = int4,
    STORAGE = plain
);


--
-- TOC entry 246 (OID 1867132)
-- Name: issn_lt(issn, issn); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION issn_lt(issn, issn) RETURNS boolean
    AS '$libdir/isbn_issn', 'issn_lt'
    LANGUAGE c;


--
-- TOC entry 247 (OID 1867133)
-- Name: issn_le(issn, issn); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION issn_le(issn, issn) RETURNS boolean
    AS '$libdir/isbn_issn', 'issn_le'
    LANGUAGE c;


--
-- TOC entry 248 (OID 1867134)
-- Name: issn_eq(issn, issn); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION issn_eq(issn, issn) RETURNS boolean
    AS '$libdir/isbn_issn', 'issn_eq'
    LANGUAGE c;


--
-- TOC entry 249 (OID 1867135)
-- Name: issn_ge(issn, issn); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION issn_ge(issn, issn) RETURNS boolean
    AS '$libdir/isbn_issn', 'issn_ge'
    LANGUAGE c;


--
-- TOC entry 250 (OID 1867136)
-- Name: issn_gt(issn, issn); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION issn_gt(issn, issn) RETURNS boolean
    AS '$libdir/isbn_issn', 'issn_gt'
    LANGUAGE c;


--
-- TOC entry 251 (OID 1867137)
-- Name: issn_ne(issn, issn); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION issn_ne(issn, issn) RETURNS boolean
    AS '$libdir/isbn_issn', 'issn_ne'
    LANGUAGE c;


--
-- TOC entry 459 (OID 1867138)
-- Name: <; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR < (
    PROCEDURE = issn_lt,
    LEFTARG = issn,
    RIGHTARG = issn,
    NEGATOR = >=
);


--
-- TOC entry 461 (OID 1867139)
-- Name: <=; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR <= (
    PROCEDURE = issn_le,
    LEFTARG = issn,
    RIGHTARG = issn,
    NEGATOR = >
);


--
-- TOC entry 463 (OID 1867140)
-- Name: =; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR = (
    PROCEDURE = issn_eq,
    LEFTARG = issn,
    RIGHTARG = issn,
    COMMUTATOR = =,
    NEGATOR = <>
);


--
-- TOC entry 458 (OID 1867141)
-- Name: >=; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR >= (
    PROCEDURE = issn_ge,
    LEFTARG = issn,
    RIGHTARG = issn,
    NEGATOR = <
);


--
-- TOC entry 460 (OID 1867142)
-- Name: >; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR > (
    PROCEDURE = issn_gt,
    LEFTARG = issn,
    RIGHTARG = issn,
    NEGATOR = <=
);


--
-- TOC entry 462 (OID 1867143)
-- Name: <>; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR <> (
    PROCEDURE = issn_ne,
    LEFTARG = issn,
    RIGHTARG = issn,
    NEGATOR = =
);


--
-- TOC entry 252 (OID 1867144)
-- Name: issn_cmp(issn, issn); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION issn_cmp(issn, issn) RETURNS integer
    AS '$libdir/isbn_issn', 'issn_cmp'
    LANGUAGE c;


--
-- TOC entry 520 (OID 1867145)
-- Name: issn_ops; Type: OPERATOR CLASS; Schema: public; Owner: postgres
--

CREATE OPERATOR CLASS issn_ops
    DEFAULT FOR TYPE issn USING btree AS
    OPERATOR 1 <(issn,issn) ,
    OPERATOR 2 <=(issn,issn) ,
    OPERATOR 3 =(issn,issn) ,
    OPERATOR 4 >=(issn,issn) ,
    OPERATOR 5 >(issn,issn) ,
    FUNCTION 1 issn_cmp(issn,issn);


--
-- TOC entry 253 (OID 1867147)
-- Name: isbn_in(cstring); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION isbn_in(cstring) RETURNS isbn
    AS '$libdir/isbn_issn', 'isbn_in'
    LANGUAGE c;


--
-- TOC entry 254 (OID 1867148)
-- Name: isbn_out(isbn); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION isbn_out(isbn) RETURNS cstring
    AS '$libdir/isbn_issn', 'isbn_out'
    LANGUAGE c;


--
-- TOC entry 15 (OID 1867146)
-- Name: isbn; Type: TYPE; Schema: public; Owner: postgres
--

CREATE TYPE isbn (
    INTERNALLENGTH = 16,
    INPUT = isbn_in,
    OUTPUT = isbn_out,
    ALIGNMENT = int4,
    STORAGE = plain
);


--
-- TOC entry 255 (OID 1867150)
-- Name: isbn_lt(isbn, isbn); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION isbn_lt(isbn, isbn) RETURNS boolean
    AS '$libdir/isbn_issn', 'isbn_lt'
    LANGUAGE c;


--
-- TOC entry 256 (OID 1867151)
-- Name: isbn_le(isbn, isbn); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION isbn_le(isbn, isbn) RETURNS boolean
    AS '$libdir/isbn_issn', 'isbn_le'
    LANGUAGE c;


--
-- TOC entry 257 (OID 1867152)
-- Name: isbn_eq(isbn, isbn); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION isbn_eq(isbn, isbn) RETURNS boolean
    AS '$libdir/isbn_issn', 'isbn_eq'
    LANGUAGE c;


--
-- TOC entry 258 (OID 1867153)
-- Name: isbn_ge(isbn, isbn); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION isbn_ge(isbn, isbn) RETURNS boolean
    AS '$libdir/isbn_issn', 'isbn_ge'
    LANGUAGE c;


--
-- TOC entry 259 (OID 1867154)
-- Name: isbn_gt(isbn, isbn); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION isbn_gt(isbn, isbn) RETURNS boolean
    AS '$libdir/isbn_issn', 'isbn_gt'
    LANGUAGE c;


--
-- TOC entry 260 (OID 1867155)
-- Name: isbn_ne(isbn, isbn); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION isbn_ne(isbn, isbn) RETURNS boolean
    AS '$libdir/isbn_issn', 'isbn_ne'
    LANGUAGE c;


--
-- TOC entry 469 (OID 1867156)
-- Name: <; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR < (
    PROCEDURE = isbn_lt,
    LEFTARG = isbn,
    RIGHTARG = isbn,
    NEGATOR = >=
);


--
-- TOC entry 471 (OID 1867157)
-- Name: <=; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR <= (
    PROCEDURE = isbn_le,
    LEFTARG = isbn,
    RIGHTARG = isbn,
    NEGATOR = >
);


--
-- TOC entry 473 (OID 1867158)
-- Name: =; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR = (
    PROCEDURE = isbn_eq,
    LEFTARG = isbn,
    RIGHTARG = isbn,
    COMMUTATOR = =,
    NEGATOR = <>
);


--
-- TOC entry 468 (OID 1867159)
-- Name: >=; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR >= (
    PROCEDURE = isbn_ge,
    LEFTARG = isbn,
    RIGHTARG = isbn,
    NEGATOR = <
);


--
-- TOC entry 470 (OID 1867160)
-- Name: >; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR > (
    PROCEDURE = isbn_gt,
    LEFTARG = isbn,
    RIGHTARG = isbn,
    NEGATOR = <=
);


--
-- TOC entry 472 (OID 1867161)
-- Name: <>; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR <> (
    PROCEDURE = isbn_ne,
    LEFTARG = isbn,
    RIGHTARG = isbn,
    NEGATOR = =
);


--
-- TOC entry 261 (OID 1867162)
-- Name: isbn_cmp(isbn, isbn); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION isbn_cmp(isbn, isbn) RETURNS integer
    AS '$libdir/isbn_issn', 'isbn_cmp'
    LANGUAGE c;


--
-- TOC entry 521 (OID 1867163)
-- Name: isbn_ops; Type: OPERATOR CLASS; Schema: public; Owner: postgres
--

CREATE OPERATOR CLASS isbn_ops
    DEFAULT FOR TYPE isbn USING btree AS
    OPERATOR 1 <(isbn,isbn) ,
    OPERATOR 2 <=(isbn,isbn) ,
    OPERATOR 3 =(isbn,isbn) ,
    OPERATOR 4 >=(isbn,isbn) ,
    OPERATOR 5 >(isbn,isbn) ,
    FUNCTION 1 isbn_cmp(isbn,isbn);


--
-- TOC entry 262 (OID 1867164)
-- Name: normal_rand(integer, double precision, double precision); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION normal_rand(integer, double precision, double precision) RETURNS SETOF double precision
    AS '$libdir/tablefunc', 'normal_rand'
    LANGUAGE c STRICT;


--
-- TOC entry 17 (OID 1867166)
-- Name: tablefunc_crosstab_2; Type: TYPE; Schema: public; Owner: postgres
--

CREATE TYPE tablefunc_crosstab_2 AS (
	row_name text,
	category_1 text,
	category_2 text
);


--
-- TOC entry 18 (OID 1867168)
-- Name: tablefunc_crosstab_3; Type: TYPE; Schema: public; Owner: postgres
--

CREATE TYPE tablefunc_crosstab_3 AS (
	row_name text,
	category_1 text,
	category_2 text,
	category_3 text
);


--
-- TOC entry 19 (OID 1867170)
-- Name: tablefunc_crosstab_4; Type: TYPE; Schema: public; Owner: postgres
--

CREATE TYPE tablefunc_crosstab_4 AS (
	row_name text,
	category_1 text,
	category_2 text,
	category_3 text,
	category_4 text
);


--
-- TOC entry 263 (OID 1867171)
-- Name: crosstab2(text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION crosstab2(text) RETURNS SETOF tablefunc_crosstab_2
    AS '$libdir/tablefunc', 'crosstab'
    LANGUAGE c STABLE STRICT;


--
-- TOC entry 264 (OID 1867172)
-- Name: crosstab3(text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION crosstab3(text) RETURNS SETOF tablefunc_crosstab_3
    AS '$libdir/tablefunc', 'crosstab'
    LANGUAGE c STABLE STRICT;


--
-- TOC entry 265 (OID 1867173)
-- Name: crosstab4(text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION crosstab4(text) RETURNS SETOF tablefunc_crosstab_4
    AS '$libdir/tablefunc', 'crosstab'
    LANGUAGE c STABLE STRICT;


--
-- TOC entry 266 (OID 1867174)
-- Name: crosstab(text, integer); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION crosstab(text, integer) RETURNS SETOF record
    AS '$libdir/tablefunc', 'crosstab'
    LANGUAGE c STABLE STRICT;


--
-- TOC entry 267 (OID 1867175)
-- Name: crosstab(text, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION crosstab(text, text) RETURNS SETOF record
    AS '$libdir/tablefunc', 'crosstab_hash'
    LANGUAGE c STABLE STRICT;


--
-- TOC entry 268 (OID 1867176)
-- Name: connectby(text, text, text, text, integer, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION connectby(text, text, text, text, integer, text) RETURNS SETOF record
    AS '$libdir/tablefunc', 'connectby_text'
    LANGUAGE c STABLE STRICT;


--
-- TOC entry 269 (OID 1867177)
-- Name: connectby(text, text, text, text, integer); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION connectby(text, text, text, text, integer) RETURNS SETOF record
    AS '$libdir/tablefunc', 'connectby_text'
    LANGUAGE c STABLE STRICT;


--
-- TOC entry 270 (OID 1867178)
-- Name: connectby(text, text, text, text, text, integer, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION connectby(text, text, text, text, text, integer, text) RETURNS SETOF record
    AS '$libdir/tablefunc', 'connectby_text_serial'
    LANGUAGE c STABLE STRICT;


--
-- TOC entry 271 (OID 1867179)
-- Name: connectby(text, text, text, text, text, integer); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION connectby(text, text, text, text, text, integer) RETURNS SETOF record
    AS '$libdir/tablefunc', 'connectby_text_serial'
    LANGUAGE c STABLE STRICT;


--
-- TOC entry 273 (OID 1867181)
-- Name: digest(text, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION digest(text, text) RETURNS bytea
    AS '$libdir/pgcrypto', 'pg_digest'
    LANGUAGE c;


--
-- TOC entry 275 (OID 1867182)
-- Name: digest(bytea, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION digest(bytea, text) RETURNS bytea
    AS '$libdir/pgcrypto', 'pg_digest'
    LANGUAGE c;


--
-- TOC entry 276 (OID 1867183)
-- Name: digest_exists(text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION digest_exists(text) RETURNS boolean
    AS '$libdir/pgcrypto', 'pg_digest_exists'
    LANGUAGE c;


--
-- TOC entry 277 (OID 1867184)
-- Name: hmac(text, text, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION hmac(text, text, text) RETURNS bytea
    AS '$libdir/pgcrypto', 'pg_hmac'
    LANGUAGE c;


--
-- TOC entry 278 (OID 1867185)
-- Name: hmac(bytea, bytea, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION hmac(bytea, bytea, text) RETURNS bytea
    AS '$libdir/pgcrypto', 'pg_hmac'
    LANGUAGE c;


--
-- TOC entry 279 (OID 1867186)
-- Name: hmac_exists(text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION hmac_exists(text) RETURNS boolean
    AS '$libdir/pgcrypto', 'pg_hmac_exists'
    LANGUAGE c;


--
-- TOC entry 280 (OID 1867187)
-- Name: crypt(text, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION crypt(text, text) RETURNS text
    AS '$libdir/pgcrypto', 'pg_crypt'
    LANGUAGE c;


--
-- TOC entry 281 (OID 1867188)
-- Name: gen_salt(text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION gen_salt(text) RETURNS text
    AS '$libdir/pgcrypto', 'pg_gen_salt'
    LANGUAGE c;


--
-- TOC entry 282 (OID 1867189)
-- Name: gen_salt(text, integer); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION gen_salt(text, integer) RETURNS text
    AS '$libdir/pgcrypto', 'pg_gen_salt_rounds'
    LANGUAGE c;


--
-- TOC entry 283 (OID 1867190)
-- Name: encrypt(bytea, bytea, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION encrypt(bytea, bytea, text) RETURNS bytea
    AS '$libdir/pgcrypto', 'pg_encrypt'
    LANGUAGE c;


--
-- TOC entry 284 (OID 1867191)
-- Name: decrypt(bytea, bytea, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION decrypt(bytea, bytea, text) RETURNS bytea
    AS '$libdir/pgcrypto', 'pg_decrypt'
    LANGUAGE c;


--
-- TOC entry 285 (OID 1867192)
-- Name: encrypt_iv(bytea, bytea, bytea, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION encrypt_iv(bytea, bytea, bytea, text) RETURNS bytea
    AS '$libdir/pgcrypto', 'pg_encrypt_iv'
    LANGUAGE c;


--
-- TOC entry 286 (OID 1867193)
-- Name: decrypt_iv(bytea, bytea, bytea, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION decrypt_iv(bytea, bytea, bytea, text) RETURNS bytea
    AS '$libdir/pgcrypto', 'pg_decrypt_iv'
    LANGUAGE c;


--
-- TOC entry 287 (OID 1867194)
-- Name: cipher_exists(text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION cipher_exists(text) RETURNS boolean
    AS '$libdir/pgcrypto', 'pg_cipher_exists'
    LANGUAGE c;


--
-- TOC entry 20 (OID 1867196)
-- Name: pgstattuple_type; Type: TYPE; Schema: public; Owner: postgres
--

CREATE TYPE pgstattuple_type AS (
	table_len bigint,
	tuple_count bigint,
	tuple_len bigint,
	tuple_percent double precision,
	dead_tuple_count bigint,
	dead_tuple_len bigint,
	dead_tuple_percent double precision,
	free_space bigint,
	free_percent double precision
);


--
-- TOC entry 288 (OID 1867197)
-- Name: pgstattuple(text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION pgstattuple(text) RETURNS pgstattuple_type
    AS '$libdir/pgstattuple', 'pgstattuple'
    LANGUAGE c STRICT;


--
-- TOC entry 289 (OID 1867198)
-- Name: pgstattuple(oid); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION pgstattuple(oid) RETURNS pgstattuple_type
    AS '$libdir/pgstattuple', 'pgstattuplebyid'
    LANGUAGE c STRICT;


--
-- TOC entry 290 (OID 1867199)
-- Name: backend_pid(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION backend_pid() RETURNS integer
    AS '$libdir/misc_utils', 'backend_pid'
    LANGUAGE c;


--
-- TOC entry 291 (OID 1867200)
-- Name: unlisten(name); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION "unlisten"(name) RETURNS integer
    AS '$libdir/misc_utils', 'unlisten'
    LANGUAGE c;


--
-- TOC entry 292 (OID 1867201)
-- Name: unlisten(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION "unlisten"() RETURNS integer
    AS 'SELECT "unlisten"(''*'')'
    LANGUAGE sql;


--
-- TOC entry 293 (OID 1867202)
-- Name: min(integer, integer); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION min(integer, integer) RETURNS integer
    AS '$libdir/misc_utils', 'min'
    LANGUAGE c;


--
-- TOC entry 294 (OID 1867203)
-- Name: max(integer, integer); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION max(integer, integer) RETURNS integer
    AS '$libdir/misc_utils', 'max'
    LANGUAGE c;


--
-- TOC entry 295 (OID 1867204)
-- Name: active_listeners(text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION active_listeners(text) RETURNS integer
    AS '$libdir/misc_utils', 'active_listeners'
    LANGUAGE c;


--
-- TOC entry 55 (OID 1867205)
-- Name: pg_ts_dict; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE pg_ts_dict (
    dict_name text NOT NULL,
    dict_init oid,
    dict_initoption text,
    dict_lexize oid NOT NULL,
    dict_comment text
);


--
-- TOC entry 296 (OID 1867212)
-- Name: lexize(oid, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION lexize(oid, text) RETURNS text[]
    AS '$libdir/tsearch2', 'lexize'
    LANGUAGE c STRICT;


--
-- TOC entry 297 (OID 1867213)
-- Name: lexize(text, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION lexize(text, text) RETURNS text[]
    AS '$libdir/tsearch2', 'lexize_byname'
    LANGUAGE c STRICT;


--
-- TOC entry 298 (OID 1867214)
-- Name: lexize(text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION lexize(text) RETURNS text[]
    AS '$libdir/tsearch2', 'lexize_bycurrent'
    LANGUAGE c STRICT;


--
-- TOC entry 299 (OID 1867215)
-- Name: set_curdict(integer); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION set_curdict(integer) RETURNS void
    AS '$libdir/tsearch2', 'set_curdict'
    LANGUAGE c STRICT;


--
-- TOC entry 300 (OID 1867216)
-- Name: set_curdict(text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION set_curdict(text) RETURNS void
    AS '$libdir/tsearch2', 'set_curdict_byname'
    LANGUAGE c STRICT;


--
-- TOC entry 301 (OID 1867217)
-- Name: dex_init(text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION dex_init(text) RETURNS internal
    AS '$libdir/tsearch2', 'dex_init'
    LANGUAGE c;


--
-- TOC entry 302 (OID 1867218)
-- Name: dex_lexize(internal, internal, integer); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION dex_lexize(internal, internal, integer) RETURNS internal
    AS '$libdir/tsearch2', 'dex_lexize'
    LANGUAGE c STRICT;


--
-- TOC entry 303 (OID 1867220)
-- Name: snb_en_init(text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION snb_en_init(text) RETURNS internal
    AS '$libdir/tsearch2', 'snb_en_init'
    LANGUAGE c;


--
-- TOC entry 304 (OID 1867221)
-- Name: snb_lexize(internal, internal, integer); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION snb_lexize(internal, internal, integer) RETURNS internal
    AS '$libdir/tsearch2', 'snb_lexize'
    LANGUAGE c STRICT;


--
-- TOC entry 305 (OID 1867223)
-- Name: snb_ru_init(text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION snb_ru_init(text) RETURNS internal
    AS '$libdir/tsearch2', 'snb_ru_init'
    LANGUAGE c;


--
-- TOC entry 306 (OID 1867225)
-- Name: spell_init(text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION spell_init(text) RETURNS internal
    AS '$libdir/tsearch2', 'spell_init'
    LANGUAGE c;


--
-- TOC entry 307 (OID 1867226)
-- Name: spell_lexize(internal, internal, integer); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION spell_lexize(internal, internal, integer) RETURNS internal
    AS '$libdir/tsearch2', 'spell_lexize'
    LANGUAGE c STRICT;


--
-- TOC entry 308 (OID 1867228)
-- Name: syn_init(text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION syn_init(text) RETURNS internal
    AS '$libdir/tsearch2', 'syn_init'
    LANGUAGE c;


--
-- TOC entry 309 (OID 1867229)
-- Name: syn_lexize(internal, internal, integer); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION syn_lexize(internal, internal, integer) RETURNS internal
    AS '$libdir/tsearch2', 'syn_lexize'
    LANGUAGE c STRICT;


--
-- TOC entry 56 (OID 1867231)
-- Name: pg_ts_parser; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE pg_ts_parser (
    prs_name text NOT NULL,
    prs_start oid NOT NULL,
    prs_nexttoken oid NOT NULL,
    prs_end oid NOT NULL,
    prs_headline oid NOT NULL,
    prs_lextype oid NOT NULL,
    prs_comment text
);


--
-- TOC entry 21 (OID 1867239)
-- Name: tokentype; Type: TYPE; Schema: public; Owner: postgres
--

CREATE TYPE tokentype AS (
	tokid integer,
	alias text,
	descr text
);


--
-- TOC entry 310 (OID 1867240)
-- Name: token_type(integer); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION token_type(integer) RETURNS SETOF tokentype
    AS '$libdir/tsearch2', 'token_type'
    LANGUAGE c STRICT;


--
-- TOC entry 311 (OID 1867241)
-- Name: token_type(text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION token_type(text) RETURNS SETOF tokentype
    AS '$libdir/tsearch2', 'token_type_byname'
    LANGUAGE c STRICT;


--
-- TOC entry 312 (OID 1867242)
-- Name: token_type(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION token_type() RETURNS SETOF tokentype
    AS '$libdir/tsearch2', 'token_type_current'
    LANGUAGE c STRICT;


--
-- TOC entry 313 (OID 1867243)
-- Name: set_curprs(integer); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION set_curprs(integer) RETURNS void
    AS '$libdir/tsearch2', 'set_curprs'
    LANGUAGE c STRICT;


--
-- TOC entry 314 (OID 1867244)
-- Name: set_curprs(text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION set_curprs(text) RETURNS void
    AS '$libdir/tsearch2', 'set_curprs_byname'
    LANGUAGE c STRICT;


--
-- TOC entry 22 (OID 1867246)
-- Name: tokenout; Type: TYPE; Schema: public; Owner: postgres
--

CREATE TYPE tokenout AS (
	tokid integer,
	token text
);


--
-- TOC entry 315 (OID 1867247)
-- Name: parse(oid, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION parse(oid, text) RETURNS SETOF tokenout
    AS '$libdir/tsearch2', 'parse'
    LANGUAGE c STRICT;


--
-- TOC entry 316 (OID 1867248)
-- Name: parse(text, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION parse(text, text) RETURNS SETOF tokenout
    AS '$libdir/tsearch2', 'parse_byname'
    LANGUAGE c STRICT;


--
-- TOC entry 317 (OID 1867249)
-- Name: parse(text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION parse(text) RETURNS SETOF tokenout
    AS '$libdir/tsearch2', 'parse_current'
    LANGUAGE c STRICT;


--
-- TOC entry 318 (OID 1867250)
-- Name: prsd_start(internal, integer); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION prsd_start(internal, integer) RETURNS internal
    AS '$libdir/tsearch2', 'prsd_start'
    LANGUAGE c;


--
-- TOC entry 319 (OID 1867251)
-- Name: prsd_getlexeme(internal, internal, internal); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION prsd_getlexeme(internal, internal, internal) RETURNS integer
    AS '$libdir/tsearch2', 'prsd_getlexeme'
    LANGUAGE c;


--
-- TOC entry 320 (OID 1867252)
-- Name: prsd_end(internal); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION prsd_end(internal) RETURNS void
    AS '$libdir/tsearch2', 'prsd_end'
    LANGUAGE c;


--
-- TOC entry 321 (OID 1867253)
-- Name: prsd_lextype(internal); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION prsd_lextype(internal) RETURNS internal
    AS '$libdir/tsearch2', 'prsd_lextype'
    LANGUAGE c;


--
-- TOC entry 322 (OID 1867254)
-- Name: prsd_headline(internal, internal, internal); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION prsd_headline(internal, internal, internal) RETURNS internal
    AS '$libdir/tsearch2', 'prsd_headline'
    LANGUAGE c;


--
-- TOC entry 57 (OID 1867256)
-- Name: pg_ts_cfg; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE pg_ts_cfg (
    ts_name text NOT NULL,
    prs_name text NOT NULL,
    locale text
);


--
-- TOC entry 58 (OID 1867263)
-- Name: pg_ts_cfgmap; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE pg_ts_cfgmap (
    ts_name text NOT NULL,
    tok_alias text NOT NULL,
    dict_name text[]
);


--
-- TOC entry 323 (OID 1867270)
-- Name: set_curcfg(integer); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION set_curcfg(integer) RETURNS void
    AS '$libdir/tsearch2', 'set_curcfg'
    LANGUAGE c STRICT;


--
-- TOC entry 324 (OID 1867271)
-- Name: set_curcfg(text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION set_curcfg(text) RETURNS void
    AS '$libdir/tsearch2', 'set_curcfg_byname'
    LANGUAGE c STRICT;


--
-- TOC entry 325 (OID 1867272)
-- Name: show_curcfg(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION show_curcfg() RETURNS oid
    AS '$libdir/tsearch2', 'show_curcfg'
    LANGUAGE c STRICT;


--
-- TOC entry 326 (OID 1867334)
-- Name: tsvector_in(cstring); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION tsvector_in(cstring) RETURNS tsvector
    AS '$libdir/tsearch2', 'tsvector_in'
    LANGUAGE c STRICT;


--
-- TOC entry 327 (OID 1867335)
-- Name: tsvector_out(tsvector); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION tsvector_out(tsvector) RETURNS cstring
    AS '$libdir/tsearch2', 'tsvector_out'
    LANGUAGE c STRICT;


--
-- TOC entry 23 (OID 1867333)
-- Name: tsvector; Type: TYPE; Schema: public; Owner: postgres
--

CREATE TYPE tsvector (
    INTERNALLENGTH = variable,
    INPUT = tsvector_in,
    OUTPUT = tsvector_out,
    ALIGNMENT = int4,
    STORAGE = extended
);


--
-- TOC entry 328 (OID 1867337)
-- Name: length(tsvector); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION length(tsvector) RETURNS integer
    AS '$libdir/tsearch2', 'tsvector_length'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 329 (OID 1867338)
-- Name: to_tsvector(oid, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION to_tsvector(oid, text) RETURNS tsvector
    AS '$libdir/tsearch2', 'to_tsvector'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 330 (OID 1867339)
-- Name: to_tsvector(text, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION to_tsvector(text, text) RETURNS tsvector
    AS '$libdir/tsearch2', 'to_tsvector_name'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 331 (OID 1867340)
-- Name: to_tsvector(text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION to_tsvector(text) RETURNS tsvector
    AS '$libdir/tsearch2', 'to_tsvector_current'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 332 (OID 1867341)
-- Name: strip(tsvector); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION strip(tsvector) RETURNS tsvector
    AS '$libdir/tsearch2', 'strip'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 333 (OID 1867342)
-- Name: setweight(tsvector, "char"); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION setweight(tsvector, "char") RETURNS tsvector
    AS '$libdir/tsearch2', 'setweight'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 334 (OID 1867343)
-- Name: concat(tsvector, tsvector); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION concat(tsvector, tsvector) RETURNS tsvector
    AS '$libdir/tsearch2', 'concat'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 474 (OID 1867344)
-- Name: ||; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR || (
    PROCEDURE = concat,
    LEFTARG = tsvector,
    RIGHTARG = tsvector
);


--
-- TOC entry 335 (OID 1867346)
-- Name: tsquery_in(cstring); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION tsquery_in(cstring) RETURNS tsquery
    AS '$libdir/tsearch2', 'tsquery_in'
    LANGUAGE c STRICT;


--
-- TOC entry 336 (OID 1867347)
-- Name: tsquery_out(tsquery); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION tsquery_out(tsquery) RETURNS cstring
    AS '$libdir/tsearch2', 'tsquery_out'
    LANGUAGE c STRICT;


--
-- TOC entry 25 (OID 1867345)
-- Name: tsquery; Type: TYPE; Schema: public; Owner: postgres
--

CREATE TYPE tsquery (
    INTERNALLENGTH = variable,
    INPUT = tsquery_in,
    OUTPUT = tsquery_out,
    ALIGNMENT = int4,
    STORAGE = plain
);


--
-- TOC entry 337 (OID 1867349)
-- Name: querytree(tsquery); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION querytree(tsquery) RETURNS text
    AS '$libdir/tsearch2', 'tsquerytree'
    LANGUAGE c STRICT;


--
-- TOC entry 338 (OID 1867350)
-- Name: to_tsquery(oid, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION to_tsquery(oid, text) RETURNS tsquery
    AS '$libdir/tsearch2', 'to_tsquery'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 339 (OID 1867351)
-- Name: to_tsquery(text, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION to_tsquery(text, text) RETURNS tsquery
    AS '$libdir/tsearch2', 'to_tsquery_name'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 340 (OID 1867352)
-- Name: to_tsquery(text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION to_tsquery(text) RETURNS tsquery
    AS '$libdir/tsearch2', 'to_tsquery_current'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 341 (OID 1867353)
-- Name: exectsq(tsvector, tsquery); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION exectsq(tsvector, tsquery) RETURNS boolean
    AS '$libdir/tsearch2', 'exectsq'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 343 (OID 1867354)
-- Name: rexectsq(tsquery, tsvector); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION rexectsq(tsquery, tsvector) RETURNS boolean
    AS '$libdir/tsearch2', 'rexectsq'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 478 (OID 1867355)
-- Name: @@; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR @@ (
    PROCEDURE = rexectsq,
    LEFTARG = tsquery,
    RIGHTARG = tsvector,
    COMMUTATOR = @@,
    RESTRICT = contsel,
    JOIN = contjoinsel
);


--
-- TOC entry 476 (OID 1867356)
-- Name: @@; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR @@ (
    PROCEDURE = exectsq,
    LEFTARG = tsvector,
    RIGHTARG = tsquery,
    COMMUTATOR = @@,
    RESTRICT = contsel,
    JOIN = contjoinsel
);


--
-- TOC entry 345 (OID 1867357)
-- Name: tsearch2(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION tsearch2() RETURNS "trigger"
    AS '$libdir/tsearch2', 'tsearch2'
    LANGUAGE c;


--
-- TOC entry 346 (OID 1867358)
-- Name: rank(real[], tsvector, tsquery); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION rank(real[], tsvector, tsquery) RETURNS real
    AS '$libdir/tsearch2', 'rank'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 347 (OID 1867359)
-- Name: rank(real[], tsvector, tsquery, integer); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION rank(real[], tsvector, tsquery, integer) RETURNS real
    AS '$libdir/tsearch2', 'rank'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 348 (OID 1867360)
-- Name: rank(tsvector, tsquery); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION rank(tsvector, tsquery) RETURNS real
    AS '$libdir/tsearch2', 'rank_def'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 349 (OID 1867361)
-- Name: rank(tsvector, tsquery, integer); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION rank(tsvector, tsquery, integer) RETURNS real
    AS '$libdir/tsearch2', 'rank_def'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 350 (OID 1867362)
-- Name: rank_cd(integer, tsvector, tsquery); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION rank_cd(integer, tsvector, tsquery) RETURNS real
    AS '$libdir/tsearch2', 'rank_cd'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 351 (OID 1867363)
-- Name: rank_cd(integer, tsvector, tsquery, integer); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION rank_cd(integer, tsvector, tsquery, integer) RETURNS real
    AS '$libdir/tsearch2', 'rank_cd'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 352 (OID 1867364)
-- Name: rank_cd(tsvector, tsquery); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION rank_cd(tsvector, tsquery) RETURNS real
    AS '$libdir/tsearch2', 'rank_cd_def'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 353 (OID 1867365)
-- Name: rank_cd(tsvector, tsquery, integer); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION rank_cd(tsvector, tsquery, integer) RETURNS real
    AS '$libdir/tsearch2', 'rank_cd_def'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 354 (OID 1867366)
-- Name: headline(oid, text, tsquery, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION headline(oid, text, tsquery, text) RETURNS text
    AS '$libdir/tsearch2', 'headline'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 355 (OID 1867367)
-- Name: headline(oid, text, tsquery); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION headline(oid, text, tsquery) RETURNS text
    AS '$libdir/tsearch2', 'headline'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 356 (OID 1867368)
-- Name: headline(text, text, tsquery, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION headline(text, text, tsquery, text) RETURNS text
    AS '$libdir/tsearch2', 'headline_byname'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 357 (OID 1867369)
-- Name: headline(text, text, tsquery); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION headline(text, text, tsquery) RETURNS text
    AS '$libdir/tsearch2', 'headline_byname'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 358 (OID 1867370)
-- Name: headline(text, tsquery, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION headline(text, tsquery, text) RETURNS text
    AS '$libdir/tsearch2', 'headline_current'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 359 (OID 1867371)
-- Name: headline(text, tsquery); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION headline(text, tsquery) RETURNS text
    AS '$libdir/tsearch2', 'headline_current'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 360 (OID 1867373)
-- Name: gtsvector_in(cstring); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION gtsvector_in(cstring) RETURNS gtsvector
    AS '$libdir/tsearch2', 'gtsvector_in'
    LANGUAGE c STRICT;


--
-- TOC entry 361 (OID 1867374)
-- Name: gtsvector_out(gtsvector); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION gtsvector_out(gtsvector) RETURNS cstring
    AS '$libdir/tsearch2', 'gtsvector_out'
    LANGUAGE c STRICT;


--
-- TOC entry 26 (OID 1867372)
-- Name: gtsvector; Type: TYPE; Schema: public; Owner: postgres
--

CREATE TYPE gtsvector (
    INTERNALLENGTH = variable,
    INPUT = gtsvector_in,
    OUTPUT = gtsvector_out,
    ALIGNMENT = int4,
    STORAGE = plain
);


--
-- TOC entry 362 (OID 1867376)
-- Name: gtsvector_consistent(gtsvector, internal, integer); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION gtsvector_consistent(gtsvector, internal, integer) RETURNS boolean
    AS '$libdir/tsearch2', 'gtsvector_consistent'
    LANGUAGE c;


--
-- TOC entry 363 (OID 1867377)
-- Name: gtsvector_compress(internal); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION gtsvector_compress(internal) RETURNS internal
    AS '$libdir/tsearch2', 'gtsvector_compress'
    LANGUAGE c;


--
-- TOC entry 364 (OID 1867378)
-- Name: gtsvector_decompress(internal); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION gtsvector_decompress(internal) RETURNS internal
    AS '$libdir/tsearch2', 'gtsvector_decompress'
    LANGUAGE c;


--
-- TOC entry 365 (OID 1867379)
-- Name: gtsvector_penalty(internal, internal, internal); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION gtsvector_penalty(internal, internal, internal) RETURNS internal
    AS '$libdir/tsearch2', 'gtsvector_penalty'
    LANGUAGE c STRICT;


--
-- TOC entry 366 (OID 1867380)
-- Name: gtsvector_picksplit(internal, internal); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION gtsvector_picksplit(internal, internal) RETURNS internal
    AS '$libdir/tsearch2', 'gtsvector_picksplit'
    LANGUAGE c;


--
-- TOC entry 367 (OID 1867381)
-- Name: gtsvector_union(bytea, internal); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION gtsvector_union(bytea, internal) RETURNS integer[]
    AS '$libdir/tsearch2', 'gtsvector_union'
    LANGUAGE c;


--
-- TOC entry 368 (OID 1867382)
-- Name: gtsvector_same(gtsvector, gtsvector, internal); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION gtsvector_same(gtsvector, gtsvector, internal) RETURNS internal
    AS '$libdir/tsearch2', 'gtsvector_same'
    LANGUAGE c;


--
-- TOC entry 522 (OID 1867383)
-- Name: gist_tsvector_ops; Type: OPERATOR CLASS; Schema: public; Owner: postgres
--

CREATE OPERATOR CLASS gist_tsvector_ops
    DEFAULT FOR TYPE tsvector USING gist AS
    STORAGE gtsvector ,
    OPERATOR 1 @@(tsvector,tsquery) RECHECK ,
    FUNCTION 1 gtsvector_consistent(gtsvector,internal,integer) ,
    FUNCTION 2 gtsvector_union(bytea,internal) ,
    FUNCTION 3 gtsvector_compress(internal) ,
    FUNCTION 4 gtsvector_decompress(internal) ,
    FUNCTION 5 gtsvector_penalty(internal,internal,internal) ,
    FUNCTION 6 gtsvector_picksplit(internal,internal) ,
    FUNCTION 7 gtsvector_same(gtsvector,gtsvector,internal);


--
-- TOC entry 27 (OID 1867385)
-- Name: statinfo; Type: TYPE; Schema: public; Owner: postgres
--

CREATE TYPE statinfo AS (
	word text,
	ndoc integer,
	nentry integer
);


--
-- TOC entry 369 (OID 1867386)
-- Name: stat(text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION stat(text) RETURNS SETOF statinfo
    AS '$libdir/tsearch2', 'ts_stat'
    LANGUAGE c STRICT;


--
-- TOC entry 370 (OID 1867387)
-- Name: reset_tsearch(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION reset_tsearch() RETURNS void
    AS '$libdir/tsearch2', 'reset_tsearch'
    LANGUAGE c STRICT;


--
-- TOC entry 371 (OID 1867388)
-- Name: get_covers(tsvector, tsquery); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION get_covers(tsvector, tsquery) RETURNS text
    AS '$libdir/tsearch2', 'get_covers'
    LANGUAGE c STRICT;


--
-- TOC entry 28 (OID 1867390)
-- Name: tsdebug; Type: TYPE; Schema: public; Owner: postgres
--

CREATE TYPE tsdebug AS (
	ts_name text,
	tok_type text,
	description text,
	token text,
	dict_name text[],
	tsvector tsvector
);


--
-- TOC entry 372 (OID 1867391)
-- Name: _get_parser_from_curcfg(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION _get_parser_from_curcfg() RETURNS text
    AS ' select prs_name from pg_ts_cfg where oid = show_curcfg() '
    LANGUAGE sql IMMUTABLE STRICT;


--
-- TOC entry 373 (OID 1867392)
-- Name: ts_debug(text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION ts_debug(text) RETURNS SETOF tsdebug
    AS '
select 
        m.ts_name,
        t.alias as tok_type,
        t.descr as description,
        p.token,
        m.dict_name,
        strip(to_tsvector(p.token)) as tsvector
from
        parse( _get_parser_from_curcfg(), $1 ) as p,
        token_type() as t,
        pg_ts_cfgmap as m,
        pg_ts_cfg as c
where
        t.tokid=p.tokid and
        t.alias = m.tok_alias and 
        m.ts_name=c.ts_name and 
        c.oid=show_curcfg() 
'
    LANGUAGE sql STRICT;


--
-- TOC entry 374 (OID 1867393)
-- Name: noup(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION noup() RETURNS "trigger"
    AS '$libdir/noup', 'noup'
    LANGUAGE c;


--
-- TOC entry 375 (OID 1867395)
-- Name: chkpass_in(cstring); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION chkpass_in(cstring) RETURNS chkpass
    AS '$libdir/chkpass', 'chkpass_in'
    LANGUAGE c;


--
-- TOC entry 376 (OID 1867396)
-- Name: chkpass_out(chkpass); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION chkpass_out(chkpass) RETURNS cstring
    AS '$libdir/chkpass', 'chkpass_out'
    LANGUAGE c;


--
-- TOC entry 29 (OID 1867394)
-- Name: chkpass; Type: TYPE; Schema: public; Owner: postgres
--

CREATE TYPE chkpass (
    INTERNALLENGTH = 16,
    INPUT = chkpass_in,
    OUTPUT = chkpass_out,
    ALIGNMENT = int4,
    STORAGE = plain
);


--
-- TOC entry 377 (OID 1867398)
-- Name: raw(chkpass); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION raw(chkpass) RETURNS text
    AS '$libdir/chkpass', 'chkpass_rout'
    LANGUAGE c;


--
-- TOC entry 378 (OID 1867399)
-- Name: eq(chkpass, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION eq(chkpass, text) RETURNS boolean
    AS '$libdir/chkpass', 'chkpass_eq'
    LANGUAGE c;


--
-- TOC entry 379 (OID 1867400)
-- Name: ne(chkpass, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION ne(chkpass, text) RETURNS boolean
    AS '$libdir/chkpass', 'chkpass_ne'
    LANGUAGE c;


--
-- TOC entry 482 (OID 1867402)
-- Name: =; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR = (
    PROCEDURE = eq,
    LEFTARG = chkpass,
    RIGHTARG = text,
    COMMUTATOR = =,
    NEGATOR = <>
);


--
-- TOC entry 481 (OID 1867403)
-- Name: <>; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR <> (
    PROCEDURE = ne,
    LEFTARG = chkpass,
    RIGHTARG = text,
    NEGATOR = =
);


--
-- TOC entry 380 (OID 1867405)
-- Name: ltree_in(cstring); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION ltree_in(cstring) RETURNS ltree
    AS '$libdir/ltree', 'ltree_in'
    LANGUAGE c STRICT;


--
-- TOC entry 381 (OID 1867406)
-- Name: ltree_out(ltree); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION ltree_out(ltree) RETURNS cstring
    AS '$libdir/ltree', 'ltree_out'
    LANGUAGE c STRICT;


--
-- TOC entry 31 (OID 1867404)
-- Name: ltree; Type: TYPE; Schema: public; Owner: postgres
--

CREATE TYPE ltree (
    INTERNALLENGTH = variable,
    INPUT = ltree_in,
    OUTPUT = ltree_out,
    ALIGNMENT = int4,
    STORAGE = extended
);


--
-- TOC entry 382 (OID 1867408)
-- Name: ltree_cmp(ltree, ltree); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION ltree_cmp(ltree, ltree) RETURNS integer
    AS '$libdir/ltree', 'ltree_cmp'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 383 (OID 1867409)
-- Name: ltree_lt(ltree, ltree); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION ltree_lt(ltree, ltree) RETURNS boolean
    AS '$libdir/ltree', 'ltree_lt'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 384 (OID 1867410)
-- Name: ltree_le(ltree, ltree); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION ltree_le(ltree, ltree) RETURNS boolean
    AS '$libdir/ltree', 'ltree_le'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 385 (OID 1867411)
-- Name: ltree_eq(ltree, ltree); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION ltree_eq(ltree, ltree) RETURNS boolean
    AS '$libdir/ltree', 'ltree_eq'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 386 (OID 1867412)
-- Name: ltree_ge(ltree, ltree); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION ltree_ge(ltree, ltree) RETURNS boolean
    AS '$libdir/ltree', 'ltree_ge'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 387 (OID 1867413)
-- Name: ltree_gt(ltree, ltree); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION ltree_gt(ltree, ltree) RETURNS boolean
    AS '$libdir/ltree', 'ltree_gt'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 388 (OID 1867414)
-- Name: ltree_ne(ltree, ltree); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION ltree_ne(ltree, ltree) RETURNS boolean
    AS '$libdir/ltree', 'ltree_ne'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 492 (OID 1867415)
-- Name: >; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR > (
    PROCEDURE = ltree_gt,
    LEFTARG = ltree,
    RIGHTARG = ltree,
    COMMUTATOR = <,
    NEGATOR = <=,
    RESTRICT = contsel,
    JOIN = contjoinsel
);


--
-- TOC entry 491 (OID 1867416)
-- Name: >=; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR >= (
    PROCEDURE = ltree_ge,
    LEFTARG = ltree,
    RIGHTARG = ltree,
    COMMUTATOR = <=,
    NEGATOR = <,
    RESTRICT = contsel,
    JOIN = contjoinsel
);


--
-- TOC entry 485 (OID 1867417)
-- Name: <; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR < (
    PROCEDURE = ltree_lt,
    LEFTARG = ltree,
    RIGHTARG = ltree,
    COMMUTATOR = >,
    NEGATOR = >=,
    RESTRICT = contsel,
    JOIN = contjoinsel
);


--
-- TOC entry 488 (OID 1867418)
-- Name: <=; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR <= (
    PROCEDURE = ltree_le,
    LEFTARG = ltree,
    RIGHTARG = ltree,
    COMMUTATOR = >=,
    NEGATOR = >,
    RESTRICT = contsel,
    JOIN = contjoinsel
);


--
-- TOC entry 497 (OID 1867419)
-- Name: <>; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR <> (
    PROCEDURE = ltree_ne,
    LEFTARG = ltree,
    RIGHTARG = ltree,
    COMMUTATOR = <>,
    NEGATOR = =,
    RESTRICT = neqsel,
    JOIN = neqjoinsel
);


--
-- TOC entry 495 (OID 1867420)
-- Name: =; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR = (
    PROCEDURE = ltree_eq,
    LEFTARG = ltree,
    RIGHTARG = ltree,
    COMMUTATOR = =,
    NEGATOR = <>,
    RESTRICT = eqsel,
    JOIN = eqjoinsel,
    SORT1 = <,
    SORT2 = <,
    LTCMP = <,
    GTCMP = >
);


--
-- TOC entry 389 (OID 1867421)
-- Name: subltree(ltree, integer, integer); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION subltree(ltree, integer, integer) RETURNS ltree
    AS '$libdir/ltree', 'subltree'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 390 (OID 1867422)
-- Name: subpath(ltree, integer, integer); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION subpath(ltree, integer, integer) RETURNS ltree
    AS '$libdir/ltree', 'subpath'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 391 (OID 1867423)
-- Name: subpath(ltree, integer); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION subpath(ltree, integer) RETURNS ltree
    AS '$libdir/ltree', 'subpath'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 392 (OID 1867424)
-- Name: index(ltree, ltree); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION "index"(ltree, ltree) RETURNS integer
    AS '$libdir/ltree', 'ltree_index'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 393 (OID 1867425)
-- Name: index(ltree, ltree, integer); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION "index"(ltree, ltree, integer) RETURNS integer
    AS '$libdir/ltree', 'ltree_index'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 394 (OID 1867426)
-- Name: nlevel(ltree); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION nlevel(ltree) RETURNS integer
    AS '$libdir/ltree', 'nlevel'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 395 (OID 1867427)
-- Name: ltree2text(ltree); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION ltree2text(ltree) RETURNS text
    AS '$libdir/ltree', 'ltree2text'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 396 (OID 1867428)
-- Name: text2ltree(text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION text2ltree(text) RETURNS ltree
    AS '$libdir/ltree', 'text2ltree'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 397 (OID 1867429)
-- Name: lca(ltree[]); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION lca(ltree[]) RETURNS ltree
    AS '$libdir/ltree', '_lca'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 398 (OID 1867430)
-- Name: lca(ltree, ltree); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION lca(ltree, ltree) RETURNS ltree
    AS '$libdir/ltree', 'lca'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 399 (OID 1867431)
-- Name: lca(ltree, ltree, ltree); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION lca(ltree, ltree, ltree) RETURNS ltree
    AS '$libdir/ltree', 'lca'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 400 (OID 1867432)
-- Name: lca(ltree, ltree, ltree, ltree); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION lca(ltree, ltree, ltree, ltree) RETURNS ltree
    AS '$libdir/ltree', 'lca'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 401 (OID 1867433)
-- Name: lca(ltree, ltree, ltree, ltree, ltree); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION lca(ltree, ltree, ltree, ltree, ltree) RETURNS ltree
    AS '$libdir/ltree', 'lca'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 402 (OID 1867434)
-- Name: lca(ltree, ltree, ltree, ltree, ltree, ltree); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION lca(ltree, ltree, ltree, ltree, ltree, ltree) RETURNS ltree
    AS '$libdir/ltree', 'lca'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 403 (OID 1867435)
-- Name: lca(ltree, ltree, ltree, ltree, ltree, ltree, ltree); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION lca(ltree, ltree, ltree, ltree, ltree, ltree, ltree) RETURNS ltree
    AS '$libdir/ltree', 'lca'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 404 (OID 1867436)
-- Name: lca(ltree, ltree, ltree, ltree, ltree, ltree, ltree, ltree); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION lca(ltree, ltree, ltree, ltree, ltree, ltree, ltree, ltree) RETURNS ltree
    AS '$libdir/ltree', 'lca'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 405 (OID 1867437)
-- Name: ltree_isparent(ltree, ltree); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION ltree_isparent(ltree, ltree) RETURNS boolean
    AS '$libdir/ltree', 'ltree_isparent'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 406 (OID 1867438)
-- Name: ltree_risparent(ltree, ltree); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION ltree_risparent(ltree, ltree) RETURNS boolean
    AS '$libdir/ltree', 'ltree_risparent'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 407 (OID 1867439)
-- Name: ltree_addltree(ltree, ltree); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION ltree_addltree(ltree, ltree) RETURNS ltree
    AS '$libdir/ltree', 'ltree_addltree'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 408 (OID 1867440)
-- Name: ltree_addtext(ltree, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION ltree_addtext(ltree, text) RETURNS ltree
    AS '$libdir/ltree', 'ltree_addtext'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 409 (OID 1867441)
-- Name: ltree_textadd(text, ltree); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION ltree_textadd(text, ltree) RETURNS ltree
    AS '$libdir/ltree', 'ltree_textadd'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 504 (OID 1867442)
-- Name: <@; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR <@ (
    PROCEDURE = ltree_risparent,
    LEFTARG = ltree,
    RIGHTARG = ltree,
    COMMUTATOR = @>,
    RESTRICT = contsel,
    JOIN = contjoinsel
);


--
-- TOC entry 499 (OID 1867443)
-- Name: @>; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR @> (
    PROCEDURE = ltree_isparent,
    LEFTARG = ltree,
    RIGHTARG = ltree,
    COMMUTATOR = <@,
    RESTRICT = contsel,
    JOIN = contjoinsel
);


--
-- TOC entry 505 (OID 1867444)
-- Name: ^<@; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR ^<@ (
    PROCEDURE = ltree_risparent,
    LEFTARG = ltree,
    RIGHTARG = ltree,
    COMMUTATOR = ^@>,
    RESTRICT = contsel,
    JOIN = contjoinsel
);


--
-- TOC entry 502 (OID 1867445)
-- Name: ^@>; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR ^@> (
    PROCEDURE = ltree_isparent,
    LEFTARG = ltree,
    RIGHTARG = ltree,
    COMMUTATOR = ^<@,
    RESTRICT = contsel,
    JOIN = contjoinsel
);


--
-- TOC entry 506 (OID 1867446)
-- Name: ||; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR || (
    PROCEDURE = ltree_addltree,
    LEFTARG = ltree,
    RIGHTARG = ltree
);


--
-- TOC entry 507 (OID 1867447)
-- Name: ||; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR || (
    PROCEDURE = ltree_addtext,
    LEFTARG = ltree,
    RIGHTARG = text
);


--
-- TOC entry 508 (OID 1867448)
-- Name: ||; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR || (
    PROCEDURE = ltree_textadd,
    LEFTARG = text,
    RIGHTARG = ltree
);


--
-- TOC entry 523 (OID 1867449)
-- Name: ltree_ops; Type: OPERATOR CLASS; Schema: public; Owner: postgres
--

CREATE OPERATOR CLASS ltree_ops
    DEFAULT FOR TYPE ltree USING btree AS
    OPERATOR 1 <(ltree,ltree) ,
    OPERATOR 2 <=(ltree,ltree) ,
    OPERATOR 3 =(ltree,ltree) ,
    OPERATOR 4 >=(ltree,ltree) ,
    OPERATOR 5 >(ltree,ltree) ,
    FUNCTION 1 ltree_cmp(ltree,ltree);


--
-- TOC entry 410 (OID 1867451)
-- Name: lquery_in(cstring); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION lquery_in(cstring) RETURNS lquery
    AS '$libdir/ltree', 'lquery_in'
    LANGUAGE c STRICT;


--
-- TOC entry 411 (OID 1867452)
-- Name: lquery_out(lquery); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION lquery_out(lquery) RETURNS cstring
    AS '$libdir/ltree', 'lquery_out'
    LANGUAGE c STRICT;


--
-- TOC entry 32 (OID 1867450)
-- Name: lquery; Type: TYPE; Schema: public; Owner: postgres
--

CREATE TYPE lquery (
    INTERNALLENGTH = variable,
    INPUT = lquery_in,
    OUTPUT = lquery_out,
    ALIGNMENT = int4,
    STORAGE = extended
);


--
-- TOC entry 412 (OID 1867454)
-- Name: ltq_regex(ltree, lquery); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION ltq_regex(ltree, lquery) RETURNS boolean
    AS '$libdir/ltree', 'ltq_regex'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 413 (OID 1867455)
-- Name: ltq_rregex(lquery, ltree); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION ltq_rregex(lquery, ltree) RETURNS boolean
    AS '$libdir/ltree', 'ltq_rregex'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 512 (OID 1867456)
-- Name: ~; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR ~ (
    PROCEDURE = ltq_rregex,
    LEFTARG = lquery,
    RIGHTARG = ltree,
    COMMUTATOR = ~,
    RESTRICT = contsel,
    JOIN = contjoinsel
);


--
-- TOC entry 510 (OID 1867457)
-- Name: ~; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR ~ (
    PROCEDURE = ltq_regex,
    LEFTARG = ltree,
    RIGHTARG = lquery,
    COMMUTATOR = ~,
    RESTRICT = contsel,
    JOIN = contjoinsel
);


--
-- TOC entry 515 (OID 1867458)
-- Name: ^~; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR ^~ (
    PROCEDURE = ltq_rregex,
    LEFTARG = lquery,
    RIGHTARG = ltree,
    COMMUTATOR = ^~,
    RESTRICT = contsel,
    JOIN = contjoinsel
);


--
-- TOC entry 514 (OID 1867459)
-- Name: ^~; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR ^~ (
    PROCEDURE = ltq_regex,
    LEFTARG = ltree,
    RIGHTARG = lquery,
    COMMUTATOR = ^~,
    RESTRICT = contsel,
    JOIN = contjoinsel
);


--
-- TOC entry 414 (OID 1867460)
-- Name: lt_q_regex(ltree, lquery[]); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION lt_q_regex(ltree, lquery[]) RETURNS boolean
    AS '$libdir/ltree', 'lt_q_regex'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 415 (OID 1867461)
-- Name: lt_q_rregex(lquery[], ltree); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION lt_q_rregex(lquery[], ltree) RETURNS boolean
    AS '$libdir/ltree', 'lt_q_rregex'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 517 (OID 1867462)
-- Name: ?; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR ? (
    PROCEDURE = lt_q_rregex,
    LEFTARG = lquery[],
    RIGHTARG = ltree,
    COMMUTATOR = ?,
    RESTRICT = contsel,
    JOIN = contjoinsel
);


--
-- TOC entry 516 (OID 1867463)
-- Name: ?; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR ? (
    PROCEDURE = lt_q_regex,
    LEFTARG = ltree,
    RIGHTARG = lquery[],
    COMMUTATOR = ?,
    RESTRICT = contsel,
    JOIN = contjoinsel
);


--
-- TOC entry 519 (OID 1867464)
-- Name: ^?; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR ^? (
    PROCEDURE = lt_q_rregex,
    LEFTARG = lquery[],
    RIGHTARG = ltree,
    COMMUTATOR = ^?,
    RESTRICT = contsel,
    JOIN = contjoinsel
);


--
-- TOC entry 518 (OID 1867465)
-- Name: ^?; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR ^? (
    PROCEDURE = lt_q_regex,
    LEFTARG = ltree,
    RIGHTARG = lquery[],
    COMMUTATOR = ^?,
    RESTRICT = contsel,
    JOIN = contjoinsel
);


--
-- TOC entry 416 (OID 1867467)
-- Name: ltxtq_in(cstring); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION ltxtq_in(cstring) RETURNS ltxtquery
    AS '$libdir/ltree', 'ltxtq_in'
    LANGUAGE c STRICT;


--
-- TOC entry 417 (OID 1867468)
-- Name: ltxtq_out(ltxtquery); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION ltxtq_out(ltxtquery) RETURNS cstring
    AS '$libdir/ltree', 'ltxtq_out'
    LANGUAGE c STRICT;


--
-- TOC entry 33 (OID 1867466)
-- Name: ltxtquery; Type: TYPE; Schema: public; Owner: postgres
--

CREATE TYPE ltxtquery (
    INTERNALLENGTH = variable,
    INPUT = ltxtq_in,
    OUTPUT = ltxtq_out,
    ALIGNMENT = int4,
    STORAGE = extended
);


--
-- TOC entry 418 (OID 1867470)
-- Name: ltxtq_exec(ltree, ltxtquery); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION ltxtq_exec(ltree, ltxtquery) RETURNS boolean
    AS '$libdir/ltree', 'ltxtq_exec'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 419 (OID 1867471)
-- Name: ltxtq_rexec(ltxtquery, ltree); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION ltxtq_rexec(ltxtquery, ltree) RETURNS boolean
    AS '$libdir/ltree', 'ltxtq_rexec'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 455 (OID 1867472)
-- Name: @; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR @ (
    PROCEDURE = ltxtq_rexec,
    LEFTARG = ltxtquery,
    RIGHTARG = ltree,
    COMMUTATOR = @,
    RESTRICT = contsel,
    JOIN = contjoinsel
);


--
-- TOC entry 454 (OID 1867473)
-- Name: @; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR @ (
    PROCEDURE = ltxtq_exec,
    LEFTARG = ltree,
    RIGHTARG = ltxtquery,
    COMMUTATOR = @,
    RESTRICT = contsel,
    JOIN = contjoinsel
);


--
-- TOC entry 457 (OID 1867474)
-- Name: ^@; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR ^@ (
    PROCEDURE = ltxtq_rexec,
    LEFTARG = ltxtquery,
    RIGHTARG = ltree,
    COMMUTATOR = ^@,
    RESTRICT = contsel,
    JOIN = contjoinsel
);


--
-- TOC entry 456 (OID 1867475)
-- Name: ^@; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR ^@ (
    PROCEDURE = ltxtq_exec,
    LEFTARG = ltree,
    RIGHTARG = ltxtquery,
    COMMUTATOR = ^@,
    RESTRICT = contsel,
    JOIN = contjoinsel
);


--
-- TOC entry 420 (OID 1867477)
-- Name: ltree_gist_in(cstring); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION ltree_gist_in(cstring) RETURNS ltree_gist
    AS '$libdir/ltree', 'ltree_gist_in'
    LANGUAGE c STRICT;


--
-- TOC entry 421 (OID 1867478)
-- Name: ltree_gist_out(ltree_gist); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION ltree_gist_out(ltree_gist) RETURNS cstring
    AS '$libdir/ltree', 'ltree_gist_out'
    LANGUAGE c STRICT;


--
-- TOC entry 34 (OID 1867476)
-- Name: ltree_gist; Type: TYPE; Schema: public; Owner: postgres
--

CREATE TYPE ltree_gist (
    INTERNALLENGTH = variable,
    INPUT = ltree_gist_in,
    OUTPUT = ltree_gist_out,
    ALIGNMENT = int4,
    STORAGE = plain
);


--
-- TOC entry 422 (OID 1867480)
-- Name: ltree_consistent(internal, internal, smallint); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION ltree_consistent(internal, internal, smallint) RETURNS boolean
    AS '$libdir/ltree', 'ltree_consistent'
    LANGUAGE c;


--
-- TOC entry 423 (OID 1867481)
-- Name: ltree_compress(internal); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION ltree_compress(internal) RETURNS internal
    AS '$libdir/ltree', 'ltree_compress'
    LANGUAGE c;


--
-- TOC entry 424 (OID 1867482)
-- Name: ltree_decompress(internal); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION ltree_decompress(internal) RETURNS internal
    AS '$libdir/ltree', 'ltree_decompress'
    LANGUAGE c;


--
-- TOC entry 425 (OID 1867483)
-- Name: ltree_penalty(internal, internal, internal); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION ltree_penalty(internal, internal, internal) RETURNS internal
    AS '$libdir/ltree', 'ltree_penalty'
    LANGUAGE c STRICT;


--
-- TOC entry 426 (OID 1867484)
-- Name: ltree_picksplit(internal, internal); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION ltree_picksplit(internal, internal) RETURNS internal
    AS '$libdir/ltree', 'ltree_picksplit'
    LANGUAGE c;


--
-- TOC entry 427 (OID 1867485)
-- Name: ltree_union(bytea, internal); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION ltree_union(bytea, internal) RETURNS integer
    AS '$libdir/ltree', 'ltree_union'
    LANGUAGE c;


--
-- TOC entry 428 (OID 1867486)
-- Name: ltree_same(internal, internal, internal); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION ltree_same(internal, internal, internal) RETURNS internal
    AS '$libdir/ltree', 'ltree_same'
    LANGUAGE c;


--
-- TOC entry 524 (OID 1867487)
-- Name: gist_ltree_ops; Type: OPERATOR CLASS; Schema: public; Owner: postgres
--

CREATE OPERATOR CLASS gist_ltree_ops
    DEFAULT FOR TYPE ltree USING gist AS
    STORAGE ltree_gist ,
    OPERATOR 1 <(ltree,ltree) ,
    OPERATOR 2 <=(ltree,ltree) ,
    OPERATOR 3 =(ltree,ltree) ,
    OPERATOR 4 >=(ltree,ltree) ,
    OPERATOR 5 >(ltree,ltree) ,
    OPERATOR 10 @>(ltree,ltree) ,
    OPERATOR 11 <@(ltree,ltree) ,
    OPERATOR 12 ~(ltree,lquery) ,
    OPERATOR 13 ~(lquery,ltree) ,
    OPERATOR 14 @(ltree,ltxtquery) ,
    OPERATOR 15 @(ltxtquery,ltree) ,
    OPERATOR 16 ?(ltree,lquery[]) ,
    OPERATOR 17 ?(lquery[],ltree) ,
    FUNCTION 1 ltree_consistent(internal,internal,smallint) ,
    FUNCTION 2 ltree_union(bytea,internal) ,
    FUNCTION 3 ltree_compress(internal) ,
    FUNCTION 4 ltree_decompress(internal) ,
    FUNCTION 5 ltree_penalty(internal,internal,internal) ,
    FUNCTION 6 ltree_picksplit(internal,internal) ,
    FUNCTION 7 ltree_same(internal,internal,internal);


--
-- TOC entry 429 (OID 1867488)
-- Name: _ltree_isparent(ltree[], ltree); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION _ltree_isparent(ltree[], ltree) RETURNS boolean
    AS '$libdir/ltree', '_ltree_isparent'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 430 (OID 1867489)
-- Name: _ltree_r_isparent(ltree, ltree[]); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION _ltree_r_isparent(ltree, ltree[]) RETURNS boolean
    AS '$libdir/ltree', '_ltree_r_isparent'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 431 (OID 1867490)
-- Name: _ltree_risparent(ltree[], ltree); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION _ltree_risparent(ltree[], ltree) RETURNS boolean
    AS '$libdir/ltree', '_ltree_risparent'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 432 (OID 1867491)
-- Name: _ltree_r_risparent(ltree, ltree[]); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION _ltree_r_risparent(ltree, ltree[]) RETURNS boolean
    AS '$libdir/ltree', '_ltree_r_risparent'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 433 (OID 1867492)
-- Name: _ltq_regex(ltree[], lquery); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION _ltq_regex(ltree[], lquery) RETURNS boolean
    AS '$libdir/ltree', '_ltq_regex'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 434 (OID 1867493)
-- Name: _ltq_rregex(lquery, ltree[]); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION _ltq_rregex(lquery, ltree[]) RETURNS boolean
    AS '$libdir/ltree', '_ltq_rregex'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 435 (OID 1867494)
-- Name: _lt_q_regex(ltree[], lquery[]); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION _lt_q_regex(ltree[], lquery[]) RETURNS boolean
    AS '$libdir/ltree', '_lt_q_regex'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 436 (OID 1867495)
-- Name: _lt_q_rregex(lquery[], ltree[]); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION _lt_q_rregex(lquery[], ltree[]) RETURNS boolean
    AS '$libdir/ltree', '_lt_q_rregex'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 437 (OID 1867496)
-- Name: _ltxtq_exec(ltree[], ltxtquery); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION _ltxtq_exec(ltree[], ltxtquery) RETURNS boolean
    AS '$libdir/ltree', '_ltxtq_exec'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 438 (OID 1867497)
-- Name: _ltxtq_rexec(ltxtquery, ltree[]); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION _ltxtq_rexec(ltxtquery, ltree[]) RETURNS boolean
    AS '$libdir/ltree', '_ltxtq_rexec'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 465 (OID 1867498)
-- Name: <@; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR <@ (
    PROCEDURE = _ltree_r_isparent,
    LEFTARG = ltree,
    RIGHTARG = ltree[],
    COMMUTATOR = @>,
    RESTRICT = contsel,
    JOIN = contjoinsel
);


--
-- TOC entry 464 (OID 1867499)
-- Name: @>; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR @> (
    PROCEDURE = _ltree_isparent,
    LEFTARG = ltree[],
    RIGHTARG = ltree,
    COMMUTATOR = <@,
    RESTRICT = contsel,
    JOIN = contjoinsel
);


--
-- TOC entry 467 (OID 1867500)
-- Name: @>; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR @> (
    PROCEDURE = _ltree_r_risparent,
    LEFTARG = ltree,
    RIGHTARG = ltree[],
    COMMUTATOR = <@,
    RESTRICT = contsel,
    JOIN = contjoinsel
);


--
-- TOC entry 466 (OID 1867501)
-- Name: <@; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR <@ (
    PROCEDURE = _ltree_risparent,
    LEFTARG = ltree[],
    RIGHTARG = ltree,
    COMMUTATOR = @>,
    RESTRICT = contsel,
    JOIN = contjoinsel
);


--
-- TOC entry 477 (OID 1867502)
-- Name: ~; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR ~ (
    PROCEDURE = _ltq_rregex,
    LEFTARG = lquery,
    RIGHTARG = ltree[],
    COMMUTATOR = ~,
    RESTRICT = contsel,
    JOIN = contjoinsel
);


--
-- TOC entry 475 (OID 1867503)
-- Name: ~; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR ~ (
    PROCEDURE = _ltq_regex,
    LEFTARG = ltree[],
    RIGHTARG = lquery,
    COMMUTATOR = ~,
    RESTRICT = contsel,
    JOIN = contjoinsel
);


--
-- TOC entry 480 (OID 1867504)
-- Name: ?; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR ? (
    PROCEDURE = _lt_q_rregex,
    LEFTARG = lquery[],
    RIGHTARG = ltree[],
    COMMUTATOR = ?,
    RESTRICT = contsel,
    JOIN = contjoinsel
);


--
-- TOC entry 479 (OID 1867505)
-- Name: ?; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR ? (
    PROCEDURE = _lt_q_regex,
    LEFTARG = ltree[],
    RIGHTARG = lquery[],
    COMMUTATOR = ?,
    RESTRICT = contsel,
    JOIN = contjoinsel
);


--
-- TOC entry 484 (OID 1867506)
-- Name: @; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR @ (
    PROCEDURE = _ltxtq_rexec,
    LEFTARG = ltxtquery,
    RIGHTARG = ltree[],
    COMMUTATOR = @,
    RESTRICT = contsel,
    JOIN = contjoinsel
);


--
-- TOC entry 483 (OID 1867507)
-- Name: @; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR @ (
    PROCEDURE = _ltxtq_exec,
    LEFTARG = ltree[],
    RIGHTARG = ltxtquery,
    COMMUTATOR = @,
    RESTRICT = contsel,
    JOIN = contjoinsel
);


--
-- TOC entry 487 (OID 1867508)
-- Name: ^<@; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR ^<@ (
    PROCEDURE = _ltree_r_isparent,
    LEFTARG = ltree,
    RIGHTARG = ltree[],
    COMMUTATOR = ^@>,
    RESTRICT = contsel,
    JOIN = contjoinsel
);


--
-- TOC entry 486 (OID 1867509)
-- Name: ^@>; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR ^@> (
    PROCEDURE = _ltree_isparent,
    LEFTARG = ltree[],
    RIGHTARG = ltree,
    COMMUTATOR = ^<@,
    RESTRICT = contsel,
    JOIN = contjoinsel
);


--
-- TOC entry 490 (OID 1867510)
-- Name: ^@>; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR ^@> (
    PROCEDURE = _ltree_r_risparent,
    LEFTARG = ltree,
    RIGHTARG = ltree[],
    COMMUTATOR = ^<@,
    RESTRICT = contsel,
    JOIN = contjoinsel
);


--
-- TOC entry 489 (OID 1867511)
-- Name: ^<@; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR ^<@ (
    PROCEDURE = _ltree_risparent,
    LEFTARG = ltree[],
    RIGHTARG = ltree,
    COMMUTATOR = ^@>,
    RESTRICT = contsel,
    JOIN = contjoinsel
);


--
-- TOC entry 494 (OID 1867512)
-- Name: ^~; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR ^~ (
    PROCEDURE = _ltq_rregex,
    LEFTARG = lquery,
    RIGHTARG = ltree[],
    COMMUTATOR = ^~,
    RESTRICT = contsel,
    JOIN = contjoinsel
);


--
-- TOC entry 493 (OID 1867513)
-- Name: ^~; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR ^~ (
    PROCEDURE = _ltq_regex,
    LEFTARG = ltree[],
    RIGHTARG = lquery,
    COMMUTATOR = ^~,
    RESTRICT = contsel,
    JOIN = contjoinsel
);


--
-- TOC entry 498 (OID 1867514)
-- Name: ^?; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR ^? (
    PROCEDURE = _lt_q_rregex,
    LEFTARG = lquery[],
    RIGHTARG = ltree[],
    COMMUTATOR = ^?,
    RESTRICT = contsel,
    JOIN = contjoinsel
);


--
-- TOC entry 496 (OID 1867515)
-- Name: ^?; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR ^? (
    PROCEDURE = _lt_q_regex,
    LEFTARG = ltree[],
    RIGHTARG = lquery[],
    COMMUTATOR = ^?,
    RESTRICT = contsel,
    JOIN = contjoinsel
);


--
-- TOC entry 501 (OID 1867516)
-- Name: ^@; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR ^@ (
    PROCEDURE = _ltxtq_rexec,
    LEFTARG = ltxtquery,
    RIGHTARG = ltree[],
    COMMUTATOR = ^@,
    RESTRICT = contsel,
    JOIN = contjoinsel
);


--
-- TOC entry 500 (OID 1867517)
-- Name: ^@; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR ^@ (
    PROCEDURE = _ltxtq_exec,
    LEFTARG = ltree[],
    RIGHTARG = ltxtquery,
    COMMUTATOR = ^@,
    RESTRICT = contsel,
    JOIN = contjoinsel
);


--
-- TOC entry 439 (OID 1867518)
-- Name: _ltree_extract_isparent(ltree[], ltree); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION _ltree_extract_isparent(ltree[], ltree) RETURNS ltree
    AS '$libdir/ltree', '_ltree_extract_isparent'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 503 (OID 1867519)
-- Name: ?@>; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR ?@> (
    PROCEDURE = _ltree_extract_isparent,
    LEFTARG = ltree[],
    RIGHTARG = ltree
);


--
-- TOC entry 440 (OID 1867520)
-- Name: _ltree_extract_risparent(ltree[], ltree); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION _ltree_extract_risparent(ltree[], ltree) RETURNS ltree
    AS '$libdir/ltree', '_ltree_extract_risparent'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 509 (OID 1867521)
-- Name: ?<@; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR ?<@ (
    PROCEDURE = _ltree_extract_risparent,
    LEFTARG = ltree[],
    RIGHTARG = ltree
);


--
-- TOC entry 441 (OID 1867522)
-- Name: _ltq_extract_regex(ltree[], lquery); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION _ltq_extract_regex(ltree[], lquery) RETURNS ltree
    AS '$libdir/ltree', '_ltq_extract_regex'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 511 (OID 1867523)
-- Name: ?~; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR ?~ (
    PROCEDURE = _ltq_extract_regex,
    LEFTARG = ltree[],
    RIGHTARG = lquery
);


--
-- TOC entry 442 (OID 1867524)
-- Name: _ltxtq_extract_exec(ltree[], ltxtquery); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION _ltxtq_extract_exec(ltree[], ltxtquery) RETURNS ltree
    AS '$libdir/ltree', '_ltxtq_extract_exec'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 513 (OID 1867525)
-- Name: ?@; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR ?@ (
    PROCEDURE = _ltxtq_extract_exec,
    LEFTARG = ltree[],
    RIGHTARG = ltxtquery
);


--
-- TOC entry 443 (OID 1867526)
-- Name: _ltree_consistent(internal, internal, smallint); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION _ltree_consistent(internal, internal, smallint) RETURNS boolean
    AS '$libdir/ltree', '_ltree_consistent'
    LANGUAGE c;


--
-- TOC entry 444 (OID 1867527)
-- Name: _ltree_compress(internal); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION _ltree_compress(internal) RETURNS internal
    AS '$libdir/ltree', '_ltree_compress'
    LANGUAGE c;


--
-- TOC entry 445 (OID 1867528)
-- Name: _ltree_penalty(internal, internal, internal); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION _ltree_penalty(internal, internal, internal) RETURNS internal
    AS '$libdir/ltree', '_ltree_penalty'
    LANGUAGE c STRICT;


--
-- TOC entry 446 (OID 1867529)
-- Name: _ltree_picksplit(internal, internal); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION _ltree_picksplit(internal, internal) RETURNS internal
    AS '$libdir/ltree', '_ltree_picksplit'
    LANGUAGE c;


--
-- TOC entry 447 (OID 1867530)
-- Name: _ltree_union(bytea, internal); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION _ltree_union(bytea, internal) RETURNS integer
    AS '$libdir/ltree', '_ltree_union'
    LANGUAGE c;


--
-- TOC entry 448 (OID 1867531)
-- Name: _ltree_same(internal, internal, internal); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION _ltree_same(internal, internal, internal) RETURNS internal
    AS '$libdir/ltree', '_ltree_same'
    LANGUAGE c;


--
-- TOC entry 525 (OID 1867532)
-- Name: gist__ltree_ops; Type: OPERATOR CLASS; Schema: public; Owner: postgres
--

CREATE OPERATOR CLASS gist__ltree_ops
    DEFAULT FOR TYPE ltree[] USING gist AS
    STORAGE ltree_gist ,
    OPERATOR 10 <@(ltree[],ltree) RECHECK ,
    OPERATOR 11 @>(ltree,ltree[]) RECHECK ,
    OPERATOR 12 ~(ltree[],lquery) RECHECK ,
    OPERATOR 13 ~(lquery,ltree[]) RECHECK ,
    OPERATOR 14 @(ltree[],ltxtquery) RECHECK ,
    OPERATOR 15 @(ltxtquery,ltree[]) RECHECK ,
    OPERATOR 16 ?(ltree[],lquery[]) RECHECK ,
    OPERATOR 17 ?(lquery[],ltree[]) RECHECK ,
    FUNCTION 1 _ltree_consistent(internal,internal,smallint) ,
    FUNCTION 2 _ltree_union(bytea,internal) ,
    FUNCTION 3 _ltree_compress(internal) ,
    FUNCTION 4 ltree_decompress(internal) ,
    FUNCTION 5 _ltree_penalty(internal,internal,internal) ,
    FUNCTION 6 _ltree_picksplit(internal,internal) ,
    FUNCTION 7 _ltree_same(internal,internal,internal);


--
-- TOC entry 59 (OID 1867535)
-- Name: dual; Type: VIEW; Schema: public; Owner: postgres
--

CREATE VIEW dual AS
    SELECT 1 AS dummy, now() AS sysdate;


--
-- TOC entry 61 (OID 1867535)
-- Name: dual; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE dual FROM PUBLIC;
GRANT SELECT ON TABLE dual TO guest;
GRANT SELECT ON TABLE dual TO PUBLIC;


--
-- TOC entry 62 (OID 1868573)
-- Name: whoami; Type: VIEW; Schema: public; Owner: postgres
--

CREATE VIEW whoami AS
    SELECT "current_user"() AS "current_user", current_schema() AS current_schema, current_schemas(true) AS current_schemas;


--
-- TOC entry 63 (OID 1868573)
-- Name: whoami; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE whoami FROM PUBLIC;
GRANT SELECT ON TABLE whoami TO guest;
GRANT SELECT ON TABLE whoami TO PUBLIC;


--
-- TOC entry 8 (OID 1912342)
-- Name: color; Type: DOMAIN; Schema: public; Owner: postgres
--

CREATE DOMAIN color AS name
	CONSTRAINT enum_values CHECK (((((VALUE = 'red'::name) OR (VALUE = 'blue'::name)) OR (VALUE = 'green'::name)) OR (VALUE = 'white'::name)));


--
-- TOC entry 9 (OID 1912360)
-- Name: shell; Type: DOMAIN; Schema: public; Owner: postgres
--

CREATE DOMAIN shell AS name;


--
-- TOC entry 37 (OID 1923125)
-- Name: textarea; Type: DOMAIN; Schema: public; Owner: postgres
--

CREATE DOMAIN textarea AS text;


--
-- TOC entry 40 (OID 1925012)
-- Name: id_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE id_seq
    INCREMENT BY 1
    NO MAXVALUE
    NO MINVALUE
    CACHE 1;


--
-- TOC entry 41 (OID 1925012)
-- Name: id_seq; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE id_seq FROM PUBLIC;
GRANT SELECT ON TABLE id_seq TO PUBLIC;
GRANT SELECT,UPDATE ON TABLE id_seq TO GROUP mime;


--
-- TOC entry 450 (OID 1925682)
-- Name: links_constuct(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION links_constuct() RETURNS "trigger"
    AS 'BEGIN 
 IF NEW.title IS NULL THEN
   NEW.title := wdbi.lwp_get_title(NEW.url);
 END IF;

 RETURN NEW; 
END; 
'
    LANGUAGE plpgsql;


--
-- TOC entry 35 (OID 1926025)
-- Name: color_model; Type: DOMAIN; Schema: public; Owner: postgres
--

CREATE DOMAIN color_model AS name
	CONSTRAINT enum_check CHECK (((((((VALUE = 'hsv'::name) OR (VALUE = 'lab'::name)) OR (VALUE = 'luv'::name)) OR (VALUE = 'cmyk'::name)) OR (VALUE = 'rgb'::name)) OR (VALUE = 'lab'::name)));


--
-- TOC entry 64 (OID 2029039)
-- Name: zip2; Type: VIEW; Schema: public; Owner: postgres
--

CREATE VIEW zip2 AS
    SELECT zip.zip, zip.city FROM zip;


SET SESSION AUTHORIZATION 'oddb';

--
-- TOC entry 36 (OID 2037699)
-- Name: url; Type: DOMAIN; Schema: public; Owner: oddb
--

CREATE DOMAIN url AS text;


SET SESSION AUTHORIZATION 'guest';

--
-- TOC entry 65 (OID 2047361)
-- Name: test; Type: TABLE; Schema: public; Owner: guest
--

CREATE TABLE test (
    a integer,
    b integer
);


--
-- TOC entry 66 (OID 2047363)
-- Name: test1; Type: TABLE; Schema: public; Owner: guest
--

CREATE TABLE test1 (
    c integer,
    d test
);


SET SESSION AUTHORIZATION 'postgres';

--
-- TOC entry 67 (OID 2051518)
-- Name: globs; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE globs (
    pattern text NOT NULL,
    "type" name NOT NULL,
    registry text
);


--
-- TOC entry 68 (OID 2051518)
-- Name: globs; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE globs FROM PUBLIC;
GRANT ALL ON TABLE globs TO GROUP mime;


--
-- TOC entry 69 (OID 2054573)
-- Name: globs_corrected; Type: VIEW; Schema: public; Owner: postgres
--

CREATE VIEW globs_corrected AS
    SELECT DISTINCT g.pattern, COALESCE(m.aliasfor, g."type") AS "type" FROM (globs g JOIN mime m ON ((m."type" = (g."type")::text))) ORDER BY g.pattern, COALESCE(m.aliasfor, g."type");


--
-- TOC entry 70 (OID 2054573)
-- Name: globs_corrected; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE globs_corrected FROM PUBLIC;
GRANT SELECT ON TABLE globs_corrected TO GROUP mime;


--
-- TOC entry 71 (OID 2054576)
-- Name: globs_problematic; Type: VIEW; Schema: public; Owner: postgres
--

CREATE VIEW globs_problematic AS
    SELECT globs.pattern, globs."type" FROM globs WHERE (globs.pattern IN (SELECT globs_corrected.pattern FROM globs_corrected GROUP BY globs_corrected.pattern HAVING (count(*) > 1))) ORDER BY globs.pattern;


--
-- TOC entry 72 (OID 2054576)
-- Name: globs_problematic; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE globs_problematic FROM PUBLIC;
GRANT SELECT ON TABLE globs_problematic TO GROUP mime;


--
-- TOC entry 451 (OID 2054610)
-- Name: mime_touch(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION mime_touch() RETURNS "trigger"
    AS 'DECLARE
 aliasfor1 mime.aliasfor%TYPE;
 tmp text;
BEGIN 
 IF NEW.aliasfor IS NOT NULL THEN

   IF NEW.type = NEW.aliasfor THEN
     RAISE EXCEPTION 
       ''Cannot define an alias to self (%)'',NEW.aliasfor;
   END IF;

   SELECT INTO aliasfor1 aliasfor 
          FROM mime m WHERE m.type = NEW.aliasfor;
   IF aliasfor1 IS NOT NULL THEN
     tmp := ''Type '' || quote_literal(NEW.aliasfor) || 
            '' is already an alias for '' || quote_literal(aliasfor1) || ''.'' ||
            '' Perhaps you want to use '' || quote_literal(aliasfor1) || '' as value.'';
     RAISE EXCEPTION 
       ''Aliases can only be defined for types, which are not aliases themselves. %'',tmp;
   END IF;

 END IF;

 RETURN NEW; 
END; 
'
    LANGUAGE plpgsql;


--
-- TOC entry 73 (OID 2054618)
-- Name: mime_globs_count; Type: VIEW; Schema: public; Owner: postgres
--

CREATE VIEW mime_globs_count AS
    SELECT m."type", count(*) AS count FROM (mime m LEFT JOIN globs_corrected g ON ((m."type" = (g."type")::text))) GROUP BY m."type" ORDER BY m."type";


--
-- TOC entry 74 (OID 2054618)
-- Name: mime_globs_count; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE mime_globs_count FROM PUBLIC;
GRANT SELECT ON TABLE mime_globs_count TO GROUP mime;


--
-- TOC entry 75 (OID 2054634)
-- Name: apps; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE apps (
    fname name DEFAULT ('_'::text || (nextval('id_seq'::text))::text) NOT NULL,
    terminal boolean,
    name text,
    exec text,
    registry name,
    available boolean,
    genericname text
);


--
-- TOC entry 77 (OID 2054634)
-- Name: apps; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE apps FROM PUBLIC;
GRANT ALL ON TABLE apps TO GROUP mime;


--
-- TOC entry 452 (OID 2057225)
-- Name: apps_touch(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION apps_touch() RETURNS "trigger"
    AS 'DECLARE
 tmp text;
BEGIN 
   IF NEW.fname IS NULL THEN
     NEW.fname := ''#''||nextval(''id_seq'');
   END IF;

 RETURN NEW; 
END; 
'
    LANGUAGE plpgsql;


--
-- TOC entry 78 (OID 2061960)
-- Name: app_input; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE app_input (
    app name NOT NULL,
    mime name NOT NULL,
    registry text
);


--
-- TOC entry 79 (OID 2061960)
-- Name: app_input; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE app_input FROM PUBLIC;
GRANT ALL ON TABLE app_input TO GROUP mime;


--
-- TOC entry 453 (OID 2062793)
-- Name: mime_corrected(name); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION mime_corrected(name) RETURNS name
    AS 'SELECT coalesce(aliasfor,type) FROM mime WHERE type = $1'
    LANGUAGE sql;


--
-- TOC entry 80 (OID 2062795)
-- Name: app_categories; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE app_categories (
    app name NOT NULL,
    category name NOT NULL
);


--
-- TOC entry 81 (OID 2062795)
-- Name: app_categories; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE app_categories FROM PUBLIC;
GRANT ALL ON TABLE app_categories TO GROUP mime;


--
-- TOC entry 84 (OID 173239)
-- Name: links_url_idx; Type: INDEX; Schema: public; Owner: postgres
--

CREATE UNIQUE INDEX links_url_idx ON links USING btree (url);


--
-- TOC entry 86 (OID 173274)
-- Name: zip_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY zip
    ADD CONSTRAINT zip_pkey PRIMARY KEY (zip);

ALTER TABLE zip CLUSTER ON zip_pkey;


--
-- TOC entry 83 (OID 173374)
-- Name: links_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY links
    ADD CONSTRAINT links_pkey PRIMARY KEY (id);


--
-- TOC entry 87 (OID 173432)
-- Name: mime_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY mime
    ADD CONSTRAINT mime_pkey PRIMARY KEY ("type");

ALTER TABLE mime CLUSTER ON mime_pkey;


--
-- TOC entry 88 (OID 184714)
-- Name: turba_objects_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY turba_objects
    ADD CONSTRAINT turba_objects_pkey PRIMARY KEY (object_id);


--
-- TOC entry 89 (OID 1867210)
-- Name: pg_ts_dict_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY pg_ts_dict
    ADD CONSTRAINT pg_ts_dict_pkey PRIMARY KEY (dict_name);


--
-- TOC entry 90 (OID 1867236)
-- Name: pg_ts_parser_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY pg_ts_parser
    ADD CONSTRAINT pg_ts_parser_pkey PRIMARY KEY (prs_name);


--
-- TOC entry 91 (OID 1867261)
-- Name: pg_ts_cfg_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY pg_ts_cfg
    ADD CONSTRAINT pg_ts_cfg_pkey PRIMARY KEY (ts_name);


--
-- TOC entry 92 (OID 1867268)
-- Name: pg_ts_cfgmap_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY pg_ts_cfgmap
    ADD CONSTRAINT pg_ts_cfgmap_pkey PRIMARY KEY (ts_name, tok_alias);


--
-- TOC entry 85 (OID 1925518)
-- Name: links_url_key; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY links
    ADD CONSTRAINT links_url_key UNIQUE (url);


--
-- TOC entry 82 (OID 1925520)
-- Name: links_name_key; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY links
    ADD CONSTRAINT links_name_key UNIQUE (name);


--
-- TOC entry 93 (OID 2051527)
-- Name: globs_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY globs
    ADD CONSTRAINT globs_pkey PRIMARY KEY (pattern, "type");

ALTER TABLE globs CLUSTER ON globs_pkey;


--
-- TOC entry 94 (OID 2054694)
-- Name: apps_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY apps
    ADD CONSTRAINT apps_pkey PRIMARY KEY (fname);

ALTER TABLE apps CLUSTER ON apps_pkey;


--
-- TOC entry 95 (OID 2061970)
-- Name: app_input_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY app_input
    ADD CONSTRAINT app_input_pkey PRIMARY KEY (app, mime);


--
-- TOC entry 96 (OID 2062801)
-- Name: app_categories_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY app_categories
    ADD CONSTRAINT app_categories_pkey PRIMARY KEY (app, category);


--
-- TOC entry 526 (OID 2051509)
-- Name: $1; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY mime
    ADD CONSTRAINT "$1" FOREIGN KEY (aliasfor) REFERENCES mime("type");


--
-- TOC entry 527 (OID 2054562)
-- Name: $1; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY globs
    ADD CONSTRAINT "$1" FOREIGN KEY ("type") REFERENCES mime("type") ON UPDATE CASCADE ON DELETE CASCADE;


--
-- TOC entry 529 (OID 2061962)
-- Name: $1; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY app_input
    ADD CONSTRAINT "$1" FOREIGN KEY (app) REFERENCES apps(fname);


--
-- TOC entry 528 (OID 2061966)
-- Name: $2; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY app_input
    ADD CONSTRAINT "$2" FOREIGN KEY (mime) REFERENCES mime("type");


--
-- TOC entry 530 (OID 2062797)
-- Name: $1; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY app_categories
    ADD CONSTRAINT "$1" FOREIGN KEY (app) REFERENCES apps(fname);


--
-- TOC entry 531 (OID 1925683)
-- Name: WDBI_before_insert; Type: TRIGGER; Schema: public; Owner: postgres
--

CREATE TRIGGER "WDBI_before_insert"
    BEFORE INSERT ON links
    FOR EACH ROW
    EXECUTE PROCEDURE links_constuct();


--
-- TOC entry 532 (OID 2054612)
-- Name: 0010_mime_touch; Type: TRIGGER; Schema: public; Owner: postgres
--

CREATE TRIGGER "0010_mime_touch"
    BEFORE INSERT OR UPDATE ON mime
    FOR EACH ROW
    EXECUTE PROCEDURE mime_touch();


--
-- TOC entry 533 (OID 2057226)
-- Name: 0010_apps_touch; Type: TRIGGER; Schema: public; Owner: postgres
--

CREATE TRIGGER "0010_apps_touch"
    BEFORE INSERT OR UPDATE ON apps
    FOR EACH ROW
    EXECUTE PROCEDURE apps_touch();


--
-- TOC entry 534 (OID 2029040)
-- Name: synonym_insert_rule; Type: RULE; Schema: public; Owner: postgres
--

CREATE RULE synonym_insert_rule AS ON INSERT TO zip2 DO INSTEAD INSERT INTO zip (city, zip) VALUES (new.city, new.zip);


--
-- TOC entry 535 (OID 2029041)
-- Name: synonym_update_rule; Type: RULE; Schema: public; Owner: postgres
--

CREATE RULE synonym_update_rule AS ON UPDATE TO zip2 DO INSTEAD UPDATE zip SET city = new.city, zip = new.zip WHERE (zip.zip = old.zip);


--
-- TOC entry 536 (OID 2029042)
-- Name: synonym_delete_rule; Type: RULE; Schema: public; Owner: postgres
--

CREATE RULE synonym_delete_rule AS ON DELETE TO zip2 DO INSTEAD DELETE FROM zip WHERE (zip.zip = old.zip);


--
-- TOC entry 3 (OID 2200)
-- Name: SCHEMA public; Type: COMMENT; Schema: -; Owner: postgres
--

COMMENT ON SCHEMA public IS 'Standard public schema';


--
-- TOC entry 6 (OID 165765)
-- Name: DOMAIN euro; Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON DOMAIN euro IS 'European dollar EUR';


--
-- TOC entry 103 (OID 165766)
-- Name: FUNCTION firstword(text); Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON FUNCTION firstword(text) IS 'Return first subword';


--
-- TOC entry 105 (OID 165767)
-- Name: FUNCTION makename(text); Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON FUNCTION makename(text) IS 'Convert to a name';


--
-- TOC entry 111 (OID 165772)
-- Name: FUNCTION path_indent(text, text); Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON FUNCTION path_indent(text, text) IS 'Count the occurences of second string in first';


--
-- TOC entry 113 (OID 165773)
-- Name: FUNCTION path_indent(text); Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON FUNCTION path_indent(text) IS 'Prepend path with nbspaces, no label';


--
-- TOC entry 116 (OID 165775)
-- Name: FUNCTION count_substrings(text, text); Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON FUNCTION count_substrings(text, text) IS 'Count the occurences of second string in first';


--
-- TOC entry 120 (OID 165778)
-- Name: FUNCTION str_repeat(text, integer); Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON FUNCTION str_repeat(text, integer) IS 'repeat a string';


--
-- TOC entry 123 (OID 165780)
-- Name: FUNCTION run_add(text, text); Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON FUNCTION run_add(text, text) IS 'This function adds $1 to global perl var $kiki::run[$1] and returns result. For running totals and such.';


--
-- TOC entry 127 (OID 165783)
-- Name: FUNCTION kiki_stamp(); Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON FUNCTION kiki_stamp() IS 'Before insert/update trigger on nodes';


--
-- TOC entry 129 (OID 165784)
-- Name: FUNCTION kiki_stamp_children(); Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON FUNCTION kiki_stamp_children() IS 'After update trigger children of node';


--
-- TOC entry 131 (OID 165785)
-- Name: FUNCTION kiki_insert(text, text); Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON FUNCTION kiki_insert(text, text) IS 'Insert a new node';


--
-- TOC entry 133 (OID 165786)
-- Name: FUNCTION sitemap_insert(text, text); Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON FUNCTION sitemap_insert(text, text) IS 'Insert a new node';


--
-- TOC entry 135 (OID 165787)
-- Name: FUNCTION kiki_ordung(); Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON FUNCTION kiki_ordung() IS 'After insert trigger on nodes';


--
-- TOC entry 137 (OID 165788)
-- Name: FUNCTION log_trigger(); Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON FUNCTION log_trigger() IS 'Trigger function used for logging';


--
-- TOC entry 140 (OID 165790)
-- Name: FUNCTION kiki_subclass(text, text); Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON FUNCTION kiki_subclass(text, text) IS 'Subclass a table';


--
-- TOC entry 142 (OID 165791)
-- Name: FUNCTION kiki_add_triggers(text); Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON FUNCTION kiki_add_triggers(text) IS 'Create necessary triggers on specified kiki table';


--
-- TOC entry 43 (OID 165917)
-- Name: TABLE links; Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON TABLE links IS 'Web Links';


--
-- TOC entry 46 (OID 165940)
-- Name: TABLE zip; Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON TABLE zip IS 'Postal codes';


--
-- TOC entry 144 (OID 166041)
-- Name: FUNCTION wdbi_atom(text); Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON FUNCTION wdbi_atom(text) IS 'find or create atom in table wdbi_atoms';


--
-- TOC entry 148 (OID 166099)
-- Name: FUNCTION sec_to_time(text); Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON FUNCTION sec_to_time(text) IS 'Format time (mysql)';


--
-- TOC entry 49 (OID 167301)
-- Name: TABLE mime; Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON TABLE mime IS 'MIME types';


--
-- TOC entry 14 (OID 173676)
-- Name: DOMAIN xml; Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON DOMAIN xml IS 'Syntactically correct XML';


--
-- TOC entry 12 (OID 1867128)
-- Name: TYPE issn; Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON TYPE issn IS 'International Standard Serial Number';


--
-- TOC entry 16 (OID 1867146)
-- Name: TYPE isbn; Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON TYPE isbn IS 'International Standard Book Number';


--
-- TOC entry 24 (OID 1867333)
-- Name: TYPE tsvector; Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON TYPE tsvector IS 'Tsearch2 word vector';


--
-- TOC entry 342 (OID 1867353)
-- Name: FUNCTION exectsq(tsvector, tsquery); Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON FUNCTION exectsq(tsvector, tsquery) IS 'boolean operation with text index';


--
-- TOC entry 344 (OID 1867354)
-- Name: FUNCTION rexectsq(tsquery, tsvector); Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON FUNCTION rexectsq(tsquery, tsvector) IS 'boolean operation with text index';


--
-- TOC entry 30 (OID 1867394)
-- Name: TYPE chkpass; Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON TYPE chkpass IS 'password type with checks';


--
-- TOC entry 60 (OID 1867533)
-- Name: VIEW dual; Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON VIEW dual IS 'Oracle like dual';


--
-- TOC entry 10 (OID 1912360)
-- Name: DOMAIN shell; Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON DOMAIN shell IS 'UNIX shell executable';


--
-- TOC entry 38 (OID 1923125)
-- Name: DOMAIN textarea; Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON DOMAIN textarea IS 'Text area';


--
-- TOC entry 76 (OID 2054634)
-- Name: TABLE apps; Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON TABLE apps IS 'Desktop applications';


