--
-- PostgreSQL database dump
--

SET client_encoding = 'UNICODE';
SET check_function_bodies = false;

SET SESSION AUTHORIZATION 'postgres';

SET search_path = public, pg_catalog;

--
-- TOC entry 133 (OID 17142)
-- Name: plpgsql_call_handler(); Type: FUNC PROCEDURAL LANGUAGE; Schema: public; Owner: postgres
--

CREATE FUNCTION plpgsql_call_handler() RETURNS language_handler
    AS '$libdir/plpgsql', 'plpgsql_call_handler'
    LANGUAGE c;


--
-- TOC entry 134 (OID 17144)
-- Name: plperl_call_handler(); Type: FUNC PROCEDURAL LANGUAGE; Schema: public; Owner: postgres
--

CREATE FUNCTION plperl_call_handler() RETURNS language_handler
    AS '$libdir/plperl', 'plperl_call_handler'
    LANGUAGE c;


SET SESSION AUTHORIZATION DEFAULT;

--
-- TOC entry 130 (OID 17143)
-- Name: plpgsql; Type: PROCEDURAL LANGUAGE; Schema: public; Owner: 
--

CREATE TRUSTED PROCEDURAL LANGUAGE plpgsql HANDLER plpgsql_call_handler;


--
-- TOC entry 131 (OID 17145)
-- Name: plperl; Type: PROCEDURAL LANGUAGE; Schema: public; Owner: 
--

CREATE TRUSTED PROCEDURAL LANGUAGE plperl HANDLER plperl_call_handler;


--
-- TOC entry 132 (OID 17146)
-- Name: plperlu; Type: PROCEDURAL LANGUAGE; Schema: public; Owner: 
--

CREATE PROCEDURAL LANGUAGE plperlu HANDLER plperl_call_handler;


SET SESSION AUTHORIZATION 'postgres';

--
-- TOC entry 4 (OID 2200)
-- Name: public; Type: ACL; Schema: -; Owner: postgres
--

REVOKE ALL ON SCHEMA public FROM PUBLIC;
GRANT ALL ON SCHEMA public TO PUBLIC;


--
-- TOC entry 5 (OID 165765)
-- Name: euro; Type: DOMAIN; Schema: public; Owner: postgres
--

CREATE DOMAIN euro AS numeric;


--
-- TOC entry 135 (OID 165766)
-- Name: firstword(text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION firstword(text) RETURNS text
    AS 'my $text=shift;
$text=~ s/\\s+.*//;
return $text;
'
    LANGUAGE plperl IMMUTABLE STRICT;


--
-- TOC entry 137 (OID 165767)
-- Name: makename(text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION makename(text) RETURNS name
    AS 'my $text=shift;
$text=~ y/A-Za-z0-9/_/c;
return lc($text);
'
    LANGUAGE plperl;


--
-- TOC entry 139 (OID 165768)
-- Name: trunc(timestamp with time zone, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION trunc(timestamp with time zone, text) RETURNS timestamp with time zone
    AS 'my ($ts,$option)=@_;
my $res;
if($ts=~/(\\d\\d\\d\\d)-(\\d\\d)-(\\d\\d)/) {
	if(lc($option) eq "mm") { $res="$1-$2-01"; }
	else { $res="$1-$2-$3"; }
}
return $res;
'
    LANGUAGE plperl;


--
-- TOC entry 140 (OID 165769)
-- Name: trunc(timestamp with time zone); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION trunc(timestamp with time zone) RETURNS timestamp with time zone
    AS 'SELECT trunc($1,''d'') as result'
    LANGUAGE sql;


--
-- TOC entry 141 (OID 165770)
-- Name: ptrue(text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION ptrue(text) RETURNS boolean
    AS 'return($_[0]?"y":"n");'
    LANGUAGE plperl;


--
-- TOC entry 142 (OID 165771)
-- Name: pfalse(text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION pfalse(text) RETURNS boolean
    AS 'return($_[0]?"n":"y");'
    LANGUAGE plperl;


--
-- TOC entry 143 (OID 165772)
-- Name: path_indent(text, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION path_indent(text, text) RETURNS text
    AS 'my ($path,$label)=@_;
my $sep="&nbsp;";

$path=~s|/[^/]*|$sep|g;

return $path.$label;
'
    LANGUAGE plperl;


--
-- TOC entry 145 (OID 165773)
-- Name: path_indent(text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION path_indent(text) RETURNS text
    AS 'my ($path)=@_;
my $sep="&nbsp;"x2;

$path=~s|/[^/]*|$sep|g;

return $path;
'
    LANGUAGE plperl;


--
-- TOC entry 147 (OID 165774)
-- Name: kiki_path_a(text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION kiki_path_a(text) RETURNS text
    AS 'my ($path)=@_;
my $depth=($path=~y|/|/|);
my @pathi=split("/",$path); 
shift @pathi; $depth--;
my @path; my $i;

for $i (0..$#pathi) {
  push @path,
           qq{<a href="}.("../"x($depth-$i-1)).qq{">$pathi[$i]</a>};
};
  
return join(" / ",@path);
'
    LANGUAGE plperl IMMUTABLE STRICT;


--
-- TOC entry 148 (OID 165775)
-- Name: count_substrings(text, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION count_substrings(text, text) RETURNS text
    AS 'my ($str1,$str2)=@_;

my $r=s/$str1/$str2/g;

return "[$r]";
'
    LANGUAGE plperl;


--
-- TOC entry 150 (OID 165776)
-- Name: path_to_depth(text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION path_to_depth(text) RETURNS integer
    AS 'my ($path)=@_;

my $n=($path=~y|/|/|);

$n=($n>1)?($n-2):$n;

return $n;
'
    LANGUAGE plperl;


--
-- TOC entry 151 (OID 165777)
-- Name: if(boolean, text, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION if(boolean, text, text) RETURNS text
    AS 'my ($if1,$then2,$else3)=@_;

if($if1 eq "f") { $if1=0; }
return $if1?$then2:$else3;
'
    LANGUAGE plperl;


--
-- TOC entry 152 (OID 165778)
-- Name: str_repeat(text, integer); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION str_repeat(text, integer) RETURNS text
    AS '
return $_[0]x$_[1];
'
    LANGUAGE plperl;


--
-- TOC entry 154 (OID 165779)
-- Name: preg_replace(text, text, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION preg_replace(text, text, text) RETURNS text
    AS '
  my ($from,$to,$str)=@_;
  $str=~s/$from/$to/g;
  return $str;
'
    LANGUAGE plperl;


--
-- TOC entry 155 (OID 165780)
-- Name: run_add(text, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION run_add(text, text) RETURNS text
    AS '
$kiki::run[$_[0]]+=$_[1];
return $kiki::run[$_[0]];
'
    LANGUAGE plperl;


--
-- TOC entry 157 (OID 165781)
-- Name: run_reset(text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION run_reset(text) RETURNS text
    AS 'SELECT run_add( $1,-run_add( $1,0)::float)'
    LANGUAGE sql;


--
-- TOC entry 158 (OID 165782)
-- Name: kiki_find_node(text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION kiki_find_node(text) RETURNS integer
    AS '
DECLARE
  id1 integer;
  path1 ALIAS for $1;
BEGIN
  SELECT INTO id1
    id
  FROM nodes
  WHERE path=path1;

  RETURN id1;
END;

'
    LANGUAGE plpgsql;


--
-- TOC entry 159 (OID 165783)
-- Name: kiki_stamp(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION kiki_stamp() RETURNS "trigger"
    AS 'DECLARE
  parent nodes%ROWTYPE;

BEGIN 

IF NEW.id = 0 OR NEW.id = 1
THEN
 RETURN NEW;
END IF;

NEW.name := coalesce(nul(NEW.name),makename(NEW.title));

IF NEW.name ISNULL 
THEN RAISE EXCEPTION ''name cannot be NULL value''; 
END IF; 

IF NEW.pid ISNULL 
THEN RAISE EXCEPTION ''cannot have NULL parent''; 
END IF; 

SELECT INTO parent 
 *
FROM nodes
WHERE id=NEW.pid;

NEW.title := coalesce(NEW.title,ucfirst(NEW.name));
NEW.path := parent.path || NEW.name || ''/'';
NEW.depth := path_to_depth(NEW.path);
NEW.idpath := parent.idpath || '','' || NEW.id;
NEW.depth := path_to_depth(NEW.path);
NEW.ordungspath := parent.ordungspath || to_char(parent.ordung,''FM9990999'');
NEW.mtime := ''now''; 
NEW.label := coalesce(NEW.label,ucfirst(NEW.name));
RETURN NEW; 
END; 

'
    LANGUAGE plpgsql;


--
-- TOC entry 161 (OID 165784)
-- Name: kiki_stamp_children(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION kiki_stamp_children() RETURNS "trigger"
    AS 'BEGIN 

IF NEW.id = 0 OR NEW.id=1
THEN
 RETURN NEW;
END IF;

IF OLD.pid != NEW.pid OR OLD.name != NEW.name
THEN
UPDATE nodes SET id=id WHERE pid=NEW.id;
END IF;

RETURN NEW; 
END; 

'
    LANGUAGE plpgsql;


--
-- TOC entry 163 (OID 165785)
-- Name: kiki_insert(text, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION kiki_insert(text, text) RETURNS text
    AS '
DECLARE
  parent_path ALIAS FOR $1;
  new_name ALIAS FOR $2;

BEGIN 

INSERT INTO nodes
 (pid,name)
SELECT
 id,new_name
FROM nodes
WHERE path=parent_path;

RETURN parent_path || new_name;

END; 

'
    LANGUAGE plpgsql;


--
-- TOC entry 165 (OID 165786)
-- Name: sitemap_insert(text, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION sitemap_insert(text, text) RETURNS text
    AS '
DECLARE
  parent_path ALIAS FOR $1;
  new_name ALIAS FOR $2;

BEGIN 

INSERT INTO sitemap
 (pid,name)
SELECT
 id,new_name
FROM nodes
WHERE path=parent_path;

RETURN parent_path || new_name;

END; 

'
    LANGUAGE plpgsql;


--
-- TOC entry 167 (OID 165787)
-- Name: kiki_ordung(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION kiki_ordung() RETURNS opaque
    AS 'DECLARE
  newordung integer;

BEGIN 

SELECT 
 coalesce(max(ordung),0) + 100
INTO newordung
FROM nodes
WHERE pid=NEW.pid;

UPDATE nodes
SET
 ordung=newordung
WHERE
 id=NEW.id;

RETURN NEW;
END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 169 (OID 165788)
-- Name: log_trigger(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION log_trigger() RETURNS "trigger"
    AS '
DECLARE
  tab0 text;
  tab1 text;

BEGIN
  tab0 := wdbi.sql_full_path(TG_RELID);
  tab1 :=tab0 || ''_log'';

EXECUTE ''
INSERT INTO '' || tab1 || ''
SELECT now(), * FROM '' || tab0 || ''
WHERE oid='' || OLD.oid || ''
'';

IF TG_OP = ''DELETE'' THEN
  RETURN OLD;
ELSE
  RETURN NEW;
END IF;

END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 171 (OID 165789)
-- Name: lookup_create(text, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION lookup_create(text, text) RETURNS text
    AS '
DECLARE
  tab0 ALIAS FOR $1;
  tab1 ALIAS FOR $2;
BEGIN
EXECUTE ''
CREATE TABLE "'' || tab1 || ''" (
        "id" integer DEFAULT nextval(''''wdbi_seq'''') PRIMARY KEY,
        "text" text,
        "ordung" real,
        "cat" integer
);

CREATE TABLE "'' || tab0 || ''_'' || tab1 || ''_l" (
        "'' || tab0 ||''_id" integer,
        "'' || tab1 ||''_id" integer
)
'';
RETURN ''lookup_create'';
END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 172 (OID 165790)
-- Name: kiki_subclass(text, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION kiki_subclass(text, text) RETURNS text
    AS '
DECLARE
  tab0 ALIAS FOR $1;
  tab1 ALIAS FOR $2;
BEGIN
EXECUTE ''
CREATE TABLE "'' || tab1 || ''" (
) INHERITS('' || tab0 || '');
''; 
RETURN kiki_add_triggers(tab1);
END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 174 (OID 165791)
-- Name: kiki_add_triggers(text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION kiki_add_triggers(text) RETURNS text
    AS '
DECLARE
  tab ALIAS FOR $1;
BEGIN
EXECUTE ''
CREATE TRIGGER "'' || tab || ''_insert" 
BEFORE INSERT ON "'' || tab || ''"  
FOR EACH ROW 
EXECUTE PROCEDURE "kiki_stamp" ();

CREATE TRIGGER "'' || tab || ''_update" 
BEFORE UPDATE ON "'' || tab || ''"  
FOR EACH ROW 
EXECUTE PROCEDURE "kiki_stamp" ();

CREATE TRIGGER "'' || tab || ''_update_children" 
AFTER UPDATE ON "'' || tab || ''"  
FOR EACH ROW 
EXECUTE PROCEDURE "kiki_stamp_children" ();
'';
RETURN ''Kiki triggers created on table '' || tab;
END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 46 (OID 165917)
-- Name: links; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE links (
    id integer DEFAULT nextval('id_seq'::text),
    url text,
    uptime integer,
    downtime integer
)
INHERITS (ljudmila.items);


--
-- TOC entry 48 (OID 165917)
-- Name: links; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE links FROM PUBLIC;
GRANT SELECT ON TABLE links TO PUBLIC;


--
-- TOC entry 49 (OID 165940)
-- Name: zip; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE zip (
    zip integer NOT NULL,
    city text
);


--
-- TOC entry 51 (OID 165940)
-- Name: zip; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE zip FROM PUBLIC;
GRANT SELECT ON TABLE zip TO PUBLIC;
GRANT ALL ON TABLE zip TO GROUP ljudmila;


--
-- TOC entry 41 (OID 166024)
-- Name: users_id_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE users_id_seq
    INCREMENT BY 1
    NO MAXVALUE
    NO MINVALUE
    CACHE 1;


--
-- TOC entry 176 (OID 166041)
-- Name: wdbi_atom(text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION wdbi_atom(text) RETURNS integer
    AS '
DECLARE
  id1 integer;
  name1 ALIAS for $1;
BEGIN
  SELECT INTO id1
    id
  FROM wdbi_atoms
  WHERE name=name1;

  IF NOT FOUND THEN
	id1 := NEXTVAL(''wdbi_atoms_id_seq'');
	INSERT INTO wdbi_atoms (id,name) VALUES (id1,name1);
  END IF;

  RETURN id1;
END;

'
    LANGUAGE plpgsql;


--
-- TOC entry 178 (OID 166097)
-- Name: trunc(timestamp without time zone, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION trunc(timestamp without time zone, text) RETURNS timestamp without time zone
    AS 'my ($ts,$option)=@_;
my $res;
if($ts=~/(\\d\\d\\d\\d)-(\\d\\d)-(\\d\\d)/) {
	if(lc($option) eq "mm") { $res="$1-$2-01"; }
	else { $res="$1-$2-$3"; }
}
return $res;
'
    LANGUAGE plperl;


--
-- TOC entry 179 (OID 166098)
-- Name: trunc(timestamp without time zone); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION trunc(timestamp without time zone) RETURNS timestamp without time zone
    AS 'SELECT trunc($1,''d'') as result'
    LANGUAGE sql;


--
-- TOC entry 180 (OID 166099)
-- Name: sec_to_time(text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION sec_to_time(text) RETURNS text
    AS '
$sec=$_[0];
if(!defined($sec)) { return undef; }
$dd=int($sec/(60*60*24));
$sec-=$dd*60*60*24;
$hh=int($sec/(60*60));
$sec-=$hh*60*60;
$mi=int($sec/60);
$sec-=$mi*60;

return sprintf("%d %2d:%02d:%02d",$dd,$hh,$mi,$sec);
return $kiki::run[$_[0]];
'
    LANGUAGE plperl IMMUTABLE;


--
-- TOC entry 182 (OID 166100)
-- Name: char(integer); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION "char"(integer) RETURNS text
    AS '
    SELECT chr($1);
'
    LANGUAGE sql;


--
-- TOC entry 183 (OID 166101)
-- Name: insert(text, integer, integer, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION "insert"(text, integer, integer, text) RETURNS text
    AS '
    SELECT substring($1 from 1 for $2 - 1) || $4 || substring($1 from $2 + $3);
'
    LANGUAGE sql;


--
-- TOC entry 184 (OID 166102)
-- Name: left(text, integer); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION "left"(text, integer) RETURNS text
    AS '
    SELECT substring($1 for $2);
'
    LANGUAGE sql;


--
-- TOC entry 185 (OID 166103)
-- Name: locate(text, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION locate(text, text) RETURNS integer
    AS '
    SELECT position($1 in $2);
'
    LANGUAGE sql;


--
-- TOC entry 186 (OID 166104)
-- Name: locate(text, text, integer); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION locate(text, text, integer) RETURNS integer
    AS '
    SELECT position($1 in substring($2 from $3)) + $3 - 1;
'
    LANGUAGE sql;


--
-- TOC entry 187 (OID 166105)
-- Name: right(text, integer); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION "right"(text, integer) RETURNS text
    AS '
    SELECT substring($1 from char_length($1) - $2 + 1);
'
    LANGUAGE sql;


--
-- TOC entry 188 (OID 166106)
-- Name: space(integer); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION space(integer) RETURNS text
    AS '
    SELECT repeat('' '', $1);
'
    LANGUAGE sql;


--
-- TOC entry 189 (OID 166107)
-- Name: ceiling(numeric); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION ceiling(numeric) RETURNS numeric
    AS '
    SELECT ceil($1);
'
    LANGUAGE sql;


--
-- TOC entry 190 (OID 166108)
-- Name: log10(double precision); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION log10(double precision) RETURNS double precision
    AS '
    SELECT log($1);
'
    LANGUAGE sql;


--
-- TOC entry 191 (OID 166109)
-- Name: log10(numeric); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION log10(numeric) RETURNS numeric
    AS '
    SELECT log($1);
'
    LANGUAGE sql;


--
-- TOC entry 192 (OID 166110)
-- Name: power(double precision, double precision); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION power(double precision, double precision) RETURNS double precision
    AS '
    SELECT pow($1, $2);
'
    LANGUAGE sql;


--
-- TOC entry 193 (OID 166111)
-- Name: power(numeric, numeric); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION power(numeric, numeric) RETURNS numeric
    AS '
    SELECT pow($1, $2);
'
    LANGUAGE sql;


--
-- TOC entry 194 (OID 166112)
-- Name: rand(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION rand() RETURNS double precision
    AS '
    SELECT random();
'
    LANGUAGE sql;


--
-- TOC entry 195 (OID 166113)
-- Name: rand(double precision); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION rand(double precision) RETURNS double precision
    AS '
    SELECT setseed($1);
    SELECT random();
'
    LANGUAGE sql;


--
-- TOC entry 196 (OID 166114)
-- Name: truncate(numeric, integer); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION "truncate"(numeric, integer) RETURNS numeric
    AS '
    SELECT trunc($1, $2);
'
    LANGUAGE sql;


--
-- TOC entry 197 (OID 166115)
-- Name: curdate(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION curdate() RETURNS date
    AS 'SELECT current_date;
'
    LANGUAGE sql;


--
-- TOC entry 198 (OID 166116)
-- Name: curtime(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION curtime() RETURNS time with time zone
    AS '
    SELECT current_time;
'
    LANGUAGE sql;


--
-- TOC entry 199 (OID 166117)
-- Name: odbc_timestamp(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION odbc_timestamp() RETURNS timestamp with time zone
    AS '
    SELECT current_timestamp;
'
    LANGUAGE sql;


--
-- TOC entry 200 (OID 166118)
-- Name: dayname(timestamp without time zone); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION dayname(timestamp without time zone) RETURNS text
    AS '
    SELECT to_char($1,''Day'');
'
    LANGUAGE sql;


--
-- TOC entry 201 (OID 166119)
-- Name: dayofmonth(timestamp without time zone); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION dayofmonth(timestamp without time zone) RETURNS integer
    AS '
    SELECT CAST(EXTRACT(day FROM $1) AS integer);
'
    LANGUAGE sql;


--
-- TOC entry 202 (OID 166120)
-- Name: dayofweek(timestamp without time zone); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION dayofweek(timestamp without time zone) RETURNS integer
    AS '
    SELECT CAST(EXTRACT(dow FROM $1) AS integer) + 1;
'
    LANGUAGE sql;


--
-- TOC entry 203 (OID 166121)
-- Name: dayofyear(timestamp without time zone); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION dayofyear(timestamp without time zone) RETURNS integer
    AS '    SELECT CAST(EXTRACT(day FROM $1) AS integer);
'
    LANGUAGE sql;


--
-- TOC entry 204 (OID 166122)
-- Name: hour(timestamp without time zone); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION "hour"(timestamp without time zone) RETURNS integer
    AS '
    SELECT CAST(EXTRACT(hour FROM $1) AS integer);
'
    LANGUAGE sql;


--
-- TOC entry 205 (OID 166123)
-- Name: minute(timestamp without time zone); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION "minute"(timestamp without time zone) RETURNS integer
    AS '
    SELECT CAST(EXTRACT(minute FROM $1) AS integer);
'
    LANGUAGE sql;


--
-- TOC entry 206 (OID 166124)
-- Name: month(timestamp without time zone); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION "month"(timestamp without time zone) RETURNS integer
    AS '
    SELECT CAST(EXTRACT(month FROM $1) AS integer);
'
    LANGUAGE sql;


--
-- TOC entry 207 (OID 166125)
-- Name: monthname(timestamp without time zone); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION monthname(timestamp without time zone) RETURNS text
    AS '
    SELECT to_char($1, ''Month'');
'
    LANGUAGE sql;


--
-- TOC entry 208 (OID 166126)
-- Name: quarter(timestamp without time zone); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION quarter(timestamp without time zone) RETURNS integer
    AS '
    SELECT CAST(EXTRACT(quarter FROM $1) AS integer);
'
    LANGUAGE sql;


--
-- TOC entry 209 (OID 166127)
-- Name: second(timestamp without time zone); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION "second"(timestamp without time zone) RETURNS integer
    AS '
    SELECT CAST(EXTRACT(second FROM $1) AS integer);
'
    LANGUAGE sql;


--
-- TOC entry 210 (OID 166128)
-- Name: week(timestamp without time zone); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION week(timestamp without time zone) RETURNS integer
    AS '
    SELECT CAST(EXTRACT(week FROM $1) AS integer);
'
    LANGUAGE sql;


--
-- TOC entry 211 (OID 166129)
-- Name: year(timestamp without time zone); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION "year"(timestamp without time zone) RETURNS integer
    AS '
    SELECT CAST(EXTRACT(year FROM $1) AS integer);
'
    LANGUAGE sql;


--
-- TOC entry 212 (OID 166130)
-- Name: odbc_user(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION odbc_user() RETURNS text
    AS '
    SELECT CAST(current_user AS TEXT);
'
    LANGUAGE sql;


--
-- TOC entry 213 (OID 166131)
-- Name: odbc_current_user(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION odbc_current_user() RETURNS text
    AS '
    SELECT CAST(current_user AS TEXT);
'
    LANGUAGE sql;


--
-- TOC entry 214 (OID 166132)
-- Name: odbc_session_user(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION odbc_session_user() RETURNS text
    AS '
    SELECT CAST(session_user AS TEXT);
'
    LANGUAGE sql;


--
-- TOC entry 215 (OID 166136)
-- Name: dblink_connect(text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION dblink_connect(text) RETURNS text
    AS '$libdir/dblink', 'dblink_connect'
    LANGUAGE c STRICT;


--
-- TOC entry 216 (OID 166137)
-- Name: dblink_disconnect(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION dblink_disconnect() RETURNS text
    AS '$libdir/dblink', 'dblink_disconnect'
    LANGUAGE c STRICT;


--
-- TOC entry 217 (OID 166138)
-- Name: dblink_open(text, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION dblink_open(text, text) RETURNS text
    AS '$libdir/dblink', 'dblink_open'
    LANGUAGE c STRICT;


--
-- TOC entry 218 (OID 166139)
-- Name: dblink_fetch(text, integer); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION dblink_fetch(text, integer) RETURNS SETOF record
    AS '$libdir/dblink', 'dblink_fetch'
    LANGUAGE c STRICT;


--
-- TOC entry 219 (OID 166140)
-- Name: dblink_close(text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION dblink_close(text) RETURNS text
    AS '$libdir/dblink', 'dblink_close'
    LANGUAGE c STRICT;


--
-- TOC entry 220 (OID 166141)
-- Name: dblink(text, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION dblink(text, text) RETURNS SETOF record
    AS '$libdir/dblink', 'dblink_record'
    LANGUAGE c STRICT;


--
-- TOC entry 221 (OID 166142)
-- Name: dblink(text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION dblink(text) RETURNS SETOF record
    AS '$libdir/dblink', 'dblink_record'
    LANGUAGE c STRICT;


--
-- TOC entry 222 (OID 166143)
-- Name: dblink_exec(text, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION dblink_exec(text, text) RETURNS text
    AS '$libdir/dblink', 'dblink_exec'
    LANGUAGE c STRICT;


--
-- TOC entry 223 (OID 166144)
-- Name: dblink_exec(text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION dblink_exec(text) RETURNS text
    AS '$libdir/dblink', 'dblink_exec'
    LANGUAGE c STRICT;


--
-- TOC entry 7 (OID 166146)
-- Name: dblink_pkey_results; Type: TYPE; Schema: public; Owner: postgres
--

CREATE TYPE dblink_pkey_results AS (
	"position" integer,
	colname text
);


--
-- TOC entry 224 (OID 166147)
-- Name: dblink_get_pkey(text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION dblink_get_pkey(text) RETURNS SETOF dblink_pkey_results
    AS '$libdir/dblink', 'dblink_get_pkey'
    LANGUAGE c STRICT;


--
-- TOC entry 225 (OID 166148)
-- Name: dblink_build_sql_insert(text, int2vector, integer, text[], text[]); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION dblink_build_sql_insert(text, int2vector, integer, text[], text[]) RETURNS text
    AS '$libdir/dblink', 'dblink_build_sql_insert'
    LANGUAGE c STRICT;


--
-- TOC entry 226 (OID 166149)
-- Name: dblink_build_sql_delete(text, int2vector, integer, text[]); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION dblink_build_sql_delete(text, int2vector, integer, text[]) RETURNS text
    AS '$libdir/dblink', 'dblink_build_sql_delete'
    LANGUAGE c STRICT;


--
-- TOC entry 227 (OID 166150)
-- Name: dblink_build_sql_update(text, int2vector, integer, text[], text[]); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION dblink_build_sql_update(text, int2vector, integer, text[], text[]) RETURNS text
    AS '$libdir/dblink', 'dblink_build_sql_update'
    LANGUAGE c STRICT;


--
-- TOC entry 228 (OID 166151)
-- Name: dblink_current_query(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION dblink_current_query() RETURNS text
    AS '$libdir/dblink', 'dblink_current_query'
    LANGUAGE c;


--
-- TOC entry 229 (OID 166178)
-- Name: database_size(name); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION database_size(name) RETURNS bigint
    AS '$libdir/dbsize', 'database_size'
    LANGUAGE c STRICT;


--
-- TOC entry 230 (OID 166179)
-- Name: relation_size(text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION relation_size(text) RETURNS bigint
    AS '$libdir/dbsize', 'relation_size'
    LANGUAGE c STRICT;


--
-- TOC entry 236 (OID 166339)
-- Name: nodes_construct(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION nodes_construct() RETURNS "trigger"
    AS '
BEGIN
 RETURN NEW;
END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 237 (OID 166340)
-- Name: nodes_destruct(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION nodes_destruct() RETURNS "trigger"
    AS '
BEGIN
 RETURN OLD;
END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 238 (OID 166341)
-- Name: nodes_touch(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION nodes_touch() RETURNS "trigger"
    AS '
BEGIN
 RETURN NEW;
END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 239 (OID 166342)
-- Name: zip_construct(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION zip_construct() RETURNS "trigger"
    AS '
BEGIN
 RETURN NEW;
END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 240 (OID 166343)
-- Name: zip_destruct(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION zip_destruct() RETURNS "trigger"
    AS '
BEGIN
 RETURN OLD;
END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 241 (OID 166344)
-- Name: zip_touch(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION zip_touch() RETURNS "trigger"
    AS '
BEGIN
 RETURN NEW;
END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 242 (OID 166345)
-- Name: foo_construct(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION foo_construct() RETURNS "trigger"
    AS '
BEGIN
 RETURN NEW;
END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 243 (OID 166346)
-- Name: foo_destruct(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION foo_destruct() RETURNS "trigger"
    AS '
BEGIN
 RETURN OLD;
END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 244 (OID 166347)
-- Name: foo_touch(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION foo_touch() RETURNS "trigger"
    AS '
BEGIN
 RETURN NEW;
END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 245 (OID 166348)
-- Name: sitemap_construct(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION sitemap_construct() RETURNS "trigger"
    AS '
BEGIN
 RETURN NEW;
END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 246 (OID 166349)
-- Name: sitemap_destruct(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION sitemap_destruct() RETURNS "trigger"
    AS '
BEGIN
 RETURN OLD;
END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 247 (OID 166350)
-- Name: sitemap_touch(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION sitemap_touch() RETURNS "trigger"
    AS '
BEGIN
 RETURN NEW;
END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 248 (OID 166369)
-- Name: foo2_construct(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION foo2_construct() RETURNS "trigger"
    AS '
BEGIN
 RETURN NEW;
END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 249 (OID 166370)
-- Name: foo2_destruct(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION foo2_destruct() RETURNS "trigger"
    AS '
BEGIN
 RETURN OLD;
END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 250 (OID 166371)
-- Name: foo2_touch(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION foo2_touch() RETURNS "trigger"
    AS '
BEGIN
 RETURN NEW;
END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 251 (OID 166374)
-- Name: palette_construct(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION palette_construct() RETURNS "trigger"
    AS '
BEGIN
 RETURN NEW;
END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 252 (OID 166375)
-- Name: palette_destruct(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION palette_destruct() RETURNS "trigger"
    AS '
BEGIN
 RETURN OLD;
END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 253 (OID 166376)
-- Name: palette_touch(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION palette_touch() RETURNS "trigger"
    AS '
BEGIN
 RETURN NEW;
END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 254 (OID 166551)
-- Name: erw_construct(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION erw_construct() RETURNS "trigger"
    AS '
BEGIN
 RETURN NEW;
END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 255 (OID 166552)
-- Name: erw_destruct(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION erw_destruct() RETURNS "trigger"
    AS '
BEGIN
 RETURN OLD;
END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 256 (OID 166553)
-- Name: erw_touch(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION erw_touch() RETURNS "trigger"
    AS '
BEGIN
 RETURN NEW;
END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 257 (OID 166615)
-- Name: costly_items_construct(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION costly_items_construct() RETURNS "trigger"
    AS 'BEGIN

 SELECT INTO NEW.charge
   p.brutto * NEW.amount
 FROM pricelist p
 WHERE p.id=NEW.price_id;

 RETURN NEW;
END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 258 (OID 166616)
-- Name: costly_items_destruct(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION costly_items_destruct() RETURNS "trigger"
    AS '
BEGIN
 RETURN OLD;
END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 259 (OID 166617)
-- Name: costly_items_touch(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION costly_items_touch() RETURNS "trigger"
    AS 'BEGIN
 SELECT INTO NEW.charge
   p.netto * NEW.amount
 FROM pricelist p
 WHERE p.id=NEW.price_id;

 RETURN NEW;
END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 260 (OID 166622)
-- Name: todo_items_construct(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION todo_items_construct() RETURNS "trigger"
    AS '
BEGIN
 RETURN NEW;
END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 261 (OID 166623)
-- Name: todo_items_destruct(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION todo_items_destruct() RETURNS "trigger"
    AS '
BEGIN
 RETURN OLD;
END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 262 (OID 166624)
-- Name: todo_items_touch(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION todo_items_touch() RETURNS "trigger"
    AS 'BEGIN
 SELECT INTO NEW.items_total
   sum(charge)
 FROM costly_items WHERE pid=NEW.id;

 RETURN NEW;
END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 263 (OID 166626)
-- Name: costly_items_update(text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION costly_items_update(text) RETURNS "trigger"
    AS '
BEGIN
 UPDATE todo_items SET id=id WHERE id=OLD.pid;
END
'
    LANGUAGE plpgsql;


--
-- TOC entry 482 (OID 166627)
-- Name: costly_items_update(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION costly_items_update() RETURNS "trigger"
    AS 'BEGIN
 IF TG_OP IN (''UPDATE'',''DELETE'') THEN
   UPDATE todo_items SET id=id WHERE id=OLD.pid;
 END IF;

 IF TG_OP IN (''INSERT'',''UPDATE'') THEN
   UPDATE todo_items SET id=id WHERE id=NEW.pid;
 END IF;

 RETURN NEW;
END
'
    LANGUAGE plpgsql;


--
-- TOC entry 264 (OID 166665)
-- Name: photos_construct(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION photos_construct() RETURNS "trigger"
    AS '
BEGIN
 RETURN NEW;
END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 265 (OID 166666)
-- Name: photos_destruct(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION photos_destruct() RETURNS "trigger"
    AS '
BEGIN
 RETURN OLD;
END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 266 (OID 166667)
-- Name: photos_touch(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION photos_touch() RETURNS "trigger"
    AS '
BEGIN
 RETURN NEW;
END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 267 (OID 166705)
-- Name: wdbi_forms_bootstrap(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION wdbi_forms_bootstrap() RETURNS text
    AS '
BEGIN
----------------------------------------------------------------
-- DATA ljudmila.public.wdbi_forms
-- generated by WDBI on 2003-04-29 08:54:41
----------------------------------------------------------------
SET search_path="public",pg_catalog;
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (''133'',''photos'','' '',''ud'',''photos'',''Fotografije'',''id'','''',''photos.name'','''',''0'','''','''',NULL);
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (''40'',''news'',''0'',''iud'',''news'',''Form news on news'',''id'',NULL,'''',NULL,NULL,''items'',NULL,NULL);
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (''186'',''sitemap'',NULL,''1iudgs'',''sitemap'',''Sitemap'',''id'',NULL,''sitemap.mtime desc'',NULL,''0'',NULL,NULL,NULL);
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (''104'',''queries'',''0'',NULL,''nodes'',''SQL Query'',''id'',NULL,NULL,NULL,NULL,NULL,NULL,NULL);
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (''1004'',''wdbi_forms'',NULL,''uids'',''wdbi_forms'',''WDBI forms'',''name'',NULL,NULL,NULL,''0'',NULL,NULL,NULL);
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (''136'',''catalog_items'',NULL,NULL,''catalog_items'',''Katalog....'',''id'',NULL,''catalog_items.ctime desc'',NULL,NULL,NULL,NULL,NULL);
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (''139'',''kiki_types'',''0'',''uids'',''kiki_types'',''Form types on types'',''id'',NULL,''mime'',NULL,NULL,NULL,NULL,NULL);
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (''144'',''zip'',''0'',''iud'',''zip'',''Form zip on zip'',''zip'',NULL,NULL,NULL,NULL,NULL,NULL,NULL);
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (NULL,''pricelist'',NULL,''1iuds'',''pricelist'',''Price List'',''id'',NULL,''brutto desc'',NULL,NULL,NULL,NULL,NULL);
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (NULL,''users'',NULL,''1uids'',''users'',''Users'',''id'',NULL,NULL,NULL,NULL,NULL,NULL,''cols="40%,60%"'');
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (''14'',''ordung'',''0'',''do'',''nodes'',''Reordering children.'',''id'','''',''ordung'','''',''0'','''','''',NULL);
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (''98'',''kategorije'',''0'',''iud'',''kategorije'',''Form kategorije on kategorije'',''id'','''','''','''',''0'','''','''',NULL);
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (''134'',''kiki_drivers'',''0'',''iudsg'',''kiki_drivers'',''Kiki drivers'',''id'','''','''','''',''0'','''','''',NULL);
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (''143'',''wdbi_fields'',''0'',''iud'',''wdbi_fields'',''Form fields'',''id'','''','''','''',''0'','''','''',NULL);
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (NULL,''costly_items'',NULL,''1iudsgf'',''costly_items'',''Costly items'',''id'',NULL,''costly_items.ctime desc'',NULL,NULL,NULL,NULL,''cols="50%,50%"'');
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (''137'',''contacts'',''1'',''sl'',''contacts'',''Contacts'',''oid'',NULL,''contacts.name'',NULL,NULL,NULL,NULL,NULL);
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (''75'',''links'',NULL,''1iudls'',''links'',''Links'',''id'',NULL,''id desc'',NULL,''0'',NULL,NULL,NULL);
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (NULL,''kiki_properties'',''0'',''iudsg'',''kiki_properties'',''Node properties'',''id'',NULL,NULL,NULL,NULL,NULL,NULL,NULL);
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (NULL,''members'',NULL,''1iudls'',''members'',''Members'',''id'',NULL,''members.ctime desc'',NULL,''0'',NULL,NULL,''cols="50%,50%"'');
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (NULL,''nodes'',NULL,''ulids'',''nodes'',''Form nodes on nodes'',''id'',NULL,''nodes.mtime desc'',NULL,''0'',NULL,NULL,NULL);
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (''1080'',''lamers'',NULL,''iudsg'',''lamers'',''Lamers'',''username'',NULL,NULL,NULL,NULL,NULL,NULL,NULL);
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (NULL,''servers'',NULL,''iud'',''servers'',''Form servers on servers'',''id'',NULL,NULL,NULL,NULL,NULL,NULL,NULL);
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (NULL,''sites'',NULL,''1iudsl'',''sites'',''Sites'',''id'',NULL,''name'',NULL,''0'',NULL,NULL,NULL);
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (NULL,''todo_items'',''1'',''iusgd1'',''todo_items'',''Tasks'',''id'',NULL,''todo_items.ctime desc'',NULL,''0'',NULL,NULL,''cols="50%,50%"'');
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (''1002'',''dns'','' '',''1iudsl'',''dns'',''DNS records'',''id'','''','''','''',''0'','''','''',NULL);
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (''0'',''mail_headers'','' '',''iudgs'',''mail'',''Form mail on mail'',''id'','''',''date desc'','''',''0'','''','''',NULL);
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (NULL,''kikis'',NULL,''1iud'',''kikis'',''Other kikis'',''oid'',NULL,NULL,NULL,NULL,NULL,NULL,NULL);
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (''0'',''mail'','' '',''iud'',''mail'',''Mail messages'',''id'','''','''','''',''0'','''','''',NULL);
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (NULL,''projects'',''1'',''1iudsl'',''projects'',''Projects'',''id'',NULL,''projects.priority desc'',NULL,NULL,NULL,NULL,''rows="40%,60%"'');
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (NULL,''filesets'',NULL,''iud'',''filesets'',''Filesets (autoform)'',''id'',NULL,''filesets.mtime desc'',NULL,NULL,NULL,NULL,NULL);
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (NULL,''files'',NULL,''iud'',''files'',''Form files on files'',''id'',NULL,''ctime desc'',NULL,NULL,NULL,NULL,NULL);
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (''1001'',''pg_stat_activity'','' '',''sg'',''pg_stat_activity'',''DB sessions'',''id'','''','''','''',''0'','''','''',NULL);
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (NULL,''playlists'',NULL,''iud'',''playlists'',''Playlists (autoform)'',''id'',NULL,''playlists.ordung'',NULL,NULL,''sitemap'',NULL,NULL);
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (''1003'',''members1'',NULL,''iudl'',''members'',''Members'',''id'',NULL,''members.mtime desc'',NULL,NULL,NULL,NULL,NULL);
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (''1004'',''wdbi_tables'',NULL,'''',''wdbi_tables'',''Database Tables'',''oid'',NULL,NULL,NULL,NULL,NULL,NULL,NULL);
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (''1005'',''organizations'',NULL,''1iudls'',''organizations'',''Member organizations'',''id'',NULL,''organizations.ctime desc'',NULL,NULL,NULL,NULL,''cols="50%,50%"'');
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (''1009'',''wdbi.triggers'',NULL,''1ius'',''wdbi.triggers'',''Triggers'',''trigger_name'',NULL,NULL,NULL,NULL,NULL,NULL,NULL);
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (''1010'',''wdbi.queries'',NULL,''1iuds'',''wdbi.queries'',''WDBI Queries'',''name'',NULL,NULL,NULL,NULL,NULL,NULL,NULL);
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (''1011'',''wdbi.attr'',NULL,''1iuds'',''wdbi.attr'',''Attributes'',''oid'',NULL,NULL,NULL,NULL,NULL,NULL,NULL);
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (''1012'',''wdbi.enum'',NULL,''1iuds'',''wdbi.enum'',''Enums'',''id'',NULL,NULL,NULL,NULL,NULL,NULL,NULL);
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (''1013'',''wdbi.ent'',NULL,''1iuds'',''wdbi.ent'',''Entities'',''id'',NULL,NULL,NULL,NULL,NULL,NULL,NULL);
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (''1014'',''wdbi.tables'',NULL,''1us'',''wdbi.tables'',''Database Tables'',''sql_path'',NULL,NULL,NULL,NULL,NULL,NULL,NULL);
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (''1015'',''wdbi.db_link'',NULL,''iud'',''wdbi.db_link'',''Database links'',''name'',NULL,NULL,NULL,NULL,NULL,NULL,NULL);
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (''1016'',''wdbi.db_link_protocol'',NULL,''iud'',''wdbi.db_link_protocol'',''Database link protocols'',''name'',NULL,NULL,NULL,NULL,NULL,NULL,NULL);
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (''1017'',''wdbi.columns'',NULL,''iuds'',''wdbi.columns'',''wdbi.columns - WDBI columns '',''id'',NULL,NULL,NULL,NULL,NULL,NULL,NULL);
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (''1018'',''ljudmila.locations'',NULL,''iud'',''ljudmila.locations'',''ljudmila.locations'',''id'',NULL,NULL,NULL,NULL,NULL,NULL,NULL);
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (''1019'',''wdbi.leg'',NULL,''1iuds'',''wdbi.leg'',''Relation Leg'',''oid'',NULL,NULL,NULL,NULL,NULL,NULL,NULL);
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (''1020'',''ljudmila.hosts'',NULL,''iuds'',''ljudmila.hosts'',''ljudmila.hosts - Network hosts (automatic)'',''id'',NULL,NULL,NULL,NULL,NULL,NULL,NULL);
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (''1021'',''ljudmila.contacts'',NULL,''iuds'',''ljudmila.contacts'',''ljudmila.contacts - Human contacts'',''id'',NULL,NULL,NULL,NULL,NULL,NULL,NULL);
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (''1022'',''ljudmila.foo'',NULL,''iuds'',''ljudmila.foo'',''ljudmila.foo (automatic)'',''id'',NULL,NULL,NULL,NULL,NULL,NULL,NULL);
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (''1023'',''ljudmila.x'',NULL,''iuds'',''ljudmila.x'',''ljudmila.x (automatic)'',''id'',NULL,NULL,NULL,NULL,NULL,NULL,NULL);
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (''1024'',''wdbi.ddls'',NULL,''iuds'',''wdbi.ddls'',''wdbi.ddls (automatic)'',''id'',NULL,NULL,NULL,NULL,NULL,NULL,NULL);
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (''1025'',''wdbi.synonims'',NULL,''iuds'',''wdbi.synonims'',''wdbi.synonims - Table synonims (automatic)'',''id'',NULL,NULL,NULL,NULL,NULL,NULL,NULL);
----------------------------------------------------------------
INSERT INTO wdbi_forms
 ("id","name","state","flags","tablename","title","primary_key","group_by","order_by","query","count","inherits","def","screen")
VALUES
 (''1026'',''wdbi.synonyms'',NULL,''iuds'',''wdbi.synonyms'',''wdbi.synonyms - Table synonyms - views with rules (automatic)'',''name'',NULL,NULL,NULL,NULL,NULL,NULL,NULL);
----------------------------------------------------------------
RETURN ''public.wdbi_forms bootstrapped'';
END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 268 (OID 166707)
-- Name: kiki_explorer_bootstrap(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION kiki_explorer_bootstrap() RETURNS text
    AS '
BEGIN
----------------------------------------------------------------
-- DATA ljudmila.public.kiki_explorer
-- generated by WDBI on 2003-04-29 10:19:13
----------------------------------------------------------------
SET search_path="public",pg_catalog;
<p>ERROR: Attribute "oid" not found </p>
<script>window.status="ERROR: Attribute \\"oid\\" not found ";</script>RETURN ''public.kiki_explorer bootstrapped'';
END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 269 (OID 166728)
-- Name: enum2_construct(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION enum2_construct() RETURNS "trigger"
    AS '
BEGIN
 RETURN NEW;
END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 270 (OID 166729)
-- Name: enum2_destruct(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION enum2_destruct() RETURNS "trigger"
    AS '
BEGIN
 RETURN OLD;
END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 271 (OID 166730)
-- Name: enum2_touch(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION enum2_touch() RETURNS "trigger"
    AS '
BEGIN
 RETURN NEW;
END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 272 (OID 166734)
-- Name: clips_construct(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION clips_construct() RETURNS "trigger"
    AS '
BEGIN
 RETURN NEW;
END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 273 (OID 166735)
-- Name: clips_destruct(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION clips_destruct() RETURNS "trigger"
    AS '
BEGIN
 RETURN OLD;
END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 274 (OID 166736)
-- Name: clips_touch(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION clips_touch() RETURNS "trigger"
    AS '
BEGIN
 RETURN NEW;
END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 275 (OID 167001)
-- Name: catalog_items_bootstrap(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION catalog_items_bootstrap() RETURNS text
    AS '
BEGIN
----------------------------------------------------------------
-- DATA ljudmila.public.catalog_items
-- generated by WDBI on 2003-09-5 08:06:37
----------------------------------------------------------------
SET search_path="public",pg_catalog;
----------------------------------------------------------------
RETURN ''public.catalog_items bootstrapped'';
END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 276 (OID 167006)
-- Name: kiki_types_bootstrap(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION kiki_types_bootstrap() RETURNS text
    AS '
BEGIN
----------------------------------------------------------------
-- DATA ljudmila.public.kiki_types
-- generated by WDBI on 2003-09-6 01:56:32
----------------------------------------------------------------
SET search_path="public",pg_catalog;
----------------------------------------------------------------
INSERT INTO kiki_types
 ("id","mime","name","encoding","driver","form","tablename")
VALUES
 (''0'',''kiki/node'',''node'','''',''kiki.php'',NULL,NULL);
----------------------------------------------------------------
INSERT INTO kiki_types
 ("id","mime","name","encoding","driver","form","tablename")
VALUES
 (''5'',''property/php'',''php expression'',''latin2'','''',NULL,NULL);
----------------------------------------------------------------
INSERT INTO kiki_types
 ("id","mime","name","encoding","driver","form","tablename")
VALUES
 (''6'',''kiki/driver'','''','''','''',NULL,NULL);
----------------------------------------------------------------
INSERT INTO kiki_types
 ("id","mime","name","encoding","driver","form","tablename")
VALUES
 (''100'',''wdbi/driver'','''','''','''',NULL,NULL);
----------------------------------------------------------------
INSERT INTO kiki_types
 ("id","mime","name","encoding","driver","form","tablename")
VALUES
 (''7'',''kiki/query'',''query'',''sql'',''/kiki/query.php'',NULL,NULL);
----------------------------------------------------------------
INSERT INTO kiki_types
 ("id","mime","name","encoding","driver","form","tablename")
VALUES
 (''2'',''kiki/project'',''project'',NULL,''kiki.php/'',''projects'',NULL);
----------------------------------------------------------------
INSERT INTO kiki_types
 ("id","mime","name","encoding","driver","form","tablename")
VALUES
 (''3'',''kiki/page'',''page'',NULL,''kiki.php/'',''sitemap'',NULL);
----------------------------------------------------------------
INSERT INTO kiki_types
 ("id","mime","name","encoding","driver","form","tablename")
VALUES
 (''4'',''property/text'',''literal text'',''latin2'','''',NULL,NULL);
----------------------------------------------------------------
INSERT INTO kiki_types
 ("id","mime","name","encoding","driver","form","tablename")
VALUES
 (''1'',''kiki/server'',''server'',NULL,''/standard'',''servers'',NULL);
----------------------------------------------------------------
INSERT INTO kiki_types
 ("id","mime","name","encoding","driver","form","tablename")
VALUES
 (''102'',''property/css'',''CSS style element'',NULL,NULL,NULL,NULL);
----------------------------------------------------------------
RETURN ''public.kiki_types bootstrapped'';
END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 52 (OID 167301)
-- Name: mime; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE mime (
    "type" text NOT NULL,
    "comment" text,
    registry text,
    aliasfor name,
    isa name
);


--
-- TOC entry 54 (OID 167301)
-- Name: mime; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE mime FROM PUBLIC;
GRANT SELECT ON TABLE mime TO iedc;
GRANT SELECT ON TABLE mime TO PUBLIC;
GRANT ALL ON TABLE mime TO GROUP mime;


--
-- TOC entry 234 (OID 173673)
-- Name: pgxml_parse(text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION pgxml_parse(text) RETURNS boolean
    AS '$libdir/pgxml_dom', 'pgxml_parse'
    LANGUAGE c STRICT;


--
-- TOC entry 235 (OID 173674)
-- Name: pgxml_xpath(text, text, text, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION pgxml_xpath(text, text, text, text) RETURNS text
    AS '$libdir/pgxml_dom', 'pgxml_xpath'
    LANGUAGE c STRICT;


--
-- TOC entry 13 (OID 173676)
-- Name: xml; Type: DOMAIN; Schema: public; Owner: postgres
--

CREATE DOMAIN xml AS text
	CONSTRAINT "validate_XML" CHECK (pgxml_parse(VALUE));


--
-- TOC entry 307 (OID 175276)
-- Name: sms_construct(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION sms_construct() RETURNS "trigger"
    AS 'DECLARE
  res TEXT;

BEGIN 
  IF NEW.msisdn IS NOT NULL AND NEW.text IS NOT NULL THEN
    SELECT INTO NEW.reply public.smsto(NEW.msisdn,NEW.text);
  END IF;

  RETURN NEW;
END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 305 (OID 175283)
-- Name: smsto(text, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION smsto(text, text) RETURNS text
    AS 'my ($msisdn,$text)=@_;

use LWP::Simple;
use WDBI::P;

my $url="https://ziga:bonec1984\\@glasnik.simobil.si/xml/".
        "?msisdn=".esc(''uri'',$msisdn)."&text=".esc(''uri'',$text);

my $response=get($url);
return $response;
'
    LANGUAGE plperlu STABLE;


--
-- TOC entry 231 (OID 182518)
-- Name: test_construct(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION test_construct() RETURNS "trigger"
    AS '
BEGIN
 RETURN NEW;
END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 232 (OID 182519)
-- Name: test_destruct(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION test_destruct() RETURNS "trigger"
    AS '
BEGIN
 RETURN OLD;
END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 233 (OID 182520)
-- Name: test_touch(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION test_touch() RETURNS "trigger"
    AS '
BEGIN
 RETURN NEW;
END;
'
    LANGUAGE plpgsql;


--
-- TOC entry 55 (OID 184698)
-- Name: imp_pref; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE imp_pref (
    username text,
    sig text,
    fullname text,
    replyto text,
    lang character varying(30)
);


--
-- TOC entry 56 (OID 184703)
-- Name: imp_addr; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE imp_addr (
    username text,
    address text,
    nickname text,
    fullname text
);


--
-- TOC entry 57 (OID 184709)
-- Name: turba_objects; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE turba_objects (
    object_id character varying(32) NOT NULL,
    owner_id character varying(255) NOT NULL,
    object_name character varying(255),
    object_alias character varying(32),
    object_email character varying(255),
    object_homeaddress character varying(255),
    object_workaddress character varying(255),
    object_homephone character varying(25),
    object_workphone character varying(25),
    object_cellphone character varying(25),
    object_fax character varying(25),
    object_title character varying(32),
    object_company character varying(32),
    object_notes text
);


--
-- TOC entry 58 (OID 184709)
-- Name: turba_objects; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE turba_objects FROM PUBLIC;
GRANT INSERT,SELECT,UPDATE,DELETE ON TABLE turba_objects TO horde;


--
-- TOC entry 277 (OID 1867129)
-- Name: issn_in(cstring); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION issn_in(cstring) RETURNS issn
    AS '$libdir/isbn_issn', 'issn_in'
    LANGUAGE c;


--
-- TOC entry 278 (OID 1867130)
-- Name: issn_out(issn); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION issn_out(issn) RETURNS cstring
    AS '$libdir/isbn_issn', 'issn_out'
    LANGUAGE c;


--
-- TOC entry 11 (OID 1867128)
-- Name: issn; Type: TYPE; Schema: public; Owner: postgres
--

CREATE TYPE issn (
    INTERNALLENGTH = 16,
    INPUT = issn_in,
    OUTPUT = issn_out,
    ALIGNMENT = int4,
    STORAGE = plain
);


--
-- TOC entry 279 (OID 1867132)
-- Name: issn_lt(issn, issn); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION issn_lt(issn, issn) RETURNS boolean
    AS '$libdir/isbn_issn', 'issn_lt'
    LANGUAGE c;


--
-- TOC entry 280 (OID 1867133)
-- Name: issn_le(issn, issn); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION issn_le(issn, issn) RETURNS boolean
    AS '$libdir/isbn_issn', 'issn_le'
    LANGUAGE c;


--
-- TOC entry 281 (OID 1867134)
-- Name: issn_eq(issn, issn); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION issn_eq(issn, issn) RETURNS boolean
    AS '$libdir/isbn_issn', 'issn_eq'
    LANGUAGE c;


--
-- TOC entry 282 (OID 1867135)
-- Name: issn_ge(issn, issn); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION issn_ge(issn, issn) RETURNS boolean
    AS '$libdir/isbn_issn', 'issn_ge'
    LANGUAGE c;


--
-- TOC entry 283 (OID 1867136)
-- Name: issn_gt(issn, issn); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION issn_gt(issn, issn) RETURNS boolean
    AS '$libdir/isbn_issn', 'issn_gt'
    LANGUAGE c;


--
-- TOC entry 284 (OID 1867137)
-- Name: issn_ne(issn, issn); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION issn_ne(issn, issn) RETURNS boolean
    AS '$libdir/isbn_issn', 'issn_ne'
    LANGUAGE c;


--
-- TOC entry 493 (OID 1867138)
-- Name: <; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR < (
    PROCEDURE = issn_lt,
    LEFTARG = issn,
    RIGHTARG = issn,
    NEGATOR = >=
);


--
-- TOC entry 495 (OID 1867139)
-- Name: <=; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR <= (
    PROCEDURE = issn_le,
    LEFTARG = issn,
    RIGHTARG = issn,
    NEGATOR = >
);


--
-- TOC entry 497 (OID 1867140)
-- Name: =; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR = (
    PROCEDURE = issn_eq,
    LEFTARG = issn,
    RIGHTARG = issn,
    COMMUTATOR = =,
    NEGATOR = <>
);


--
-- TOC entry 492 (OID 1867141)
-- Name: >=; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR >= (
    PROCEDURE = issn_ge,
    LEFTARG = issn,
    RIGHTARG = issn,
    NEGATOR = <
);


--
-- TOC entry 494 (OID 1867142)
-- Name: >; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR > (
    PROCEDURE = issn_gt,
    LEFTARG = issn,
    RIGHTARG = issn,
    NEGATOR = <=
);


--
-- TOC entry 496 (OID 1867143)
-- Name: <>; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR <> (
    PROCEDURE = issn_ne,
    LEFTARG = issn,
    RIGHTARG = issn,
    NEGATOR = =
);


--
-- TOC entry 285 (OID 1867144)
-- Name: issn_cmp(issn, issn); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION issn_cmp(issn, issn) RETURNS integer
    AS '$libdir/isbn_issn', 'issn_cmp'
    LANGUAGE c;


--
-- TOC entry 554 (OID 1867145)
-- Name: issn_ops; Type: OPERATOR CLASS; Schema: public; Owner: postgres
--

CREATE OPERATOR CLASS issn_ops
    DEFAULT FOR TYPE issn USING btree AS
    OPERATOR 1 <(issn,issn) ,
    OPERATOR 2 <=(issn,issn) ,
    OPERATOR 3 =(issn,issn) ,
    OPERATOR 4 >=(issn,issn) ,
    OPERATOR 5 >(issn,issn) ,
    FUNCTION 1 issn_cmp(issn,issn);


--
-- TOC entry 286 (OID 1867147)
-- Name: isbn_in(cstring); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION isbn_in(cstring) RETURNS isbn
    AS '$libdir/isbn_issn', 'isbn_in'
    LANGUAGE c;


--
-- TOC entry 287 (OID 1867148)
-- Name: isbn_out(isbn); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION isbn_out(isbn) RETURNS cstring
    AS '$libdir/isbn_issn', 'isbn_out'
    LANGUAGE c;


--
-- TOC entry 15 (OID 1867146)
-- Name: isbn; Type: TYPE; Schema: public; Owner: postgres
--

CREATE TYPE isbn (
    INTERNALLENGTH = 16,
    INPUT = isbn_in,
    OUTPUT = isbn_out,
    ALIGNMENT = int4,
    STORAGE = plain
);


--
-- TOC entry 288 (OID 1867150)
-- Name: isbn_lt(isbn, isbn); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION isbn_lt(isbn, isbn) RETURNS boolean
    AS '$libdir/isbn_issn', 'isbn_lt'
    LANGUAGE c;


--
-- TOC entry 289 (OID 1867151)
-- Name: isbn_le(isbn, isbn); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION isbn_le(isbn, isbn) RETURNS boolean
    AS '$libdir/isbn_issn', 'isbn_le'
    LANGUAGE c;


--
-- TOC entry 290 (OID 1867152)
-- Name: isbn_eq(isbn, isbn); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION isbn_eq(isbn, isbn) RETURNS boolean
    AS '$libdir/isbn_issn', 'isbn_eq'
    LANGUAGE c;


--
-- TOC entry 291 (OID 1867153)
-- Name: isbn_ge(isbn, isbn); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION isbn_ge(isbn, isbn) RETURNS boolean
    AS '$libdir/isbn_issn', 'isbn_ge'
    LANGUAGE c;


--
-- TOC entry 292 (OID 1867154)
-- Name: isbn_gt(isbn, isbn); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION isbn_gt(isbn, isbn) RETURNS boolean
    AS '$libdir/isbn_issn', 'isbn_gt'
    LANGUAGE c;


--
-- TOC entry 293 (OID 1867155)
-- Name: isbn_ne(isbn, isbn); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION isbn_ne(isbn, isbn) RETURNS boolean
    AS '$libdir/isbn_issn', 'isbn_ne'
    LANGUAGE c;


--
-- TOC entry 503 (OID 1867156)
-- Name: <; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR < (
    PROCEDURE = isbn_lt,
    LEFTARG = isbn,
    RIGHTARG = isbn,
    NEGATOR = >=
);


--
-- TOC entry 505 (OID 1867157)
-- Name: <=; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR <= (
    PROCEDURE = isbn_le,
    LEFTARG = isbn,
    RIGHTARG = isbn,
    NEGATOR = >
);


--
-- TOC entry 507 (OID 1867158)
-- Name: =; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR = (
    PROCEDURE = isbn_eq,
    LEFTARG = isbn,
    RIGHTARG = isbn,
    COMMUTATOR = =,
    NEGATOR = <>
);


--
-- TOC entry 502 (OID 1867159)
-- Name: >=; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR >= (
    PROCEDURE = isbn_ge,
    LEFTARG = isbn,
    RIGHTARG = isbn,
    NEGATOR = <
);


--
-- TOC entry 504 (OID 1867160)
-- Name: >; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR > (
    PROCEDURE = isbn_gt,
    LEFTARG = isbn,
    RIGHTARG = isbn,
    NEGATOR = <=
);


--
-- TOC entry 506 (OID 1867161)
-- Name: <>; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR <> (
    PROCEDURE = isbn_ne,
    LEFTARG = isbn,
    RIGHTARG = isbn,
    NEGATOR = =
);


--
-- TOC entry 294 (OID 1867162)
-- Name: isbn_cmp(isbn, isbn); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION isbn_cmp(isbn, isbn) RETURNS integer
    AS '$libdir/isbn_issn', 'isbn_cmp'
    LANGUAGE c;


--
-- TOC entry 555 (OID 1867163)
-- Name: isbn_ops; Type: OPERATOR CLASS; Schema: public; Owner: postgres
--

CREATE OPERATOR CLASS isbn_ops
    DEFAULT FOR TYPE isbn USING btree AS
    OPERATOR 1 <(isbn,isbn) ,
    OPERATOR 2 <=(isbn,isbn) ,
    OPERATOR 3 =(isbn,isbn) ,
    OPERATOR 4 >=(isbn,isbn) ,
    OPERATOR 5 >(isbn,isbn) ,
    FUNCTION 1 isbn_cmp(isbn,isbn);


--
-- TOC entry 295 (OID 1867164)
-- Name: normal_rand(integer, double precision, double precision); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION normal_rand(integer, double precision, double precision) RETURNS SETOF double precision
    AS '$libdir/tablefunc', 'normal_rand'
    LANGUAGE c STRICT;


--
-- TOC entry 17 (OID 1867166)
-- Name: tablefunc_crosstab_2; Type: TYPE; Schema: public; Owner: postgres
--

CREATE TYPE tablefunc_crosstab_2 AS (
	row_name text,
	category_1 text,
	category_2 text
);


--
-- TOC entry 18 (OID 1867168)
-- Name: tablefunc_crosstab_3; Type: TYPE; Schema: public; Owner: postgres
--

CREATE TYPE tablefunc_crosstab_3 AS (
	row_name text,
	category_1 text,
	category_2 text,
	category_3 text
);


--
-- TOC entry 19 (OID 1867170)
-- Name: tablefunc_crosstab_4; Type: TYPE; Schema: public; Owner: postgres
--

CREATE TYPE tablefunc_crosstab_4 AS (
	row_name text,
	category_1 text,
	category_2 text,
	category_3 text,
	category_4 text
);


--
-- TOC entry 296 (OID 1867171)
-- Name: crosstab2(text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION crosstab2(text) RETURNS SETOF tablefunc_crosstab_2
    AS '$libdir/tablefunc', 'crosstab'
    LANGUAGE c STABLE STRICT;


--
-- TOC entry 297 (OID 1867172)
-- Name: crosstab3(text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION crosstab3(text) RETURNS SETOF tablefunc_crosstab_3
    AS '$libdir/tablefunc', 'crosstab'
    LANGUAGE c STABLE STRICT;


--
-- TOC entry 298 (OID 1867173)
-- Name: crosstab4(text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION crosstab4(text) RETURNS SETOF tablefunc_crosstab_4
    AS '$libdir/tablefunc', 'crosstab'
    LANGUAGE c STABLE STRICT;


--
-- TOC entry 299 (OID 1867174)
-- Name: crosstab(text, integer); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION crosstab(text, integer) RETURNS SETOF record
    AS '$libdir/tablefunc', 'crosstab'
    LANGUAGE c STABLE STRICT;


--
-- TOC entry 300 (OID 1867175)
-- Name: crosstab(text, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION crosstab(text, text) RETURNS SETOF record
    AS '$libdir/tablefunc', 'crosstab_hash'
    LANGUAGE c STABLE STRICT;


--
-- TOC entry 301 (OID 1867176)
-- Name: connectby(text, text, text, text, integer, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION connectby(text, text, text, text, integer, text) RETURNS SETOF record
    AS '$libdir/tablefunc', 'connectby_text'
    LANGUAGE c STABLE STRICT;


--
-- TOC entry 302 (OID 1867177)
-- Name: connectby(text, text, text, text, integer); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION connectby(text, text, text, text, integer) RETURNS SETOF record
    AS '$libdir/tablefunc', 'connectby_text'
    LANGUAGE c STABLE STRICT;


--
-- TOC entry 303 (OID 1867178)
-- Name: connectby(text, text, text, text, text, integer, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION connectby(text, text, text, text, text, integer, text) RETURNS SETOF record
    AS '$libdir/tablefunc', 'connectby_text_serial'
    LANGUAGE c STABLE STRICT;


--
-- TOC entry 304 (OID 1867179)
-- Name: connectby(text, text, text, text, text, integer); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION connectby(text, text, text, text, text, integer) RETURNS SETOF record
    AS '$libdir/tablefunc', 'connectby_text_serial'
    LANGUAGE c STABLE STRICT;


--
-- TOC entry 306 (OID 1867181)
-- Name: digest(text, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION digest(text, text) RETURNS bytea
    AS '$libdir/pgcrypto', 'pg_digest'
    LANGUAGE c;


--
-- TOC entry 308 (OID 1867182)
-- Name: digest(bytea, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION digest(bytea, text) RETURNS bytea
    AS '$libdir/pgcrypto', 'pg_digest'
    LANGUAGE c;


--
-- TOC entry 309 (OID 1867183)
-- Name: digest_exists(text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION digest_exists(text) RETURNS boolean
    AS '$libdir/pgcrypto', 'pg_digest_exists'
    LANGUAGE c;


--
-- TOC entry 310 (OID 1867184)
-- Name: hmac(text, text, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION hmac(text, text, text) RETURNS bytea
    AS '$libdir/pgcrypto', 'pg_hmac'
    LANGUAGE c;


--
-- TOC entry 311 (OID 1867185)
-- Name: hmac(bytea, bytea, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION hmac(bytea, bytea, text) RETURNS bytea
    AS '$libdir/pgcrypto', 'pg_hmac'
    LANGUAGE c;


--
-- TOC entry 312 (OID 1867186)
-- Name: hmac_exists(text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION hmac_exists(text) RETURNS boolean
    AS '$libdir/pgcrypto', 'pg_hmac_exists'
    LANGUAGE c;


--
-- TOC entry 313 (OID 1867187)
-- Name: crypt(text, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION crypt(text, text) RETURNS text
    AS '$libdir/pgcrypto', 'pg_crypt'
    LANGUAGE c;


--
-- TOC entry 314 (OID 1867188)
-- Name: gen_salt(text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION gen_salt(text) RETURNS text
    AS '$libdir/pgcrypto', 'pg_gen_salt'
    LANGUAGE c;


--
-- TOC entry 315 (OID 1867189)
-- Name: gen_salt(text, integer); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION gen_salt(text, integer) RETURNS text
    AS '$libdir/pgcrypto', 'pg_gen_salt_rounds'
    LANGUAGE c;


--
-- TOC entry 316 (OID 1867190)
-- Name: encrypt(bytea, bytea, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION encrypt(bytea, bytea, text) RETURNS bytea
    AS '$libdir/pgcrypto', 'pg_encrypt'
    LANGUAGE c;


--
-- TOC entry 317 (OID 1867191)
-- Name: decrypt(bytea, bytea, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION decrypt(bytea, bytea, text) RETURNS bytea
    AS '$libdir/pgcrypto', 'pg_decrypt'
    LANGUAGE c;


--
-- TOC entry 318 (OID 1867192)
-- Name: encrypt_iv(bytea, bytea, bytea, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION encrypt_iv(bytea, bytea, bytea, text) RETURNS bytea
    AS '$libdir/pgcrypto', 'pg_encrypt_iv'
    LANGUAGE c;


--
-- TOC entry 319 (OID 1867193)
-- Name: decrypt_iv(bytea, bytea, bytea, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION decrypt_iv(bytea, bytea, bytea, text) RETURNS bytea
    AS '$libdir/pgcrypto', 'pg_decrypt_iv'
    LANGUAGE c;


--
-- TOC entry 320 (OID 1867194)
-- Name: cipher_exists(text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION cipher_exists(text) RETURNS boolean
    AS '$libdir/pgcrypto', 'pg_cipher_exists'
    LANGUAGE c;


--
-- TOC entry 20 (OID 1867196)
-- Name: pgstattuple_type; Type: TYPE; Schema: public; Owner: postgres
--

CREATE TYPE pgstattuple_type AS (
	table_len bigint,
	tuple_count bigint,
	tuple_len bigint,
	tuple_percent double precision,
	dead_tuple_count bigint,
	dead_tuple_len bigint,
	dead_tuple_percent double precision,
	free_space bigint,
	free_percent double precision
);


--
-- TOC entry 321 (OID 1867197)
-- Name: pgstattuple(text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION pgstattuple(text) RETURNS pgstattuple_type
    AS '$libdir/pgstattuple', 'pgstattuple'
    LANGUAGE c STRICT;


--
-- TOC entry 322 (OID 1867198)
-- Name: pgstattuple(oid); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION pgstattuple(oid) RETURNS pgstattuple_type
    AS '$libdir/pgstattuple', 'pgstattuplebyid'
    LANGUAGE c STRICT;


--
-- TOC entry 323 (OID 1867199)
-- Name: backend_pid(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION backend_pid() RETURNS integer
    AS '$libdir/misc_utils', 'backend_pid'
    LANGUAGE c;


--
-- TOC entry 324 (OID 1867200)
-- Name: unlisten(name); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION "unlisten"(name) RETURNS integer
    AS '$libdir/misc_utils', 'unlisten'
    LANGUAGE c;


--
-- TOC entry 325 (OID 1867201)
-- Name: unlisten(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION "unlisten"() RETURNS integer
    AS 'SELECT "unlisten"(''*'')'
    LANGUAGE sql;


--
-- TOC entry 326 (OID 1867202)
-- Name: min(integer, integer); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION min(integer, integer) RETURNS integer
    AS '$libdir/misc_utils', 'min'
    LANGUAGE c;


--
-- TOC entry 327 (OID 1867203)
-- Name: max(integer, integer); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION max(integer, integer) RETURNS integer
    AS '$libdir/misc_utils', 'max'
    LANGUAGE c;


--
-- TOC entry 328 (OID 1867204)
-- Name: active_listeners(text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION active_listeners(text) RETURNS integer
    AS '$libdir/misc_utils', 'active_listeners'
    LANGUAGE c;


--
-- TOC entry 59 (OID 1867205)
-- Name: pg_ts_dict; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE pg_ts_dict (
    dict_name text NOT NULL,
    dict_init oid,
    dict_initoption text,
    dict_lexize oid NOT NULL,
    dict_comment text
);


--
-- TOC entry 329 (OID 1867212)
-- Name: lexize(oid, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION lexize(oid, text) RETURNS text[]
    AS '$libdir/tsearch2', 'lexize'
    LANGUAGE c STRICT;


--
-- TOC entry 330 (OID 1867213)
-- Name: lexize(text, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION lexize(text, text) RETURNS text[]
    AS '$libdir/tsearch2', 'lexize_byname'
    LANGUAGE c STRICT;


--
-- TOC entry 331 (OID 1867214)
-- Name: lexize(text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION lexize(text) RETURNS text[]
    AS '$libdir/tsearch2', 'lexize_bycurrent'
    LANGUAGE c STRICT;


--
-- TOC entry 332 (OID 1867215)
-- Name: set_curdict(integer); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION set_curdict(integer) RETURNS void
    AS '$libdir/tsearch2', 'set_curdict'
    LANGUAGE c STRICT;


--
-- TOC entry 333 (OID 1867216)
-- Name: set_curdict(text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION set_curdict(text) RETURNS void
    AS '$libdir/tsearch2', 'set_curdict_byname'
    LANGUAGE c STRICT;


--
-- TOC entry 334 (OID 1867217)
-- Name: dex_init(text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION dex_init(text) RETURNS internal
    AS '$libdir/tsearch2', 'dex_init'
    LANGUAGE c;


--
-- TOC entry 335 (OID 1867218)
-- Name: dex_lexize(internal, internal, integer); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION dex_lexize(internal, internal, integer) RETURNS internal
    AS '$libdir/tsearch2', 'dex_lexize'
    LANGUAGE c STRICT;


--
-- TOC entry 336 (OID 1867220)
-- Name: snb_en_init(text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION snb_en_init(text) RETURNS internal
    AS '$libdir/tsearch2', 'snb_en_init'
    LANGUAGE c;


--
-- TOC entry 337 (OID 1867221)
-- Name: snb_lexize(internal, internal, integer); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION snb_lexize(internal, internal, integer) RETURNS internal
    AS '$libdir/tsearch2', 'snb_lexize'
    LANGUAGE c STRICT;


--
-- TOC entry 338 (OID 1867223)
-- Name: snb_ru_init(text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION snb_ru_init(text) RETURNS internal
    AS '$libdir/tsearch2', 'snb_ru_init'
    LANGUAGE c;


--
-- TOC entry 339 (OID 1867225)
-- Name: spell_init(text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION spell_init(text) RETURNS internal
    AS '$libdir/tsearch2', 'spell_init'
    LANGUAGE c;


--
-- TOC entry 340 (OID 1867226)
-- Name: spell_lexize(internal, internal, integer); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION spell_lexize(internal, internal, integer) RETURNS internal
    AS '$libdir/tsearch2', 'spell_lexize'
    LANGUAGE c STRICT;


--
-- TOC entry 341 (OID 1867228)
-- Name: syn_init(text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION syn_init(text) RETURNS internal
    AS '$libdir/tsearch2', 'syn_init'
    LANGUAGE c;


--
-- TOC entry 342 (OID 1867229)
-- Name: syn_lexize(internal, internal, integer); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION syn_lexize(internal, internal, integer) RETURNS internal
    AS '$libdir/tsearch2', 'syn_lexize'
    LANGUAGE c STRICT;


--
-- TOC entry 60 (OID 1867231)
-- Name: pg_ts_parser; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE pg_ts_parser (
    prs_name text NOT NULL,
    prs_start oid NOT NULL,
    prs_nexttoken oid NOT NULL,
    prs_end oid NOT NULL,
    prs_headline oid NOT NULL,
    prs_lextype oid NOT NULL,
    prs_comment text
);


--
-- TOC entry 21 (OID 1867239)
-- Name: tokentype; Type: TYPE; Schema: public; Owner: postgres
--

CREATE TYPE tokentype AS (
	tokid integer,
	alias text,
	descr text
);


--
-- TOC entry 343 (OID 1867240)
-- Name: token_type(integer); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION token_type(integer) RETURNS SETOF tokentype
    AS '$libdir/tsearch2', 'token_type'
    LANGUAGE c STRICT;


--
-- TOC entry 344 (OID 1867241)
-- Name: token_type(text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION token_type(text) RETURNS SETOF tokentype
    AS '$libdir/tsearch2', 'token_type_byname'
    LANGUAGE c STRICT;


--
-- TOC entry 345 (OID 1867242)
-- Name: token_type(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION token_type() RETURNS SETOF tokentype
    AS '$libdir/tsearch2', 'token_type_current'
    LANGUAGE c STRICT;


--
-- TOC entry 346 (OID 1867243)
-- Name: set_curprs(integer); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION set_curprs(integer) RETURNS void
    AS '$libdir/tsearch2', 'set_curprs'
    LANGUAGE c STRICT;


--
-- TOC entry 347 (OID 1867244)
-- Name: set_curprs(text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION set_curprs(text) RETURNS void
    AS '$libdir/tsearch2', 'set_curprs_byname'
    LANGUAGE c STRICT;


--
-- TOC entry 22 (OID 1867246)
-- Name: tokenout; Type: TYPE; Schema: public; Owner: postgres
--

CREATE TYPE tokenout AS (
	tokid integer,
	token text
);


--
-- TOC entry 348 (OID 1867247)
-- Name: parse(oid, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION parse(oid, text) RETURNS SETOF tokenout
    AS '$libdir/tsearch2', 'parse'
    LANGUAGE c STRICT;


--
-- TOC entry 349 (OID 1867248)
-- Name: parse(text, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION parse(text, text) RETURNS SETOF tokenout
    AS '$libdir/tsearch2', 'parse_byname'
    LANGUAGE c STRICT;


--
-- TOC entry 350 (OID 1867249)
-- Name: parse(text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION parse(text) RETURNS SETOF tokenout
    AS '$libdir/tsearch2', 'parse_current'
    LANGUAGE c STRICT;


--
-- TOC entry 351 (OID 1867250)
-- Name: prsd_start(internal, integer); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION prsd_start(internal, integer) RETURNS internal
    AS '$libdir/tsearch2', 'prsd_start'
    LANGUAGE c;


--
-- TOC entry 352 (OID 1867251)
-- Name: prsd_getlexeme(internal, internal, internal); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION prsd_getlexeme(internal, internal, internal) RETURNS integer
    AS '$libdir/tsearch2', 'prsd_getlexeme'
    LANGUAGE c;


--
-- TOC entry 353 (OID 1867252)
-- Name: prsd_end(internal); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION prsd_end(internal) RETURNS void
    AS '$libdir/tsearch2', 'prsd_end'
    LANGUAGE c;


--
-- TOC entry 354 (OID 1867253)
-- Name: prsd_lextype(internal); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION prsd_lextype(internal) RETURNS internal
    AS '$libdir/tsearch2', 'prsd_lextype'
    LANGUAGE c;


--
-- TOC entry 355 (OID 1867254)
-- Name: prsd_headline(internal, internal, internal); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION prsd_headline(internal, internal, internal) RETURNS internal
    AS '$libdir/tsearch2', 'prsd_headline'
    LANGUAGE c;


--
-- TOC entry 61 (OID 1867256)
-- Name: pg_ts_cfg; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE pg_ts_cfg (
    ts_name text NOT NULL,
    prs_name text NOT NULL,
    locale text
);


--
-- TOC entry 62 (OID 1867263)
-- Name: pg_ts_cfgmap; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE pg_ts_cfgmap (
    ts_name text NOT NULL,
    tok_alias text NOT NULL,
    dict_name text[]
);


--
-- TOC entry 356 (OID 1867270)
-- Name: set_curcfg(integer); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION set_curcfg(integer) RETURNS void
    AS '$libdir/tsearch2', 'set_curcfg'
    LANGUAGE c STRICT;


--
-- TOC entry 357 (OID 1867271)
-- Name: set_curcfg(text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION set_curcfg(text) RETURNS void
    AS '$libdir/tsearch2', 'set_curcfg_byname'
    LANGUAGE c STRICT;


--
-- TOC entry 358 (OID 1867272)
-- Name: show_curcfg(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION show_curcfg() RETURNS oid
    AS '$libdir/tsearch2', 'show_curcfg'
    LANGUAGE c STRICT;


--
-- TOC entry 359 (OID 1867334)
-- Name: tsvector_in(cstring); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION tsvector_in(cstring) RETURNS tsvector
    AS '$libdir/tsearch2', 'tsvector_in'
    LANGUAGE c STRICT;


--
-- TOC entry 360 (OID 1867335)
-- Name: tsvector_out(tsvector); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION tsvector_out(tsvector) RETURNS cstring
    AS '$libdir/tsearch2', 'tsvector_out'
    LANGUAGE c STRICT;


--
-- TOC entry 23 (OID 1867333)
-- Name: tsvector; Type: TYPE; Schema: public; Owner: postgres
--

CREATE TYPE tsvector (
    INTERNALLENGTH = variable,
    INPUT = tsvector_in,
    OUTPUT = tsvector_out,
    ALIGNMENT = int4,
    STORAGE = extended
);


--
-- TOC entry 361 (OID 1867337)
-- Name: length(tsvector); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION length(tsvector) RETURNS integer
    AS '$libdir/tsearch2', 'tsvector_length'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 362 (OID 1867338)
-- Name: to_tsvector(oid, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION to_tsvector(oid, text) RETURNS tsvector
    AS '$libdir/tsearch2', 'to_tsvector'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 363 (OID 1867339)
-- Name: to_tsvector(text, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION to_tsvector(text, text) RETURNS tsvector
    AS '$libdir/tsearch2', 'to_tsvector_name'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 364 (OID 1867340)
-- Name: to_tsvector(text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION to_tsvector(text) RETURNS tsvector
    AS '$libdir/tsearch2', 'to_tsvector_current'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 365 (OID 1867341)
-- Name: strip(tsvector); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION strip(tsvector) RETURNS tsvector
    AS '$libdir/tsearch2', 'strip'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 366 (OID 1867342)
-- Name: setweight(tsvector, "char"); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION setweight(tsvector, "char") RETURNS tsvector
    AS '$libdir/tsearch2', 'setweight'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 367 (OID 1867343)
-- Name: concat(tsvector, tsvector); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION concat(tsvector, tsvector) RETURNS tsvector
    AS '$libdir/tsearch2', 'concat'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 508 (OID 1867344)
-- Name: ||; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR || (
    PROCEDURE = concat,
    LEFTARG = tsvector,
    RIGHTARG = tsvector
);


--
-- TOC entry 368 (OID 1867346)
-- Name: tsquery_in(cstring); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION tsquery_in(cstring) RETURNS tsquery
    AS '$libdir/tsearch2', 'tsquery_in'
    LANGUAGE c STRICT;


--
-- TOC entry 369 (OID 1867347)
-- Name: tsquery_out(tsquery); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION tsquery_out(tsquery) RETURNS cstring
    AS '$libdir/tsearch2', 'tsquery_out'
    LANGUAGE c STRICT;


--
-- TOC entry 25 (OID 1867345)
-- Name: tsquery; Type: TYPE; Schema: public; Owner: postgres
--

CREATE TYPE tsquery (
    INTERNALLENGTH = variable,
    INPUT = tsquery_in,
    OUTPUT = tsquery_out,
    ALIGNMENT = int4,
    STORAGE = plain
);


--
-- TOC entry 370 (OID 1867349)
-- Name: querytree(tsquery); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION querytree(tsquery) RETURNS text
    AS '$libdir/tsearch2', 'tsquerytree'
    LANGUAGE c STRICT;


--
-- TOC entry 371 (OID 1867350)
-- Name: to_tsquery(oid, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION to_tsquery(oid, text) RETURNS tsquery
    AS '$libdir/tsearch2', 'to_tsquery'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 372 (OID 1867351)
-- Name: to_tsquery(text, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION to_tsquery(text, text) RETURNS tsquery
    AS '$libdir/tsearch2', 'to_tsquery_name'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 373 (OID 1867352)
-- Name: to_tsquery(text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION to_tsquery(text) RETURNS tsquery
    AS '$libdir/tsearch2', 'to_tsquery_current'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 374 (OID 1867353)
-- Name: exectsq(tsvector, tsquery); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION exectsq(tsvector, tsquery) RETURNS boolean
    AS '$libdir/tsearch2', 'exectsq'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 376 (OID 1867354)
-- Name: rexectsq(tsquery, tsvector); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION rexectsq(tsquery, tsvector) RETURNS boolean
    AS '$libdir/tsearch2', 'rexectsq'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 512 (OID 1867355)
-- Name: @@; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR @@ (
    PROCEDURE = rexectsq,
    LEFTARG = tsquery,
    RIGHTARG = tsvector,
    COMMUTATOR = @@,
    RESTRICT = contsel,
    JOIN = contjoinsel
);


--
-- TOC entry 510 (OID 1867356)
-- Name: @@; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR @@ (
    PROCEDURE = exectsq,
    LEFTARG = tsvector,
    RIGHTARG = tsquery,
    COMMUTATOR = @@,
    RESTRICT = contsel,
    JOIN = contjoinsel
);


--
-- TOC entry 378 (OID 1867357)
-- Name: tsearch2(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION tsearch2() RETURNS "trigger"
    AS '$libdir/tsearch2', 'tsearch2'
    LANGUAGE c;


--
-- TOC entry 379 (OID 1867358)
-- Name: rank(real[], tsvector, tsquery); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION rank(real[], tsvector, tsquery) RETURNS real
    AS '$libdir/tsearch2', 'rank'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 380 (OID 1867359)
-- Name: rank(real[], tsvector, tsquery, integer); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION rank(real[], tsvector, tsquery, integer) RETURNS real
    AS '$libdir/tsearch2', 'rank'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 381 (OID 1867360)
-- Name: rank(tsvector, tsquery); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION rank(tsvector, tsquery) RETURNS real
    AS '$libdir/tsearch2', 'rank_def'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 382 (OID 1867361)
-- Name: rank(tsvector, tsquery, integer); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION rank(tsvector, tsquery, integer) RETURNS real
    AS '$libdir/tsearch2', 'rank_def'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 383 (OID 1867362)
-- Name: rank_cd(integer, tsvector, tsquery); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION rank_cd(integer, tsvector, tsquery) RETURNS real
    AS '$libdir/tsearch2', 'rank_cd'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 384 (OID 1867363)
-- Name: rank_cd(integer, tsvector, tsquery, integer); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION rank_cd(integer, tsvector, tsquery, integer) RETURNS real
    AS '$libdir/tsearch2', 'rank_cd'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 385 (OID 1867364)
-- Name: rank_cd(tsvector, tsquery); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION rank_cd(tsvector, tsquery) RETURNS real
    AS '$libdir/tsearch2', 'rank_cd_def'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 386 (OID 1867365)
-- Name: rank_cd(tsvector, tsquery, integer); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION rank_cd(tsvector, tsquery, integer) RETURNS real
    AS '$libdir/tsearch2', 'rank_cd_def'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 387 (OID 1867366)
-- Name: headline(oid, text, tsquery, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION headline(oid, text, tsquery, text) RETURNS text
    AS '$libdir/tsearch2', 'headline'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 388 (OID 1867367)
-- Name: headline(oid, text, tsquery); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION headline(oid, text, tsquery) RETURNS text
    AS '$libdir/tsearch2', 'headline'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 389 (OID 1867368)
-- Name: headline(text, text, tsquery, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION headline(text, text, tsquery, text) RETURNS text
    AS '$libdir/tsearch2', 'headline_byname'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 390 (OID 1867369)
-- Name: headline(text, text, tsquery); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION headline(text, text, tsquery) RETURNS text
    AS '$libdir/tsearch2', 'headline_byname'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 391 (OID 1867370)
-- Name: headline(text, tsquery, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION headline(text, tsquery, text) RETURNS text
    AS '$libdir/tsearch2', 'headline_current'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 392 (OID 1867371)
-- Name: headline(text, tsquery); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION headline(text, tsquery) RETURNS text
    AS '$libdir/tsearch2', 'headline_current'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 393 (OID 1867373)
-- Name: gtsvector_in(cstring); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION gtsvector_in(cstring) RETURNS gtsvector
    AS '$libdir/tsearch2', 'gtsvector_in'
    LANGUAGE c STRICT;


--
-- TOC entry 394 (OID 1867374)
-- Name: gtsvector_out(gtsvector); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION gtsvector_out(gtsvector) RETURNS cstring
    AS '$libdir/tsearch2', 'gtsvector_out'
    LANGUAGE c STRICT;


--
-- TOC entry 26 (OID 1867372)
-- Name: gtsvector; Type: TYPE; Schema: public; Owner: postgres
--

CREATE TYPE gtsvector (
    INTERNALLENGTH = variable,
    INPUT = gtsvector_in,
    OUTPUT = gtsvector_out,
    ALIGNMENT = int4,
    STORAGE = plain
);


--
-- TOC entry 395 (OID 1867376)
-- Name: gtsvector_consistent(gtsvector, internal, integer); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION gtsvector_consistent(gtsvector, internal, integer) RETURNS boolean
    AS '$libdir/tsearch2', 'gtsvector_consistent'
    LANGUAGE c;


--
-- TOC entry 396 (OID 1867377)
-- Name: gtsvector_compress(internal); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION gtsvector_compress(internal) RETURNS internal
    AS '$libdir/tsearch2', 'gtsvector_compress'
    LANGUAGE c;


--
-- TOC entry 397 (OID 1867378)
-- Name: gtsvector_decompress(internal); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION gtsvector_decompress(internal) RETURNS internal
    AS '$libdir/tsearch2', 'gtsvector_decompress'
    LANGUAGE c;


--
-- TOC entry 398 (OID 1867379)
-- Name: gtsvector_penalty(internal, internal, internal); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION gtsvector_penalty(internal, internal, internal) RETURNS internal
    AS '$libdir/tsearch2', 'gtsvector_penalty'
    LANGUAGE c STRICT;


--
-- TOC entry 399 (OID 1867380)
-- Name: gtsvector_picksplit(internal, internal); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION gtsvector_picksplit(internal, internal) RETURNS internal
    AS '$libdir/tsearch2', 'gtsvector_picksplit'
    LANGUAGE c;


--
-- TOC entry 400 (OID 1867381)
-- Name: gtsvector_union(bytea, internal); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION gtsvector_union(bytea, internal) RETURNS integer[]
    AS '$libdir/tsearch2', 'gtsvector_union'
    LANGUAGE c;


--
-- TOC entry 401 (OID 1867382)
-- Name: gtsvector_same(gtsvector, gtsvector, internal); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION gtsvector_same(gtsvector, gtsvector, internal) RETURNS internal
    AS '$libdir/tsearch2', 'gtsvector_same'
    LANGUAGE c;


--
-- TOC entry 556 (OID 1867383)
-- Name: gist_tsvector_ops; Type: OPERATOR CLASS; Schema: public; Owner: postgres
--

CREATE OPERATOR CLASS gist_tsvector_ops
    DEFAULT FOR TYPE tsvector USING gist AS
    STORAGE gtsvector ,
    OPERATOR 1 @@(tsvector,tsquery) RECHECK ,
    FUNCTION 1 gtsvector_consistent(gtsvector,internal,integer) ,
    FUNCTION 2 gtsvector_union(bytea,internal) ,
    FUNCTION 3 gtsvector_compress(internal) ,
    FUNCTION 4 gtsvector_decompress(internal) ,
    FUNCTION 5 gtsvector_penalty(internal,internal,internal) ,
    FUNCTION 6 gtsvector_picksplit(internal,internal) ,
    FUNCTION 7 gtsvector_same(gtsvector,gtsvector,internal);


--
-- TOC entry 27 (OID 1867385)
-- Name: statinfo; Type: TYPE; Schema: public; Owner: postgres
--

CREATE TYPE statinfo AS (
	word text,
	ndoc integer,
	nentry integer
);


--
-- TOC entry 402 (OID 1867386)
-- Name: stat(text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION stat(text) RETURNS SETOF statinfo
    AS '$libdir/tsearch2', 'ts_stat'
    LANGUAGE c STRICT;


--
-- TOC entry 403 (OID 1867387)
-- Name: reset_tsearch(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION reset_tsearch() RETURNS void
    AS '$libdir/tsearch2', 'reset_tsearch'
    LANGUAGE c STRICT;


--
-- TOC entry 404 (OID 1867388)
-- Name: get_covers(tsvector, tsquery); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION get_covers(tsvector, tsquery) RETURNS text
    AS '$libdir/tsearch2', 'get_covers'
    LANGUAGE c STRICT;


--
-- TOC entry 28 (OID 1867390)
-- Name: tsdebug; Type: TYPE; Schema: public; Owner: postgres
--

CREATE TYPE tsdebug AS (
	ts_name text,
	tok_type text,
	description text,
	token text,
	dict_name text[],
	tsvector tsvector
);


--
-- TOC entry 405 (OID 1867391)
-- Name: _get_parser_from_curcfg(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION _get_parser_from_curcfg() RETURNS text
    AS ' select prs_name from pg_ts_cfg where oid = show_curcfg() '
    LANGUAGE sql IMMUTABLE STRICT;


--
-- TOC entry 406 (OID 1867392)
-- Name: ts_debug(text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION ts_debug(text) RETURNS SETOF tsdebug
    AS '
select 
        m.ts_name,
        t.alias as tok_type,
        t.descr as description,
        p.token,
        m.dict_name,
        strip(to_tsvector(p.token)) as tsvector
from
        parse( _get_parser_from_curcfg(), $1 ) as p,
        token_type() as t,
        pg_ts_cfgmap as m,
        pg_ts_cfg as c
where
        t.tokid=p.tokid and
        t.alias = m.tok_alias and 
        m.ts_name=c.ts_name and 
        c.oid=show_curcfg() 
'
    LANGUAGE sql STRICT;


--
-- TOC entry 407 (OID 1867393)
-- Name: noup(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION noup() RETURNS "trigger"
    AS '$libdir/noup', 'noup'
    LANGUAGE c;


--
-- TOC entry 408 (OID 1867395)
-- Name: chkpass_in(cstring); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION chkpass_in(cstring) RETURNS chkpass
    AS '$libdir/chkpass', 'chkpass_in'
    LANGUAGE c;


--
-- TOC entry 409 (OID 1867396)
-- Name: chkpass_out(chkpass); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION chkpass_out(chkpass) RETURNS cstring
    AS '$libdir/chkpass', 'chkpass_out'
    LANGUAGE c;


--
-- TOC entry 29 (OID 1867394)
-- Name: chkpass; Type: TYPE; Schema: public; Owner: postgres
--

CREATE TYPE chkpass (
    INTERNALLENGTH = 16,
    INPUT = chkpass_in,
    OUTPUT = chkpass_out,
    ALIGNMENT = int4,
    STORAGE = plain
);


--
-- TOC entry 410 (OID 1867398)
-- Name: raw(chkpass); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION raw(chkpass) RETURNS text
    AS '$libdir/chkpass', 'chkpass_rout'
    LANGUAGE c;


--
-- TOC entry 411 (OID 1867399)
-- Name: eq(chkpass, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION eq(chkpass, text) RETURNS boolean
    AS '$libdir/chkpass', 'chkpass_eq'
    LANGUAGE c;


--
-- TOC entry 412 (OID 1867400)
-- Name: ne(chkpass, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION ne(chkpass, text) RETURNS boolean
    AS '$libdir/chkpass', 'chkpass_ne'
    LANGUAGE c;


--
-- TOC entry 516 (OID 1867402)
-- Name: =; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR = (
    PROCEDURE = eq,
    LEFTARG = chkpass,
    RIGHTARG = text,
    COMMUTATOR = =,
    NEGATOR = <>
);


--
-- TOC entry 515 (OID 1867403)
-- Name: <>; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR <> (
    PROCEDURE = ne,
    LEFTARG = chkpass,
    RIGHTARG = text,
    NEGATOR = =
);


--
-- TOC entry 413 (OID 1867405)
-- Name: ltree_in(cstring); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION ltree_in(cstring) RETURNS ltree
    AS '$libdir/ltree', 'ltree_in'
    LANGUAGE c STRICT;


--
-- TOC entry 414 (OID 1867406)
-- Name: ltree_out(ltree); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION ltree_out(ltree) RETURNS cstring
    AS '$libdir/ltree', 'ltree_out'
    LANGUAGE c STRICT;


--
-- TOC entry 31 (OID 1867404)
-- Name: ltree; Type: TYPE; Schema: public; Owner: postgres
--

CREATE TYPE ltree (
    INTERNALLENGTH = variable,
    INPUT = ltree_in,
    OUTPUT = ltree_out,
    ALIGNMENT = int4,
    STORAGE = extended
);


--
-- TOC entry 415 (OID 1867408)
-- Name: ltree_cmp(ltree, ltree); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION ltree_cmp(ltree, ltree) RETURNS integer
    AS '$libdir/ltree', 'ltree_cmp'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 416 (OID 1867409)
-- Name: ltree_lt(ltree, ltree); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION ltree_lt(ltree, ltree) RETURNS boolean
    AS '$libdir/ltree', 'ltree_lt'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 417 (OID 1867410)
-- Name: ltree_le(ltree, ltree); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION ltree_le(ltree, ltree) RETURNS boolean
    AS '$libdir/ltree', 'ltree_le'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 418 (OID 1867411)
-- Name: ltree_eq(ltree, ltree); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION ltree_eq(ltree, ltree) RETURNS boolean
    AS '$libdir/ltree', 'ltree_eq'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 419 (OID 1867412)
-- Name: ltree_ge(ltree, ltree); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION ltree_ge(ltree, ltree) RETURNS boolean
    AS '$libdir/ltree', 'ltree_ge'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 420 (OID 1867413)
-- Name: ltree_gt(ltree, ltree); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION ltree_gt(ltree, ltree) RETURNS boolean
    AS '$libdir/ltree', 'ltree_gt'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 421 (OID 1867414)
-- Name: ltree_ne(ltree, ltree); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION ltree_ne(ltree, ltree) RETURNS boolean
    AS '$libdir/ltree', 'ltree_ne'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 526 (OID 1867415)
-- Name: >; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR > (
    PROCEDURE = ltree_gt,
    LEFTARG = ltree,
    RIGHTARG = ltree,
    COMMUTATOR = <,
    NEGATOR = <=,
    RESTRICT = contsel,
    JOIN = contjoinsel
);


--
-- TOC entry 525 (OID 1867416)
-- Name: >=; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR >= (
    PROCEDURE = ltree_ge,
    LEFTARG = ltree,
    RIGHTARG = ltree,
    COMMUTATOR = <=,
    NEGATOR = <,
    RESTRICT = contsel,
    JOIN = contjoinsel
);


--
-- TOC entry 519 (OID 1867417)
-- Name: <; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR < (
    PROCEDURE = ltree_lt,
    LEFTARG = ltree,
    RIGHTARG = ltree,
    COMMUTATOR = >,
    NEGATOR = >=,
    RESTRICT = contsel,
    JOIN = contjoinsel
);


--
-- TOC entry 522 (OID 1867418)
-- Name: <=; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR <= (
    PROCEDURE = ltree_le,
    LEFTARG = ltree,
    RIGHTARG = ltree,
    COMMUTATOR = >=,
    NEGATOR = >,
    RESTRICT = contsel,
    JOIN = contjoinsel
);


--
-- TOC entry 531 (OID 1867419)
-- Name: <>; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR <> (
    PROCEDURE = ltree_ne,
    LEFTARG = ltree,
    RIGHTARG = ltree,
    COMMUTATOR = <>,
    NEGATOR = =,
    RESTRICT = neqsel,
    JOIN = neqjoinsel
);


--
-- TOC entry 529 (OID 1867420)
-- Name: =; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR = (
    PROCEDURE = ltree_eq,
    LEFTARG = ltree,
    RIGHTARG = ltree,
    COMMUTATOR = =,
    NEGATOR = <>,
    RESTRICT = eqsel,
    JOIN = eqjoinsel,
    SORT1 = <,
    SORT2 = <,
    LTCMP = <,
    GTCMP = >
);


--
-- TOC entry 422 (OID 1867421)
-- Name: subltree(ltree, integer, integer); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION subltree(ltree, integer, integer) RETURNS ltree
    AS '$libdir/ltree', 'subltree'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 423 (OID 1867422)
-- Name: subpath(ltree, integer, integer); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION subpath(ltree, integer, integer) RETURNS ltree
    AS '$libdir/ltree', 'subpath'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 424 (OID 1867423)
-- Name: subpath(ltree, integer); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION subpath(ltree, integer) RETURNS ltree
    AS '$libdir/ltree', 'subpath'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 425 (OID 1867424)
-- Name: index(ltree, ltree); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION "index"(ltree, ltree) RETURNS integer
    AS '$libdir/ltree', 'ltree_index'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 426 (OID 1867425)
-- Name: index(ltree, ltree, integer); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION "index"(ltree, ltree, integer) RETURNS integer
    AS '$libdir/ltree', 'ltree_index'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 427 (OID 1867426)
-- Name: nlevel(ltree); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION nlevel(ltree) RETURNS integer
    AS '$libdir/ltree', 'nlevel'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 428 (OID 1867427)
-- Name: ltree2text(ltree); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION ltree2text(ltree) RETURNS text
    AS '$libdir/ltree', 'ltree2text'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 429 (OID 1867428)
-- Name: text2ltree(text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION text2ltree(text) RETURNS ltree
    AS '$libdir/ltree', 'text2ltree'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 430 (OID 1867429)
-- Name: lca(ltree[]); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION lca(ltree[]) RETURNS ltree
    AS '$libdir/ltree', '_lca'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 431 (OID 1867430)
-- Name: lca(ltree, ltree); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION lca(ltree, ltree) RETURNS ltree
    AS '$libdir/ltree', 'lca'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 432 (OID 1867431)
-- Name: lca(ltree, ltree, ltree); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION lca(ltree, ltree, ltree) RETURNS ltree
    AS '$libdir/ltree', 'lca'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 433 (OID 1867432)
-- Name: lca(ltree, ltree, ltree, ltree); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION lca(ltree, ltree, ltree, ltree) RETURNS ltree
    AS '$libdir/ltree', 'lca'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 434 (OID 1867433)
-- Name: lca(ltree, ltree, ltree, ltree, ltree); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION lca(ltree, ltree, ltree, ltree, ltree) RETURNS ltree
    AS '$libdir/ltree', 'lca'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 435 (OID 1867434)
-- Name: lca(ltree, ltree, ltree, ltree, ltree, ltree); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION lca(ltree, ltree, ltree, ltree, ltree, ltree) RETURNS ltree
    AS '$libdir/ltree', 'lca'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 436 (OID 1867435)
-- Name: lca(ltree, ltree, ltree, ltree, ltree, ltree, ltree); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION lca(ltree, ltree, ltree, ltree, ltree, ltree, ltree) RETURNS ltree
    AS '$libdir/ltree', 'lca'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 437 (OID 1867436)
-- Name: lca(ltree, ltree, ltree, ltree, ltree, ltree, ltree, ltree); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION lca(ltree, ltree, ltree, ltree, ltree, ltree, ltree, ltree) RETURNS ltree
    AS '$libdir/ltree', 'lca'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 438 (OID 1867437)
-- Name: ltree_isparent(ltree, ltree); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION ltree_isparent(ltree, ltree) RETURNS boolean
    AS '$libdir/ltree', 'ltree_isparent'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 439 (OID 1867438)
-- Name: ltree_risparent(ltree, ltree); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION ltree_risparent(ltree, ltree) RETURNS boolean
    AS '$libdir/ltree', 'ltree_risparent'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 440 (OID 1867439)
-- Name: ltree_addltree(ltree, ltree); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION ltree_addltree(ltree, ltree) RETURNS ltree
    AS '$libdir/ltree', 'ltree_addltree'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 441 (OID 1867440)
-- Name: ltree_addtext(ltree, text); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION ltree_addtext(ltree, text) RETURNS ltree
    AS '$libdir/ltree', 'ltree_addtext'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 442 (OID 1867441)
-- Name: ltree_textadd(text, ltree); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION ltree_textadd(text, ltree) RETURNS ltree
    AS '$libdir/ltree', 'ltree_textadd'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 538 (OID 1867442)
-- Name: <@; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR <@ (
    PROCEDURE = ltree_risparent,
    LEFTARG = ltree,
    RIGHTARG = ltree,
    COMMUTATOR = @>,
    RESTRICT = contsel,
    JOIN = contjoinsel
);


--
-- TOC entry 533 (OID 1867443)
-- Name: @>; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR @> (
    PROCEDURE = ltree_isparent,
    LEFTARG = ltree,
    RIGHTARG = ltree,
    COMMUTATOR = <@,
    RESTRICT = contsel,
    JOIN = contjoinsel
);


--
-- TOC entry 539 (OID 1867444)
-- Name: ^<@; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR ^<@ (
    PROCEDURE = ltree_risparent,
    LEFTARG = ltree,
    RIGHTARG = ltree,
    COMMUTATOR = ^@>,
    RESTRICT = contsel,
    JOIN = contjoinsel
);


--
-- TOC entry 536 (OID 1867445)
-- Name: ^@>; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR ^@> (
    PROCEDURE = ltree_isparent,
    LEFTARG = ltree,
    RIGHTARG = ltree,
    COMMUTATOR = ^<@,
    RESTRICT = contsel,
    JOIN = contjoinsel
);


--
-- TOC entry 540 (OID 1867446)
-- Name: ||; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR || (
    PROCEDURE = ltree_addltree,
    LEFTARG = ltree,
    RIGHTARG = ltree
);


--
-- TOC entry 541 (OID 1867447)
-- Name: ||; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR || (
    PROCEDURE = ltree_addtext,
    LEFTARG = ltree,
    RIGHTARG = text
);


--
-- TOC entry 542 (OID 1867448)
-- Name: ||; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR || (
    PROCEDURE = ltree_textadd,
    LEFTARG = text,
    RIGHTARG = ltree
);


--
-- TOC entry 557 (OID 1867449)
-- Name: ltree_ops; Type: OPERATOR CLASS; Schema: public; Owner: postgres
--

CREATE OPERATOR CLASS ltree_ops
    DEFAULT FOR TYPE ltree USING btree AS
    OPERATOR 1 <(ltree,ltree) ,
    OPERATOR 2 <=(ltree,ltree) ,
    OPERATOR 3 =(ltree,ltree) ,
    OPERATOR 4 >=(ltree,ltree) ,
    OPERATOR 5 >(ltree,ltree) ,
    FUNCTION 1 ltree_cmp(ltree,ltree);


--
-- TOC entry 443 (OID 1867451)
-- Name: lquery_in(cstring); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION lquery_in(cstring) RETURNS lquery
    AS '$libdir/ltree', 'lquery_in'
    LANGUAGE c STRICT;


--
-- TOC entry 444 (OID 1867452)
-- Name: lquery_out(lquery); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION lquery_out(lquery) RETURNS cstring
    AS '$libdir/ltree', 'lquery_out'
    LANGUAGE c STRICT;


--
-- TOC entry 32 (OID 1867450)
-- Name: lquery; Type: TYPE; Schema: public; Owner: postgres
--

CREATE TYPE lquery (
    INTERNALLENGTH = variable,
    INPUT = lquery_in,
    OUTPUT = lquery_out,
    ALIGNMENT = int4,
    STORAGE = extended
);


--
-- TOC entry 445 (OID 1867454)
-- Name: ltq_regex(ltree, lquery); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION ltq_regex(ltree, lquery) RETURNS boolean
    AS '$libdir/ltree', 'ltq_regex'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 446 (OID 1867455)
-- Name: ltq_rregex(lquery, ltree); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION ltq_rregex(lquery, ltree) RETURNS boolean
    AS '$libdir/ltree', 'ltq_rregex'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 546 (OID 1867456)
-- Name: ~; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR ~ (
    PROCEDURE = ltq_rregex,
    LEFTARG = lquery,
    RIGHTARG = ltree,
    COMMUTATOR = ~,
    RESTRICT = contsel,
    JOIN = contjoinsel
);


--
-- TOC entry 544 (OID 1867457)
-- Name: ~; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR ~ (
    PROCEDURE = ltq_regex,
    LEFTARG = ltree,
    RIGHTARG = lquery,
    COMMUTATOR = ~,
    RESTRICT = contsel,
    JOIN = contjoinsel
);


--
-- TOC entry 549 (OID 1867458)
-- Name: ^~; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR ^~ (
    PROCEDURE = ltq_rregex,
    LEFTARG = lquery,
    RIGHTARG = ltree,
    COMMUTATOR = ^~,
    RESTRICT = contsel,
    JOIN = contjoinsel
);


--
-- TOC entry 548 (OID 1867459)
-- Name: ^~; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR ^~ (
    PROCEDURE = ltq_regex,
    LEFTARG = ltree,
    RIGHTARG = lquery,
    COMMUTATOR = ^~,
    RESTRICT = contsel,
    JOIN = contjoinsel
);


--
-- TOC entry 447 (OID 1867460)
-- Name: lt_q_regex(ltree, lquery[]); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION lt_q_regex(ltree, lquery[]) RETURNS boolean
    AS '$libdir/ltree', 'lt_q_regex'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 448 (OID 1867461)
-- Name: lt_q_rregex(lquery[], ltree); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION lt_q_rregex(lquery[], ltree) RETURNS boolean
    AS '$libdir/ltree', 'lt_q_rregex'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 551 (OID 1867462)
-- Name: ?; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR ? (
    PROCEDURE = lt_q_rregex,
    LEFTARG = lquery[],
    RIGHTARG = ltree,
    COMMUTATOR = ?,
    RESTRICT = contsel,
    JOIN = contjoinsel
);


--
-- TOC entry 550 (OID 1867463)
-- Name: ?; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR ? (
    PROCEDURE = lt_q_regex,
    LEFTARG = ltree,
    RIGHTARG = lquery[],
    COMMUTATOR = ?,
    RESTRICT = contsel,
    JOIN = contjoinsel
);


--
-- TOC entry 553 (OID 1867464)
-- Name: ^?; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR ^? (
    PROCEDURE = lt_q_rregex,
    LEFTARG = lquery[],
    RIGHTARG = ltree,
    COMMUTATOR = ^?,
    RESTRICT = contsel,
    JOIN = contjoinsel
);


--
-- TOC entry 552 (OID 1867465)
-- Name: ^?; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR ^? (
    PROCEDURE = lt_q_regex,
    LEFTARG = ltree,
    RIGHTARG = lquery[],
    COMMUTATOR = ^?,
    RESTRICT = contsel,
    JOIN = contjoinsel
);


--
-- TOC entry 449 (OID 1867467)
-- Name: ltxtq_in(cstring); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION ltxtq_in(cstring) RETURNS ltxtquery
    AS '$libdir/ltree', 'ltxtq_in'
    LANGUAGE c STRICT;


--
-- TOC entry 450 (OID 1867468)
-- Name: ltxtq_out(ltxtquery); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION ltxtq_out(ltxtquery) RETURNS cstring
    AS '$libdir/ltree', 'ltxtq_out'
    LANGUAGE c STRICT;


--
-- TOC entry 33 (OID 1867466)
-- Name: ltxtquery; Type: TYPE; Schema: public; Owner: postgres
--

CREATE TYPE ltxtquery (
    INTERNALLENGTH = variable,
    INPUT = ltxtq_in,
    OUTPUT = ltxtq_out,
    ALIGNMENT = int4,
    STORAGE = extended
);


--
-- TOC entry 451 (OID 1867470)
-- Name: ltxtq_exec(ltree, ltxtquery); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION ltxtq_exec(ltree, ltxtquery) RETURNS boolean
    AS '$libdir/ltree', 'ltxtq_exec'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 452 (OID 1867471)
-- Name: ltxtq_rexec(ltxtquery, ltree); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION ltxtq_rexec(ltxtquery, ltree) RETURNS boolean
    AS '$libdir/ltree', 'ltxtq_rexec'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 489 (OID 1867472)
-- Name: @; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR @ (
    PROCEDURE = ltxtq_rexec,
    LEFTARG = ltxtquery,
    RIGHTARG = ltree,
    COMMUTATOR = @,
    RESTRICT = contsel,
    JOIN = contjoinsel
);


--
-- TOC entry 488 (OID 1867473)
-- Name: @; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR @ (
    PROCEDURE = ltxtq_exec,
    LEFTARG = ltree,
    RIGHTARG = ltxtquery,
    COMMUTATOR = @,
    RESTRICT = contsel,
    JOIN = contjoinsel
);


--
-- TOC entry 491 (OID 1867474)
-- Name: ^@; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR ^@ (
    PROCEDURE = ltxtq_rexec,
    LEFTARG = ltxtquery,
    RIGHTARG = ltree,
    COMMUTATOR = ^@,
    RESTRICT = contsel,
    JOIN = contjoinsel
);


--
-- TOC entry 490 (OID 1867475)
-- Name: ^@; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR ^@ (
    PROCEDURE = ltxtq_exec,
    LEFTARG = ltree,
    RIGHTARG = ltxtquery,
    COMMUTATOR = ^@,
    RESTRICT = contsel,
    JOIN = contjoinsel
);


--
-- TOC entry 453 (OID 1867477)
-- Name: ltree_gist_in(cstring); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION ltree_gist_in(cstring) RETURNS ltree_gist
    AS '$libdir/ltree', 'ltree_gist_in'
    LANGUAGE c STRICT;


--
-- TOC entry 454 (OID 1867478)
-- Name: ltree_gist_out(ltree_gist); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION ltree_gist_out(ltree_gist) RETURNS cstring
    AS '$libdir/ltree', 'ltree_gist_out'
    LANGUAGE c STRICT;


--
-- TOC entry 34 (OID 1867476)
-- Name: ltree_gist; Type: TYPE; Schema: public; Owner: postgres
--

CREATE TYPE ltree_gist (
    INTERNALLENGTH = variable,
    INPUT = ltree_gist_in,
    OUTPUT = ltree_gist_out,
    ALIGNMENT = int4,
    STORAGE = plain
);


--
-- TOC entry 455 (OID 1867480)
-- Name: ltree_consistent(internal, internal, smallint); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION ltree_consistent(internal, internal, smallint) RETURNS boolean
    AS '$libdir/ltree', 'ltree_consistent'
    LANGUAGE c;


--
-- TOC entry 456 (OID 1867481)
-- Name: ltree_compress(internal); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION ltree_compress(internal) RETURNS internal
    AS '$libdir/ltree', 'ltree_compress'
    LANGUAGE c;


--
-- TOC entry 457 (OID 1867482)
-- Name: ltree_decompress(internal); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION ltree_decompress(internal) RETURNS internal
    AS '$libdir/ltree', 'ltree_decompress'
    LANGUAGE c;


--
-- TOC entry 458 (OID 1867483)
-- Name: ltree_penalty(internal, internal, internal); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION ltree_penalty(internal, internal, internal) RETURNS internal
    AS '$libdir/ltree', 'ltree_penalty'
    LANGUAGE c STRICT;


--
-- TOC entry 459 (OID 1867484)
-- Name: ltree_picksplit(internal, internal); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION ltree_picksplit(internal, internal) RETURNS internal
    AS '$libdir/ltree', 'ltree_picksplit'
    LANGUAGE c;


--
-- TOC entry 460 (OID 1867485)
-- Name: ltree_union(bytea, internal); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION ltree_union(bytea, internal) RETURNS integer
    AS '$libdir/ltree', 'ltree_union'
    LANGUAGE c;


--
-- TOC entry 461 (OID 1867486)
-- Name: ltree_same(internal, internal, internal); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION ltree_same(internal, internal, internal) RETURNS internal
    AS '$libdir/ltree', 'ltree_same'
    LANGUAGE c;


--
-- TOC entry 558 (OID 1867487)
-- Name: gist_ltree_ops; Type: OPERATOR CLASS; Schema: public; Owner: postgres
--

CREATE OPERATOR CLASS gist_ltree_ops
    DEFAULT FOR TYPE ltree USING gist AS
    STORAGE ltree_gist ,
    OPERATOR 1 <(ltree,ltree) ,
    OPERATOR 2 <=(ltree,ltree) ,
    OPERATOR 3 =(ltree,ltree) ,
    OPERATOR 4 >=(ltree,ltree) ,
    OPERATOR 5 >(ltree,ltree) ,
    OPERATOR 10 @>(ltree,ltree) ,
    OPERATOR 11 <@(ltree,ltree) ,
    OPERATOR 12 ~(ltree,lquery) ,
    OPERATOR 13 ~(lquery,ltree) ,
    OPERATOR 14 @(ltree,ltxtquery) ,
    OPERATOR 15 @(ltxtquery,ltree) ,
    OPERATOR 16 ?(ltree,lquery[]) ,
    OPERATOR 17 ?(lquery[],ltree) ,
    FUNCTION 1 ltree_consistent(internal,internal,smallint) ,
    FUNCTION 2 ltree_union(bytea,internal) ,
    FUNCTION 3 ltree_compress(internal) ,
    FUNCTION 4 ltree_decompress(internal) ,
    FUNCTION 5 ltree_penalty(internal,internal,internal) ,
    FUNCTION 6 ltree_picksplit(internal,internal) ,
    FUNCTION 7 ltree_same(internal,internal,internal);


--
-- TOC entry 462 (OID 1867488)
-- Name: _ltree_isparent(ltree[], ltree); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION _ltree_isparent(ltree[], ltree) RETURNS boolean
    AS '$libdir/ltree', '_ltree_isparent'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 463 (OID 1867489)
-- Name: _ltree_r_isparent(ltree, ltree[]); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION _ltree_r_isparent(ltree, ltree[]) RETURNS boolean
    AS '$libdir/ltree', '_ltree_r_isparent'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 464 (OID 1867490)
-- Name: _ltree_risparent(ltree[], ltree); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION _ltree_risparent(ltree[], ltree) RETURNS boolean
    AS '$libdir/ltree', '_ltree_risparent'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 465 (OID 1867491)
-- Name: _ltree_r_risparent(ltree, ltree[]); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION _ltree_r_risparent(ltree, ltree[]) RETURNS boolean
    AS '$libdir/ltree', '_ltree_r_risparent'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 466 (OID 1867492)
-- Name: _ltq_regex(ltree[], lquery); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION _ltq_regex(ltree[], lquery) RETURNS boolean
    AS '$libdir/ltree', '_ltq_regex'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 467 (OID 1867493)
-- Name: _ltq_rregex(lquery, ltree[]); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION _ltq_rregex(lquery, ltree[]) RETURNS boolean
    AS '$libdir/ltree', '_ltq_rregex'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 468 (OID 1867494)
-- Name: _lt_q_regex(ltree[], lquery[]); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION _lt_q_regex(ltree[], lquery[]) RETURNS boolean
    AS '$libdir/ltree', '_lt_q_regex'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 469 (OID 1867495)
-- Name: _lt_q_rregex(lquery[], ltree[]); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION _lt_q_rregex(lquery[], ltree[]) RETURNS boolean
    AS '$libdir/ltree', '_lt_q_rregex'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 470 (OID 1867496)
-- Name: _ltxtq_exec(ltree[], ltxtquery); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION _ltxtq_exec(ltree[], ltxtquery) RETURNS boolean
    AS '$libdir/ltree', '_ltxtq_exec'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 471 (OID 1867497)
-- Name: _ltxtq_rexec(ltxtquery, ltree[]); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION _ltxtq_rexec(ltxtquery, ltree[]) RETURNS boolean
    AS '$libdir/ltree', '_ltxtq_rexec'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 499 (OID 1867498)
-- Name: <@; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR <@ (
    PROCEDURE = _ltree_r_isparent,
    LEFTARG = ltree,
    RIGHTARG = ltree[],
    COMMUTATOR = @>,
    RESTRICT = contsel,
    JOIN = contjoinsel
);


--
-- TOC entry 498 (OID 1867499)
-- Name: @>; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR @> (
    PROCEDURE = _ltree_isparent,
    LEFTARG = ltree[],
    RIGHTARG = ltree,
    COMMUTATOR = <@,
    RESTRICT = contsel,
    JOIN = contjoinsel
);


--
-- TOC entry 501 (OID 1867500)
-- Name: @>; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR @> (
    PROCEDURE = _ltree_r_risparent,
    LEFTARG = ltree,
    RIGHTARG = ltree[],
    COMMUTATOR = <@,
    RESTRICT = contsel,
    JOIN = contjoinsel
);


--
-- TOC entry 500 (OID 1867501)
-- Name: <@; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR <@ (
    PROCEDURE = _ltree_risparent,
    LEFTARG = ltree[],
    RIGHTARG = ltree,
    COMMUTATOR = @>,
    RESTRICT = contsel,
    JOIN = contjoinsel
);


--
-- TOC entry 511 (OID 1867502)
-- Name: ~; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR ~ (
    PROCEDURE = _ltq_rregex,
    LEFTARG = lquery,
    RIGHTARG = ltree[],
    COMMUTATOR = ~,
    RESTRICT = contsel,
    JOIN = contjoinsel
);


--
-- TOC entry 509 (OID 1867503)
-- Name: ~; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR ~ (
    PROCEDURE = _ltq_regex,
    LEFTARG = ltree[],
    RIGHTARG = lquery,
    COMMUTATOR = ~,
    RESTRICT = contsel,
    JOIN = contjoinsel
);


--
-- TOC entry 514 (OID 1867504)
-- Name: ?; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR ? (
    PROCEDURE = _lt_q_rregex,
    LEFTARG = lquery[],
    RIGHTARG = ltree[],
    COMMUTATOR = ?,
    RESTRICT = contsel,
    JOIN = contjoinsel
);


--
-- TOC entry 513 (OID 1867505)
-- Name: ?; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR ? (
    PROCEDURE = _lt_q_regex,
    LEFTARG = ltree[],
    RIGHTARG = lquery[],
    COMMUTATOR = ?,
    RESTRICT = contsel,
    JOIN = contjoinsel
);


--
-- TOC entry 518 (OID 1867506)
-- Name: @; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR @ (
    PROCEDURE = _ltxtq_rexec,
    LEFTARG = ltxtquery,
    RIGHTARG = ltree[],
    COMMUTATOR = @,
    RESTRICT = contsel,
    JOIN = contjoinsel
);


--
-- TOC entry 517 (OID 1867507)
-- Name: @; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR @ (
    PROCEDURE = _ltxtq_exec,
    LEFTARG = ltree[],
    RIGHTARG = ltxtquery,
    COMMUTATOR = @,
    RESTRICT = contsel,
    JOIN = contjoinsel
);


--
-- TOC entry 521 (OID 1867508)
-- Name: ^<@; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR ^<@ (
    PROCEDURE = _ltree_r_isparent,
    LEFTARG = ltree,
    RIGHTARG = ltree[],
    COMMUTATOR = ^@>,
    RESTRICT = contsel,
    JOIN = contjoinsel
);


--
-- TOC entry 520 (OID 1867509)
-- Name: ^@>; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR ^@> (
    PROCEDURE = _ltree_isparent,
    LEFTARG = ltree[],
    RIGHTARG = ltree,
    COMMUTATOR = ^<@,
    RESTRICT = contsel,
    JOIN = contjoinsel
);


--
-- TOC entry 524 (OID 1867510)
-- Name: ^@>; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR ^@> (
    PROCEDURE = _ltree_r_risparent,
    LEFTARG = ltree,
    RIGHTARG = ltree[],
    COMMUTATOR = ^<@,
    RESTRICT = contsel,
    JOIN = contjoinsel
);


--
-- TOC entry 523 (OID 1867511)
-- Name: ^<@; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR ^<@ (
    PROCEDURE = _ltree_risparent,
    LEFTARG = ltree[],
    RIGHTARG = ltree,
    COMMUTATOR = ^@>,
    RESTRICT = contsel,
    JOIN = contjoinsel
);


--
-- TOC entry 528 (OID 1867512)
-- Name: ^~; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR ^~ (
    PROCEDURE = _ltq_rregex,
    LEFTARG = lquery,
    RIGHTARG = ltree[],
    COMMUTATOR = ^~,
    RESTRICT = contsel,
    JOIN = contjoinsel
);


--
-- TOC entry 527 (OID 1867513)
-- Name: ^~; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR ^~ (
    PROCEDURE = _ltq_regex,
    LEFTARG = ltree[],
    RIGHTARG = lquery,
    COMMUTATOR = ^~,
    RESTRICT = contsel,
    JOIN = contjoinsel
);


--
-- TOC entry 532 (OID 1867514)
-- Name: ^?; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR ^? (
    PROCEDURE = _lt_q_rregex,
    LEFTARG = lquery[],
    RIGHTARG = ltree[],
    COMMUTATOR = ^?,
    RESTRICT = contsel,
    JOIN = contjoinsel
);


--
-- TOC entry 530 (OID 1867515)
-- Name: ^?; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR ^? (
    PROCEDURE = _lt_q_regex,
    LEFTARG = ltree[],
    RIGHTARG = lquery[],
    COMMUTATOR = ^?,
    RESTRICT = contsel,
    JOIN = contjoinsel
);


--
-- TOC entry 535 (OID 1867516)
-- Name: ^@; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR ^@ (
    PROCEDURE = _ltxtq_rexec,
    LEFTARG = ltxtquery,
    RIGHTARG = ltree[],
    COMMUTATOR = ^@,
    RESTRICT = contsel,
    JOIN = contjoinsel
);


--
-- TOC entry 534 (OID 1867517)
-- Name: ^@; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR ^@ (
    PROCEDURE = _ltxtq_exec,
    LEFTARG = ltree[],
    RIGHTARG = ltxtquery,
    COMMUTATOR = ^@,
    RESTRICT = contsel,
    JOIN = contjoinsel
);


--
-- TOC entry 472 (OID 1867518)
-- Name: _ltree_extract_isparent(ltree[], ltree); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION _ltree_extract_isparent(ltree[], ltree) RETURNS ltree
    AS '$libdir/ltree', '_ltree_extract_isparent'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 537 (OID 1867519)
-- Name: ?@>; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR ?@> (
    PROCEDURE = _ltree_extract_isparent,
    LEFTARG = ltree[],
    RIGHTARG = ltree
);


--
-- TOC entry 473 (OID 1867520)
-- Name: _ltree_extract_risparent(ltree[], ltree); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION _ltree_extract_risparent(ltree[], ltree) RETURNS ltree
    AS '$libdir/ltree', '_ltree_extract_risparent'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 543 (OID 1867521)
-- Name: ?<@; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR ?<@ (
    PROCEDURE = _ltree_extract_risparent,
    LEFTARG = ltree[],
    RIGHTARG = ltree
);


--
-- TOC entry 474 (OID 1867522)
-- Name: _ltq_extract_regex(ltree[], lquery); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION _ltq_extract_regex(ltree[], lquery) RETURNS ltree
    AS '$libdir/ltree', '_ltq_extract_regex'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 545 (OID 1867523)
-- Name: ?~; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR ?~ (
    PROCEDURE = _ltq_extract_regex,
    LEFTARG = ltree[],
    RIGHTARG = lquery
);


--
-- TOC entry 475 (OID 1867524)
-- Name: _ltxtq_extract_exec(ltree[], ltxtquery); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION _ltxtq_extract_exec(ltree[], ltxtquery) RETURNS ltree
    AS '$libdir/ltree', '_ltxtq_extract_exec'
    LANGUAGE c IMMUTABLE STRICT;


--
-- TOC entry 547 (OID 1867525)
-- Name: ?@; Type: OPERATOR; Schema: public; Owner: postgres
--

CREATE OPERATOR ?@ (
    PROCEDURE = _ltxtq_extract_exec,
    LEFTARG = ltree[],
    RIGHTARG = ltxtquery
);


--
-- TOC entry 476 (OID 1867526)
-- Name: _ltree_consistent(internal, internal, smallint); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION _ltree_consistent(internal, internal, smallint) RETURNS boolean
    AS '$libdir/ltree', '_ltree_consistent'
    LANGUAGE c;


--
-- TOC entry 477 (OID 1867527)
-- Name: _ltree_compress(internal); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION _ltree_compress(internal) RETURNS internal
    AS '$libdir/ltree', '_ltree_compress'
    LANGUAGE c;


--
-- TOC entry 478 (OID 1867528)
-- Name: _ltree_penalty(internal, internal, internal); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION _ltree_penalty(internal, internal, internal) RETURNS internal
    AS '$libdir/ltree', '_ltree_penalty'
    LANGUAGE c STRICT;


--
-- TOC entry 479 (OID 1867529)
-- Name: _ltree_picksplit(internal, internal); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION _ltree_picksplit(internal, internal) RETURNS internal
    AS '$libdir/ltree', '_ltree_picksplit'
    LANGUAGE c;


--
-- TOC entry 480 (OID 1867530)
-- Name: _ltree_union(bytea, internal); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION _ltree_union(bytea, internal) RETURNS integer
    AS '$libdir/ltree', '_ltree_union'
    LANGUAGE c;


--
-- TOC entry 481 (OID 1867531)
-- Name: _ltree_same(internal, internal, internal); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION _ltree_same(internal, internal, internal) RETURNS internal
    AS '$libdir/ltree', '_ltree_same'
    LANGUAGE c;


--
-- TOC entry 559 (OID 1867532)
-- Name: gist__ltree_ops; Type: OPERATOR CLASS; Schema: public; Owner: postgres
--

CREATE OPERATOR CLASS gist__ltree_ops
    DEFAULT FOR TYPE ltree[] USING gist AS
    STORAGE ltree_gist ,
    OPERATOR 10 <@(ltree[],ltree) RECHECK ,
    OPERATOR 11 @>(ltree,ltree[]) RECHECK ,
    OPERATOR 12 ~(ltree[],lquery) RECHECK ,
    OPERATOR 13 ~(lquery,ltree[]) RECHECK ,
    OPERATOR 14 @(ltree[],ltxtquery) RECHECK ,
    OPERATOR 15 @(ltxtquery,ltree[]) RECHECK ,
    OPERATOR 16 ?(ltree[],lquery[]) RECHECK ,
    OPERATOR 17 ?(lquery[],ltree[]) RECHECK ,
    FUNCTION 1 _ltree_consistent(internal,internal,smallint) ,
    FUNCTION 2 _ltree_union(bytea,internal) ,
    FUNCTION 3 _ltree_compress(internal) ,
    FUNCTION 4 ltree_decompress(internal) ,
    FUNCTION 5 _ltree_penalty(internal,internal,internal) ,
    FUNCTION 6 _ltree_picksplit(internal,internal) ,
    FUNCTION 7 _ltree_same(internal,internal,internal);


--
-- TOC entry 63 (OID 1867535)
-- Name: dual; Type: VIEW; Schema: public; Owner: postgres
--

CREATE VIEW dual AS
    SELECT 1 AS dummy, now() AS sysdate;


--
-- TOC entry 65 (OID 1867535)
-- Name: dual; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE dual FROM PUBLIC;
GRANT SELECT ON TABLE dual TO guest;
GRANT SELECT ON TABLE dual TO PUBLIC;


--
-- TOC entry 66 (OID 1868573)
-- Name: whoami; Type: VIEW; Schema: public; Owner: postgres
--

CREATE VIEW whoami AS
    SELECT "current_user"() AS "current_user", current_schema() AS current_schema, current_schemas(true) AS current_schemas;


--
-- TOC entry 67 (OID 1868573)
-- Name: whoami; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE whoami FROM PUBLIC;
GRANT SELECT ON TABLE whoami TO guest;
GRANT SELECT ON TABLE whoami TO PUBLIC;


--
-- TOC entry 8 (OID 1912342)
-- Name: color; Type: DOMAIN; Schema: public; Owner: postgres
--

CREATE DOMAIN color AS name
	CONSTRAINT enum_values CHECK (((((VALUE = 'red'::name) OR (VALUE = 'blue'::name)) OR (VALUE = 'green'::name)) OR (VALUE = 'white'::name)));


--
-- TOC entry 9 (OID 1912360)
-- Name: shell; Type: DOMAIN; Schema: public; Owner: postgres
--

CREATE DOMAIN shell AS name;


--
-- TOC entry 37 (OID 1923125)
-- Name: textarea; Type: DOMAIN; Schema: public; Owner: postgres
--

CREATE DOMAIN textarea AS text;


--
-- TOC entry 43 (OID 1925012)
-- Name: id_seq; Type: SEQUENCE; Schema: public; Owner: postgres
--

CREATE SEQUENCE id_seq
    INCREMENT BY 1
    NO MAXVALUE
    NO MINVALUE
    CACHE 1;


--
-- TOC entry 45 (OID 1925012)
-- Name: id_seq; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE id_seq FROM PUBLIC;
GRANT SELECT ON TABLE id_seq TO PUBLIC;
GRANT SELECT,UPDATE ON TABLE id_seq TO GROUP mime;


--
-- TOC entry 483 (OID 1925682)
-- Name: links_constuct(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION links_constuct() RETURNS "trigger"
    AS 'BEGIN 
 IF NEW.title IS NULL THEN
   NEW.title := wdbi.lwp_get_title(NEW.url);
 END IF;

 RETURN NEW; 
END; 
'
    LANGUAGE plpgsql;


--
-- TOC entry 35 (OID 1926025)
-- Name: color_model; Type: DOMAIN; Schema: public; Owner: postgres
--

CREATE DOMAIN color_model AS name
	CONSTRAINT enum_check CHECK (((((((VALUE = 'hsv'::name) OR (VALUE = 'lab'::name)) OR (VALUE = 'luv'::name)) OR (VALUE = 'cmyk'::name)) OR (VALUE = 'rgb'::name)) OR (VALUE = 'lab'::name)));


--
-- TOC entry 68 (OID 2029039)
-- Name: zip2; Type: VIEW; Schema: public; Owner: postgres
--

CREATE VIEW zip2 AS
    SELECT zip.zip, zip.city FROM zip;


SET SESSION AUTHORIZATION 'oddb';

--
-- TOC entry 36 (OID 2037699)
-- Name: url; Type: DOMAIN; Schema: public; Owner: oddb
--

CREATE DOMAIN url AS text;


SET SESSION AUTHORIZATION 'postgres';

--
-- TOC entry 69 (OID 2051518)
-- Name: globs; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE globs (
    pattern text NOT NULL,
    "type" name NOT NULL,
    registry text
);


--
-- TOC entry 70 (OID 2051518)
-- Name: globs; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE globs FROM PUBLIC;
GRANT ALL ON TABLE globs TO GROUP mime;


--
-- TOC entry 71 (OID 2054573)
-- Name: globs_corrected; Type: VIEW; Schema: public; Owner: postgres
--

CREATE VIEW globs_corrected AS
    SELECT DISTINCT g.pattern, COALESCE(m.aliasfor, g."type") AS "type" FROM (globs g JOIN mime m ON ((m."type" = (g."type")::text))) ORDER BY g.pattern, COALESCE(m.aliasfor, g."type");


--
-- TOC entry 72 (OID 2054573)
-- Name: globs_corrected; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE globs_corrected FROM PUBLIC;
GRANT SELECT ON TABLE globs_corrected TO GROUP mime;


--
-- TOC entry 73 (OID 2054576)
-- Name: globs_problematic; Type: VIEW; Schema: public; Owner: postgres
--

CREATE VIEW globs_problematic AS
    SELECT globs.pattern, globs."type" FROM globs WHERE (globs.pattern IN (SELECT globs_corrected.pattern FROM globs_corrected GROUP BY globs_corrected.pattern HAVING (count(*) > 1))) ORDER BY globs.pattern;


--
-- TOC entry 74 (OID 2054576)
-- Name: globs_problematic; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE globs_problematic FROM PUBLIC;
GRANT SELECT ON TABLE globs_problematic TO GROUP mime;


--
-- TOC entry 484 (OID 2054610)
-- Name: mime_touch(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION mime_touch() RETURNS "trigger"
    AS 'DECLARE
 aliasfor1 mime.aliasfor%TYPE;
 tmp text;
BEGIN 
 IF NEW.aliasfor IS NOT NULL THEN

   IF NEW.type = NEW.aliasfor THEN
     RAISE EXCEPTION 
       ''Cannot define an alias to self (%)'',NEW.aliasfor;
   END IF;

   SELECT INTO aliasfor1 aliasfor 
          FROM mime m WHERE m.type = NEW.aliasfor;
   IF aliasfor1 IS NOT NULL THEN
     tmp := ''Type '' || quote_literal(NEW.aliasfor) || 
            '' is already an alias for '' || quote_literal(aliasfor1) || ''.'' ||
            '' Perhaps you want to use '' || quote_literal(aliasfor1) || '' as value.'';
     RAISE EXCEPTION 
       ''Aliases can only be defined for types, which are not aliases themselves. %'',tmp;
   END IF;

 END IF;

 RETURN NEW; 
END; 
'
    LANGUAGE plpgsql;


--
-- TOC entry 75 (OID 2054618)
-- Name: mime_globs_count; Type: VIEW; Schema: public; Owner: postgres
--

CREATE VIEW mime_globs_count AS
    SELECT m."type", count(*) AS count FROM (mime m LEFT JOIN globs_corrected g ON ((m."type" = (g."type")::text))) GROUP BY m."type" ORDER BY m."type";


--
-- TOC entry 76 (OID 2054618)
-- Name: mime_globs_count; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE mime_globs_count FROM PUBLIC;
GRANT SELECT ON TABLE mime_globs_count TO GROUP mime;


--
-- TOC entry 77 (OID 2054634)
-- Name: apps; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE apps (
    fname name DEFAULT ('_'::text || (nextval('id_seq'::text))::text) NOT NULL,
    terminal boolean,
    name text,
    exec text NOT NULL,
    registry name,
    available boolean,
    genericname text,
    priority double precision,
    must boolean,
    may boolean,
    "comment" text,
    project name,
    plugin_for name,
    gui_for name
);


--
-- TOC entry 79 (OID 2054634)
-- Name: apps; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE apps FROM PUBLIC;
GRANT ALL ON TABLE apps TO GROUP mime;
GRANT ALL ON TABLE apps TO GROUP desktop;


--
-- TOC entry 485 (OID 2057225)
-- Name: apps_touch(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION apps_touch() RETURNS "trigger"
    AS 'DECLARE
 tmp text;
BEGIN 
   IF NEW.fname IS NULL THEN
     NEW.fname := ''#''||nextval(''id_seq'');
   END IF;

 RETURN NEW; 
END; 
'
    LANGUAGE plpgsql;


--
-- TOC entry 80 (OID 2061960)
-- Name: app_mime; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE app_mime (
    app name NOT NULL,
    mime name NOT NULL,
    registry text,
    glob name,
    "action" name,
    flags name
);


--
-- TOC entry 81 (OID 2061960)
-- Name: app_mime; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE app_mime FROM PUBLIC;
GRANT ALL ON TABLE app_mime TO GROUP desktop;


--
-- TOC entry 486 (OID 2062793)
-- Name: mime_corrected(name); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION mime_corrected(name) RETURNS name
    AS 'SELECT coalesce(aliasfor,type) FROM mime WHERE type = $1'
    LANGUAGE sql;


--
-- TOC entry 82 (OID 2062795)
-- Name: app_category; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE app_category (
    app name NOT NULL,
    category name NOT NULL,
    registry text
);


--
-- TOC entry 83 (OID 2062795)
-- Name: app_category; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE app_category FROM PUBLIC;
GRANT ALL ON TABLE app_category TO GROUP mime;


--
-- TOC entry 84 (OID 2063613)
-- Name: app_input_view; Type: VIEW; Schema: public; Owner: postgres
--

CREATE VIEW app_input_view AS
    SELECT DISTINCT mime_corrected(mime) AS mime, app, priority FROM (app_mime app_input JOIN apps a ON ((app_input.app = a.fname))) WHERE a.available ORDER BY mime_corrected(mime), priority, app;


--
-- TOC entry 85 (OID 2063613)
-- Name: app_input_view; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE app_input_view FROM PUBLIC;
GRANT ALL ON TABLE app_input_view TO GROUP mime;


--
-- TOC entry 86 (OID 2063949)
-- Name: configuration; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE configuration (
    configuration name NOT NULL,
    enabled boolean,
    extends name
);


--
-- TOC entry 87 (OID 2063949)
-- Name: configuration; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE configuration FROM PUBLIC;
GRANT ALL ON TABLE configuration TO GROUP mime;


--
-- TOC entry 88 (OID 2063953)
-- Name: app_configuration; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE app_configuration (
    app name NOT NULL,
    configuration name DEFAULT 'slix-2.0'::name NOT NULL,
    enabled boolean,
    must boolean DEFAULT true,
    want boolean DEFAULT true
);


--
-- TOC entry 89 (OID 2063953)
-- Name: app_configuration; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE app_configuration FROM PUBLIC;
GRANT ALL ON TABLE app_configuration TO GROUP mime;


--
-- TOC entry 39 (OID 2063983)
-- Name: uri; Type: DOMAIN; Schema: public; Owner: postgres
--

CREATE DOMAIN uri AS text;


--
-- TOC entry 90 (OID 2064003)
-- Name: app_exec; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE app_exec (
    app name NOT NULL,
    exec text NOT NULL,
    registry uri
);


--
-- TOC entry 91 (OID 2064003)
-- Name: app_exec; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE app_exec FROM PUBLIC;
GRANT ALL ON TABLE app_exec TO GROUP desktop;


--
-- TOC entry 40 (OID 2064639)
-- Name: version; Type: DOMAIN; Schema: public; Owner: postgres
--

CREATE DOMAIN "version" AS text;


--
-- TOC entry 92 (OID 2064698)
-- Name: mime_view; Type: VIEW; Schema: public; Owner: postgres
--

CREATE VIEW mime_view AS
    SELECT DISTINCT COALESCE(mime.aliasfor, (mime."type")::name) AS "type" FROM mime ORDER BY COALESCE(mime.aliasfor, (mime."type")::name);


--
-- TOC entry 93 (OID 2064698)
-- Name: mime_view; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE mime_view FROM PUBLIC;
GRANT ALL ON TABLE mime_view TO GROUP desktop;


--
-- TOC entry 94 (OID 2064701)
-- Name: mime_not_handled; Type: VIEW; Schema: public; Owner: postgres
--

CREATE VIEW mime_not_handled AS
    SELECT mime_view."type" FROM mime_view WHERE (NOT (mime_view."type" IN (SELECT app_input_view.mime FROM app_input_view)));


--
-- TOC entry 95 (OID 2064701)
-- Name: mime_not_handled; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE mime_not_handled FROM PUBLIC;
GRANT ALL ON TABLE mime_not_handled TO GROUP desktop;


--
-- TOC entry 96 (OID 2064798)
-- Name: mime_stats; Type: VIEW; Schema: public; Owner: postgres
--

CREATE VIEW mime_stats AS
    ((((SELECT 'mime_not_handled'::name AS name, count(*) AS value FROM mime_not_handled) UNION (SELECT 'mime_unique' AS name, count(*) AS value FROM mime_view))) UNION (SELECT 'mime_defined' AS name, count(*) AS value FROM mime));


--
-- TOC entry 487 (OID 2064807)
-- Name: app_input_touch(); Type: FUNCTION; Schema: public; Owner: postgres
--

CREATE FUNCTION app_input_touch() RETURNS "trigger"
    AS 'DECLARE
 aliasfor1 mime.aliasfor%TYPE;
 tmp text;
BEGIN 
 IF NEW.mime LIKE ''*%'' THEN
   SELECT INTO tmp
     coalesce(g.type,NEW.mime) FROM globs_corrected g WHERE g.pattern=NEW.mime;
   NEW.mime := tmp;
 END IF;

 RETURN NEW; 
END; 
'
    LANGUAGE plpgsql;


--
-- TOC entry 97 (OID 2067672)
-- Name: xmls; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE xmls (
    xml xml
);


--
-- TOC entry 98 (OID 2068206)
-- Name: action_verb; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE action_verb (
    name name NOT NULL,
    "class" name
);


--
-- TOC entry 99 (OID 2068322)
-- Name: icon; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE icon (
    icon name NOT NULL
);


--
-- TOC entry 100 (OID 2068322)
-- Name: icon; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE icon FROM PUBLIC;
GRANT ALL ON TABLE icon TO GROUP desktop;


--
-- TOC entry 101 (OID 2068326)
-- Name: app_icon; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE app_icon (
    app name NOT NULL,
    icon name NOT NULL,
    registry text
);


--
-- TOC entry 102 (OID 2068326)
-- Name: app_icon; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE app_icon FROM PUBLIC;
GRANT ALL ON TABLE app_icon TO GROUP desktop;


--
-- TOC entry 103 (OID 2068332)
-- Name: app_registry; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE app_registry (
    app name NOT NULL,
    registry text NOT NULL
);


--
-- TOC entry 104 (OID 2068332)
-- Name: app_registry; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE app_registry FROM PUBLIC;
GRANT ALL ON TABLE app_registry TO GROUP desktop;


--
-- TOC entry 105 (OID 2071468)
-- Name: project; Type: TABLE; Schema: public; Owner: postgres
--

CREATE TABLE project (
    projectname_short name,
    projectname_full text NOT NULL,
    desc_short text,
    desc_full text,
    latest_release_version "version",
    latest_release_date date,
    app name,
    home url,
    freshmeat name,
    forge uri,
    package uri
);


--
-- TOC entry 106 (OID 2071468)
-- Name: project; Type: ACL; Schema: public; Owner: postgres
--

REVOKE ALL ON TABLE project FROM PUBLIC;
GRANT ALL ON TABLE project TO GROUP desktop;


--
-- Data for TOC entry 560 (OID 165917)
-- Name: links; Type: TABLE DATA; Schema: public; Owner: postgres
--

COPY links (id, pid, "type", uid, ctime, mtime, atime, etime, name, label, title, body, state, keywords, ref, href, ordung, target, blurb, url, uptime, downtime) FROM stdin;
30115	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	/.	\N	Slashdot	News for nerds. Stuff that matters.	n	link	\N	\N	\N	\N	\N	http://www.slashdot.org/	\N	\N
30116	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	2000	\N	Review 2000	A cultural, humanistic and a civil-society review.	n	magazine 	\N	\N	\N	\N	\N	http://www.ljudmila.org/2000/	\N	\N
30117	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	2227	\N	2227	Energetic and provocative x-hard core band.	n	music, band, core, audio	\N	\N	\N	\N	\N	http://www.ljudmila.org/stripcore/mu.htm	\N	\N
30118	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	7-11	\N	7-11	The archives of this dynamic mailing list. 	n	link	\N	\N	\N	\N	\N	http://www.7-11.org/	\N	\N
30119	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	[plug in]	\N	[plug In]	Internationally oriented pilot project initiating, sponsoring and mediating innovative concepts to expand experimental artistic interaction with new media.	n	links	\N	\N	\N	\N	\N	http://www.iplugin.org/	\N	\N
30120	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	a_s_u	\N	Art:servers:unlimited 	Digital photo diary -London July 98.	n	event, photo	\N	\N	\N	\N	\N	http://www.ljudmila.org/asu/	\N	\N
30121	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	absolute1	\N	Absolute One	slovenian pavillion at the 2001 Venice Biennale	n	latest, festival	\N	\N	\N	\N	\N	http://absoluteone.ljudmila.org/	\N	\N
30122	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	ai-bilten	\N	Bilten Amnesty International	Bilten Amnesty International is a quarterly human rights journal published by Amnesty International Slovenia.	n	legal, magazine	\N	\N	\N	\N	\N	http://www.ljudmila.org/aibilten/	\N	\N
30123	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	altra	\N	Altra	Altra is non-governmental organization, helping people with mental disorder.	n	ngo, help	\N	\N	\N	\N	\N	http://www.ljudmila.org/altra/	\N	\N
30124	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	amnesty	\N	Amnesty International	Home page of the Slovenian chapter.	n	ngo, international, institution, help, RIP	\N	\N	\N	\N	\N	http://www.ljudmila.org/ai-slo/	\N	\N
30125	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	ana monro	\N	Ana Monro Theatre	Street and comedy theatre group. 	n	street, theatre, festival, performance, comedy, impro	\N	\N	\N	\N	\N	http://www.ljudmila.org/ana_monro/	\N	\N
30126	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	anarhiv	\N	Anarhiv - Skratova Citalnica	Elf's reading room is a resource centre for people interested in radical social change.	n	education, project, young	\N	\N	\N	\N	\N	http://www.ljudmila.org/anarhiv/	\N	\N
30127	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	andreja	\N	Andreja Kuluncic	Croatian visual artist, rising star of croatian net art scene.	n	art, artist, latest	\N	\N	\N	\N	\N	http://www.andreja.org/	\N	\N
30128	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	anti-ish	\N	Anti-ish	A critical view on the working of a high-school institution. 	n	education	\N	\N	\N	\N	\N	http://www.ljudmila.org/ish/	\N	\N
30129	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	arnes	\N	Arnes	Arnes - academic and research network of Slovenia.	n	links	\N	\N	\N	\N	\N	http://www.arnes.si/	\N	\N
30130	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	atomic	\N	Atomic	Site for atomic exhibition in Kluze.	n	art, artist, exhibition, performance	\N	\N	\N	\N	\N	http://www.ljudmila.org/atomic/	\N	\N
30131	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	b&te	\N	Beauty And The East	Ljubljana based conference of the Nettime mailing list and community.	n	event, nettime, project	\N	\N	\N	\N	\N	http://www.ljudmila.org/nettime/	\N	\N
30132	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	badurina	\N	Lara Badurina	Consumaction.	n	art, artist, 	\N	\N	\N	\N	\N	http://www.ljudmila.org/badurina/	\N	\N
30133	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	bajko	\N	Bajko Kulauzovic	nice background:)	n	personal	\N	\N	\N	\N	\N	http://www.ljudmila.org/~bajkok/	\N	\N
30134	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	begunec	\N	Akcija Begunec	Refuge issue in Slovenia.	n	ngo, issue	\N	\N	\N	\N	\N	http://www.ljudmila.org/begunec/	\N	\N
30135	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	beitthron	\N	Beitthron	Electronic Music For Theatre, Performance, Instalations, Movie, etc.	n	music	\N	\N	\N	\N	\N	http://www.ljudmila.org/beitthron/	\N	\N
30136	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	buba	\N	Buba	Booking & promotion.	n	music	\N	\N	\N	\N	\N	http://www.ljudmila.org/buba/	\N	\N
30137	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	camillo	\N	Giulio Delminio Camillo	Site dedicated to this famous 16th century artist.	n	art, artist, theatre,	\N	\N	\N	\N	\N	http://www.ljudmila.org/camillo/	\N	\N
30138	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	ccc	\N	Centre For Culture And Communication	Budapest based multilayered centre.	n	link	\N	\N	\N	\N	\N	http://www.c3.hu/	\N	\N
30139	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	ceh	\N	Mladinski Ceh	A major youth organization.	n	youth, organization, center, community, 	\N	\N	\N	\N	\N	http://www.ljudmila.org/ceh/	\N	\N
30140	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	chikenz	\N	7sea-chikenz	Find your way trough this multicultural site.	n	latest infowar initiative	\N	\N	\N	\N	\N	http://www.ljudmila.org/~chikenz/	\N	\N
30141	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	city of women	\N	International Festival Of Contemporary Arts - City Of Women	City of Women is an international festival of contemporary arts, focusing on art and culture by women as expressed in the performing arts, theatre, music, the visual arts, installation and multi-media art, literature, film and video.	n	festival	\N	\N	\N	\N	\N	http://www.cityofwomen-a.si/	\N	\N
30142	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	co	\N	Crossing Over	International video festival.	n	video, art, festival, event, latest	\N	\N	\N	\N	\N	http://www.ljudmila.org/co/	\N	\N
30143	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	consume	\N	Consume The Net	Fed up with being held to ransom in the local loop, phased by fees toISP's, concious of community? OK so lets build a fresh network, one that is local, global, fast, expanding, public and user-constructed. This site outlines some starting points for such a network and the progress being made toward its establishment.	n	link	\N	\N	\N	\N	\N	http://www.consume.net/	\N	\N
30144	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	coop	\N	Coop	Retina's experimental project involving youth cooperatives.	n	international, institution, project	\N	\N	\N	\N	\N	http://www.ljudmila.org/coop/	\N	\N
30146	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	crsn	\N	Corrosion	Mixup of hackerism, technical craftmanship, music composing, graphic design & animation, programing and creative software development. 	n	music, design, animation, 	\N	\N	\N	\N	\N	http://www.crsn.com/	\N	\N
30147	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	delak	\N	Slovenian Performing Arts Information Centre 	The database for theatre professionals, produced with the Ministry of Culture.	n	project, theatre	\N	\N	\N	\N	\N	http://www.delak.org/	\N	\N
30148	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	desk.nl	\N	Desk.nl	The first contents provider.	n	link	\N	\N	\N	\N	\N	http://www.desk.nl/	\N	\N
30149	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	djoni	\N	Djoni - Bomba	Last updated 23.12.1993.	n	artist, pyrotechnics, kud	\N	\N	\N	\N	\N	http://www.ljudmila.org/djoni/	\N	\N
30150	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	documenta x	\N	Documenta X	The only existing online copy of this web site.	n	link	\N	\N	\N	\N	\N	http://www.vuk.org/dx/	\N	\N
30151	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	dragan	\N	Sreco Dragan	Transsubstantiation of video piece by a true video classic.	n	architecture, artist, art, enironment	\N	\N	\N	\N	\N	http://www.ljudmila.org/video/sreco/	\N	\N
30152	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	dri	\N	Domestic Research Institute	Documentation on the last project of this scientific centre.	n	artist, research institute, group	\N	\N	\N	\N	\N	http://www.ljudmila.org/scca/dri/	\N	\N
30153	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	drpic	\N	Marko Drpic	Marko Drpic's Bookmarks	n	personal	\N	\N	\N	\N	\N	http://www.ljudmila.org/ksu/	\N	\N
30154	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	druga godba	\N	World Music Festival Druga Godba	Informations about traditional music festival.	n	festival	\N	\N	\N	\N	\N	http://www.ljudmila.org/drugagodba/	\N	\N
30155	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	druga zemlja	\N	DRUGA ZEMLJA	Notes on a land beyond topologies.	n	eco	\N	\N	\N	\N	\N	http://druga.ljudmila.org/	\N	\N
30156	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	e-missions	\N	E-missions	Stream of 2 net.radio events taking place in Ljudmila.	n	audio, net.radio, 	\N	\N	\N	\N	\N	http://www.ljudmila.org/e-missions/	\N	\N
30157	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	easylife	\N	Easylife	Home of Alexei Shoulgin, cyberMayakovski. 	n	link	\N	\N	\N	\N	\N	http://www.easylife.org/	\N	\N
30158	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	eclipse	\N	Breakfast On Grass- Eclipse	Find your way to the grassy plain and have breakfast.	n	artist, art, performance, flash, porno, xxx, latest	\N	\N	\N	\N	\N	http://www.ljudmila.org/eclipse/	\N	\N
30159	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	ee.icro	\N	Embracing The Earth 	An environmental awareness action project, which connects people, especially children, from all over the world in a common action towards a better and brighter future for all of us. 	n	youth, organization, eco	\N	\N	\N	\N	\N	http://www.ljudmila.org/ee.icro/	\N	\N
30160	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	eko	\N	Urad Za Intervencije-ekoloski Sektor	save the planet, kill yourself	n	ecology, latest	\N	\N	\N	\N	\N	http://eko.ljudmila.org	\N	\N
30161	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	ekran	\N	Ekran	The only professional film related magazine in Slovenia.	n	film, magazine, television, movie	\N	\N	\N	\N	\N	http://www.ljudmila.org/ekran/	\N	\N
30162	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	esad	\N	Esad Babacic	Some poems of esad babacic - the car.	n	artist, art 	\N	\N	\N	\N	\N	http://www.ljudmila.org/daktari/	\N	\N
30163	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	eurokaz	\N	Eurokaz	A festival dedicated to investigative theatre.	n	theatre	\N	\N	\N	\N	\N	http://www.ljudmila.org/eurokaz/	\N	\N
30164	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	evening	\N	Evening Select	A low-budget talk-show, which was shot in Ljubljana, Slovenia. 	n	video	\N	\N	\N	\N	\N	http://www.ljudmila.org/eveningselect/	\N	\N
30165	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	everything	\N	Everything	Everything.	n	link	\N	\N	\N	\N	\N	http://everything.blockstackers.com/	\N	\N
30166	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	exponto	\N	Exponto 99	International multimedia festival.	n	festival, media, art, culture, theatre	\N	\N	\N	\N	\N	http://www.ljudmila.org/exponto/	\N	\N
30167	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	fifuck	\N	Fifuck	The joy of surfing the net	n	internet, personal 	\N	\N	\N	\N	\N	http://www.ljudmila.org/fifuck/	\N	\N
30168	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	fishkin	\N	Vadim Fishkin	Chronologi of art projects.	n	art, artist, project, exhibition 	\N	\N	\N	\N	\N	http://www.ljudmila.org/fishkin/	\N	\N
30169	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	fourklor	\N	Fourklor	physical theatre group	n	artist	\N	\N	\N	\N	\N	http://www.ljudmila.org/fourklor/	\N	\N
30170	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	globala	\N	Globala	initiative for promotion of antiglobalist movement	n	group, education, ngo, ecology	\N	\N	\N	\N	\N	http://www.ljudmila.org/globala/	\N	\N
30171	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	grejpfrut	\N	Grejpfrut	Very talented and amazing ppl.	n	magazine, group	\N	\N	\N	\N	\N	http://www.ljudmila.org/grejpfrut/	\N	\N
30172	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	groselj	\N	Andrej Groselj	Cyber-home of slovenian sculpturist.	n	art, artist	\N	\N	\N	\N	\N	http://www.ljudmila.org/groselj/	\N	\N
30173	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	grzinic & smid	\N	Marina Grzinic & Aina Smid	The famous web restaging of the complete works by slovenian most known video makers.	n	cyber, video, net.art, 	\N	\N	\N	\N	\N	http://www.ljudmila.org/quantum.east/	\N	\N
30174	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	hexpo	\N	Hexpo	International Streaming Festival	n	festival	\N	\N	\N	\N	\N	http://www.radiostudent.si/mzx/hexpo/	\N	\N
30175	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	i/p/a.k	\N	I/p/a.k	photo-press agency 	n	photo	\N	\N	\N	\N	\N	http://www.ipak.org./	\N	\N
30176	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	iands	\N	Iands	Association for Near Death Studies. 	n	free	\N	\N	\N	\N	\N	http://www.ljudmila.org/iands/	\N	\N
30177	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	iearn	\N	IEARN	Slovenian chapter of this important international chain.	n	international, youth, project, education, chain	\N	\N	\N	\N	\N	http://www.ljudmila.org/iearn/	\N	\N
30178	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	impro	\N	Slovenian Impro Associacion	Slovenian associacion for improvisational theatre. Includes groups doing both shortform and longform improv.	n	theatre	\N	\N	\N	\N	\N	http://www.impro-drustvo.si/	\N	\N
118965	\N	\N	\N	2004-03-02 00:00:00+01	\N	\N	\N	\N	\N	Joel on Software	\N	n	\N	\N	\N	\N	\N	\N	http://www.joelonsoftware.com/	\N	\N
30180	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	irational	\N	Irational	Base of Heath Bunting's scary net.art practice.	n	link	\N	\N	\N	\N	\N	http://www.irational.org/	\N	\N
30181	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	irc.si	\N	Irc.si	Home page of a very intense slovenian IRC community.	n	internet, community, irc, youth, 	\N	\N	\N	\N	\N	http://www.ljudmila.org/irc/	\N	\N
30182	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	isoc.si	\N	Isoc.si	Slovenian chapter of Internet Society.	n	communication, culture, society, internet, manual	\N	\N	\N	\N	\N	http://www.ljudmila.org/isoc/	\N	\N
30183	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	jaklic	\N	Bostjan Jaklic	Bostjan Jaklic's Home Page. 	n	personal	\N	\N	\N	\N	\N	http://www.ljudmila.org/~bostjan/	\N	\N
30184	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	jkz	\N	Jamarski Klub Zeleznicar	One of the oldest speleological assotiations in Slovenia	n	freetime, cave	\N	\N	\N	\N	\N	http://www.ljudmila.org/jkz/	\N	\N
30185	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	jodi	\N	Jodi	The most prolific net.artists around.	n	link	\N	\N	\N	\N	\N	http://www.jodi.org/	\N	\N
30186	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	july 4th	\N	4TH OF JULY NET.CAST	Ljudmila contribution to the ICA net.radio event in London, 04.07.1998 .	n	event, radio, netcast	\N	\N	\N	\N	\N	http://www.ljudmila.org/july04/	\N	\N
30187	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	jungehunde	\N	Junge Hunde	JUNGE HUNDE is a network of producers, directors and organizers from different European countries. The goal of network is to promote and present young theatre and dance artists and to introduce them to large international audiences. 	n	festival	\N	\N	\N	\N	\N	http://www.jungehunde.net/	\N	\N
30188	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	k4	\N	K4	The historic night club, part of the students organization.	n	student, club, dance, music, youth, freetime	\N	\N	\N	\N	\N	http://www.ljudmila.org/sou/k4/	\N	\N
30189	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	kaljeviq	\N	Darko Kaljeviq	Short novels dedicated to famous people.	n	book	\N	\N	\N	\N	\N	http://www.ljudmila.org/dk/	\N	\N
30190	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	kapa	\N	Kapa	Association for Cultural and Artistic Production.	n	group, institution	\N	\N	\N	\N	\N	http://www.ljudmila.org/kapa/	\N	\N
30191	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	kimototimora	\N	Kimoto Timora	Net-zine for cyber-theory, political activism and net.art.	n	magazine, project	\N	\N	\N	\N	\N	http://www.kimototimora.org/	\N	\N
30192	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	kinetikon 	\N	Kinetikon Pictures	The house that have produced the famous film about Laibach 'Bravo'.	n	documentary, film, project, art	\N	\N	\N	\N	\N	http://www.ljudmila.org/kinetikon/	\N	\N
30193	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	kinoatelje	\N	Kinoatelje	Multilingual site about cinematography in Slovenia.	n	film	\N	\N	\N	\N	\N	http://www.kinoatelje.org/	\N	\N
30194	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	kinoteka	\N	Kinoteka	Slovenian Cinematheque - an autonomous cultural institution.	n	film	\N	\N	\N	\N	\N	http://www.kinoteka.si/	\N	\N
30195	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	kitch	\N	Kitch: Xxx Sale	buy some kitch on XXX SALE	n	artist	\N	\N	\N	\N	\N	http://www.trgonet.com/kitch/	\N	\N
30196	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	kocjancic	\N	Damjan Kocjancic	Young photographer, successfull.	n	art, photography, image, artist, foto	\N	\N	\N	\N	\N	http://www.ljudmila.org/stripcore/damjan/damjan.htm	\N	\N
30197	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	kololjub	\N	Kololjub	Association for progressive cycling.	n	freetime, cycling, RIP	\N	\N	\N	\N	\N	http://www.ljudmila.org/kololjub/	\N	\N
30198	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	koritnik	\N	Ziga Koritnik	Slovenia's only dedicated jazz photographer. 	n	art, artist, photography, image, jazz	\N	\N	\N	\N	\N	http://www.ljudmila.org/scca/koritnik/	\N	\N
30199	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	kosnik	\N	Marko Kosnik	International project by a great networker.	n	artist, text, archive, station	\N	\N	\N	\N	\N	http://www.ljudmila.org/scca/kosnik/	\N	\N
30200	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	kovacic	\N	Marko A Kovacic	A pictoresque display of various projects by the pioneer of multimediality.	n	video, performance, art, installation, artist	\N	\N	\N	\N	\N	http://www.ljudmila.org/scca/mare/	\N	\N
30201	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	kracina	\N	Damjan Kracina	Inventive and humorous panorama of sculpture and installation work.	n	art, net, artist, 	\N	\N	\N	\N	\N	http://www.ljudmila.org/scca/kracina/	\N	\N
30202	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	kreuh	\N	Darij Kreuh	A complex insight into the work and dreams of Slovenia's only vrml artist.	n	virtual, art, artist, exhibition	\N	\N	\N	\N	\N	http://www.ljudmila.org/scca/kreuh/	\N	\N
30203	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	kricac	\N	Kricac	Secret organization. 	n	student, action, group, 	\N	\N	\N	\N	\N	http://www.ljudmila.org/kricac/	\N	\N
30204	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	krompir	\N	Krompir - Cyber Magazin	Must see cyber-zine.	n	magazine, cyber, information, 	\N	\N	\N	\N	\N	http://www.ljudmila.org/uw2/	\N	\N
30205	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	kud	\N	KUD France Preseren	One of the most important independent culture centres in Ljubljana.	n	theatre, festival, exhibition, art, music, gallery, bar, cybercafe	\N	\N	\N	\N	\N	http://www.kud-fp.si/	\N	\N
30206	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	kudcineast	\N	Kulturno Umetniko Drutvo Cineast 	Group of young film enthusiasts, organizers of a unique festival.	n	festival, movie, film, video, art	\N	\N	\N	\N	\N	http://www.ljudmila.org/kudcineast/	\N	\N
118987	\N	\N	\N	2004-04-05 00:00:00+02	\N	\N	\N	\N	\N	PHP Classes - Class: Forms generation and validation	\N	n	\N	\N	\N	\N	\N	\N	http://phpclasses.php-homepage.de/browse/package/1.html	\N	\N
118988	\N	\N	\N	2004-04-06 00:00:00+02	\N	\N	\N	\N	\N	Gaphor Homepage on SourceForge	\N	n	\N	\N	\N	\N	\N	\N	http://gaphor.sourceforge.net/	\N	\N
30207	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	labeco	\N	Labeco	Center for ecological research.	n	ecology, environment, information, 	\N	\N	\N	\N	\N	http://www.ljudmila.org/labeco/	\N	\N
30208	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	labinary	\N	Labinary	Re:cyclopedia	n	eco	\N	\N	\N	\N	\N	http://www.labinary.org/	\N	\N
30209	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	laibach	\N	Laibach	The first home page of Laibach, the band. 	n	band, music, audio, group, 	\N	\N	\N	\N	\N	http://www.ljudmila.org/embassy/3a/3a.htm	\N	\N
30210	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	las	\N	Ljudmila Audio Studio	Home of Ljudmila Audio Studio (Earotica)	n	latest, audio	\N	\N	\N	\N	\N	http://las.ljudmila.org	\N	\N
30211	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	lenardic	\N	Mart Lenardic	An e-book (The Even Greater Gatsby, short stories) and some other fiction byMart Lenardic.	n	artist, magazine	\N	\N	\N	\N	\N	http://www.ljudmila.org/lenardic/	\N	\N
30212	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	lesbo	\N	Lesbo	Full contents of the internationally aclaimed lesbian magazine.	n	magazine, women	\N	\N	\N	\N	\N	http://www.ljudmila.org/lesbo/	\N	\N
30213	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	literatura	\N	Literatura	Cyber LITERATURE - new culture!	n	book, 	\N	\N	\N	\N	\N	http://www.drustvo-literatura.si/	\N	\N
30214	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	living green	\N	Living Green	Ecology Cultural Society, focused on artistic projects.	n	ecology, green, organization, environment, 	\N	\N	\N	\N	\N	http://www.ljudmila.org/livinggg/	\N	\N
30215	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	lolita 	\N	Lolita	HiEnergy Turbo Porno Funk Jazz Overdrive Crossover Rock'n'Roll band.	n	music, audio, band	\N	\N	\N	\N	\N	http://www.ljudmila.org/lolita/	\N	\N
30216	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	mac.net	\N	Mac Net Kit	Basic information on how to get a mac online.	n	manual, mac, internet, RIP	\N	\N	\N	\N	\N	http://www.ljudmila.org/~nejc/MacStuff/Mac.html	\N	\N
30217	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	madrigalisti	\N	Ljubljanski Madrigalisti	The Ljubljana Madrigalists - singing choir.	n	music	\N	\N	\N	\N	\N	http://www.madrigalisti-pz.si/	\N	\N
30218	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	makrolab	\N	Makrolab	Web manifestation of Makrolab, done for DocumentaX and for the future.	n	art, artist, atol, Makrolab, project, installation marko peljhan	\N	\N	\N	\N	\N	http://makrolab.ljudmila.org/	\N	\N
30219	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	mama	\N	Klub Net Kulture [mama] 	if you ever go to zagreb, go see these guys.	n	link	\N	\N	\N	\N	\N	http://mama.mi2.hr/	\N	\N
30220	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	managers	\N	Managers 98	Computer bulettin board - Managers 98	n	education	\N	\N	\N	\N	\N	http://www.ljudmila.org/managers/	\N	\N
30221	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	manifesta	\N	Manifesta 	International Biennial of Contemporary Art Ljubljana, 23 June - 24 September 2000  	n	project	\N	\N	\N	\N	\N	http://www.manifesta.org/	\N	\N
30222	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	maska	\N	Maska 	Journal for performing arts founded in 1920.	n	magazine,  theatre	\N	\N	\N	\N	\N	http://www.ljudmila.org/maska/	\N	\N
30223	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	matkurja	\N	Mat'Kurja	The definitive web directory for Slovenia, featuring the also definitive hen. A site to reload a lot.	n	link	\N	\N	\N	\N	\N	http://www.matkurja.com/	\N	\N
30224	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	mechanisms 	\N	Open Space Of Dalmation Town	Overall study of open public space represented on Dalmatian towns. 	n	education, student, 	\N	\N	\N	\N	\N	http://www.ljudmila.org/mehanizmi/	\N	\N
30225	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	media	\N	Journalistic Evenings	A series of monthly public discussions on journalism and the media, in the framework of its Media Programme. 	n	media, project	\N	\N	\N	\N	\N	http://www.ljudmila.org/media/	\N	\N
30226	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	mediawatch	\N	Mediawatch	Media Watch web site brings articles and studies on media and journalism in Slovenia and other countries, which are published in Media Watch quarterly bulletin and Media Watch book edition. It also includes summaries of the international monthly public discussions on media and journalism, organised in Ljubljana by the Peace Institute.	n	latest, education, magazine	\N	\N	\N	\N	\N	http://mediawatch.ljudmila.org/	\N	\N
30227	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	metod	\N	Metod Sem	The body remains the status of art object with those crossing the art articulation of his exterior (Aplication) in being inside (Implantation) up to a new, redesigned body. Only one such body, which is fractalized with help of modern technology, can successful colonise new, alternative worlds on the region of aesthetic perception, generated by himself. Homo aestheticus of new informatical-digital tribalism.	n	artist	\N	\N	\N	\N	\N	http://www.ljudmila.org/metasenzor/	\N	\N
30228	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	mi2	\N	Mi2	Official home page of band mi2.	n	music, band	\N	\N	\N	\N	\N	http://www.ljudmila.org/mi2/	\N	\N
30229	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	milla	\N	Milla Jovovich	Slovenian page about this great-looking movie star.	n	film	\N	\N	\N	\N	\N	http://www.ljudmila.org/~tdrnovs/milla_jovovich/	\N	\N
30230	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	mim	\N	Media In Media	The online catalogue of an international exhibition.	n	project, exhibition, art, media	\N	\N	\N	\N	\N	http://www.ljudmila.org/scca/mvm/	\N	\N
30231	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	mobilatorij	\N	Mobilni Digitalni Mobilatorij	very proud to present a mobile digital classroom, coming to your part of slovenia and the world.	n	latest, projects	\N	\N	\N	\N	\N	http://www.mobilatorij.org/	\N	\N
30232	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	modic	\N	Marko Modic	Extremely rich dbase of photos by this internationally aclaimed artist.	n	artist, photography, image, art	\N	\N	\N	\N	\N	http://www.ljudmila.org/modic/	\N	\N
30233	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	moe	\N	Ministry Of Experiment	Audio art and net.radio hub.	n	net.radio, radio, audio, stream, transmission 	\N	\N	\N	\N	\N	http://www.radiostudent.si/mzx/	\N	\N
30234	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	mojca	\N	Mojca.net	home of photographer and fashion designer Mojca Janzelj	n	photo	\N	\N	\N	\N	\N	http://www.ljudmila.org/~mjanzelj/	\N	\N
30235	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	most	\N	Most - Service Civil International Slovenia 	Co-ordinates voluntary work and international workcamps in Slovenia. 	n	civil, service, organization, ngo, 	\N	\N	\N	\N	\N	http://www.ljudmila.org/~most/	\N	\N
30236	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	mss	\N	Mladinski Svet Slovenije	National Youth Council of Slovenia.	n	youth, education	\N	\N	\N	\N	\N	http://www.ljudmila.org/mss/	\N	\N
30237	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	nag	\N	Net.art Generator	the fully automated net.art generator -you can create a net.art site or view the sites in the gallery	n	net.art project latest luka 	\N	\N	\N	\N	\N	http://nag.ljudmila.org/	\N	\N
30238	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	naps	\N	Net.art Per Se	A gentle and groundbreaking conversation about net specific art.	n	event	\N	\N	\N	\N	\N	http://www.ljudmila.org/naps/	\N	\N
30239	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	ncj	\N	Net Criticism Jukebox	A unique foundry of audio recordings of net.critics.	n	music, stream, audio, 	\N	\N	\N	\N	\N	http://www.ljudmila.org/nettime/jukebox.htm	\N	\N
30240	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	netbettler	\N	Netbettler	The artist on the internet holds the image of his mythical twin in front of his face and meditates on the value of copyright in data ecstasy. 	n	net.art, event	\N	\N	\N	\N	\N	http://www.ljudmila.org/scca/mvm/netbettler/	\N	\N
30241	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	neuropa	\N	Neuropa  Netcasting Presences	The major and infamous gathering of the masses.	n	project, netcast, travel	\N	\N	\N	\N	\N	http://www.neuropa.org/	\N	\N
30242	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	neutro	\N	Neutro	Criticism on the subject of slovenian integration towards NATO and EU.	n	group, issue, student	\N	\N	\N	\N	\N	http://www.ljudmila.org/neutro/	\N	\N
30243	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	novak 	\N	Bostjan Novak	Great work of slovenian sculpture artist.	n	art, artist, sculptures	\N	\N	\N	\N	\N	http://www.ljudmila.org/bnovak/	\N	\N
30244	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	nsk	\N	Neue Slowenische Kunst	The world's first universal state. 	n	legal	\N	\N	\N	\N	\N	http://www.ljudmila.org/nsk/	\N	\N
30245	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	ops!comuna	\N	Ops!Comuna - Radio.ljudmila.org	interactive radio station based on OSS	n	latest, music	\N	\N	\N	\N	\N	http://radio.ljudmila.org/	\N	\N
30246	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	orang	\N	Orang Node At Ljudmila	ORANG is an open audio archive system, based on the internet. 	n	music, audio, archive, latest	\N	\N	\N	\N	\N	http://www.ljudmila.org:81/	\N	\N
30247	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	os trnovo	\N	OS Trnovo	Page of the elementary school in trnovo, Ljubljana.	n	education, school, youth, 	\N	\N	\N	\N	\N	http://www.ljudmila.org/ostrnovo/	\N	\N
30248	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	osi	\N	Open Society Institute-Slovenia	Home page of this very important institution.	n	organization, ngo	\N	\N	\N	\N	\N	http://www.soros.si/	\N	\N
30249	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	osi-eu	\N	OSI Program Europska Unija	Project that focuses on acession of East-europian countries to the European Union 	n	project	\N	\N	\N	\N	\N	http://www.ljudmila.org/eu/	\N	\N
30250	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	oxo	\N	OXO	A zine of a group of young graphic designers and thinkers. 	n	magazine, design	\N	\N	\N	\N	\N	http://www.ljudmila.org/oxo/	\N	\N
30251	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	p.a.r.a.s.i.t.e. 	\N	P.A.R.A.S.I.T.E. Museum	Official home page of this important instutution.	n	museum, art, artist	\N	\N	\N	\N	\N	http://www.ljudmila.org/scca/parasite/	\N	\N
30252	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	paranoid	\N	Paranoid	E-zine about metal	n	music, magazine, metal	\N	\N	\N	\N	\N	http://www.ljudmila.org/paranoid/	\N	\N
30253	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	pd	\N	Partydroge	Informations about party drugs.	n	youth, education, drugs, freetime, 	\N	\N	\N	\N	\N	http://www.ljudmila.org/partydroge/	\N	\N
30254	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	perceptions	\N	Perceptions	Some still-shots from Ljudmila's 3d artist Igor.	n	artist, group, art, 3d, animation	\N	\N	\N	\N	\N	http://www.ljudmila.org/perceptions/	\N	\N
30255	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	pernus	\N	Rok Pernus	2 Ready 2B Made	n	art, artist	\N	\N	\N	\N	\N	http://www.ljudmila.org/readymade/	\N	\N
30256	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	pgp	\N	Protecting Your Electronic Privacy, Using Cryptography And Steganography	How to protect your privacy with cryptography and how to hide messages with steganography. On this page you can freely download one of the best cryptograhic software PGP (Pretty Good Privacy) and steganographic software S-tools.	n	education	\N	\N	\N	\N	\N	http://mail.ljudmila.org/matej/pgp/	\N	\N
30257	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	pic	\N	Pravno Informacijski Center	Legal Information Center.	n	ngo, legal, news, information, human, rights, 	\N	\N	\N	\N	\N	http://www.pic.si/	\N	\N
30258	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	pintar	\N	Boris Pintar	Some writings from Slovenian free-lance writer.	n	art, artist	\N	\N	\N	\N	\N	http://www.ljudmila.org/~bpintar/	\N	\N
30259	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	poetryandwine	\N	Days Of Poetry And Wine	Official site of the 4th international festival Days of Poetry and Wine.	n	festival, event, 	\N	\N	\N	\N	\N	http://www.poetryandwine.org/	\N	\N
30260	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	pogacnik	\N	Marko Pogacnik	Earth is crying for help	n	environment, ecology, issue 	\N	\N	\N	\N	\N	http://www.ljudmila.org/pogacnik/	\N	\N
30261	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	polajnar	\N	Don't Kill Anyone, I Love You	Gojmir Polajnar's novel, Don't Kill Anyone, I Love You, is a dark thriller that encompasses themes of love, sex, conspiracy and betrayal.	n	books	\N	\N	\N	\N	\N	http://members.tripod.com/polajnar/	\N	\N
30262	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	portfolio	\N	Internet Portfolio	13 slovenian visual artists portfolios, an educational project.	n	project, portfolio	\N	\N	\N	\N	\N	http://www.ljudmila.org/scca/port.htm	\N	\N
30263	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	potiho	\N	Potiho	petra's hp	n	personal	\N	\N	\N	\N	\N	http://www.ljudmila.org/potiho/	\N	\N
118989	1	\N	\N	2004-04-06 00:00:00+02	\N	\N	\N	\N	\N	Internet Trampolin - slovenske računalniške firme	\N	0		\N	\N	\N	\N	\N	http://www.feri.uni-mb.si/trampolin/_Firme_Slo.html	\N	\N
30264	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	prosenc	\N	Natasa Prosenc	Extensive bio, and credits of all videos made by one of the most established authors.	n	artist, art, video	\N	\N	\N	\N	\N	http://www.ljudmila.org/scca/natasa/	\N	\N
30265	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	public_netbase	\N	Public_netbase	\N	n	links	\N	\N	\N	\N	\N	http://www.netbase.org/	\N	\N
30266	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	pungercar	\N	Marija Mojca Pungercar	The police files on this misterious conceptual artist.	n	artist	\N	\N	\N	\N	\N	http://www.ljudmila.org/scca/mojca/	\N	\N
30267	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	purg	\N	Franc Purg	Extremely strong contents, questioning the faith of all true catholics.	n	net.art, artist, art, net	\N	\N	\N	\N	\N	http://www.ljudmila.org/scca/purg/	\N	\N
30268	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	radyoyo	\N	Radyoyo	Flash and lots of nerves required.	n	music	\N	\N	\N	\N	\N	http://www.radyoyo.si/	\N	\N
30269	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	rcs	\N	Radio Club Slovenia	Radio amateurs gathering point.	n	radio, amateurs, audio, 	\N	\N	\N	\N	\N	http://www.ljudmila.org/rkslo/	\N	\N
30270	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	reboot	\N	Planet Reboot	A place for reflection.	n	project	\N	\N	\N	\N	\N	http://www.ljudmila.org/planetreboot/	\N	\N
30271	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	refresh	\N	Refresh: Artistic Loop Project	One of the starting point for the international artistic loop project.	n	project, art, loop	\N	\N	\N	\N	\N	http://www.ljudmila.org/fresh.htm	\N	\N
30272	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	rene	\N	Rene Rusjan	A kind of a lumber room for lay-asside memories, objects, photos, words, times... work in progress.	n	artist, movie	\N	\N	\N	\N	\N	http://www.ljudmila.org/rene/	\N	\N
30273	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	retina	\N	Retina	Gives support to non-governmental and non-institutional organizations and activities.	n	association, organization, ngo, environment, civil, rights, human, culture	\N	\N	\N	\N	\N	http://www.ljudmila.org/retina/civilna/retina/	\N	\N
30274	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	rine	\N	Research On The Internet In New Europe	An international survey about use of the internet and internet users in european countries.	n	international, project, research, education	\N	\N	\N	\N	\N	http://www.rine.org/	\N	\N
30275	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	rom	\N	Racunalniska Okoljska Mreza	Education, networking and support for activities in defence of nature.	n	ecology, environment, organization, ngo, 	\N	\N	\N	\N	\N	http://www.ljudmila.org/rom/	\N	\N
30276	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	rtv-srbija	\N	RTV-srbija	I am watching TV news, and I started to take drugs. 	n	artist, project 	\N	\N	\N	\N	\N	http://www.ljudmila.org/rtvsrbija/	\N	\N
30277	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	scca	\N	Soros Centre For Contemporary Arts 	Part of the Open Society Institute dedicated to advancement of CA in .si.	n	artist, institute	\N	\N	\N	\N	\N	http://www.ljudmila.org/scca/	\N	\N
30278	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	scriptwriting	\N	Show Me Your Tongue	Learn the art of script-writing.	n	education, film, 	\N	\N	\N	\N	\N	http://www.ljudmila.org/scriptwriting/	\N	\N
30279	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	sef	\N	SLOVENIAN E-FORUM	Society for Energy Economics andEnvironment	n	eco, ngo	\N	\N	\N	\N	\N	http://www.ljudmila.org/sef/	\N	\N
30280	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	seg	\N	Slovensko Ekolosko Gibanje	The movement aimed at enabling all living beings to live in the future.	n	ecology, nature, movement, environment	\N	\N	\N	\N	\N	http://www.ljudmila.org/seg/	\N	\N
30281	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	sfrj	\N	Www.sfrj.com	<font color=0000FF><span class=sfrj>yugoslavs         of </font><font color=ffffff>all nations</font> <font color=CC0000>- unite!</font>	n	links	\N	\N	\N	\N	\N	http://www.sfrj.com/	\N	\N
30282	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	sgs	\N	Sgs	slovenian gay pages	n	gender	\N	\N	\N	\N	\N	http://www.ljudmila.org/sgs/	\N	\N
30283	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	simic	\N	Mirko Simic	Dozens of screenshots and full documentation on this award winning video artist.	n	video, art, artist, group	\N	\N	\N	\N	\N	http://www.ljudmila.org/stripcore/simo.htm	\N	\N
30284	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	siqrd	\N	Slovenian Queer Resources Directory	Most comprehensive and vast information about the slovenian and global gay scene.	n	gay, lesbian, homo, queer, gender	\N	\N	\N	\N	\N	http://www.ljudmila.org/siqrd/	\N	\N
30285	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	skylined	\N	Skylined	Great music, design and philosophy underground resources.	n	music	\N	\N	\N	\N	\N	http://www.skylined.org/	\N	\N
30286	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	snd	\N	Distance Education 	Sample of work materials for distance on-line education in Elementary Schools 	n	education	\N	\N	\N	\N	\N	http://www.ljudmila.org/snd/	\N	\N
30287	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	sos	\N	SOS Phone	Official home page of this important community service. 	n	organization, phone, help, gender, telefon, institution, sos	\N	\N	\N	\N	\N	http://www.ljudmila.org/sos/	\N	\N
30288	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	south-east	\N	Europa South-east	Declaration of the Europa South-East policy forum  on the Stability Pact.	n	institution, issue, legal, information	\N	\N	\N	\N	\N	http://www.ljudmila.org/southeast/	\N	\N
30289	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	srce	\N	Students Resources Centre	Immense quantities relevant to students.	n	student, education, program	\N	\N	\N	\N	\N	http://www.ljudmila.org/srce/	\N	\N
30290	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	ssdzm	\N	Studentska Sekcija Drustva Za Marketing	A non profit marketing organization.	n	marketing, student, organization, 	\N	\N	\N	\N	\N	http://www.ljudmila.org/ssdms/	\N	\N
30291	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	stipendije	\N	Scolarships For Study In Slovenia	Full base of scholarships for and from Slovenia. 	n	scolarship, education, student, 	\N	\N	\N	\N	\N	http://stipendije.ljudmila.org/	\N	\N
30292	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	stokelj	\N	Bojan Stokelj	A fotographer's kick at photoshop and corporate logos.	n	image, video, bryce, artistexhibition	\N	\N	\N	\N	\N	http://www.ljudmila.org/worldtour/	\N	\N
118985	1	\N	\N	2004-03-29 00:00:00+02	\N	\N	\N	\N	\N	Index of /analiza/geometrija	\N	0		\N	\N	\N	\N	\N	http://torina.fe.uni-lj.si/analiza/geometrija/	\N	\N
30293	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	strelnikoff 	\N	Strelnikoff 	Instruction for understanding Bitchkraft - latest cd of this Slovenian band.	n	music	\N	\N	\N	\N	\N	http://www.ljudmila.org/strelnikoff/ 	\N	\N
30294	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	stripburger	\N	Stripburger	Slovenia's only comics magazine, internationally very networked.	n	comics, strip, magazine, underground, art	\N	\N	\N	\N	\N	http://www.ljudmila.org/stripcore/com.htm	\N	\N
30295	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	stripcore	\N	Strip Core	An Internet encyclopedia on the work of these gifted Hard Core artists.	n	art, group, magazine, music, strip, comics	\N	\N	\N	\N	\N	http://www.ljudmila.org/stripcore/	\N	\N
30296	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	stular	\N	Andrej Stular	Andrej Stular known especially for his comics published in Stripburger, took a part at the Strip Core 8999 project with the Skrana exhibition - selection of comics and painting from his latest period. At the opening his short film production was screened. Author, that joined the Strip Core multimedia group in 1999 gained in Slovenia several awards for photography, film and comics.	n	artist	\N	\N	\N	\N	\N	http://www.ljudmila.org/stripcore/andrej/andrej.htm	\N	\N
30297	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	stunff	\N	Stunff	A zine of the philosophical faculty students.	n	magazine, philosophy	\N	\N	\N	\N	\N	http://www.ljudmila.org/stunff/	\N	\N
30298	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	suncokret	\N	SUNCOKRET - Centar Za Humanitarni Rad	Centre for Grassroots Relief Work from Zagreb, Croatia.	n	student, ngo, assistance, human, youth	\N	\N	\N	\N	\N	http://www.ljudmila.org/~damjan/suncokret.html	\N	\N
118992	1	\N	\N	2004-04-17 18:46:22.154084+02	\N	\N	\N	\N	\N	CS 453A Cool graphics websites	\N	n	courseware graphics	\N	\N	\N	\N	\N	http://userfs.cec.wustl.edu/~cs453/websites/	\N	\N
30309	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	trabakula	\N	Trabakula: Rijeka - Split - Dubrovnik 	A Caravan of Slovene Artists along the Croatian Coast Rijeka - Split - Dubrovnik 5. - 15.4. 1996. 	1	festival	\N	\N	\N	\N	\N	http://www.ljudmila.org/trabakula/	\N	\N
30308	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	titoville	\N	Josip Broz TITO	Very cool page dedicated to this famous leader.	1	education, project	\N	\N	\N	\N	\N	http://titoville.com/	\N	\N
30307	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	tito	\N	Secret Internet Terrorist  Organization 	Secret Internet Terrorist Organization snipping at Nick Negroponte.	1	initiative, project, 	\N	\N	\N	\N	\N	http://www.ljudmila.org/tito/	\N	\N
30306	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	tia	\N	Tiskovna Informativna Agencija 	Alternative News Agency.	1	institution, environment, gender, news, student, information	\N	\N	\N	\N	\N	http://www.ljudmila.org/tia/	\N	\N
30305	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	theatre museum	\N	Slovenian National Theatre Museum	Presentation of the national theatre museum.	1	museum, theatre	\N	\N	\N	\N	\N	http://www.ljudmila.org/~lukap/muzej/	\N	\N
30304	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	terrah	\N	Terrah	Terrah - the freelancer and the author of the saying: Strip Core is the state of conscience - art is a recyclement, is the one that appeared on the Maj vej song by 2.2.2.7, and has presented himself in the last years in Metelkova City with serials of collages: Retrometelkova (May 1997), Psyche (Sept. 1998) and Fake Collage (June 1999). On his internet site you can find a selection of his collages.	1	artist	\N	\N	\N	\N	\N	http://www.ljudmila.org/stripcore/terrah/terrah1.htm	\N	\N
30303	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	telekom hate	\N	Telekom Hatepage	The major and infamous gathering of the masses.	1	project, initiative, telekom	\N	\N	\N	\N	\N	http://www.ljudmila.org/telehp/	\N	\N
30302	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	tagref	\N	Tagref	Mirrored html tag reference.	1	manual, html, link	\N	\N	\N	\N	\N	http://www.ljudmila.org/tagref/	\N	\N
30301	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	svizs	\N	Sindikat Vzgoje, Izobrazevanja In Znanosti Slovenije	Official home page of this important independent union.	1	education, science, organization, 	\N	\N	\N	\N	\N	http://www.sviz-sl.si/	\N	\N
30300	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	sustersic	\N	Apolonija Sustersic	Research into spatial laws of cyberspace, and much more.	1	space, art, artist, net	\N	\N	\N	\N	\N	http://www.ljudmila.org/scca/space.txt/	\N	\N
30299	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	sustarsic	\N	Dusan Sustarsic	Net exhibition of wood, stone and bone sculptures	1	art, artist	\N	\N	\N	\N	\N	http://www.ljudmila.org/bela/	\N	\N
118967	\N	\N	\N	2004-03-07 00:00:00+01	\N	\N	\N	\N	\N	Diferencialna in računska geometrija	\N	n	\N	\N	\N	\N	\N	\N	http://matematika.fri.uni-lj.si/geompd/	\N	\N
118968	\N	\N	\N	2004-03-08 00:00:00+01	\N	\N	\N	\N	\N	NullLogic Groupware - Welcome	\N	n	\N	\N	\N	\N	\N	\N	http://nullgroupware.sourceforge.net/groupware/	\N	\N
118969	\N	\N	\N	2004-03-15 00:00:00+01	\N	\N	\N	\N	\N	glpresent	\N	n	\N	\N	\N	\N	\N	\N	http://www.cse.unsw.edu.au/~cgray/glpresent/	\N	\N
118970	\N	\N	\N	2004-03-24 00:00:00+01	\N	\N	\N	\N	\N	Differnet	\N	n	\N	\N	\N	\N	\N	\N	http://www.differnet.com/	\N	\N
118971	\N	\N	\N	2004-03-24 00:00:00+01	\N	\N	\N	\N	\N	Icons	\N	n	\N	\N	\N	\N	\N	\N	http://jimmac.musichall.cz/gorilla.php3#	\N	\N
118972	\N	\N	\N	2004-03-24 00:00:00+01	\N	\N	\N	\N	\N	Everaldo.com	\N	n	\N	\N	\N	\N	\N	\N	http://www.everaldo.com/	\N	\N
118973	\N	\N	\N	2004-03-24 00:00:00+01	\N	\N	\N	\N	\N	Sodipodi:	\N	n	\N	\N	\N	\N	\N	\N	http://www.sodipodi.com/index.php3?section=clipart/flags	\N	\N
118974	\N	\N	\N	2004-03-24 00:00:00+01	\N	\N	\N	\N	\N	Mozilla SVG Project	\N	n	\N	\N	\N	\N	\N	\N	http://www.mozilla.org/projects/svg/	\N	\N
118975	\N	\N	\N	2004-03-24 00:00:00+01	\N	\N	\N	\N	\N	CSSED Index page	\N	n	\N	\N	\N	\N	\N	\N	http://cssed.sourceforge.net/	\N	\N
118976	\N	\N	\N	2004-03-24 00:00:00+01	\N	\N	\N	\N	\N	064dwm.gif (GIF Image, 800x600 pixels)	\N	n	\N	\N	\N	\N	\N	\N	http://www.inp.nsk.su/~bolkhov/teach/inpunix/064dwm.gif	\N	\N
118977	\N	\N	\N	2004-03-24 00:00:00+01	\N	\N	\N	\N	\N	Linux Live CD [SLAX] - index page	\N	n	\N	\N	\N	\N	\N	\N	http://slax.linux-live.org/	\N	\N
118978	\N	\N	\N	2004-03-24 00:00:00+01	\N	\N	\N	\N	\N	http://www.libsdl.de/projects/konverter/	\N	n	\N	\N	\N	\N	\N	\N	http://www.libsdl.de/projects/konverter/	\N	\N
118979	\N	\N	\N	2004-03-25 00:00:00+01	\N	\N	\N	\N	\N	Animation Project -- RendView	\N	n	\N	\N	\N	\N	\N	\N	http://www.cip.physik.uni-muenchen.de/~wwieser/ani/rendview/	\N	\N
118980	\N	\N	\N	2004-03-25 00:00:00+01	\N	\N	\N	\N	\N	PT Open Gui	\N	n	\N	\N	\N	\N	\N	\N	http://www.nic.fi/~juhe/ptbcbgui/	\N	\N
118981	\N	\N	\N	2004-03-25 00:00:00+01	\N	\N	\N	\N	\N	hugin - Panorama Tools GUI	\N	n	\N	\N	\N	\N	\N	\N	http://hugin.sourceforge.net/	\N	\N
118982	\N	\N	\N	2004-03-28 00:00:00+01	\N	\N	\N	\N	\N	Using RUTH	\N	n	\N	\N	\N	\N	\N	\N	http://www.cs.rutgers.edu/~village/ruth/use.html	\N	\N
118991	1	\N	\N	2004-04-14 00:00:00+02	\N	\N	\N	\N	\N	The SphereXP	\N	n	linux desktop	\N	\N	\N	\N	\N	http://www.hamar.sk/sphere/	\N	\N
118984	\N	\N	\N	2004-03-28 00:00:00+01	\N	\N	\N	\N	\N	Talking Heads: Contents	\N	n	\N	\N	\N	\N	\N	\N	http://www.haskins.yale.edu/haskins/HEADS/contents.html	\N	\N
118986	\N	\N	\N	2004-03-31 00:00:00+02	\N	\N	\N	\N	\N	IFSgr	\N	n	\N	\N	\N	\N	\N	\N	http://trific.ath.cx/software/ifsgr/	\N	\N
118993	1	\N	\N	2004-04-17 18:48:20.980855+02	\N	\N	\N	\N	\N	Ken Perlin	\N	n	professor java nyu graphics inventor	\N	\N	\N	\N	\N	http://www.mrl.nyu.edu/~perlin/	\N	\N
118995	\N	\N	\N	2004-04-21 00:00:00+02	\N	\N	\N	\N	\N	DocBook Wiki	\N	n	\N	\N	\N	\N	\N	\N	http://doc-book.sourceforge.net/homepage/	\N	\N
118996	\N	\N	\N	2004-04-21 00:00:00+02	\N	\N	\N	\N	\N	MemeCode - i.Task	\N	n	\N	\N	\N	\N	\N	\N	http://www.memecode.com/itask.php	\N	\N
118983	1	\N	\N	2004-03-28 00:00:00+01	\N	\N	\N	\N	\N	Visão Geral	\N	0		\N	\N	\N	\N	\N	http://www.telemidia.puc-rio.br/~pslr/mestrado/dissertacao/bibliografia.htm	\N	\N
116646	\N	\N	\N	2003-01-09 00:00:00+01	\N	\N	\N	\N	\N	Google Search	\N	1	\N	\N	\N	\N	\N	\N	javascript:q=document.getSelection();for(i=0;i<frames.length;i++){q=frames[i].document.getSelection();if(q)break;}if(!q)void(q=prompt('Google search:',''));if(q)location.href='http://www.google.com/search?q='+escape(q)	\N	\N
116645	\N	\N	\N	2002-05-27 00:00:00+02	\N	\N	\N	\N	\N	Freshmeat search	\N	1	\N	\N	\N	\N	\N	\N	javascript:q=document.getSelection();for(i=0;i<frames.length;i++){q=frames[i].document.getSelection();if(q)break;}if(!q)void(q=prompt('freshmeat search:',''));if(q)location.href='http://freshmeat.net/search/?q='+escape(q)	\N	\N
116644	\N	\N	\N	2000-06-16 00:00:00+02	\N	\N	\N	\N	\N	Latest Builds	\N	1	\N	\N	\N	\N	\N	\N	http://ftp.mozilla.org/pub/mozilla/nightly/latest/	\N	\N
116643	\N	\N	\N	2000-06-15 00:00:00+02	\N	\N	\N	\N	\N	The Mozilla Organization	\N	1	\N	\N	\N	\N	\N	\N	http://www.mozilla.org/	\N	\N
115942	\N	\N	\N	2002-09-24 20:34:26.099064+02	\N	\N	\N	\N	\N	RTV Slovenija	\N	1		\N	\N	\N	\N	\N	http://www.rtvslo.si/	\N	\N
30179	1	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	index	\N	Index	A grand pubblishers initiative, gathering of small but influential humanities mediators.	0	project, literature, social science	\N	\N	\N	\N	\N	http://www.ljudmila.org/index/	\N	\N
115941	\N	\N	\N	2002-09-24 20:34:10.321691+02	\N	\N	\N	\N	\N	SiOL Vizija Pro Plus	\N	1		\N	\N	\N	\N	\N	http://vizija.siol.net/	\N	\N
115940	\N	\N	\N	2002-09-24 20:23:59.113736+02	\N	\N	\N	\N	\N	Kraftwerk	\N	1		\N	\N	\N	\N	\N	http://www.kraftwerk.de/	0	0
115939	\N	\N	\N	2002-09-24 20:22:54.486159+02	\N	\N	\N	\N	\N	Atom Films	\N	1		\N	\N	\N	\N	\N	http://www.atomfilms.com/	\N	\N
30335	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	zsbih	\N	Zveza Studentov Bosne In Hercegovine	Information source about the community of students from Bosnia and Herzegovina.	1	student, youth, organization	\N	\N	\N	\N	\N	http://www.ljudmila.org/~zsbih/	\N	\N
30334	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	zrs	\N	Zveza Radioamaterjev Slovenije	A very popular home page of radio amateurs.	1	radio, amateurs, free	\N	\N	\N	\N	\N	http://www.hamradio.si/	\N	\N
30333	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	zpms	\N	Zveza Prijateljev Mladine	Slovenian youth association.	1	youth	\N	\N	\N	\N	\N	http://www.ljudmila.org/zpms/	\N	\N
30332	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	zofa	\N	Zofa	One of the most provocative students journals in Slovenia.	1	student, magazine	\N	\N	\N	\N	\N	http://www.ljudmila.org/zofa/	\N	\N
30331	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	zkp4	\N	Zentral Komite Proceedings	The online version of the Ljudmila/Nettime printed success.	1	magazine, book	\N	\N	\N	\N	\N	http://www.ljudmila.org/nettime/zkp4/	\N	\N
30330	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	zkp 3.2.1	\N	ZKP 3.2.1  	The full contents of this historical Nettime xerox volume from the heroic period.	1	book, art, nettime	\N	\N	\N	\N	\N	http://www.ljudmila.org/zkp321/	\N	\N
30328	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	zip	\N	Za In Proti	Institution for the culture of the conversation.	1	institution	\N	\N	\N	\N	\N	http://www.ljudmila.org/debata/	\N	\N
30327	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	yprs	\N	Young People In A Risk Society	Invitation to  the conference Young People in a Risk Society. The Conference will be held between 30 November and 2 December, 2000 in Ljubljana, Slovenia.	1	links	\N	\N	\N	\N	\N	http://www.mss.edus.si/um/ypirs/	\N	\N
30326	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	yga	\N	Young Green Alternative	A very criptic page of a very criptic organization. 	1	environment, youth, ecology, green, 	\N	\N	\N	\N	\N	http://www.ljudmila.org/mza/	\N	\N
30325	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	wes 	\N	Wes Eichenwald	American in Slovenia.	1	personal	\N	\N	\N	\N	\N	http://www.pogoer.org/	\N	\N
30324	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	water and sculptures	\N	Water And Sculptures: Event On River Ljubljanica	The flyer for a sculpture project. 	1	project, event, art	\N	\N	\N	\N	\N	http://www.ljudmila.org/vodakipi/	\N	\N
30323	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	vuk	\N	Vuk Cosic	Home server of a pioneer of net.art international.	1	net.art, art, artist, webmaster, 	\N	\N	\N	\N	\N	http://www.vukcosic.org/	\N	\N
30322	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	vujinovic	\N	Tanja Vujinovic	Portfolio of a Serbian conceptual artist.	1	art, artist, portfolio	\N	\N	\N	\N	\N	http://www.ljudmila.org/vujinovic/	\N	\N
30321	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	vitra	\N	Vitra	Centre for Sustainable Development.	1	ecology, development, environment, organization	\N	\N	\N	\N	\N	http://www.ljudmila.org/vitra/	\N	\N
30320	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	velodrome online	\N	Velodrome Online - Electronic Cafe International 1996	Anti couch-potato computer.	1	project, initiative	\N	\N	\N	\N	\N	http://www.ljudmila.org/stripcore/vello.htm	\N	\N
30319	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	vasovalci	\N	Vasovalci	Men's vocal group from Ljubljana.	1	music	\N	\N	\N	\N	\N	http://www.vasovalci-pz.si/ 	\N	\N
30318	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	varl	\N	Petra Varl	Vast presentation of real gentle visual art.	1	artist, art, visual	\N	\N	\N	\N	\N	http://www.ljudmila.org/scca/petra/	\N	\N
30317	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	val	\N	Folklorno Drustvo VAL Piran	The folkloric dance group VAL from Piran.	1	culture, dance, group, 	\N	\N	\N	\N	\N	http://www.drustvo-val.si/	\N	\N
30316	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	v2	\N	V2	Institute for Unstable Media, Rotterdam.	1	link	\N	\N	\N	\N	\N	http://www.v2.nl/	\N	\N
30315	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	usenet	\N	Usenet	Web pointer to the ljudmila news server.	1	usenet, manual, news	\N	\N	\N	\N	\N	http://www.ljudmila.org/usenet/	\N	\N
30314	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	urbanaria	\N	Urbanaria: Exhibition Of The Soros Center For Contemporary Arts	Vast resources concerning art as urban intervention - Ljubljana from February 1994 to November 1997.	1	project, art, exhibition 	\N	\N	\N	\N	\N	http://www.ljudmila.org/scca/urbanaria/	\N	\N
30313	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	unikat	\N	UNIKAT Theatre	Slovenian theatre group.	1	theatre, youth	\N	\N	\N	\N	\N	http://www.ljudmila.org/unikat/	\N	\N
116659	\N	\N	\N	2000-06-15 00:00:00+02	\N	\N	\N	\N	\N	lxr - Mozilla Cross-Reference	\N	1	\N	\N	\N	\N	\N	\N	http://lxr.mozilla.org/	\N	\N
30312	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	uad	\N	Ustvarjalno Astronomsko Drustvo	Creative astronomy association. 	1	freetime, astronomy, 	\N	\N	\N	\N	\N	http://www.ljudmila.org/uad/	\N	\N
30311	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	tretji	\N	Drustvo Tretji Element	Send e-mail to this interesting institution.	1	ngo	\N	\N	\N	\N	\N	http://www.drustvo-tretji-element.si/	\N	\N
30310	\N	\N	\N	2002-09-10 02:35:21.767417+02	\N	\N	\N	transnacionala	\N	Transnacionala	Project that focus on communication among entities from different cultural, social and political backgrounds	1	project, 	\N	\N	\N	\N	\N	http://www.ljudmila.org/trans/	\N	\N
116878	1	\N	\N	2002-09-29 00:00:00+02	\N	\N	\N	\N	\N	cmsInfo - Bitflux Home	\N	1		\N	\N	\N	\N	\N	http://www.cmsinfo.org/index.php3?section_id=54	\N	\N
116877	\N	\N	\N	2003-01-16 00:00:00+01	\N	\N	\N	\N	\N	debian.ljudmila.org: Slovenski repozitorij dodatnih Debian paketov	\N	1	\N	\N	\N	\N	\N	\N	http://debian.ljudmila.org/	\N	\N
116862	\N	\N	\N	2000-06-16 00:00:00+02	\N	\N	\N	\N	\N	Crash Recovery - Alphanumerica's Total Recall	\N	1	\N	\N	\N	\N	\N	\N	http://aphrodite.mozdev.org/total_recall.html	\N	\N
116857	\N	\N	\N	2000-06-15 00:00:00+02	\N	\N	\N	\N	\N	bugzilla - Bug-Tracking System	\N	1	\N	\N	\N	\N	\N	\N	http://bugzilla.mozilla.org/	\N	\N
116715	\N	\N	\N	2002-10-02 00:00:00+02	\N	\N	\N	\N	\N	The IMAP Connection -- INTERNET MESSAGE ACCESS PROTOCOL - VERSION 4rev1	\N	1	\N	\N	\N	\N	\N	\N	http://www.imap.org/papers/docs/rfc2060.html	\N	\N
116714	\N	\N	\N	2002-09-21 00:00:00+02	\N	\N	\N	\N	\N	spamexorcize	\N	1	\N	\N	\N	\N	\N	\N	http://www.erphesfurt.de/mario/spamexorcize*en	\N	\N
116713	\N	\N	\N	2002-09-19 00:00:00+02	\N	\N	\N	\N	\N	StarLogo on the Web	\N	1	\N	\N	\N	\N	\N	\N	http://education.mit.edu/starlogo/	\N	\N
116712	\N	\N	\N	2002-09-19 00:00:00+02	\N	\N	\N	\N	\N	AtomFilms - Angry Kid: Goalie	\N	1	\N	\N	\N	\N	\N	\N	http://atomfilms.shockwave.com/af/content/atom_699	\N	\N
116711	\N	\N	\N	1998-10-02 00:00:00+02	\N	\N	\N	\N	\N	The BOFH-style Excuse Server	\N	1	\N	\N	\N	\N	\N	\N	http://www.cs.wisc.edu/~ballard/bofh/bofhserver.html	\N	\N
116710	\N	\N	\N	1998-10-02 00:00:00+02	\N	\N	\N	\N	\N	The Cool Word of the Day Page	\N	1	\N	\N	\N	\N	\N	\N	http://www.edu.yorku.ca/wotd/	\N	\N
116677	1	\N	\N	2003-01-11 00:00:00+01	\N	\N	\N	\N	\N	Typo3 Login	\N	0		\N	\N	\N	\N	\N	http://wila.ljudmila.org/testsite-3.5b4/typo3/index.php	\N	\N
116678	1	\N	\N	2003-01-13 00:00:00+01	\N	\N	\N	\N	\N	www.ljudmila.org - Login	\N	0		\N	\N	\N	\N	\N	https://webmail.ljudmila.org/src/login.php	\N	\N
116674	1	\N	\N	2002-10-07 00:00:00+02	\N	\N	\N	\N	\N	wila.ljudmila.org	\N	0		\N	\N	\N	\N	\N	http://wila.ljudmila.org/radio/	\N	\N
116675	1	\N	\N	2003-01-09 00:00:00+01	\N	\N	\N	\N	\N	KIKI @ http://wila/ljudmila	\N	0		\N	\N	\N	\N	\N	http://wila.ljudmila.org/ljudmila/	\N	\N
116709	\N	\N	\N	1998-09-23 00:00:00+02	\N	\N	\N	\N	\N	User Friendly the Comic Strip: Cartoons	\N	1	\N	\N	\N	\N	\N	\N	http://www.userfriendly.org/static/	\N	\N
116708	\N	\N	\N	1998-10-01 00:00:00+02	\N	\N	\N	\N	\N	Debian Ports	\N	1	\N	\N	\N	\N	\N	\N	http://www.debian.org/ports/	\N	\N
116707	\N	\N	\N	1998-10-01 00:00:00+02	\N	\N	\N	\N	\N	CD Vendors	\N	1	\N	\N	\N	\N	\N	\N	http://www.debian.org/CD/vendors	\N	\N
116706	\N	\N	\N	1998-10-01 00:00:00+02	\N	\N	\N	\N	\N	The FTP server network	\N	1	\N	\N	\N	\N	\N	\N	http://www.debian.org/distrib/ftplist	\N	\N
116705	\N	\N	\N	1998-10-01 00:00:00+02	\N	\N	\N	\N	\N	Debian Packages	\N	1	\N	\N	\N	\N	\N	\N	http://packages.debian.org/	\N	\N
116704	\N	\N	\N	2000-07-03 00:00:00+02	\N	\N	\N	\N	\N	Documentation	\N	1	\N	\N	\N	\N	\N	\N	http://www.debian.org/doc/	\N	\N
116703	\N	\N	\N	2000-07-03 00:00:00+02	\N	\N	\N	\N	\N	Installation Manual	\N	1	\N	\N	\N	\N	\N	\N	http://www.debian.org/releases/stable/installmanual	\N	\N
116702	\N	\N	\N	1998-08-16 00:00:00+02	\N	\N	\N	\N	\N	Debian Weekly News	\N	1	\N	\N	\N	\N	\N	\N	http://www.debian.org/News/weekly/	\N	\N
116701	\N	\N	\N	1998-10-01 00:00:00+02	\N	\N	\N	\N	\N	Donations to Software in the Public Interest	\N	1	\N	\N	\N	\N	\N	\N	http://www.debian.org/donations	\N	\N
116700	\N	\N	\N	1998-10-01 00:00:00+02	\N	\N	\N	\N	\N	Debian Free Software Guidelines	\N	1	\N	\N	\N	\N	\N	\N	http://www.debian.org/social_contract#guidelines	\N	\N
116699	\N	\N	\N	1998-10-01 00:00:00+02	\N	\N	\N	\N	\N	Debian Social Contract	\N	1	\N	\N	\N	\N	\N	\N	http://www.debian.org/social_contract	\N	\N
116698	\N	\N	\N	1998-10-01 00:00:00+02	\N	\N	\N	\N	\N	About Debian	\N	1	\N	\N	\N	\N	\N	\N	http://www.debian.org/intro/about	\N	\N
116697	\N	\N	\N	1998-10-01 00:00:00+02	\N	\N	\N	\N	\N	Security Information	\N	1	\N	\N	\N	\N	\N	\N	http://security.debian.org/	\N	\N
116696	\N	\N	\N	2000-07-03 00:00:00+02	\N	\N	\N	\N	\N	Stable Release Information	\N	1	\N	\N	\N	\N	\N	\N	http://www.debian.org/releases/stable/	\N	\N
116695	\N	\N	\N	1998-10-02 00:00:00+02	\N	\N	\N	\N	\N	Linoleum: Linux Programming References	\N	1	\N	\N	\N	\N	\N	\N	http://leapster.org/linoleum/	\N	\N
116694	\N	\N	\N	1998-10-01 00:00:00+02	\N	\N	\N	\N	\N	GNOME	\N	1	\N	\N	\N	\N	\N	\N	http://www.gnome.org/	\N	\N
116693	\N	\N	\N	1998-10-01 00:00:00+02	\N	\N	\N	\N	\N	KDE	\N	1	\N	\N	\N	\N	\N	\N	http://www.kde.org/	\N	\N
116692	\N	\N	\N	1998-10-01 00:00:00+02	\N	\N	\N	\N	\N	Themes.org	\N	1	\N	\N	\N	\N	\N	\N	http://themes.freshmeat.net/	\N	\N
116691	\N	\N	\N	2000-07-03 00:00:00+02	\N	\N	\N	\N	\N	Linux Journal	\N	1	\N	\N	\N	\N	\N	\N	http://www.linuxjournal.com/	\N	\N
116690	\N	\N	\N	2000-07-03 00:00:00+02	\N	\N	\N	\N	\N	Linux Gazette	\N	1	\N	\N	\N	\N	\N	\N	http://www.linuxgazette.com/	\N	\N
116689	\N	\N	\N	1998-08-16 00:00:00+02	\N	\N	\N	\N	\N	Slashdot.org	\N	1	\N	\N	\N	\N	\N	\N	http://slashdot.org/	\N	\N
116688	\N	\N	\N	1998-08-16 00:00:00+02	\N	\N	\N	\N	\N	Linux Weekly News	\N	1	\N	\N	\N	\N	\N	\N	http://www.lwn.net/	\N	\N
116687	\N	\N	\N	1998-10-02 00:00:00+02	\N	\N	\N	\N	\N	Scientific Applications on Linux (SAL)	\N	1	\N	\N	\N	\N	\N	\N	http://SAL.KachinaTech.COM/	\N	\N
116686	\N	\N	\N	2000-07-03 00:00:00+02	\N	\N	\N	\N	\N	LinuxApps	\N	1	\N	\N	\N	\N	\N	\N	http://www.linuxapps.com/	\N	\N
116685	\N	\N	\N	1998-08-25 00:00:00+02	\N	\N	\N	\N	\N	FreshMeat	\N	1	\N	\N	\N	\N	\N	\N	http://freshmeat.net/	\N	\N
116684	\N	\N	\N	2000-07-03 00:00:00+02	\N	\N	\N	\N	\N	Linux Documentation Project	\N	1	\N	\N	\N	\N	\N	\N	http://www.linuxdoc.org/	\N	\N
116682	\N	\N	\N	1998-08-16 00:00:00+02	\N	\N	\N	\N	\N	Linux Kernel	\N	1	\N	\N	\N	\N	\N	\N	http://www.kernel.org/	\N	\N
116681	\N	\N	\N	2000-07-03 00:00:00+02	\N	\N	\N	\N	\N	Linux Online	\N	1	\N	\N	\N	\N	\N	\N	http://www.linux.org/	\N	\N
116680	\N	\N	\N	2000-07-03 00:00:00+02	\N	\N	\N	\N	\N	Linux.com	\N	1	\N	\N	\N	\N	\N	\N	http://www.linux.com/	\N	\N
116679	\N	\N	\N	2003-01-14 00:00:00+01	\N	\N	\N	\N	\N	The Open Web Application Security Project	\N	1	\N	\N	\N	\N	\N	\N	http://www.owasp.org/	\N	\N
116676	\N	\N	\N	2003-01-09 00:00:00+01	\N	\N	\N	\N	\N	Sauron: SQL table descriptions	\N	1	\N	\N	\N	\N	\N	\N	http://sauron.jyu.fi/docs/tables.html#wks_entries	\N	\N
116673	\N	\N	\N	2002-09-29 00:00:00+02	\N	\N	\N	\N	\N	Xopus.org	\N	1	\N	\N	\N	\N	\N	\N	http://xopus.org/index.jsp?menu=demo	\N	\N
116672	\N	\N	\N	2002-09-29 00:00:00+02	\N	\N	\N	\N	\N	OSCOM - Open Source Content Management	\N	1	\N	\N	\N	\N	\N	\N	http://www.oscom.org/	\N	\N
116669	\N	\N	\N	2001-11-21 00:00:00+01	\N	\N	\N	\N	\N	PHPDoc 1.0beta	\N	1	\N	\N	\N	\N	\N	\N	http://www.phpdoc.de/pear/index2.html	\N	\N
116668	\N	\N	\N	2001-11-21 00:00:00+01	\N	\N	\N	\N	\N	PHP Manual	\N	1	\N	\N	\N	\N	\N	\N	http://localhost/doc/phpdoc/html/	\N	\N
116666	\N	\N	\N	2000-06-16 00:00:00+02	\N	\N	\N	\N	\N	NewZilla - the Unofficial Netscape 6 and Mozilla FAQ	\N	1	\N	\N	\N	\N	\N	\N	http://www.gerbilbox.com/newzilla/	\N	\N
117103	1	\N	\N	2003-02-11 00:00:00+01	\N	\N	\N	\N	\N	KIKI @ http://wila.ljudmila.org/	\N	0		\N	\N	\N	\N	\N	http://val.ljudmila.net/kiki/	\N	\N
116716	1	\N	\N	2002-10-04 00:00:00+02	\N	\N	\N	\N	\N	Index of /mu	\N	0		\N	\N	\N	\N	\N	http://mila.ljudmila.org/mu/?M=D	\N	\N
116670	1	\N	\N	2001-11-21 00:00:00+01	\N	\N	\N	\N	\N	phpMyAdmin 2.2.0 - wila	\N	0		\N	\N	\N	\N	\N	http://wila/phpmyadmin/index.php	\N	\N
116665	\N	\N	\N	2000-06-16 00:00:00+02	\N	\N	\N	\N	\N	Alphanumerica's Mozilla Development Projects	\N	1	\N	\N	\N	\N	\N	\N	http://www.mozdev.org/	\N	\N
116664	\N	\N	\N	2000-06-16 00:00:00+02	\N	\N	\N	\N	\N	MozillaZine	\N	1	\N	\N	\N	\N	\N	\N	http://www.mozillazine.org/	\N	\N
116663	\N	\N	\N	2000-06-16 00:00:00+02	\N	\N	\N	\N	\N	Newsgroups	\N	1	\N	\N	\N	\N	\N	\N	http://www.mozilla.org/community.html	\N	\N
116661	\N	\N	\N	2000-06-15 00:00:00+02	\N	\N	\N	\N	\N	tinderbox - Tree Status	\N	1	\N	\N	\N	\N	\N	\N	http://tinderbox.mozilla.org/showbuilds.cgi	\N	\N
116660	\N	\N	\N	2000-06-15 00:00:00+02	\N	\N	\N	\N	\N	bonsai - CVS Tree Control	\N	1	\N	\N	\N	\N	\N	\N	http://bonsai.mozilla.org/	\N	\N
117221	\N	\N	\N	2003-04-03 00:00:00+02	\N	\N	\N	\N	\N	The NeXTVIEW	\N	1	\N	\N	\N	\N	\N	\N	http://www.thejagcompany.com/jtfolden/NeXTVIEW/	\N	\N
116658	\N	\N	\N	2000-06-15 00:00:00+02	\N	\N	\N	\N	\N	KDE User Interface Guidelines	\N	1	\N	\N	\N	\N	\N	\N	http://developer.kde.org/documentation/standards/kde/style/basics/	\N	\N
116657	\N	\N	\N	2000-06-15 00:00:00+02	\N	\N	\N	\N	\N	Microsoft User Experience and Interface Design Resources	\N	1	\N	\N	\N	\N	\N	\N	http://msdn.microsoft.com/ui/	\N	\N
116656	\N	\N	\N	2000-06-15 00:00:00+02	\N	\N	\N	\N	\N	IBM/Ease of Use/Design	\N	1	\N	\N	\N	\N	\N	\N	http://www-3.ibm.com/ibm/easy/eou_ext.nsf/Publish/561	\N	\N
116655	\N	\N	\N	2000-06-15 00:00:00+02	\N	\N	\N	\N	\N	Macintosh Human Interface Guidelines	\N	1	\N	\N	\N	\N	\N	\N	http://developer.apple.com/techpubs/mac/HIGuidelines/HIGuidelines-2.html	\N	\N
116654	\N	\N	\N	2000-06-15 00:00:00+02	\N	\N	\N	\N	\N	RFC Archive	\N	1	\N	\N	\N	\N	\N	\N	http://www.faqs.org/rfcs/	\N	\N
116653	\N	\N	\N	2000-06-15 00:00:00+02	\N	\N	\N	\N	\N	World Wide Web Consortium	\N	1	\N	\N	\N	\N	\N	\N	http://www.w3c.org/	\N	\N
116652	\N	\N	\N	2000-06-15 00:00:00+02	\N	\N	\N	\N	\N	Download Source Code	\N	1	\N	\N	\N	\N	\N	\N	http://www.mozilla.org/source.html	\N	\N
116651	\N	\N	\N	2000-06-15 00:00:00+02	\N	\N	\N	\N	\N	Documentation	\N	1	\N	\N	\N	\N	\N	\N	http://www.mozilla.org/docs/	\N	\N
116650	\N	\N	\N	2000-06-15 00:00:00+02	\N	\N	\N	\N	\N	Getting Involved	\N	1	\N	\N	\N	\N	\N	\N	http://www.mozilla.org/get-involved.html	\N	\N
116649	\N	\N	\N	2000-06-15 00:00:00+02	\N	\N	\N	\N	\N	Feedback	\N	1	\N	\N	\N	\N	\N	\N	http://www.mozilla.org/feedback.html	\N	\N
116648	\N	\N	\N	2000-06-15 00:00:00+02	\N	\N	\N	\N	\N	Weekly Status Update	\N	1	\N	\N	\N	\N	\N	\N	http://www.mozilla.org/status/	\N	\N
116647	\N	\N	\N	2003-01-09 00:00:00+01	\N	\N	\N	\N	\N	W3Schools Online	\N	1	\N	\N	\N	\N	\N	\N	http://www.w3schools.com/default.asp	\N	\N
116683	\N	\N	\N	1998-08-16 00:00:00+02	\N	\N	\N	GNU	\N	GNU Project	\N	1	\N	\N	\N	\N	\N	\N	http://www.gnu.org/	\N	\N
117983	\N	\N	\N	2002-12-10 00:00:00+01	\N	\N	\N	\N	\N	SQL Reference Contents	\N	1	\N	\N	\N	\N	\N	\N	http://developer.mimer.com/documentation/Mimer_SQL_Reference_Manual/Mimer_SQL_ReferenceTOC.html	\N	\N
117982	\N	\N	\N	2002-12-10 00:00:00+01	\N	\N	\N	\N	\N	SQL99	\N	1	\N	\N	\N	\N	\N	\N	http://developer.mimer.com/documentation/Mimer_SQL_Reference_Manual/Intro_SQL_Stds5.html	\N	\N
117981	\N	\N	\N	2002-12-10 00:00:00+01	\N	\N	\N	\N	\N	Slashdot | Joe Clark's Answers -- In Valid XHTML	\N	1	\N	\N	\N	\N	\N	\N	http://interviews.slashdot.org/interviews/02/12/09/1446221.shtml?tid=95	\N	\N
117980	\N	\N	\N	2002-12-10 00:00:00+01	\N	\N	\N	\N	\N	Accessible cinema (Joe Clark: Media Access)	\N	1	\N	\N	\N	\N	\N	\N	http://joeclark.org/access/cinema/	\N	\N
117979	\N	\N	\N	2002-12-08 00:00:00+01	\N	\N	\N	\N	\N	Underground History - Disused Stations on London's Underground	\N	1	\N	\N	\N	\N	\N	\N	http://www.starfury.demon.co.uk/uground/	\N	\N
117978	\N	\N	\N	2002-08-14 00:00:00+02	\N	\N	\N	\N	\N	Karl Sims home page	\N	1	\N	\N	\N	\N	\N	\N	http://www.genarts.com/karl/	\N	\N
117977	\N	\N	\N	2002-08-08 00:00:00+02	\N	\N	\N	\N	\N	120seconds.com - Bite-sized Entertainment	\N	1	\N	\N	\N	\N	\N	\N	http://www.120seconds.com/index.cfm	\N	\N
117976	\N	\N	\N	2002-08-08 00:00:00+02	\N	\N	\N	\N	\N	mozdev.org - cascades: screenshots	\N	1	\N	\N	\N	\N	\N	\N	http://cascades.mozdev.org/screenshots.html#firstDemo	\N	\N
117975	\N	\N	\N	2003-03-21 00:00:00+01	\N	\N	\N	\N	\N	Google News	\N	1	\N	\N	\N	\N	\N	\N	http://news.google.com/	\N	\N
117974	\N	\N	\N	2003-02-09 00:00:00+01	\N	\N	\N	\N	\N	kuro5hin.org || technology and culture, from the trenches	\N	1	\N	\N	\N	\N	\N	\N	http://www.kuro5hin.org/	\N	\N
117973	\N	\N	\N	2002-08-14 00:00:00+02	\N	\N	\N	\N	\N	CNN.com	\N	1	\N	\N	\N	\N	\N	\N	http://www.cnn.com/	\N	\N
117972	\N	\N	\N	2002-08-14 00:00:00+02	\N	\N	\N	\N	\N	Mladina On-Line	\N	1	\N	\N	\N	\N	\N	\N	http://www.mladina.si/	\N	\N
117971	\N	\N	\N	2002-08-14 00:00:00+02	\N	\N	\N	\N	\N	24ur.com - Naslovnica	\N	1	\N	\N	\N	\N	\N	\N	http://24ur.com/naslovnica/index.php	\N	\N
117970	\N	\N	\N	2002-08-14 00:00:00+02	\N	\N	\N	\N	\N	Delo	\N	1	\N	\N	\N	\N	\N	\N	http://www.delo.si/	\N	\N
117969	\N	\N	\N	2002-08-14 00:00:00+02	\N	\N	\N	\N	\N	RTV Slovenija	\N	1	\N	\N	\N	\N	\N	\N	http://www.rtvslo.si/servlet/page?_pageid=57,940,951&_dad=portal30&_schema=PORTAL30	\N	\N
117968	\N	\N	\N	2002-08-14 00:00:00+02	\N	\N	\N	\N	\N	Mobitel	\N	1	\N	\N	\N	\N	\N	\N	http://www.mobitel.si/	\N	\N
117967	\N	\N	\N	2002-08-14 00:00:00+02	\N	\N	\N	\N	\N	Ars - 3 program	\N	1	\N	\N	\N	\N	\N	\N	http://realsrv.rtvslo.si:81/smil/radio/ars.ram	\N	\N
117966	\N	\N	\N	2002-08-14 00:00:00+02	\N	\N	\N	\N	\N	Val 202 - 2 program	\N	1	\N	\N	\N	\N	\N	\N	http://realsrv.rtvslo.si:81/smil/radio/val202.ram	\N	\N
117965	\N	\N	\N	2002-08-14 00:00:00+02	\N	\N	\N	\N	\N	A1 - 1 program	\N	1	\N	\N	\N	\N	\N	\N	http://realsrv.rtvslo.si:81/smil/radio/a1.ram	\N	\N
117964	\N	\N	\N	2002-08-14 00:00:00+02	\N	\N	\N	\N	\N	Trnfest	\N	1	\N	\N	\N	\N	\N	\N	http://www.ljudmila.org/live.ram	\N	\N
117963	\N	\N	\N	2002-08-14 00:00:00+02	\N	\N	\N	\N	\N	TV SLO v živo	\N	1	\N	\N	\N	\N	\N	\N	http://realsrv.rtvslo.si:8080/ramgen/live/G2/slo1.rm	\N	\N
117962	\N	\N	\N	2002-08-14 00:00:00+02	\N	\N	\N	\N	\N	Radio Student Ljubljana	\N	1	\N	\N	\N	\N	\N	\N	http://www.radiostudent.si/	\N	\N
117961	\N	\N	\N	2002-08-14 00:00:00+02	\N	\N	\N	\N	\N	MINET - Mladinski internet portal	\N	1	\N	\N	\N	\N	\N	\N	http://www.minet.si/	\N	\N
117960	\N	\N	\N	2002-08-14 00:00:00+02	\N	\N	\N	\N	\N	Megaklik - Vas vodnik po dogodkih	\N	1	\N	\N	\N	\N	\N	\N	http://www.megaklik.si/	\N	\N
117959	\N	\N	\N	2002-08-14 00:00:00+02	\N	\N	\N	\N	\N	ZVPL - Kam ste namenjeni zvecer?	\N	1	\N	\N	\N	\N	\N	\N	http://www.zvpl.com/	\N	\N
117958	\N	\N	\N	2002-08-14 00:00:00+02	\N	\N	\N	\N	\N	MSN Hotmail	\N	1	\N	\N	\N	\N	\N	\N	http://www.hotmail.com/	\N	\N
117957	\N	\N	\N	2002-08-14 00:00:00+02	\N	\N	\N	\N	\N	email.si	\N	1	\N	\N	\N	\N	\N	\N	http://www.email.si/	\N	\N
117956	\N	\N	\N	2002-08-14 00:00:00+02	\N	\N	\N	\N	\N	PinkPonk	\N	1	\N	\N	\N	\N	\N	\N	http://mail.pinkponk.com/	\N	\N
117955	\N	\N	\N	2002-08-14 00:00:00+02	\N	\N	\N	\N	\N	COBISS/OPAC	\N	1	\N	\N	\N	\N	\N	\N	http://cobiss.izum.si/scripts/cobiss?ukaz=getid&lang=win	\N	\N
117954	\N	\N	\N	2002-08-14 00:00:00+02	\N	\N	\N	\N	\N	OLOPLAN - slovenski iskalni stroj	\N	1	\N	\N	\N	\N	\N	\N	http://www.oloplan.com/	\N	\N
117953	\N	\N	\N	2002-08-14 00:00:00+02	\N	\N	\N	\N	\N	Telefonski imenik Slovenije	\N	1	\N	\N	\N	\N	\N	\N	http://tis.telekom.si/	\N	\N
117952	\N	\N	\N	2002-08-14 00:00:00+02	\N	\N	\N	\N	\N	Bolha.com - bolsji sejem na internetu! Oglasi in avkcije.	\N	1	\N	\N	\N	\N	\N	\N	http://www.bolha.com/	\N	\N
117951	\N	\N	\N	2002-08-14 00:00:00+02	\N	\N	\N	\N	\N	Mat'Kurja	\N	1	\N	\N	\N	\N	\N	\N	http://www.matkurja.com/slo/	\N	\N
117950	\N	\N	\N	2002-08-14 00:00:00+02	\N	\N	\N	\N	\N	Najdi.si	\N	1	\N	\N	\N	\N	\N	\N	http://www.najdi.si/	\N	\N
117949	\N	\N	\N	2002-08-14 00:00:00+02	\N	\N	\N	\N	\N	Google	\N	1	\N	\N	\N	\N	\N	\N	http://www.google.com/	\N	\N
117948	\N	\N	\N	2002-08-14 00:00:00+02	\N	\N	\N	\N	\N	Debian bug tracking system	\N	1	\N	\N	\N	\N	\N	\N	http://www.debian.org/Bugs/	\N	\N
117947	\N	\N	\N	2003-04-23 00:00:00+02	\N	\N	\N	\N	\N	Slo-Tech | nova perspektiva računalništva | Komentarji na novice	\N	1	\N	\N	\N	\N	\N	\N	http://www.slo-tech.com/script/news/izpiskomentarjev.shtml?nID=8714	\N	\N
117946	\N	\N	\N	2003-04-23 00:00:00+02	\N	\N	\N	\N	\N	3delavnica - Slovenska digitalna kultura	\N	1	\N	\N	\N	\N	\N	\N	http://www.3delavnica.com/	\N	\N
117241	1	\N	\N	2003-04-15 00:00:00+02	\N	\N	\N	\N	\N	HTML() bookmarklet library	\N	1		\N	\N	\N	\N	\N	http://www.angelfire.com/ca/redwards/html__.calendar.html	\N	\N
117228	\N	\N	\N	2003-04-07 00:00:00+02	\N	\N	\N	\N	\N	Open Labs™ Home	\N	1	\N	\N	\N	\N	\N	\N	http://www.openlabs.com/	\N	\N
117227	\N	\N	\N	2003-04-07 00:00:00+02	\N	\N	\N	\N	\N	Page history	\N	1	\N	\N	\N	\N	\N	\N	javascript:q=document.location;location.href='http://web.archive.org/web/*/'+q	\N	\N
117223	\N	\N	\N	2003-04-03 00:00:00+02	\N	\N	\N	\N	\N	OPENSTEP Icons	\N	1	\N	\N	\N	\N	\N	\N	http://www.itoda.com/openstep/icons/	\N	\N
117222	\N	\N	\N	2003-04-03 00:00:00+02	\N	\N	\N	\N	\N	NeXT Icons	\N	1	\N	\N	\N	\N	\N	\N	http://www.geocities.com/CapitolHill/4698/index.html	\N	\N
117219	\N	\N	\N	2003-03-31 00:00:00+02	\N	\N	\N	\N	\N	PicoGUI - Home	\N	1	\N	\N	\N	\N	\N	\N	http://www.picogui.org/	\N	\N
117218	\N	\N	\N	2003-03-31 00:00:00+02	\N	\N	\N	\N	\N	GNUsl Home Page	\N	1	\N	\N	\N	\N	\N	\N	http://nl.ijs.si/GNUsl/	\N	\N
117214	\N	\N	\N	2003-03-29 00:00:00+01	\N	\N	\N	\N	\N	Slovenska GNU/Linux distribucija	\N	1	\N	\N	\N	\N	\N	\N	http://gand.owca.info/	\N	\N
117998	\N	\N	\N	2003-03-15 00:00:00+01	\N	\N	\N	\N	\N	DATABASE DEBUNKINGS	\N	1	\N	\N	\N	\N	\N	\N	http://www.dbdebunk.com/	\N	\N
117988	\N	\N	\N	2002-12-26 00:00:00+01	\N	\N	\N	\N	\N	about:blank	\N	1	\N	\N	\N	\N	\N	\N	about:blank	\N	\N
117213	\N	\N	\N	2003-03-31 00:00:00+02	\N	\N	\N	\N	\N	Debian GNU/Linux -- The Universal Operating System	\N	1	\N	\N	\N	\N	\N	\N	http://www.debian.org/	\N	\N
117152	\N	\N	\N	2003-03-14 00:00:00+01	\N	\N	\N	\N	\N	Unicode and multilingual support in HTML, fonts, Web browsers and other applications	\N	1	\N	\N	\N	\N	\N	\N	http://www.alanwood.net/unicode/	\N	\N
117133	\N	\N	\N	2003-03-03 00:00:00+01	\N	\N	\N	\N	\N	The Media Application Server(TM): MAS(TM)	\N	1	\N	\N	\N	\N	\N	\N	http://www.mediaapplicationserver.net/	\N	\N
117130	\N	\N	\N	2003-02-22 00:00:00+01	\N	\N	\N	\N	\N	ERW: Entities and relationships on the web	\N	1	\N	\N	\N	\N	\N	\N	http://erw.dsi.unimi.it/	\N	\N
117111	\N	\N	\N	2003-02-14 00:00:00+01	\N	\N	\N	\N	\N	XulPlanet.com	\N	1	\N	\N	\N	\N	\N	\N	http://www.xulplanet.com/	\N	\N
117098	\N	\N	\N	2003-02-01 00:00:00+01	\N	\N	\N	\N	\N	Išči z Google-om: information_schema	\N	1	\N	\N	\N	\N	\N	\N	http://www.google.com/search?q=information_schema&ie=UTF-8&oe=UTF-8&hl=sl&btnG=I%C5%A1%C4%8Di+z+Google-om&lr=	\N	\N
117097	\N	\N	\N	2003-02-01 00:00:00+01	\N	\N	\N	\N	\N	Standards and/or guides of  JTC 1/SC 32	\N	1	\N	\N	\N	\N	\N	\N	http://www.iso.ch/iso/en/stdsdevelopment/tc/tclist/TechnicalCommitteeStandardsListPage.TechnicalCommitteeStandardsList?COMMID=160&printable=true	\N	\N
117096	\N	\N	\N	2003-01-30 00:00:00+01	\N	\N	\N	\N	\N	Slovenski film	\N	1	\N	\N	\N	\N	\N	\N	http://www.filmsi.net/	\N	\N
117088	\N	\N	\N	2003-01-26 00:00:00+01	\N	\N	\N	\N	\N	dotLRN - Collaboraid	\N	1	\N	\N	\N	\N	\N	\N	http://dotlrn.collaboraid.net/dotlrn/?	\N	\N
117087	\N	\N	\N	2003-01-26 00:00:00+01	\N	\N	\N	\N	\N	Magic Numbers Home Page	\N	1	\N	\N	\N	\N	\N	\N	http://catb.org/~esr/magic-numbers/	\N	\N
118000	1	\N	\N	2003-03-21 00:00:00+01	\N	\N	\N	\N	\N	Mutella Remote Control: Overview	\N	0		\N	\N	\N	\N	\N	http://cavalo.ljudmila.org:12374/remote/	\N	\N
117085	\N	\N	\N	2003-01-21 00:00:00+01	\N	\N	\N	\N	\N	KNOPPIX Linux Live CD	\N	1	\N	\N	\N	\N	\N	\N	http://www.knoppix.org/	\N	\N
117084	\N	\N	\N	2003-01-21 00:00:00+01	\N	\N	\N	\N	\N	Knoppix Linux	\N	1	\N	\N	\N	\N	\N	\N	http://www.knoppix.net/	\N	\N
117081	\N	\N	\N	2003-01-20 00:00:00+01	\N	\N	\N	\N	\N	perl video tools - Allen Day	\N	1	\N	\N	\N	\N	\N	\N	http://www.wooly.org/~allenday/perl/video.php	\N	\N
117080	\N	\N	\N	2003-01-19 00:00:00+01	\N	\N	\N	\N	\N	Discordian Software Archive	\N	1	\N	\N	\N	\N	\N	\N	http://www.discordia.ch/Programs/	\N	\N
118082	\N	\N	\N	2003-07-09 00:00:00+02	\N	\N	\N	\N	\N	KIKI:val	\N	0		\N	\N	\N	\N	\N	http://val.ljudmila.net/kiki/login.php	\N	\N
118081	\N	\N	\N	2003-07-09 00:00:00+02	\N	\N	\N	\N	\N	KIKI:ljudmila	\N	0		\N	\N	\N	\N	\N	https://wila.ljudmila.org/ljudmila/	\N	\N
118080	\N	\N	\N	2003-07-09 00:00:00+02	\N	\N	\N	\N	\N	KIKI:makrolab	\N	0		\N	\N	\N	\N	\N	http://makrolab.ljudmila.net/kiki/login.php	\N	\N
118917	1	\N	\N	2003-12-16 00:00:00+01	\N	\N	\N	\N	\N	PostgreSQL SDBC driver	\N	1		\N	\N	\N	\N	\N	http://dba.openoffice.org/drivers/postgresql/index.html	\N	\N
118916	\N	\N	\N	2003-12-16 00:00:00+01	\N	\N	\N	\N	\N	TWiki . Cinelerra . WebHome	\N	1	\N	\N	\N	\N	\N	\N	http://www.ftconsult.com/twiki/bin/view/Cinelerra/WebHome	\N	\N
118852	\N	\N	\N	2003-07-26 00:00:00+02	\N	\N	\N	\N	\N	GMencoder	\N	1	\N	\N	\N	\N	\N	\N	http://gmencoder.sourceforge.net/	\N	\N
118085	\N	\N	\N	2003-07-18 00:00:00+02	\N	\N	\N	\N	\N	Jahshaka - Realtime Editing and Effects	\N	1	\N	\N	\N	\N	\N	\N	http://www.jahshaka.com/	\N	\N
116889	\N	\N	\N	2003-01-19 00:00:00+01	\N	\N	\N	\N	\N	The Emperor Norton Utilities	\N	1	\N	\N	\N	\N	\N	\N	http://yoyo.cc.monash.edu.au/~acb/norton/	\N	\N
116879	\N	\N	\N	2003-01-17 00:00:00+01	\N	\N	\N	\N	\N	informator - moj, tvoj in njihov	\N	1	\N	\N	\N	\N	\N	\N	http://info.ljudmila.org/	\N	\N
118998	1	\N	\N	2004-04-25 00:22:26.187056+02	\N	\N	\N	\N	\N	The Manhattan Virtual Classroom - A fast, free course management system for online learning	\N	n	intranet	\N	\N	\N	\N	\N	http://manhattan.sourceforge.net/	\N	\N
118929	\N	\N	\N	2004-01-04 00:00:00+01	\N	\N	\N	\N	\N	Pluto Brilliant Living	\N	1	\N	\N	\N	\N	\N	\N	http://www.plutohome.com/	\N	\N
118928	\N	\N	\N	2004-01-04 00:00:00+01	\N	\N	\N	\N	\N	Linux 3D Graphics Programming	\N	1	\N	\N	\N	\N	\N	\N	http://www.linux3dgraphicsprogramming.org/announce/listdir.php3?top=AllTopics	\N	\N
118927	\N	\N	\N	2004-01-04 00:00:00+01	\N	\N	\N	\N	\N	TWiki . Cinelerra . CinelerraManualTOC	\N	1	\N	\N	\N	\N	\N	\N	http://www.ftconsult.com/twiki/bin/view/Cinelerra/CinelerraManualTOC	\N	\N
118930	1	\N	\N	2004-01-04 00:00:00+01	\N	\N	\N	\N	\N	Slashdot | Who Wants to be the Next Dell?	\N	0		\N	\N	\N	\N	\N	http://slashdot.org/articles/04/01/04/159238.shtml?tid=126	\N	\N
118067	\N	\N	\N	2003-05-26 00:00:00+02	\N	\N	\N	\N	\N	CGUdS: NMM: Home	\N	1	\N	\N	\N	\N	\N	\N	http://graphics.cs.uni-sb.de/NMM/	\N	\N
118021	\N	\N	\N	2003-04-28 00:00:00+02	\N	\N	\N	\N	\N	Mini-Box M-100	\N	1	\N	\N	\N	\N	\N	\N	http://store.ituner.com/ituner/miniboxm100.html	\N	\N
118012	\N	\N	\N	2003-04-24 00:00:00+02	\N	\N	\N	\N	\N	http://nl.ijs.si/gnusl/	\N	1	\N	\N	\N	\N	\N	\N	http://nl.ijs.si/gnusl/	\N	\N
118011	\N	\N	\N	2003-04-24 00:00:00+02	\N	\N	\N	\N	\N	apt-get.org: Unofficial APT repositories - package search	\N	1	\N	\N	\N	\N	\N	\N	http://www.apt-get.org/search.php	\N	\N
118008	\N	\N	\N	2003-04-23 00:00:00+02	\N	\N	\N	\N	\N	VecerONLINE	\N	1	\N	\N	\N	\N	\N	\N	http://www.vecer.si/	\N	\N
118006	\N	\N	\N	2003-04-23 00:00:00+02	\N	\N	\N	\N	\N	Kiberpipa.org :: BadCarma Service Provider	\N	1	\N	\N	\N	\N	\N	\N	http://www.cyberpipe.org/	\N	\N
118005	\N	\N	\N	2003-04-18 00:00:00+02	\N	\N	\N	\N	\N	Desktop Menu Specification	\N	1	\N	\N	\N	\N	\N	\N	http://www.freedesktop.org/standards/menu/draft/menu-spec/menu-spec.html	\N	\N
118004	\N	\N	\N	2003-04-02 00:00:00+02	\N	\N	\N	\N	\N	ANIA.gif (GIF Image, 150x150 pixels)	\N	1	\N	\N	\N	\N	\N	\N	http://www.fuckedworld.com/ANIA.gif	\N	\N
118003	\N	\N	\N	2003-04-01 00:00:00+02	\N	\N	\N	\N	\N	Sourceforge : Welcome	\N	1	\N	\N	\N	\N	\N	\N	http://alioth.debian.org/	\N	\N
118002	\N	\N	\N	2003-03-27 00:00:00+01	\N	\N	\N	\N	\N	Christoph's page - Raytracing	\N	1	\N	\N	\N	\N	\N	\N	http://www-public.tu-bs.de:8080/~y0013390/raytracing.html	\N	\N
118001	\N	\N	\N	2003-03-23 00:00:00+01	\N	\N	\N	\N	\N	Google rezultat iskanja slik: vg.swan.ac.uk/gallery/AW/Wood.jpg	\N	1	\N	\N	\N	\N	\N	\N	http://images.google.com/imgres?imgurl=vg.swan.ac.uk/gallery/AW/Wood.jpg&imgrefurl=http://vg.swan.ac.uk/gallery/&h=480&w=480&prev=/images%3Fq%3Dwood%2Btexture%26start%3D40%26svnum%3D10%26hl%3Dsl%26lr%3D%26ie%3DUTF-8%26sa%3DN	\N	\N
117999	\N	\N	\N	2003-03-15 00:00:00+01	\N	\N	\N	\N	\N	Choosing the Right XML Database?	\N	1	\N	\N	\N	\N	\N	\N	http://developers.slashdot.org/comments.pl?sid=56815&cid=0&pid=0&startat=&threshold=1&mode=nested&commentsort=0&op=Change	\N	\N
117997	\N	\N	\N	2003-03-15 00:00:00+01	\N	\N	\N	\N	\N	Products	\N	1	\N	\N	\N	\N	\N	\N	http://www.alphora.com/tiern.asp?ID=DATAPHOR	\N	\N
117996	\N	\N	\N	2003-03-15 00:00:00+01	\N	\N	\N	\N	\N	Sleepycat Software: Products: Berkeley DB XML	\N	1	\N	\N	\N	\N	\N	\N	http://www.sleepycat.com/products/xml.shtml	\N	\N
117995	\N	\N	\N	2003-03-15 00:00:00+01	\N	\N	\N	\N	\N	Slashdot | Choosing the Right XML Database?	\N	1	\N	\N	\N	\N	\N	\N	http://developers.slashdot.org/article.pl?sid=03/03/12/0543220	\N	\N
117994	\N	\N	\N	2003-03-15 00:00:00+01	\N	\N	\N	\N	\N	Dan's Software	\N	1	\N	\N	\N	\N	\N	\N	http://www.zblob.com/software/dan_soft.html	\N	\N
117993	\N	\N	\N	2003-03-05 00:00:00+01	\N	\N	\N	\N	\N	Debian Quality Assurance -- Debian Developer's Packages Overview	\N	1	\N	\N	\N	\N	\N	\N	http://qa.debian.org/developer.php	\N	\N
117992	\N	\N	\N	2003-03-05 00:00:00+01	\N	\N	\N	\N	\N	Ascend v2 - Main Page	\N	1	\N	\N	\N	\N	\N	\N	http://ascend.adigital.info/?P=2	\N	\N
117991	\N	\N	\N	2003-02-16 00:00:00+01	\N	\N	\N	\N	\N	CGUdS: NMM: Status	\N	1	\N	\N	\N	\N	\N	\N	http://graphics.cs.uni-sb.de/NMM/Status/index.html	\N	\N
117990	\N	\N	\N	2003-02-15 00:00:00+01	\N	\N	\N	\N	\N	Filters for Avisynth and VirtualDub	\N	1	\N	\N	\N	\N	\N	\N	http://shelob.mordor.net/dgraft/	\N	\N
117989	\N	\N	\N	2003-02-14 00:00:00+01	\N	\N	\N	\N	\N	Trail of tears: MySQL, ODBC &amp; OpenOffice 1.0 - Feb 7, 2003	\N	1	\N	\N	\N	\N	\N	\N	http://www.linuxworld.com/2003/0207.barr.html	\N	\N
117987	\N	\N	\N	2002-12-17 00:00:00+01	\N	\N	\N	\N	\N	HTMLDOC - Easy Software Products	\N	1	\N	\N	\N	\N	\N	\N	http://www.easysw.com/htmldoc/	\N	\N
117986	\N	\N	\N	2002-12-17 00:00:00+01	\N	\N	\N	\N	\N	Using the DocBook DTD for Internal Documents?	\N	1	\N	\N	\N	\N	\N	\N	http://ask.slashdot.org/comments.pl?sid=42037&cid=0&pid=0&startat=&threshold=0&mode=nested&commentsort=0&op=Change	\N	\N
117985	\N	\N	\N	2002-12-14 00:00:00+01	\N	\N	\N	\N	\N	CSS Border	\N	1	\N	\N	\N	\N	\N	\N	http://www.w3schools.com/css/css_border.asp	\N	\N
117984	\N	\N	\N	2002-12-11 00:00:00+01	\N	\N	\N	\N	\N	Displaying Typed Tables in the Information Schema	\N	1	\N	\N	\N	\N	\N	\N	http://216.239.51.100/search?q=cache:KrbSTFEiE28C:www.sqlstandards.org/SC32/WG3/Meetings/E3B_2001_07_Electronic/e3b017.pdf+sql99+information_schema&hl=en&ie=UTF-8	\N	\N
118994	1	\N	\N	2004-04-20 00:00:00+02	\N	\N	\N	\N	\N	Image Gallery for Blue Dot Cinelerra	\N	n	video skin cinelerra kde	\N	\N	\N	\N	\N	http://www.esat.kuleuven.ac.be/~kmuylken/shots-cinelerra/images.html	\N	\N
118999	1	\N	\N	2004-04-25 21:39:56.401952+02	\N	\N	\N	Ljudmila	\N	Ljubljana Digital Media Lab - Ljudmila	\N	n		\N	\N	\N	\N	\N	http://www.ljudmila.org/	\N	\N
118007	1	\N	\N	2003-04-23 00:00:00+02	\N	\N	\N	SloTech	\N	Slo-Tech | nova perspektiva računalništva	\N	1		\N	\N	\N	\N	\N	http://www.slo-tech.com/	\N	\N
119041	\N	\N	\N	2004-07-12 00:00:00+02	\N	\N	\N	\N	\N	PostgreSQL News Updated PostgreSQL driver for OpenOffice.org Released	\N	n	\N	\N	\N	\N	\N	\N	http://www.postgresql.org/news/199.html	\N	\N
119001	1	\N	\N	2004-04-26 21:31:11.436716+02	\N	\N	\N	\N	\N	Diogene87 on Sourceforge	\N	n		\N	\N	\N	\N	\N	http://diogene87.org/	\N	\N
119002	\N	\N	\N	2004-04-28 00:00:00+02	\N	\N	\N	\N	\N	Mondrian components	\N	n	\N	\N	\N	\N	\N	\N	http://apoptosis.dyndns.org:8080/@md=d&cd=//open/mondrian/doc/&c=8ri@//open/mondrian/doc/index.html	\N	\N
119003	\N	\N	\N	2004-04-29 00:00:00+02	\N	\N	\N	\N	\N	XIA Projects 2003	\N	n	\N	\N	\N	\N	\N	\N	http://www.xiaprojects.com/www/prodotti/kxdocker/main.php	\N	\N
119005	\N	\N	\N	2004-05-01 00:00:00+02	\N	\N	\N	\N	\N	David Forsey's Home Page	\N	n	\N	\N	\N	\N	\N	\N	http://www.cs.ubc.ca/~forsey/	\N	\N
119006	\N	\N	\N	2004-05-02 00:00:00+02	\N	\N	\N	\N	\N	Presentation of The Formulas Rendering Plug-In For The Gimp 2	\N	n	\N	\N	\N	\N	\N	\N	http://openair.free.fr/nbenoit/gimp-plugin-formula.htm	\N	\N
119007	\N	\N	\N	2004-05-08 00:00:00+02	\N	\N	\N	\N	\N	Exporting a Complex Mesh	\N	n	\N	\N	\N	\N	\N	\N	http://www.janw.gothere.uk.com/exportmesh.html#povray1	\N	\N
119008	\N	\N	\N	2004-05-14 00:00:00+02	\N	\N	\N	\N	\N	profilemanager.harmen.ch - a profile manager for laptop and other users	\N	n	\N	\N	\N	\N	\N	\N	http://profilemanager.harmen.ch/	\N	\N
119009	\N	\N	\N	2004-05-19 00:00:00+02	\N	\N	\N	\N	\N	Index of /2002/12/cal	\N	n	\N	\N	\N	\N	\N	\N	http://www.w3.org/2002/12/cal/	\N	\N
119010	\N	\N	\N	2004-05-19 00:00:00+02	\N	\N	\N	\N	\N	RdfCalendar - ESW Wiki	\N	n	\N	\N	\N	\N	\N	\N	http://esw.w3.org/topic/RdfCalendar	\N	\N
119013	1	\N	\N	2004-05-19 22:45:57.920341+02	\N	\N	\N	\N	\N	Moz Tips Wiki - MozTipsWiki	\N	n	mozilla wiki	\N	\N	\N	\N	\N	http://www.moztips.com/wiki/	\N	\N
118990	1	\N	\N	2004-04-07 00:00:00+02	\N	\N	\N	\N	\N	Slovenske računalniške firme	\N	0	business hardware	\N	\N	\N	\N	\N	http://www.kopa.si/povezave/Slo_rac_firme.htm	\N	\N
119004	1	\N	\N	2004-04-29 00:00:00+02	\N	\N	\N	\N	\N	Welcome to Schema Mania	\N	n	database	\N	\N	\N	\N	\N	http://www.schemamania.org/	\N	\N
119014	1	\N	\N	2004-05-19 22:47:33.705074+02	\N	\N	\N	\N	\N	Online XUL examples	\N	n	mozilla xul gui	\N	\N	\N	\N	\N	http://www.hevanet.com/acorbin/xul/top.xul	\N	\N
119015	\N	\N	\N	2004-05-20 00:00:00+02	\N	\N	\N	\N	\N	The Linux-Penguin again...	\N	n	\N	\N	\N	\N	\N	\N	http://www.home.unix-ag.org/simon/penguin/	\N	\N
119016	\N	\N	\N	2004-05-20 00:00:00+02	\N	\N	\N	\N	\N	SoL - Server optimized Linux	\N	n	\N	\N	\N	\N	\N	\N	http://www.sol-linux.com/	\N	\N
119017	\N	\N	\N	2004-06-03 00:00:00+02	\N	\N	\N	\N	\N	Ryzom	\N	n	\N	\N	\N	\N	\N	\N	http://ryzom.com/	\N	\N
119018	\N	\N	\N	2004-06-03 00:00:00+02	\N	\N	\N	\N	\N	The Nebula Device 2	\N	n	\N	\N	\N	\N	\N	\N	http://nebuladevice.cubik.org/	\N	\N
119019	\N	\N	\N	2004-06-03 00:00:00+02	\N	\N	\N	\N	\N	Nevrax.org : home	\N	n	\N	\N	\N	\N	\N	\N	http://nevrax.org/	\N	\N
119020	\N	\N	\N	2004-06-05 00:00:00+02	\N	\N	\N	\N	\N	Encyclopedia of Organ Stops	\N	n	\N	\N	\N	\N	\N	\N	http://www.organstops.org/MainFrame1.html	\N	\N
119021	\N	\N	\N	2004-06-07 00:00:00+02	\N	\N	\N	\N	\N	Abu	\N	n	\N	\N	\N	\N	\N	\N	http://www.fuhringer.com/thomas/abu/	\N	\N
119022	\N	\N	\N	2004-06-07 00:00:00+02	\N	\N	\N	\N	\N	NSV ActiveX TV channel	\N	n	\N	\N	\N	\N	\N	\N	http://www.scvi.net/tv/tv4.htm	\N	\N
119023	\N	\N	\N	2004-06-07 00:00:00+02	\N	\N	\N	\N	\N	Radiotelevision Chipiona	\N	n	\N	\N	\N	\N	\N	\N	http://www.chipiona.tv/	\N	\N
119024	\N	\N	\N	2004-06-07 00:00:00+02	\N	\N	\N	\N	\N	WINAMP.COM | Forums - NSV for Linux	\N	n	\N	\N	\N	\N	\N	\N	http://forums.winamp.com/showthread.php?s=214316045b3e3d99eb690260e03c0093&threadid=158287&highlight=vp3+linux	\N	\N
119025	1	\N	\N	2004-06-11 12:44:17.284851+02	\N	\N	\N	\N	\N	ANDY FOULDS DESIGN	\N	n		\N	\N	\N	\N	\N	http://www.andyfoulds.co.uk/main.html	\N	\N
119026	\N	\N	\N	2004-06-12 00:00:00+02	\N	\N	\N	\N	\N	Linux Audio Users Guide	\N	n	\N	\N	\N	\N	\N	\N	http://www.djcj.org/LAU/guide/index.php	\N	\N
119027	\N	\N	\N	2004-06-12 00:00:00+02	\N	\N	\N	\N	\N	Linux Pipe Organ	\N	n	\N	\N	\N	\N	\N	\N	http://orgue.com/linux_organ/index-e.shtml	\N	\N
119028	\N	\N	\N	2004-06-12 00:00:00+02	\N	\N	\N	\N	\N	JEUX, a Pipe Organ SoundFont	\N	n	\N	\N	\N	\N	\N	\N	http://members.aol.com/realmac/jeux1.htm	\N	\N
119029	\N	\N	\N	2004-06-15 00:00:00+02	\N	\N	\N	\N	\N	XPde desktop environment	\N	n	\N	\N	\N	\N	\N	\N	http://www.xpde.com/index.php	\N	\N
119030	\N	\N	\N	2004-06-17 00:00:00+02	\N	\N	\N	\N	\N	USC Viterbi School of Engineering	\N	n	\N	\N	\N	\N	\N	\N	http://www.usc.edu/dept/engineering/news/2004_stories/2004_06_15_desbrun.html	\N	\N
119031	\N	\N	\N	2004-06-17 00:00:00+02	\N	\N	\N	\N	\N	FogBUGZ	\N	n	\N	\N	\N	\N	\N	\N	http://try.fogbugz.com/?id=24194IWAYRK	\N	\N
119032	\N	\N	\N	2004-06-24 00:00:00+02	\N	\N	\N	\N	\N	Havoc Pennington's home page	\N	n	\N	\N	\N	\N	\N	\N	http://ometer.com/	\N	\N
119033	\N	\N	\N	2004-06-30 00:00:00+02	\N	\N	\N	\N	\N	Fluffy's Home Page	\N	n	\N	\N	\N	\N	\N	\N	http://www.simons-rock.edu/~fluffy/index.php3?link=.%2FCurrent+Projects%2FEvent+Calendar%2FDownload.html	\N	\N
119034	\N	\N	\N	2004-06-30 00:00:00+02	\N	\N	\N	\N	\N	khtml2png	\N	n	\N	\N	\N	\N	\N	\N	http://www.babysimon.co.uk/khtml2png/index.html	\N	\N
119035	\N	\N	\N	2004-07-01 00:00:00+02	\N	\N	\N	\N	\N	Photo Organizer	\N	n	\N	\N	\N	\N	\N	\N	http://www.k-i-s.net/article.php?article=6	\N	\N
119036	\N	\N	\N	2004-07-01 00:00:00+02	\N	\N	\N	\N	\N	Kenton Lee: X Window System Consulting	\N	n	\N	\N	\N	\N	\N	\N	http://www.rahul.net/kenton/index.shtml	\N	\N
119037	\N	\N	\N	2004-07-01 00:00:00+02	\N	\N	\N	\N	\N	Kenton Lee: X Window System and Motif WWW Sites (frames)	\N	n	\N	\N	\N	\N	\N	\N	http://www.rahul.net/kenton/xsites.framed.html	\N	\N
119038	\N	\N	\N	2004-07-02 00:00:00+02	\N	\N	\N	\N	\N	The Art of Unix Programming	\N	n	\N	\N	\N	\N	\N	\N	http://www.faqs.org/docs/artu/	\N	\N
119039	\N	\N	\N	2004-07-05 00:00:00+02	\N	\N	\N	\N	\N	2004: Metadata for the desktop	\N	n	\N	\N	\N	\N	\N	\N	http://usefulinc.com/articles/2004/desktop-metadata	\N	\N
119040	\N	\N	\N	2004-07-05 00:00:00+02	\N	\N	\N	\N	\N	Haystack Home	\N	n	\N	\N	\N	\N	\N	\N	http://haystack.lcs.mit.edu/	\N	\N
\.


--
-- Data for TOC entry 561 (OID 165940)
-- Name: zip; Type: TABLE DATA; Schema: public; Owner: postgres
--

COPY zip (zip, city) FROM stdin;
1000	Ljubljana
1001	Ljubljana
1111	Ljubljana - Vič
1210	Ljubljana - Šentvid
1211	Ljubljana - Šmartno
1215	Medvode
1216	Smlednik
1218	Komenda
1219	Laze v Tuhinju
1223	Blagovica
1230	Domžale
1233	Dob
1234	Mengeš
1241	Kamnik
1260	Ljubljana - Polje
1261	Ljubljana - Dobrunje
1272	Polšnik
1276	Primskovo
1281	Kresnice
1282	Sava
1290	Grosuplje
1292	Ig
1301	Krka
1310	Ribnica
1313	Struge
1314	Rob
1318	Loški Potok
1351	Brezovica pri Ljubljani
1352	Preserje
1353	Borovnica
1354	Horjul
1355	Polhov Gradec
1356	Dobrova
1370	Logatec
1372	Hotedršica
1373	Rovte
1380	Cerknica
1382	Begunje pri Cerknici
1384	Grahovo
1411	Izlake
1412	Kisovec
1414	Podkum
1423	Dobovec
1430	Hrastnik
1434	Loka pri Zidanem Mostu
1501	Ljubljana - Ministrstvo za notranje zadeve
1502	Ljubljana - Ministrstvo za finance
1504	Ljubljana - Gospodarska zbornica Slovenije
1506	Ljubljana - Slovenske Železnice
1507	Ljubljana - ZZZS, Zavod za zdravstveno zavarovanje Slovenije
1511	Ljubljana - Slovenijales
1513	Ljubljana - SKB banka
1514	Ljubljana - Kompas
1515	Ljubljana - Litostroj
1516	Ljubljana - Elektro
1518	Ljubljana - ZPIZ, Zavod za pokojninsko in invalidsko zavarovanje
1519	Ljubljana - Stanovanjsko podjetje
1520	Ljubljana - Nova Ljubljanska banka
1521	Ljubljana - Iskra
1526	Ljubljana - LEK
1527	Ljubljana - Petrol
1528	Ljubljana - Emona
1529	Ljubljana - Žito
1531	Ljubljana - Golden products
1532	Ljubljana - Salomonov oglasnik
1535	Ljubljana - Ministrstvo za promet in zveze
1536	Ljubljana - Mladinska knjiga Založba
1550	Ljubljana - RTV Slovenija
2000	Maribor
2001	Maribor - poštni predali
2136	Zgornja Ložnica
2204	Miklavž na Dravskem polju
2208	Pohorje
2212	Šentilj v Slovenskih goricah
2214	Sladki Vrh
2215	Ceršak
2221	Jarenina
2222	Jakobski Dol
2223	Jurovski Dol
2230	Lenart v Slovenskih goricah
2233	Sveta Ana v Slovenskih goricah
2234	Benedikt
2235	Sveta Trojica v Slovenskih goricah
2236	Cerkvenjak
2250	Ptuj
2251	Ptuj
2256	Juršinci
2257	Polenšak
2258	Sveti Tomaž
2259	Ivanjkovci
2273	Podgorci
2275	Miklavž pri Ormožu
2276	Kog
2281	Markovci pri Ptuju
2282	Cirkulane
2286	Podlehnik
2310	Slovenska Bistrica
2318	Laporje
2323	Ptujska Gora
2324	Lovrenc na Dravskem polju
2326	Cirkovce
2331	Pragersko
2342	Ruše
2344	Lovrenc na Pohorju
2351	Kamnica
2352	Selnica ob Dravi
2362	Kapla
2363	Podvelka
2364	Ribnica na Pohorju
2373	Šentjanž pri Dravogradu
2380	Slovenj Gradec
2381	Podgorje pri Slovenj Gradcu
2391	Prevalje
2392	Mežica
2501	Maribor - Upravna enota RS
2502	Maribor - RUJP, Republiška uprava za javne prihodke
2507	Maribor - Zavarovalnica Maribor
3001	Celje - poštni predali
3204	Dobrna
3206	Stranice
3210	Slovenske Konjice
3223	Loka pri Žusmu
3224	Dobje pri Planini
3225	Planina pri Sevnici
3230	Šentjur
3232	Ponikva
3233	Kalobje
3241	Podplat
3250	Rogaška Slatina
3252	Rogatec
3253	Pristava pri Mestinju
3257	Podsreda
3260	Kozje
3262	Prevorje
3264	Sveti Štefan
3270	Laško
3271	Šentrupert pri Preboldu
3272	Rimske Toplice
3273	Jurklošter
3311	Šempeter v Savinjski dolini
3312	Prebold
3313	Polzela
3333	Ljubno ob Savinji
3501	Celje - Poštna banka Slovenije
3502	Celje - Kovinotehna
4000	Kranj
4001	Kranj - poštni predali
4205	Preddvor
4207	Cerklje na Gorenjskem
4220	Škofja Loka
4223	Poljane nad Škofjo Loko
4227	Selca
4244	Podnart
4245	Kropa
4246	Kamna Gorica
4248	Lesce
4260	Bled
4263	Bohinjska Bela
4264	Bohinjska Bistrica
4265	Bohinjsko jezero
4270	Jesenice
4273	Blejska Dobrava
4275	Begunje na Gorenjskem
4280	Kranjska Gora
4294	Križe
4501	Kranj - Merkur
4502	Kranj - Sava
5000	Nova Gorica
5210	Anhovo
5211	Kojsko
5213	Kanal
5214	Kal nad Kanalom
5220	Tolmin
5222	Kobarid
5230	Bovec
5231	Log pod Mangrtom
5243	Podbrdo
5250	Solkan
5261	Šempas
5263	Dobravlje
5272	Podnanos
5273	Col
5280	Idrija
5282	Cerkno
5283	Slap ob Idrijci
5290	Šempeter pri Gorici
5291	Miren
5295	Branik
5296	Kostanjevica na Krasu
6000	Koper
6001	Koper - Capodistria - poštni predali
6210	Sežana
6216	Podgorje
6223	Komen
6225	Hruševje
6230	Postojna
6232	Planina
6240	Kozina
6242	Materija
6244	Podgrad
6250	Ilirska Bistrica
6253	Knežak
6254	Jelšane
6255	Prem
6256	Košana
6257	Pivka
6258	Prestranek
6276	Pobegi
6310	Izola - Isola
6320	Portorož - Portorose
6323	Strunjan - Strugnano - (sezonska pošta)
6330	Piran - Pirano
6501	Koper - Luka
6502	Koper - Splošna banka
6503	Koper - Adriatic, zavarovalna družba
6504	Koper - Interevropa, mednarodna špedicija
6505	Koper - Emona, Obala
8000	Novo Mesto
8232	Šentrupert
8233	Mirna
8255	Pišece
8257	Dobova
8258	Kapele
8259	Bizeljsko
8261	Jesenice na Dolenjskem
8262	Krška vas
8263	Cerklje ob Krki
8270	Krško
8273	Leskovec pri Krškem
8282	Koprivnica
8283	Blanca
8290	Sevnica
8293	Studenec
8294	Boštanj
8296	Krmelj
8297	Šentjanž
8310	Šentjernej
8311	Kostanjevica na Krki
8330	Metlika
8331	Suhor
8332	Gradac
8351	Straža
9201	Puconci
9204	Šalovci
9205	Hodoš - Hodos
9206	Križevci
9207	Prosenjakovci - Partosfalva
9220	Lendava - Lendva
9221	Martjanci
9222	Bogojina
9226	Moravske Toplice
9231	Beltinci
9240	Ljutomer
9242	Križevci pri Ljutomerju
9252	Radenci
9261	Cankova
9262	Rogašovci
9263	Kuzma
9264	Grad
9265	Bodonci
\.


--
-- Data for TOC entry 562 (OID 167301)
-- Name: mime; Type: TABLE DATA; Schema: public; Owner: postgres
--

COPY mime ("type", "comment", registry, aliasfor, isa) FROM stdin;
all/all	All Files and Folders	slix.xml	\N	\N
all/allfiles	All Files	slix.xml	\N	\N
application/andrew-inset	Andrew Toolkit inset	freedesktop.org.xml	\N	\N
application/chm	HTML Help Document	slix.xml	application/x-chm	\N
application/futuresplash	Netscape Shockwave Flash	slix.xml	\N	\N
application/illustrator	Adobe Illustrator document	freedesktop.org.xml	\N	\N
application/mac-binhex40	Macintosh BinHex-encoded file	freedesktop.org.xml	\N	\N
application/mathematica	Mathematica™ Notebook	slix.ljudmila.org.xml	\N	\N
application/mathml+xml	MathML Document	slix.xml	text/x-mathml	\N
application/ms-tnef	TNEF File	slix.xml	\N	\N
application/msexcel	Microsoft Excel Spreadsheet	slix.xml	application/vnd.ms-excel	\N
application/mspowerpoint	Microsoft PowerPoint Presentation	slix.xml	application/vnd.ms-powerpoint	\N
application/msword	Microsoft Word Document	slix.xml	\N	\N
application/octet-stream	unknown	freedesktop.org.xml	\N	\N
application/oda	ODA document	freedesktop.org.xml	\N	\N
application/ogg	Ogg Vorbis audio	freedesktop.org.xml	\N	\N
application/pdf	PDF document	freedesktop.org.xml	\N	\N
application/pgp	PGP message	freedesktop.org.xml	\N	\N
application/pgp-encrypted	PGP/MIME-encrypted message header	freedesktop.org.xml	application/pgp	\N
application/pgp-keys	PGP keys	freedesktop.org.xml	application/pgp	\N
application/pgp-signature	detached OpenPGP signature	freedesktop.org.xml	\N	\N
application/pkcs10	S/MIME Certification Request	slix.xml	\N	\N
application/pkcs7-mime	S/MIME file	freedesktop.org.xml	\N	\N
application/pkcs7-signature	detached S/MIME signature	freedesktop.org.xml	\N	\N
application/postscript	PostScript document	freedesktop.org.xml	\N	\N
application/rtf	Rich Text Format	freedesktop.org.xml	\N	\N
application/sieve	SIEVE Mail Filter Script	slix.xml	\N	\N
application/smil	Synchronized Multimedia Integration Language	freedesktop.org.xml	\N	\N
application/vnd.corel-draw	Corel Draw drawing	freedesktop.org.xml	\N	\N
application/vnd.hp-hpgl	HP Graphics Language (plotter)	freedesktop.org.xml	\N	\N
application/vnd.hp-pcl	HP Printer Control Language file	freedesktop.org.xml	\N	\N
application/vnd.lotus-1-2-3	Lotus 1-2-3 spreadsheet	freedesktop.org.xml	\N	\N
application/vnd.mozilla.xul+xml	Mozilla XUL file	slix.xml	\N	text/xml
application/vnd.ms-asf	ASF Media	slix.xml	\N	\N
application/vnd.ms-excel	Microsoft Excel spreadsheet	freedesktop.org.xml	\N	\N
application/vnd.ms-powerpoint	Microsoft PowerPoint presentation	freedesktop.org.xml	\N	\N
application/vnd.ms-word	Microsoft Word document	freedesktop.org.xml	application/msword	\N
application/vnd.palm	Palmpilot database/document	freedesktop.org.xml	\N	\N
application/vnd.rn-realmedia	RealAudio/Video document	freedesktop.org.xml	\N	\N
application/vnd.stardivision.calc	StarCalc spreadsheet	freedesktop.org.xml	\N	\N
application/vnd.stardivision.chart	StarChart chart	freedesktop.org.xml	\N	\N
application/vnd.stardivision.draw	StarDraw drawing	freedesktop.org.xml	\N	\N
application/vnd.stardivision.impress	StarImpress presentation	freedesktop.org.xml	\N	\N
application/vnd.stardivision.mail	StarMail email	freedesktop.org.xml	\N	\N
application/vnd.stardivision.math	StarMath formula	freedesktop.org.xml	\N	\N
application/vnd.stardivision.writer	StarWriter document	freedesktop.org.xml	\N	\N
application/vnd.sun.xml.calc	OpenOffice.org Calc spreadsheet	freedesktop.org.xml	\N	\N
application/vnd.sun.xml.calc.template	OpenOffice.org Calc spreadsheet template	freedesktop.org.xml	\N	\N
application/vnd.sun.xml.draw	OpenOffice.org Draw drawing	freedesktop.org.xml	\N	\N
application/vnd.sun.xml.draw.template	OpenOffice.org Draw drawing template	freedesktop.org.xml	\N	\N
application/vnd.sun.xml.impress	OpenOffice.org Impress presentation	freedesktop.org.xml	\N	\N
application/vnd.sun.xml.impress.template	OpenOffice.org Impress presentation template	freedesktop.org.xml	\N	\N
application/vnd.sun.xml.math	OpenOffice.org Math formula	freedesktop.org.xml	\N	\N
application/vnd.sun.xml.writer	OpenOffice.org Writer document	freedesktop.org.xml	\N	\N
application/vnd.sun.xml.writer.global	OpenOffice.org Writer global document	freedesktop.org.xml	\N	\N
application/vnd.sun.xml.writer.template	OpenOffice.org Writer document template	freedesktop.org.xml	\N	\N
application/vnd.wordperfect	WordPerfect document	freedesktop.org.xml	\N	\N
application/wordperfect	WordPerfect Document	slix.xml	application/vnd.wordperfect	\N
application/x-abiword	AbiWord document	freedesktop.org.xml	\N	\N
application/x-ace	ACE Archive	slix.xml	\N	\N
application/x-afm	PostScript Font Metrics	slix.xml	application/x-font-afm	\N
application/x-amipro	Lotus AmiPro document	freedesktop.org.xml	\N	\N
application/x-applix-spreadsheet	Applix Spreadsheets spreadsheet	freedesktop.org.xml	\N	\N
application/x-applix-word	Applix Words document	freedesktop.org.xml	\N	\N
application/x-applixgraphics	Applix Graphics Document	slix.xml	image/x-applix-graphics	\N
application/x-applixspread	Applix Spreadsheets Document	slix.xml	application/x-applix-spreadsheet	\N
application/x-applixword	Applix Words Document	slix.xml	application/x-applix-word	\N
application/x-arc	ARC Archive	freedesktop.org.xml	\N	\N
application/x-archive	AR archive	freedesktop.org.xml	\N	\N
application/x-arj	ARJ archive	freedesktop.org.xml	\N	\N
application/x-artsbuilder	Arts Builder	slix.xml	\N	\N
application/x-asp	active server page	freedesktop.org.xml	\N	\N
application/x-aup	Audacity project	slix.xml	\N	\N
application/x-awk	AWK script	freedesktop.org.xml	\N	\N
application/x-bcpio	BCPIO document	freedesktop.org.xml	\N	\N
application/x-bittorrent	BitTorrent seed file	freedesktop.org.xml	\N	\N
application/x-blender	Blender scene	freedesktop.org.xml	\N	\N
application/x-bz2dvi	Bzip2 compressed DVI File	slix.xml	\N	\N
application/x-bzip	bzip archive	freedesktop.org.xml	\N	\N
application/x-bzip-compressed-tar	tar archive (bzip-compressed)	freedesktop.org.xml	\N	\N
application/x-bzip2	Bzip2 File	slix.xml	application/x-bzip	\N
application/x-cd-image	raw CD image	freedesktop.org.xml	\N	\N
application/x-cda	CD Audio	slix.xml	\N	\N
application/x-celestia-script	Celestia script file	slix.xml	\N	\N
application/x-cgi	CGI script	freedesktop.org.xml	\N	\N
application/x-chess-pgn	PGN chess game	freedesktop.org.xml	\N	\N
application/x-chm	\N	clashes.xml	\N	\N
application/x-class-file	Java byte code	freedesktop.org.xml	\N	\N
application/x-compress	UNIX-compressed file	freedesktop.org.xml	\N	\N
application/x-compressed-tar	tar archive (gzip-compressed)	freedesktop.org.xml	\N	\N
application/x-core	program crash data	freedesktop.org.xml	\N	\N
application/x-cpio	CPIO archive	freedesktop.org.xml	\N	\N
application/x-cpio-compressed	CPIO archive (gzip-compressed)	freedesktop.org.xml	\N	\N
application/x-csh	C shell script	freedesktop.org.xml	\N	\N
application/x-cue	CDRWIN cue-sheet	slix.xml	\N	\N
application/x-dbase	dBASE document	freedesktop.org.xml	\N	\N
application/x-dbm	\N	freedesktop.org.xml	\N	\N
application/x-dc-rom	Dreamcast ROM	freedesktop.org.xml	\N	\N
application/x-deb	Debian package	freedesktop.org.xml	\N	\N
application/x-debian-package	Debian Package	slix.xml	application/x-deb	\N
application/x-designer	Qt Designer file	freedesktop.org.xml	\N	\N
application/x-desktop	desktop configuration file	freedesktop.org.xml	\N	\N
application/x-dia	Dia Diagram	slix.xml	application/x-dia-diagram	\N
application/x-dia-diagram	Dia diagram	freedesktop.org.xml	\N	\N
application/x-dvi	TeX DVI document	freedesktop.org.xml	\N	\N
application/x-e-theme	Enlightenment theme	freedesktop.org.xml	\N	\N
application/x-edu	Edu Document	slix.xml	\N	\N
application/x-edugallery	Edu Gallery Document	slix.xml	\N	\N
application/x-egon	Egon Animator animation	freedesktop.org.xml	\N	\N
application/x-executable	executable	freedesktop.org.xml	\N	\N
application/x-font-afm	Adobe font metrics	freedesktop.org.xml	\N	\N
application/x-font-bdf	BDF font	freedesktop.org.xml	\N	\N
application/x-font-dos	DOS font	freedesktop.org.xml	\N	\N
application/x-font-framemaker	Adobe FrameMaker font	freedesktop.org.xml	\N	\N
application/x-font-ghostscript	Ghostscript Font	slix.xml	application/x-font-type1	\N
application/x-font-libgrx	LIBGRX font	freedesktop.org.xml	\N	\N
application/x-font-linux-psf	Linux PSF console font	freedesktop.org.xml	\N	\N
application/x-font-otf	OpenType font	freedesktop.org.xml	\N	\N
application/x-font-pcf	PCF font	freedesktop.org.xml	application/x-font-type1	\N
application/x-font-snf	SNF Bitmap Font	slix.xml	\N	\N
application/x-font-speedo	Speedo font	freedesktop.org.xml	\N	\N
application/x-font-sunos-news	SunOS News font	freedesktop.org.xml	\N	\N
application/x-font-tex	TeX font	freedesktop.org.xml	\N	\N
application/x-font-tex-tfm	TeX font metrics	freedesktop.org.xml	\N	\N
application/x-font-ttc	TrueType Font Collection	slix.xml	\N	\N
application/x-font-ttf	TrueType font	freedesktop.org.xml	\N	\N
application/x-font-type1	font	freedesktop.org.xml	\N	\N
application/x-font-vfont	V font	freedesktop.org.xml	\N	\N
application/x-frame	\N	freedesktop.org.xml	\N	\N
application/x-gameboy-rom	Game Boy ROM	freedesktop.org.xml	\N	\N
application/x-gdbm	\N	freedesktop.org.xml	\N	\N
application/x-genesis-rom	Genesis ROM	freedesktop.org.xml	\N	\N
application/x-gettext	GNU Gettext Message Catalog	slix.xml	text/x-gettext-translation	\N
application/x-gettext-translation	translated messages (machine-readable)	freedesktop.org.xml	\N	\N
application/x-gettext-translation-template	\N	clashes.xml	\N	\N
application/x-glade	Glade project	freedesktop.org.xml	\N	\N
application/x-gmc-link	GMC link	freedesktop.org.xml	\N	\N
application/x-gnucash	GnuCash spreadsheet	freedesktop.org.xml	\N	\N
application/x-gnumeric	Gnumeric spreadsheet	freedesktop.org.xml	\N	\N
application/x-graphite	Graphite scientific graph	freedesktop.org.xml	\N	\N
application/x-gtar	gtar archive	freedesktop.org.xml	\N	\N
application/x-gtktalog	GTKtalog catalog	freedesktop.org.xml	\N	\N
application/x-gzdvi	Gzip compressed DVI File	slix.xml	\N	\N
application/x-gzip	gzip archive	freedesktop.org.xml	application/x-compressed-tar	\N
application/x-gzpostscript	PostScript document (gzip-compressed)	freedesktop.org.xml	\N	\N
application/x-hancomword	HancomWord Document	slix.xml	\N	\N
application/x-hdf	HDF document	freedesktop.org.xml	\N	\N
application/x-ipod-firmware	iPod firmware	freedesktop.org.xml	\N	\N
application/x-iso	ISO9660 image file	slix.xml	application/x-cd-image	\N
application/x-jar	Java archive	freedesktop.org.xml	\N	\N
application/x-java	Java class	freedesktop.org.xml	\N	\N
application/x-java-applet	Java Applet	slix.xml	\N	\N
application/x-java-bean	Netscape Java(TM) Plug-in 1.3.1-b24	slix.xml	\N	\N
application/x-javascript	Javascript program	freedesktop.org.xml	\N	\N
application/x-jbuilder-project	JBuilder project	freedesktop.org.xml	\N	\N
application/x-k3b	K3b Project	slix.xml	\N	\N
application/x-karbon	Karbon14 drawing	freedesktop.org.xml	\N	\N
application/x-kcachegrind	Cachegrind/Callgrind Profile Dump	slix.xml	\N	\N
application/x-kchart	KChart chart	freedesktop.org.xml	\N	\N
application/x-kcsrc	KDE Color Theme	slix.xml	\N	\N
application/x-kde-wallet	KDE Wallet File	slix.xml	\N	\N
application/x-kdevelop	KDevelop Project File	slix.xml	\N	\N
application/x-kformula	KFormula formula	freedesktop.org.xml	\N	\N
application/x-kgeo	KGeo Figure	slix.xml	\N	\N
application/x-kgetlist	Kget Download List	slix.xml	\N	\N
application/x-kig	Kig Figure	slix.xml	\N	\N
application/x-killustrator	KIllustrator drawing	freedesktop.org.xml	\N	\N
application/x-kivio	Kivio flowchart	freedesktop.org.xml	\N	\N
application/x-kolf	Kolf Saved Game	slix.xml	\N	\N
application/x-kommander	Kommander File	slix.xml	\N	\N
application/x-konsole	File to open a shell	slix.xml	\N	\N
application/x-kontour	Kontour drawing	freedesktop.org.xml	\N	\N
application/x-kourse	Kolf course	slix.xml	\N	\N
application/x-kpovmodeler	KPovModeler scene	freedesktop.org.xml	\N	\N
application/x-kpresenter	KPresenter presentation	freedesktop.org.xml	\N	\N
application/x-krita	Krita document	freedesktop.org.xml	\N	\N
application/x-kseg	KSeg Document	slix.xml	\N	\N
application/x-kspread	KSpread spreadsheet	freedesktop.org.xml	\N	\N
application/x-kspread-crypt	KSpread spreadsheet (encrypted)	freedesktop.org.xml	\N	\N
application/x-ksysguard	KDE System Guard	slix.xml	\N	\N
application/x-ksysv-package	Saved Init Configuration	freedesktop.org.xml	\N	\N
application/x-kudesigner	Kugar Report Template	slix.xml	\N	\N
application/x-kugar	Kugar document	freedesktop.org.xml	\N	\N
application/x-kword	KWord document	freedesktop.org.xml	\N	\N
application/x-kword-crypt	KWord document (encrypted)	freedesktop.org.xml	\N	\N
application/x-lha	LHA archive	freedesktop.org.xml	\N	\N
application/x-lhz	LHZ archive	freedesktop.org.xml	\N	\N
application/x-linguist	message catalog	freedesktop.org.xml	\N	\N
application/x-lyx	LyX document	freedesktop.org.xml	\N	\N
application/x-lzop	LZO archive	freedesktop.org.xml	\N	\N
application/x-macbinary	Macintosh MacBinary file	freedesktop.org.xml	\N	\N
application/x-magicpoint	MagicPoint presentation	freedesktop.org.xml	\N	\N
application/x-matroska	Matroska video	freedesktop.org.xml	\N	\N
application/x-mif	FrameMaker MIF document	freedesktop.org.xml	\N	\N
application/x-mozilla-bookmarks	Mozilla bookmarks	freedesktop.org.xml	\N	\N
application/x-ms-dos-executable	DOS/Windows executable	freedesktop.org.xml	\N	\N
application/x-msaccess	Microsoft Access Database	slix.xml	\N	\N
application/x-mswinurl	\N	freedesktop.org.xml	\N	\N
application/x-mswrite	Microsoft Write document	freedesktop.org.xml	\N	\N
application/x-msx-rom	MSX ROM	freedesktop.org.xml	\N	\N
application/x-n64-rom	Nintendo64 ROM	freedesktop.org.xml	\N	\N
application/x-nautilus-link	Nautilus link	freedesktop.org.xml	\N	\N
application/x-nes-rom	NES ROM	freedesktop.org.xml	\N	\N
application/x-netcdf	Unidata NetCDF document	freedesktop.org.xml	\N	\N
application/x-netscape-bookmarks	Netscape bookmarks	freedesktop.org.xml	\N	\N
application/x-object	object code	freedesktop.org.xml	\N	\N
application/x-ogg	Ogg Multimedia	slix.xml	application/ogg	\N
application/x-ole-storage	OLE2 compound document storage	freedesktop.org.xml	\N	\N
application/x-oleo	GNU Oleo spreadsheet	freedesktop.org.xml	\N	\N
application/x-palm-database	Palm OS database	freedesktop.org.xml	\N	\N
application/x-pef-executable	PEF executable	freedesktop.org.xml	\N	\N
application/x-perl	Perl script	freedesktop.org.xml	\N	\N
application/x-perl-module	PERL Module	slix.xml	application/x-perl	\N
application/x-php	PHP script	freedesktop.org.xml	\N	\N
application/x-pkcs12	PKCS#12 certificate bundle	freedesktop.org.xml	\N	\N
application/x-profile	profiler results	freedesktop.org.xml	\N	\N
application/x-pw	Pathetic Writer document	freedesktop.org.xml	\N	\N
application/x-python	Python script	freedesktop.org.xml	\N	\N
application/x-python-bytecode	Python bytecode	freedesktop.org.xml	\N	\N
application/x-quattropro	Quattro Pro spreadsheet	freedesktop.org.xml	\N	\N
application/x-qw	Quicken document	freedesktop.org.xml	\N	\N
application/x-rar	RAR archive	freedesktop.org.xml	\N	\N
application/x-reject	rejected patch	freedesktop.org.xml	\N	\N
application/x-rpm	RPM package	freedesktop.org.xml	\N	\N
application/x-ruby	Ruby script	freedesktop.org.xml	\N	\N
application/x-sc	\N	freedesktop.org.xml	\N	\N
application/x-scribus	Scribus Document	slix.xml	text/x-scribus	\N
application/x-shar	shell archive	freedesktop.org.xml	\N	\N
application/x-shared-library-la	shared library (la)	freedesktop.org.xml	\N	\N
application/x-sharedlib	shared library	freedesktop.org.xml	\N	\N
application/x-shellscript	shell script	freedesktop.org.xml	\N	\N
application/x-shockwave-flash	Shockwave Flash file	freedesktop.org.xml	\N	\N
application/x-siag	Siag spreadsheet	freedesktop.org.xml	\N	\N
application/x-slix-application	This is an application folder	slix.xml	\N	\N
application/x-slp	Stampede package	freedesktop.org.xml	\N	\N
application/x-smb-workgroup	Windows Workgroup	slix.xml	\N	\N
application/x-sms-rom	SMS/Game Gear ROM	freedesktop.org.xml	\N	\N
application/x-ssm	Spiral Synth Modular setup	slix.xml	\N	\N
application/x-staroffice	StarOffice 5.0	slix.xml	\N	\N
application/x-stuffit	Macintosh StuffIt archive	freedesktop.org.xml	\N	\N
application/x-sv4cpio	SV4 CPIO archive	freedesktop.org.xml	\N	\N
application/x-sv4crc	SV4 CPIP archive (with CRC)	freedesktop.org.xml	\N	\N
application/x-tar	tar archive	freedesktop.org.xml	\N	\N
application/x-tarz	tar archive (compressed)	freedesktop.org.xml	\N	\N
application/x-tbz	Bzipped Tar Archive	slix.xml	application/x-bzip-compressed-tar	\N
application/x-tex-gf	generic Metafont font file	freedesktop.org.xml	\N	\N
application/x-tex-pk	packed Metafont font file	freedesktop.org.xml	\N	\N
application/x-texmacs	GNU TeXMacs file	slix.xml	text/x-texmacs	\N
application/x-tgif	TGIF document	freedesktop.org.xml	\N	\N
application/x-tgz	Gzipped Tar Archive	slix.xml	application/x-compressed-tar	\N
application/x-theme	theme	freedesktop.org.xml	\N	\N
application/x-toutdoux	ToutDoux document	freedesktop.org.xml	\N	\N
application/x-trash	backup file	freedesktop.org.xml	\N	\N
application/x-troff	Troff document	freedesktop.org.xml	\N	\N
application/x-troff-man	Troff document (with manpage macros)	freedesktop.org.xml	\N	\N
application/x-troff-man-compressed	manual page (compressed)	freedesktop.org.xml	\N	\N
application/x-tuberling	Potato	slix.xml	\N	\N
application/x-tzo	tar archive (LZO-compressed)	freedesktop.org.xml	\N	\N
application/x-uml	Umbrello UML Modeller File	slix.xml	text/x-xmi	\N
application/x-ustar	ustar archive	freedesktop.org.xml	\N	\N
application/x-vnd.kde.kexi	Kexi Project File	slix.xml	\N	\N
application/x-vnd.kde.kplato	\N	slix.xml	\N	\N
application/x-vnd.kde.kugar.mixed	Kugar Archive File	slix.xml	\N	\N
application/x-wais-source	WAIS source code	freedesktop.org.xml	\N	\N
application/x-webarchive	Web Archive	slix.xml	\N	\N
application/x-wpg	WordPerfect/Drawperfect image	freedesktop.org.xml	\N	\N
application/x-x509-ca-cert	DER/PEM/Netscape-encoded X.509 certificate	freedesktop.org.xml	\N	\N
application/x-xbel	XBEL bookmarks	freedesktop.org.xml	\N	\N
application/x-zerosize	empty document	freedesktop.org.xml	\N	\N
application/x-zip	Zip Archive	slix.xml	application/zip	\N
application/x-zoo	zoo archive	freedesktop.org.xml	\N	\N
application/x-zynaddsubfx-master	ZynAddSubFx Synthesizer Master	slix.ljudmila.org.xml	\N	\N
application/xhtml+xml	XHTML page	freedesktop.org.xml	\N	\N
application/zip	ZIP archive	freedesktop.org.xml	\N	\N
audio/aac	AAC Sound	slix.xml	\N	\N
audio/ac3	Dolby Digital audio	freedesktop.org.xml	\N	\N
audio/basic	ULAW (Sun) audio	freedesktop.org.xml	\N	\N
audio/mp4	MPEG-4 Audio	slix.xml	\N	\N
audio/prs.sid	Commodore 64 audio	freedesktop.org.xml	\N	\N
audio/vnd.rn-realaudio	RealAudio File	slix.xml	audio/x-pn-realaudio	\N
audio/vorbis	Ogg Vorbis Audio	slix.xml	\N	\N
audio/x-adpcm	PCM audio	freedesktop.org.xml	\N	\N
audio/x-aifc	AIFC audio	freedesktop.org.xml	\N	\N
audio/x-aiff	AIFF/Amiga/Mac audio	freedesktop.org.xml	\N	\N
audio/x-aiffc	AIFF audio	freedesktop.org.xml	\N	\N
audio/x-flac	FLAC audio	freedesktop.org.xml	\N	\N
audio/x-it	Impulse Tracker audio	freedesktop.org.xml	\N	\N
audio/x-karaoke	Karaoke File	slix.xml	\N	\N
audio/x-matroska	Matroska Audio	slix.xml	application/x-matroska	\N
audio/x-midi	MIDI audio	freedesktop.org.xml	\N	\N
audio/x-mod	Amiga SoundTracker audio	freedesktop.org.xml	audio/x-it	\N
audio/x-mp2	MPEG Layer 2 audio file	\N	\N	\N
audio/x-mp3	MPEG Layer 3 audio file	freedesktop.org.xml	\N	\N
audio/x-mp3-playlist	MP3 playlist	freedesktop.org.xml	\N	\N
audio/x-mpeg	MP3 audio	freedesktop.org.xml	\N	\N
audio/x-mpegurl	MP3 audio (streamed)	freedesktop.org.xml	\N	\N
audio/x-ms-asx	Playlist	freedesktop.org.xml	\N	\N
audio/x-oggflac	Ogg FLAC Audio	slix.xml	\N	\N
audio/x-pn-realaudio	RealAudio broadcast	freedesktop.org.xml	\N	\N
audio/x-pn-realaudio-plugin	Netscape Neimenovan vstavek	slix.xml	\N	\N
audio/x-riff	RIFF audio	freedesktop.org.xml	\N	\N
audio/x-rosegarden	Rosegarden file	slix.xml	\N	\N
audio/x-rosegarden-device	Rosegarden device file	slix.xml	\N	\N
audio/x-rosegarden21	Rosegarden 2.1 file	slix.xml	\N	\N
audio/x-s3m	Scream Tracker 3 audio	freedesktop.org.xml	\N	\N
audio/x-scpls	MP3 ShoutCast playlist	freedesktop.org.xml	\N	\N
audio/x-sid	SIDplay music file	slix.ljudmila.org.xml	\N	\N
audio/x-soundfont	Soundfont	slix.xml	\N	\N
audio/x-speex	Speex Audio	slix.xml	\N	\N
audio/x-stm	Scream Tracker audio	freedesktop.org.xml	\N	\N
audio/x-voc	VOC audio	freedesktop.org.xml	\N	\N
audio/x-vorbis	Ogg Vorbis Audio	slix.xml	\N	\N
audio/x-wav	WAV audio	freedesktop.org.xml	\N	\N
audio/x-xi	Scream Tracker instrument	freedesktop.org.xml	\N	\N
audio/x-xm	FastTracker II audio	freedesktop.org.xml	\N	\N
fonts/folder	Fonts folder	slix.xml	\N	\N
fonts/system-folder	System fonts folder	slix.xml	\N	\N
image/cgm	Computer Graphics Metafile	freedesktop.org.xml	\N	\N
image/dpx	Digital Moving Picture Exchange image	freedesktop.org.xml	\N	\N
image/fax-g3	CCITT G3 fax	freedesktop.org.xml	\N	\N
image/g3fax	G3 fax image	freedesktop.org.xml	\N	\N
image/gif	GIF image	freedesktop.org.xml	\N	\N
image/ief	IEF image	freedesktop.org.xml	\N	\N
image/jp2	JPEG-2000 image	freedesktop.org.xml	\N	\N
image/jpeg	JPEG image	freedesktop.org.xml	\N	\N
image/pjpeg	JPEG Image	slix.xml	\N	\N
image/png	PNG image	freedesktop.org.xml	\N	\N
image/rle	Run Length Encoded bitmap	freedesktop.org.xml	\N	\N
image/svg+xml	scalable SVG image	freedesktop.org.xml	\N	\N
image/tiff	TIFF image	freedesktop.org.xml	\N	\N
image/vnd.djvu	DjVu image	freedesktop.org.xml	\N	\N
image/vnd.dwg	AutoCAD image	freedesktop.org.xml	\N	\N
image/vnd.dxf	DXF vector image	freedesktop.org.xml	\N	\N
image/x-3ds	3D Studio image	freedesktop.org.xml	\N	\N
image/x-applix-graphics	Applix Graphics image	freedesktop.org.xml	\N	\N
image/x-bmp	Windows BMP image	freedesktop.org.xml	\N	\N
image/x-cmu-raster	CMU raster image	freedesktop.org.xml	\N	\N
image/x-compressed-xcf	GIMP image (compressed)	freedesktop.org.xml	\N	\N
image/x-dcm	Digital Imaging and Communications in Medicine image	freedesktop.org.xml	\N	\N
image/x-dib	Device Independant Bitmap	freedesktop.org.xml	\N	\N
image/x-eps	Encapsulated PostScript image	freedesktop.org.xml	\N	\N
image/x-fits	Flexible Image Transport System	freedesktop.org.xml	\N	\N
image/x-fpx	FlashPix image	freedesktop.org.xml	\N	\N
image/x-icb	Truevision Targa image	freedesktop.org.xml	\N	\N
image/x-ico	Microsoft Windows icon	freedesktop.org.xml	\N	\N
image/x-iff	IFF image	freedesktop.org.xml	\N	\N
image/x-ilbm	ILBM image	freedesktop.org.xml	\N	\N
image/x-jng	JNG image	freedesktop.org.xml	\N	\N
image/x-lwo	LightWave object	freedesktop.org.xml	\N	\N
image/x-lws	LightWave scene	freedesktop.org.xml	\N	\N
image/x-msod	Microsoft Office drawing	freedesktop.org.xml	\N	\N
image/x-niff	\N	freedesktop.org.xml	\N	\N
image/x-pcx	PCX Image	freedesktop.org.xml	\N	\N
image/x-photo-cd	PhotoCD image	freedesktop.org.xml	\N	\N
image/x-pict	Macintosh Quickdraw/PICT drawing	freedesktop.org.xml	\N	\N
image/x-portable-anymap	PNM image	freedesktop.org.xml	\N	\N
image/x-portable-bitmap	Portable Bitmap File Format	freedesktop.org.xml	\N	\N
image/x-portable-graymap	Portable Graymap File Format	freedesktop.org.xml	\N	\N
image/x-portable-greymap	Portable Graymap Image	slix.xml	image/x-portable-graymap	\N
image/x-portable-pixmap	Portable Pixmap File Format	freedesktop.org.xml	\N	\N
image/x-psd	Photoshop image	freedesktop.org.xml	\N	\N
image/x-rgb	RGB image	freedesktop.org.xml	\N	\N
image/x-sgi	Silicon Graphics IRIS image	freedesktop.org.xml	\N	\N
image/x-sun-raster	SUN Rasterfile image	freedesktop.org.xml	\N	\N
image/x-targa	Truevision Targa Image	slix.xml	image/x-tga	\N
image/x-tga	TarGA image	freedesktop.org.xml	\N	\N
image/x-vnd.adobe.photoshop	Adobe Photoshop Image	slix.xml	image/x-psd	\N
image/x-vnd.trolltech.qpicture	QPicture Metafile	slix.xml	\N	\N
image/x-win-bitmap	Windows cursor	freedesktop.org.xml	\N	\N
image/x-wmf	Microsoft WMF file	freedesktop.org.xml	\N	\N
image/x-xbitmap	X BitMap image	freedesktop.org.xml	\N	\N
image/x-xbm	X BitMap Image	slix.xml	image/x-xbitmap	\N
image/x-xcf	GIMP image	freedesktop.org.xml	\N	\N
image/x-xcf-gimp	GIMP Native Image Format	slix.xml	image/x-xcf	\N
image/x-xcursor	X11 Mouse Cursor	slix.xml	\N	\N
image/x-xfig	XFig image	freedesktop.org.xml	\N	\N
image/x-xpixmap	X PixMap image	freedesktop.org.xml	\N	\N
image/x-xpm	X PixMap Image	slix.xml	image/x-xpixmap	\N
image/x-xwindowdump	X window image	freedesktop.org.xml	\N	\N
inode/blockdevice	block device	freedesktop.org.xml	\N	\N
inode/chardevice	character device	freedesktop.org.xml	\N	\N
inode/directory	folder	freedesktop.org.xml	\N	\N
inode/directory-locked	Locked Folder	slix.xml	\N	\N
inode/fifo	pipe	freedesktop.org.xml	\N	\N
inode/mount-point	mount point	freedesktop.org.xml	\N	\N
inode/socket	socket	freedesktop.org.xml	\N	\N
inode/symlink	symbolic link	freedesktop.org.xml	\N	\N
interface/x-winamp-skin	Compressed Winamp Skin	slix.xml	\N	\N
kdedevice/cdrom_mounted	Mounted CD-ROM	slix.xml	\N	\N
kdedevice/cdrom_unmounted	Unmounted CD-ROM	slix.xml	\N	\N
kdedevice/cdwriter_mounted	Mounted CD Writer	slix.xml	\N	\N
kdedevice/cdwriter_unmounted	Unmounted CD Writer	slix.xml	\N	\N
kdedevice/dvd_mounted	Mounted DVD	slix.xml	\N	\N
kdedevice/dvd_unmounted	Unmounted DVD	slix.xml	\N	\N
kdedevice/floppy5_mounted	Mounted 5¼" Floppy	slix.xml	\N	\N
kdedevice/floppy5_unmounted	Unmounted 5¼" Floppy	slix.xml	\N	\N
kdedevice/floppy_mounted	Mounted Floppy	slix.xml	\N	\N
kdedevice/floppy_unmounted	Unmounted Floppy	slix.xml	\N	\N
kdedevice/hdd_mounted	Mounted Hard Disc Partition	slix.xml	\N	\N
kdedevice/hdd_unmounted	Unmounted Hard Disc Partition	slix.xml	\N	\N
kdedevice/nfs_mounted	Mounted NFS Resource	slix.xml	\N	\N
kdedevice/nfs_unmounted	Unmounted NFS Resource	slix.xml	\N	\N
kdedevice/smb_mounted	Mounted Samba (Microsoft Network) Share	slix.xml	\N	\N
kdedevice/smb_unmounted	Unmounted Samba (Microsoft Network) Share	slix.xml	\N	\N
kdedevice/zip_mounted	Mounted Zip Disk	slix.xml	\N	\N
kdedevice/zip_unmounted	Unmounted Zip Disk	slix.xml	\N	\N
message/delivery-status	mail delivery report	freedesktop.org.xml	\N	\N
message/disposition-notification	mail disposition report	freedesktop.org.xml	\N	\N
message/external-body	reference to remote file	freedesktop.org.xml	\N	\N
message/news	Usenet news message	freedesktop.org.xml	\N	\N
message/partial	partial email message	freedesktop.org.xml	\N	\N
message/rfc822	email message	freedesktop.org.xml	\N	\N
message/x-gnu-rmail	GNU mail message	freedesktop.org.xml	\N	\N
model/vrml	VRML document	freedesktop.org.xml	\N	\N
multipart/alternative	message in several formats	freedesktop.org.xml	\N	\N
multipart/appledouble	Macintosh AppleDouble-encoded file	freedesktop.org.xml	\N	\N
multipart/digest	message digest	freedesktop.org.xml	\N	\N
multipart/encrypted	encrypted message	freedesktop.org.xml	\N	\N
multipart/mixed	compound documents	freedesktop.org.xml	\N	\N
multipart/related	compound document	freedesktop.org.xml	\N	\N
multipart/report	mail system report	freedesktop.org.xml	\N	\N
multipart/signed	signed message	freedesktop.org.xml	\N	\N
multipart/x-mixed-replace	stream of data (server push)	freedesktop.org.xml	\N	\N
print/class	Class of printers	slix.xml	\N	\N
print/driver	Printer driver	slix.xml	\N	\N
print/folder	Print folder	slix.xml	\N	\N
print/jobs	Print Jobs	slix.xml	\N	\N
print/manager	Print Management Tool	slix.xml	\N	\N
print/printer	Printer	slix.xml	\N	\N
print/printermodel	Printer model	slix.xml	\N	\N
text/calendar	iCalendar file	freedesktop.org.xml	\N	\N
text/css	Cascading Style Sheet	freedesktop.org.xml	\N	\N
text/directory	directory information file	freedesktop.org.xml	\N	\N
text/docbook	DocBook Document	slix.xml	\N	\N
text/enriched	enriched text document	freedesktop.org.xml	\N	\N
text/html	HTML page	freedesktop.org.xml	\N	\N
text/htmlh	help page	freedesktop.org.xml	\N	\N
text/mathml	MathML document	freedesktop.org.xml	text/x-mathml	\N
text/mrml	Multimedia Retrieval Markup Language Document	slix.xml	\N	\N
text/opml+xml	Outline Processor Markup Language	slix.ljudmila.org.xml	\N	\N
text/plain	plain text document	freedesktop.org.xml	\N	\N
text/rdf	Resource Description Framework (RDF) file	freedesktop.org.xml	text/rdf+xml	\N
text/rdf+xml	\N	clashes.xml	\N	\N
text/rfc822-headers	email headers	freedesktop.org.xml	\N	\N
text/richtext	rich text document	freedesktop.org.xml	\N	\N
text/rss	RDF Site Summary	freedesktop.org.xml	\N	\N
text/rtf	RTF Document	slix.xml	application/rtf	\N
text/sgml	SGML document	freedesktop.org.xml	\N	\N
text/spreadsheet	Spreadsheet interchange document	freedesktop.org.xml	\N	\N
text/tab-separated-values	text document (with tab-separated values)	freedesktop.org.xml	\N	\N
text/vnd.wap.wml	WML document	freedesktop.org.xml	\N	\N
text/x-adasrc	Ada source code	freedesktop.org.xml	\N	\N
text/x-aiml+xml	Artificial Intelligence Markup Language	slix.ljudmila.org.xml	\N	\N
text/x-authors	author list	freedesktop.org.xml	\N	\N
text/x-bibtex	Bibtex bibliographic data	freedesktop.org.xml	\N	\N
text/x-c++hdr	C++ source code header	freedesktop.org.xml	\N	\N
text/x-c++src	C++ source code	freedesktop.org.xml	\N	\N
text/x-chdr	C source code header	freedesktop.org.xml	\N	\N
text/x-comma-separated-values	text document (with comma-separated values)	freedesktop.org.xml	\N	\N
text/x-copying	software license terms	freedesktop.org.xml	\N	\N
text/x-credits	software author credits	freedesktop.org.xml	\N	\N
text/x-csharp	C# source code	freedesktop.org.xml	\N	\N
text/x-csrc	C source code	freedesktop.org.xml	\N	\N
text/x-csv	Text File with Comma Separated Values	slix.xml	text/x-comma-separated-values	\N
text/x-dcl	DCL script	freedesktop.org.xml	\N	\N
text/x-diff	Differences Between Files	slix.xml	text/x-patch	\N
text/x-dsl	DSSSL document	freedesktop.org.xml	\N	\N
text/x-dtd	document type definition	freedesktop.org.xml	\N	\N
text/x-emacs-lisp	Emacs Lisp source code	freedesktop.org.xml	\N	\N
text/x-fortran	Fortran source code	freedesktop.org.xml	\N	\N
text/x-gettext-translation	translated messages	freedesktop.org.xml	\N	\N
text/x-gettext-translation-template	message translation template	freedesktop.org.xml	\N	\N
text/x-graphviz	Graph Description in Graphviz DOT Format	slix.ljudmila.org.xml	\N	\N
text/x-gtkrc	GTK configuration	freedesktop.org.xml	\N	\N
text/x-haskell	Haskell source code	freedesktop.org.xml	\N	\N
text/x-idl	IDL document	freedesktop.org.xml	\N	\N
text/x-install	software installation instructions	freedesktop.org.xml	\N	\N
text/x-java	Java source code	freedesktop.org.xml	\N	\N
text/x-katefilelist	File List (for the Kate File List Loader Plugin)	slix.xml	\N	\N
text/x-kilepr	Kile Project	slix.xml	\N	\N
text/x-ksh	Korn shell script	freedesktop.org.xml	\N	\N
text/x-ksysv-log	SysV-Init Editor Log File	freedesktop.org.xml	\N	\N
text/x-latex	LaTeX Document	slix.xml	\N	\N
text/x-ldif	LDAP Addressbook	slix.xml	\N	\N
text/x-literate-haskell	Literate haskell source code	freedesktop.org.xml	\N	\N
text/x-log	application log	freedesktop.org.xml	\N	\N
text/x-makefile	Makefile	freedesktop.org.xml	\N	\N
text/x-mathml	\N	clashes.xml	\N	\N
text/x-moc	Qt Meta Object file	freedesktop.org.xml	\N	\N
text/x-mswinurl	Internet Shortcut	slix.xml	text/x-uri	\N
text/x-muse+xml	Muse sequencer File	slix.ljudmila.org.xml	\N	\N
text/x-objcsrc	Objective-C source code	freedesktop.org.xml	\N	\N
text/x-pascal	Pascal source code	freedesktop.org.xml	\N	\N
text/x-patch	differences between files	freedesktop.org.xml	\N	\N
text/x-readme	README document	freedesktop.org.xml	\N	\N
text/x-scheme	Scheme source code	freedesktop.org.xml	\N	\N
text/x-scribus	Scribus Document	slix.ljudmila.org.xml	\N	\N
text/x-setext	Setext document	freedesktop.org.xml	\N	\N
text/x-speech	Speech document	freedesktop.org.xml	\N	\N
text/x-sql	SQL code	freedesktop.org.xml	\N	\N
text/x-tcl	Tcl script	freedesktop.org.xml	\N	\N
text/x-tex	TeX document	freedesktop.org.xml	\N	\N
text/x-texinfo	TeXInfo document	freedesktop.org.xml	\N	\N
text/x-texmacs	GNU TeXmacs Document	slix.ljudmila.org.xml	\N	\N
text/x-troff-me	Troff ME input document	freedesktop.org.xml	\N	\N
text/x-troff-mm	Troff MM input document	freedesktop.org.xml	\N	\N
text/x-troff-ms	Troff MS input document	freedesktop.org.xml	\N	\N
text/x-uil	X-Motif UIL table	freedesktop.org.xml	\N	\N
text/x-uri	resource location	freedesktop.org.xml	\N	\N
text/x-vcalendar	vCalendar interchange file	freedesktop.org.xml	\N	\N
text/x-vcard	electronic business card	freedesktop.org.xml	\N	\N
text/x-xmi	XML Metadata Interchange file	freedesktop.org.xml	\N	\N
text/x-xslfo	XSL Formating Object file	freedesktop.org.xml	\N	\N
text/x-xslt	XSLT stylesheet	freedesktop.org.xml	\N	\N
text/xmcd	CD Database File	freedesktop.org.xml	\N	\N
text/xml	eXtensible Markup Language document	freedesktop.org.xml	\N	\N
video/isivideo	ISI video	freedesktop.org.xml	\N	\N
video/mp4	MPEG-4 Video	slix.xml	\N	\N
video/mpeg	MPEG video	freedesktop.org.xml	\N	\N
video/quicktime	QuickTime video	freedesktop.org.xml	\N	\N
video/vivo	Vivo video	freedesktop.org.xml	\N	\N
video/vnd.rn-realvideo	RealVideo File	slix.xml	\N	\N
video/wavelet	Wavelet video	freedesktop.org.xml	\N	\N
video/x-anim	ANIM animation	freedesktop.org.xml	\N	\N
video/x-avi	AVI video	freedesktop.org.xml	video/x-msvideo	\N
video/x-flic	AutoDesk FLIC animation	freedesktop.org.xml	\N	\N
video/x-matroska	Matroska Video	slix.xml	application/x-matroska	\N
video/x-mng	MNG animation	freedesktop.org.xml	\N	\N
video/x-ms-asf	Microsoft ASF video	freedesktop.org.xml	\N	\N
video/x-ms-wmv	Microsoft WMV video	freedesktop.org.xml	\N	\N
video/x-msvideo	Microsoft AVI video	freedesktop.org.xml	\N	\N
video/x-nsv	Nullsoft video	freedesktop.org.xml	\N	\N
video/x-ogm	Ogg/Ogm Video	slix.xml	\N	\N
video/x-real-video	RealVideo video	freedesktop.org.xml	\N	\N
video/x-sgi-movie	SGI video	freedesktop.org.xml	\N	\N
video/x-theora	Theora Video	slix.xml	\N	\N
text/x-objective-caml	Objective Caml code	\N	\N	\N
text/*	All text types	\N	\N	\N
image/*	All image types	\N	\N	\N
audio/*	All audio types	\N	\N	\N
video/*	All video types	\N	\N	\N
application/*	All application types	\N	\N	\N
\.


--
-- Data for TOC entry 563 (OID 184698)
-- Name: imp_pref; Type: TABLE DATA; Schema: public; Owner: postgres
--

COPY imp_pref (username, sig, fullname, replyto, lang) FROM stdin;
\.


--
-- Data for TOC entry 564 (OID 184703)
-- Name: imp_addr; Type: TABLE DATA; Schema: public; Owner: postgres
--

COPY imp_addr (username, address, nickname, fullname) FROM stdin;
\.


--
-- Data for TOC entry 565 (OID 184709)
-- Name: turba_objects; Type: TABLE DATA; Schema: public; Owner: postgres
--

COPY turba_objects (object_id, owner_id, object_name, object_alias, object_email, object_homeaddress, object_workaddress, object_homephone, object_workphone, object_cellphone, object_fax, object_title, object_company, object_notes) FROM stdin;
\.


--
-- Data for TOC entry 566 (OID 1867205)
-- Name: pg_ts_dict; Type: TABLE DATA; Schema: public; Owner: postgres
--

COPY pg_ts_dict (dict_name, dict_init, dict_initoption, dict_lexize, dict_comment) FROM stdin;
simple	1867217	\N	1867218	Simple example of dictionary.
en_stem	1867220	/usr/share/postgresql/contrib/english.stop	1867221	English Stemmer. Snowball.
ru_stem	1867223	/usr/share/postgresql/contrib/russian.stop	1867221	Russian Stemmer. Snowball.
ispell_template	1867225	\N	1867226	ISpell interface. Must have .dict and .aff files
synonym	1867228	\N	1867229	Example of synonym dictionary
\.


--
-- Data for TOC entry 567 (OID 1867231)
-- Name: pg_ts_parser; Type: TABLE DATA; Schema: public; Owner: postgres
--

COPY pg_ts_parser (prs_name, prs_start, prs_nexttoken, prs_end, prs_headline, prs_lextype, prs_comment) FROM stdin;
default	1867250	1867251	1867252	1867254	1867253	Parser from OpenFTS v0.34
\.


--
-- Data for TOC entry 568 (OID 1867256)
-- Name: pg_ts_cfg; Type: TABLE DATA; Schema: public; Owner: postgres
--

COPY pg_ts_cfg (ts_name, prs_name, locale) FROM stdin;
default	default	C
default_russian	default	ru_RU.KOI8-R
simple	default	\N
\.


--
-- Data for TOC entry 569 (OID 1867263)
-- Name: pg_ts_cfgmap; Type: TABLE DATA; Schema: public; Owner: postgres
--

COPY pg_ts_cfgmap (ts_name, tok_alias, dict_name) FROM stdin;
default	lword	{en_stem}
default	nlword	{simple}
default	word	{simple}
default	email	{simple}
default	url	{simple}
default	host	{simple}
default	sfloat	{simple}
default	version	{simple}
default	part_hword	{simple}
default	nlpart_hword	{simple}
default	lpart_hword	{en_stem}
default	hword	{simple}
default	lhword	{en_stem}
default	nlhword	{simple}
default	uri	{simple}
default	file	{simple}
default	float	{simple}
default	int	{simple}
default	uint	{simple}
default_russian	lword	{en_stem}
default_russian	nlword	{ru_stem}
default_russian	word	{ru_stem}
default_russian	email	{simple}
default_russian	url	{simple}
default_russian	host	{simple}
default_russian	sfloat	{simple}
default_russian	version	{simple}
default_russian	part_hword	{simple}
default_russian	nlpart_hword	{ru_stem}
default_russian	lpart_hword	{en_stem}
default_russian	hword	{ru_stem}
default_russian	lhword	{en_stem}
default_russian	nlhword	{ru_stem}
default_russian	uri	{simple}
default_russian	file	{simple}
default_russian	float	{simple}
default_russian	int	{simple}
default_russian	uint	{simple}
simple	lword	{simple}
simple	nlword	{simple}
simple	word	{simple}
simple	email	{simple}
simple	url	{simple}
simple	host	{simple}
simple	sfloat	{simple}
simple	version	{simple}
simple	part_hword	{simple}
simple	nlpart_hword	{simple}
simple	lpart_hword	{simple}
simple	hword	{simple}
simple	lhword	{simple}
simple	nlhword	{simple}
simple	uri	{simple}
simple	file	{simple}
simple	float	{simple}
simple	int	{simple}
simple	uint	{simple}
\.


--
-- Data for TOC entry 570 (OID 2051518)
-- Name: globs; Type: TABLE DATA; Schema: public; Owner: postgres
--

COPY globs (pattern, "type", registry) FROM stdin;
*%	application/x-trash	freedesktop.org.xml
*.*GF	application/x-tex-gf	slix.xml
*.*gf	application/x-tex-gf	freedesktop.org.xml
*.123	application/vnd.lotus-1-2-3	freedesktop.org.xml
*.3ds	image/x-3ds	freedesktop.org.xml
*.669	audio/x-mod	freedesktop.org.xml
*.AAC	audio/aac	slix.xml
*.ABW	application/x-abiword	slix.xml
*.AC3	audio/ac3	slix.xml
*.ACE	application/x-ace	slix.xml
*.AFM	application/x-afm	slix.xml
*.AI	application/illustrator	slix.xml
*.AIFF	audio/x-aiff	slix.xml
*.ARC	application/x-arc	slix.xml
*.ARJ	application/x-arj	slix.xml
*.ASF	video/x-ms-asf	slix.xml
*.ASX	video/x-ms-asf	slix.xml
*.AU	audio/basic	slix.xml
*.AUP	application/x-aup	slix.xml
*.AVI	video/x-msvideo	slix.xml
*.BDF	application/x-font-bdf	slix.xml
*.BDF.Z	application/x-font-bdf	slix.xml
*.BDF.gz	application/x-font-bdf	slix.xml
*.BLEND	application/x-blender	freedesktop.org.xml
*.BMP	image/x-bmp	slix.xml
*.BZ	application/x-bzip	slix.xml
*.BZ2	application/x-bzip2	slix.xml
*.C	text/x-c++src	freedesktop.org.xml
*.CDA	application/x-cda	slix.xml
*.CEL	application/x-celestia-script	slix.xml
*.CGM	image/cgm	slix.xml
*.CHM	application/chm	slix.xml
*.CLS	text/x-tex	slix.xml
*.CPP	text/x-c++src	slix.xml
*.CSSL	text/css	freedesktop.org.xml
*.CSV	text/x-csv	slix.xml
*.CUE	application/x-cue	slix.xml
*.DBF	application/x-dbase	slix.xml
*.DEB	application/x-deb	slix.xml
*.DIA	application/x-dia	slix.xml
*.DIA.GZ	application/x-dia	slix.xml
*.DOC	application/msword	slix.xml
*.DPR	text/x-pascal	slix.xml
*.DVI	application/x-dvi	slix.xml
*.DXF	image/vnd.dxf	slix.xml
*.EPS	image/x-eps	slix.xml
*.EPSF	image/x-eps	slix.xml
*.EPSI	image/x-eps	slix.xml
*.F	text/x-fortran	slix.xml
*.FIG	image/x-xfig	slix.xml
*.FLAC	audio/x-flac	slix.xml
*.FLC	video/x-flic	slix.xml
*.FLI	video/x-flic	slix.xml
*.G3	image/fax-g3	slix.xml
*.GIF	image/gif	slix.xml
*.GNUMERIC	application/x-gnumeric	slix.xml
*.GRA	application/x-graphite	slix.xml
*.GSF	application/x-font-ghostscript	slix.xml
*.H	text/x-c++hdr	slix.xml
*.HTM	text/html	slix.xml
*.HTML	text/html	slix.xml
*.HWP	application/x-hancomword	slix.xml
*.ICO	image/x-ico	slix.xml
*.ISO	application/x-iso	slix.xml
*.IT	audio/x-mod	slix.xml
*.JNG	image/x-jng	slix.xml
*.JP2	image/jp2	slix.xml
*.JPEG	image/jpeg	slix.xml
*.JPG	image/jpeg	slix.xml
*.KAR	audio/x-karaoke	slix.xml
*.KCSRC	application/x-kcsrc	slix.xml
*.LDIF	text/x-ldif	slix.xml
*.LHA	application/x-lha	slix.xml
*.LTX	text/x-tex	slix.xml
*.LZH	application/x-lha	slix.xml
*.M15	audio/x-mod	slix.xml
*.M3U	audio/x-mpegurl	slix.xml
*.M4A	audio/mp4	slix.xml
*.M4V	video/mp4	slix.xml
*.MDA	application/x-msaccess	slix.xml
*.MDB	application/x-msaccess	slix.xml
*.MDE	application/x-msaccess	slix.xml
*.MGP	application/x-magicpoint	slix.xml
*.MID	audio/x-midi	slix.xml
*.MKA	audio/x-matroska	slix.xml
*.MKV	video/x-matroska	slix.xml
*.MML	application/mathml+xml	slix.xml
*.MNG	video/x-mng	slix.xml
*.MOD	audio/x-mod	slix.xml
*.MOOV	video/quicktime	slix.xml
*.MOV	video/quicktime	slix.xml
*.MP3	audio/x-mp3	slix.xml
*.MP4	video/mp4	slix.xml
*.MPEG	video/mpeg	slix.xml
*.MPG	video/mpeg	slix.xml
*.MRML	text/mrml	slix.xml
*.MSOD	image/x-msod	slix.xml
*.MTM	audio/x-mod	slix.xml
*.MooV	video/quicktime	slix.xml
*.NSV	video/x-nsv	freedesktop.org.xml
*.OGG	application/ogg	slix.xml
*.OGM	video/x-ogm	slix.xml
*.OTF	application/x-font-otf	slix.xml
*.P	text/x-pascal	slix.xml
*.P10	application/pkcs10	slix.xml
*.P12	application/x-pkcs12	slix.xml
*.P7C	application/pkcs7-mime	slix.xml
*.P7M	application/pkcs7-mime	slix.xml
*.P7S	application/pkcs7-signature	slix.xml
*.PAS	text/x-pascal	slix.xml
*.PBM	image/x-portable-bitmap	slix.xml
*.PBMRAW	image/x-portable-bitmap	slix.xml
*.PCD	image/x-photo-cd	slix.xml
*.PCF	application/x-font-pcf	slix.xml
*.PCF.Z	application/x-font-pcf	slix.xml
*.PCF.gz	application/x-font-pcf	slix.xml
*.PCX	image/x-pcx	slix.xml
*.PDB	application/vnd.palm	slix.xml
*.PDF	application/pdf	slix.xml
*.PERL	application/x-perl	slix.xml
*.PFA	application/x-font-type1	slix.xml
*.PFB	application/x-font-type1	slix.xml
*.PGM	image/x-portable-greymap	slix.xml
*.PGMRAW	image/x-portable-greymap	slix.xml
*.PHP	application/x-php	slix.xml
*.PHP3	application/x-php	slix.xml
*.PHP4	application/x-php	slix.xml
*.PL	application/x-perl	slix.xml
*.PLS	audio/x-scpls	slix.xml
*.PM	application/x-perl-module	slix.xml
*.PNG	image/png	slix.xml
*.PNM	image/x-portable-pixmap	slix.xml
*.PP	text/x-pascal	slix.xml
*.PPM	image/x-portable-pixmap	slix.xml
*.PPMRAW	image/x-portable-pixmap	slix.xml
*.PPS	application/mspowerpoint	slix.xml
*.PPT	application/mspowerpoint	slix.xml
*.PPZ	application/mspowerpoint	slix.xml
*.PRC	application/vnd.palm	slix.xml
*.PS	application/postscript	slix.xml
*.PSD	image/x-vnd.adobe.photoshop	slix.xml
*.QT	video/quicktime	slix.xml
*.QTVR	video/quicktime	slix.xml
*.RA	audio/vnd.rn-realaudio	slix.xml
*.RAM	audio/vnd.rn-realaudio	slix.xml
*.RAR	application/x-rar	slix.xml
*.RB	application/x-ruby	slix.xml
*.RDF	text/rdf	slix.xml
*.RG	audio/x-rosegarden	slix.xml
*.RGD	audio/x-rosegarden-device	slix.xml
*.RM	application/vnd.rn-realmedia	slix.xml
*.RSS	text/rss	slix.xml
*.RTF	text/rtf	slix.xml
*.RUBY	application/x-ruby	slix.xml
*.RV	video/vnd.rn-realvideo	slix.xml
*.S3M	audio/x-mod	slix.xml
*.SAM	application/x-amipro	slix.xml
*.SCD	application/x-scribus	slix.xml
*.SCD.GZ	application/x-scribus	slix.xml
*.SDC	application/vnd.stardivision.calc	slix.xml
*.SDD	application/vnd.stardivision.impress	slix.xml
*.SDW	application/vnd.stardivision.writer	slix.xml
*.SF2	audio/x-soundfont	slix.xml
*.SGML	text/sgml	slix.xml
*.SLA	application/x-scribus	slix.xml
*.SLA.GZ	application/x-scribus	slix.xml
*.SND	audio/basic	slix.xml
*.SNF	application/x-font-snf	slix.xml
*.SNF.Z	application/x-font-snf	slix.xml
*.SNF.gz	application/x-font-snf	slix.xml
*.SPD	application/x-font-speedo	slix.xml
*.SPX	audio/x-speex	slix.xml
*.SQL	text/x-sql	slix.xml
*.SSM	application/x-ssm	slix.xml
*.STM	audio/x-mod	slix.xml
*.STY	text/x-tex	slix.xml
*.SVG	image/svg+xml	slix.xml
*.SVGZ	image/svg+xml	slix.xml
*.SXC	application/vnd.sun.xml.calc	slix.xml
*.SXD	application/vnd.sun.xml.draw	slix.xml
*.SXI	application/vnd.sun.xml.impress	slix.xml
*.SXW	application/vnd.sun.xml.writer	slix.xml
*.TEX	text/x-tex	slix.xml
*.TGA	image/x-targa	slix.xml
*.TIF	image/tiff	slix.xml
*.TIFF	image/tiff	slix.xml
*.TM	application/x-texmacs	slix.xml
*.TTC	application/x-font-ttc	slix.xml
*.TTF	application/x-font-ttf	slix.xml
*.ULT	audio/x-mod	slix.xml
*.UNI	audio/x-mod	slix.xml
*.URL	text/x-mswinurl	slix.xml
*.VCF	text/x-vcard	slix.xml
*.VCT	text/x-vcard	slix.xml
*.WAR	application/x-webarchive	slix.xml
*.WAV	audio/x-wav	slix.xml
*.WB1	application/x-quattropro	slix.xml
*.WB2	application/x-quattropro	slix.xml
*.WB3	application/x-quattropro	slix.xml
*.WMF	image/x-wmf	slix.xml
*.WML	text/vnd.wap.wml	slix.xml
*.WPD	application/wordperfect	slix.xml
*.WSZ	interface/x-winamp-skin	slix.xml
*.XBM	image/x-xbm	slix.xml
*.XCF	image/x-xcf	slix.xml
*.XLC	application/msexcel	slix.xml
*.XLL	application/msexcel	slix.xml
*.XLM	application/msexcel	slix.xml
*.XLS	application/msexcel	slix.xml
*.XLW	application/msexcel	slix.xml
*.XM	audio/x-mod	freedesktop.org.xml
*.XMI	application/x-uml	slix.xml
*.XML	text/xml	slix.xml
*.XPM	image/x-xpm	slix.xml
*.XUL	application/vnd.mozilla.xul+xml	slix.xml
*.Z	application/x-compress	freedesktop.org.xml
*.ZIP	application/x-zip	slix.xml
*.ZOO	application/x-zoo	slix.xml
*.a	application/x-archive	freedesktop.org.xml
*.aac	audio/aac	slix.xml
*.abw	application/x-abiword	freedesktop.org.xml
*.abw.CRASHED	application/x-abiword	freedesktop.org.xml
*.abw.bz2	application/x-abiword	slix.xml
*.abw.gz	application/x-abiword	freedesktop.org.xml
*.ac3	audio/ac3	freedesktop.org.xml
*.ace	application/x-ace	slix.xml
*.adb	text/x-adasrc	freedesktop.org.xml
*.ads	text/x-adasrc	freedesktop.org.xml
*.afm	application/x-afm	slix.xml
*.afm	application/x-font-afm	freedesktop.org.xml
*.ag	application/x-applixgraphics	slix.xml
*.ag	image/x-applix-graphics	freedesktop.org.xml
*.ai	application/illustrator	freedesktop.org.xml
*.aif	audio/x-aiff	freedesktop.org.xml
*.aifc	audio/x-aiff	freedesktop.org.xml
*.aiff	audio/x-aiff	freedesktop.org.xml
*.aiml	text/x-aiml+xml	slix.ljudmila.org.xml
*.al	application/x-perl	freedesktop.org.xml
*.anim[1-9j]	video/x-anim	freedesktop.org.xml
*.app	application/x-slix-application	slix.xml
*.arc	application/x-arc	slix.xml
*.arj	application/x-arj	freedesktop.org.xml
*.arts	application/x-artsbuilder	slix.xml
*.as	application/x-applix-spreadsheet	freedesktop.org.xml
*.as	application/x-applixspread	slix.xml
*.asc	application/pgp-encrypted	slix.xml
*.asc	application/pgp-keys	slix.xml
*.asc	text/plain	freedesktop.org.xml
*.asf	video/x-ms-asf	freedesktop.org.xml
*.asp	application/x-asp	freedesktop.org.xml
*.asx	video/x-ms-asf	freedesktop.org.xml
*.au	audio/basic	freedesktop.org.xml
*.aup	application/x-aup	slix.xml
*.avi	video/x-msvideo	freedesktop.org.xml
*.aw	application/x-applix-word	freedesktop.org.xml
*.aw	application/x-applixword	slix.xml
*.bak	application/x-trash	freedesktop.org.xml
*.bcpio	application/x-bcpio	freedesktop.org.xml
*.bdf	application/x-font-bdf	freedesktop.org.xml
*.bdf.Z	application/x-font-bdf	slix.xml
*.bdf.gz	application/x-font-bdf	slix.xml
*.bib	text/x-bibtex	freedesktop.org.xml
*.bin	application/octet-stream	freedesktop.org.xml
*.blend	application/x-blender	freedesktop.org.xml
*.blend*	application/x-blender	slix.ljudmila.org.xml
*.blender	application/x-blender	freedesktop.org.xml
*.bmp	image/x-bmp	freedesktop.org.xml
*.bz	application/x-bzip	freedesktop.org.xml
*.bz2	application/x-bzip	freedesktop.org.xml
*.bz2	application/x-bzip2	slix.xml
*.bzabw	application/x-abiword	slix.xml
*.c	text/x-csrc	freedesktop.org.xml
*.c++	text/x-c++src	freedesktop.org.xml
*.cc	text/x-c++src	freedesktop.org.xml
*.cda	application/x-cda	slix.xml
*.cdf	application/x-netcdf	freedesktop.org.xml
*.cdr	application/vnd.corel-draw	freedesktop.org.xml
*.cel	application/x-celestia-script	slix.xml
*.cer	application/x-x509-ca-cert	freedesktop.org.xml
*.cert	application/x-x509-ca-cert	freedesktop.org.xml
*.cgi	application/x-cgi	freedesktop.org.xml
*.cgm	image/cgm	freedesktop.org.xml
*.chm	application/chm	slix.xml
*.chm	application/x-chm	clashes.xml
*.chrt	application/x-kchart	freedesktop.org.xml
*.class	application/x-java	freedesktop.org.xml
*.cls	text/x-tex	freedesktop.org.xml
*.course	application/x-kourse	slix.xml
*.cpio	application/x-cpio	freedesktop.org.xml
*.cpio.gz	application/x-cpio-compressed	freedesktop.org.xml
*.cpp	text/x-c++src	freedesktop.org.xml
*.crt	application/x-x509-ca-cert	freedesktop.org.xml
*.cs	text/x-csharp	freedesktop.org.xml
*.csh	application/x-shellscript	freedesktop.org.xml
*.css	text/css	freedesktop.org.xml
*.csv	text/x-comma-separated-values	freedesktop.org.xml
*.csv	text/x-csv	slix.xml
*.cue	application/x-cue	slix.xml
*.cur	image/x-win-bitmap	freedesktop.org.xml
*.cxx	text/x-c++src	freedesktop.org.xml
*.dat	video/mpeg	freedesktop.org.xml
*.dbf	application/x-dbase	freedesktop.org.xml
*.dc	application/x-dc-rom	freedesktop.org.xml
*.dcl	text/x-dcl	freedesktop.org.xml
*.dcm	image/x-dcm	freedesktop.org.xml
*.deb	application/x-deb	freedesktop.org.xml
*.deb	application/x-debian-package	slix.xml
*.der	application/x-x509-ca-cert	freedesktop.org.xml
*.desktop	application/x-desktop	freedesktop.org.xml
*.dia	application/x-dia	slix.xml
*.dia	application/x-dia-diagram	freedesktop.org.xml
*.dia.gz	application/x-dia	slix.xml
*.dia.gz	application/x-dia-diagram	clashes.xml
*.dif	text/x-diff	slix.xml
*.dif	text/x-patch	clashes.xml
*.diff	text/x-diff	slix.xml
*.diff	text/x-patch	freedesktop.org.xml
*.djv	image/vnd.djvu	freedesktop.org.xml
*.djvu	image/vnd.djvu	freedesktop.org.xml
*.doc	application/msword	slix.xml
*.doc	application/vnd.ms-word	freedesktop.org.xml
*.docbook	text/docbook	slix.xml
*.dot	application/vnd.ms-word	slix.ljudmila.org.xml
*.dot	text/x-graphviz	slix.ljudmila.org.xml
*.dpr	text/x-pascal	slix.xml
*.dsl	text/x-dsl	freedesktop.org.xml
*.dtd	text/x-dtd	freedesktop.org.xml
*.dvi	application/x-dvi	freedesktop.org.xml
*.dvi.bz2	application/x-bz2dvi	slix.xml
*.dvi.gz	application/x-gzdvi	slix.xml
*.dwg	image/vnd.dwg	freedesktop.org.xml
*.dxf	image/vnd.dxf	freedesktop.org.xml
*.edu	application/x-edu	slix.xml
*.edugallery	application/x-edugallery	slix.xml
*.egon	application/x-egon	freedesktop.org.xml
*.el	text/x-emacs-lisp	freedesktop.org.xml
*.eps	image/x-eps	freedesktop.org.xml
*.epsf	image/x-eps	freedesktop.org.xml
*.epsi	image/x-eps	freedesktop.org.xml
*.etheme	application/x-e-theme	freedesktop.org.xml
*.etx	text/x-setext	freedesktop.org.xml
*.exe	application/x-executable	freedesktop.org.xml
*.exe	application/x-ms-dos-executable	freedesktop.org.xml
*.ez	application/andrew-inset	freedesktop.org.xml
*.f	text/x-fortran	freedesktop.org.xml
*.f77	text/x-fortran	slix.xml
*.f90	text/x-fortran	slix.xml
*.f95	text/x-fortran	slix.xml
*.fig	image/x-xfig	freedesktop.org.xml
*.fits	image/x-fits	freedesktop.org.xml
*.flac	audio/x-flac	freedesktop.org.xml
*.flc	video/x-flic	freedesktop.org.xml
*.fli	video/x-flic	freedesktop.org.xml
*.flw	application/x-kivio	freedesktop.org.xml
*.fo	text/x-xslfo	freedesktop.org.xml
*.for	text/x-fortran	slix.xml
*.fpp	text/x-fortran	slix.xml
*.ftn	text/x-fortran	slix.xml
*.g3	image/fax-g3	freedesktop.org.xml
*.gb	application/x-gameboy-rom	freedesktop.org.xml
*.gcrd	text/x-vcard	freedesktop.org.xml
*.gen	application/x-genesis-rom	freedesktop.org.xml
*.gg	application/x-sms-rom	freedesktop.org.xml
*.gif	image/gif	freedesktop.org.xml
*.glade	application/x-glade	freedesktop.org.xml
*.gmo	application/x-gettext-translation	freedesktop.org.xml
*.gnc	application/x-gnucash	freedesktop.org.xml
*.gnucash	application/x-gnucash	freedesktop.org.xml
*.gnumeric	application/x-gnumeric	freedesktop.org.xml
*.gpg	application/pgp	clashes.xml
*.gpg	application/pgp-encrypted	slix.xml
*.gpg	application/pgp-keys	slix.xml
*.gra	application/x-graphite	freedesktop.org.xml
*.graphviz	text/x-graphviz	slix.ljudmila.org.xml
*.gsf	application/x-font-ghostscript	slix.xml
*.gsf	application/x-font-type1	freedesktop.org.xml
*.gtar	application/x-gtar	freedesktop.org.xml
*.gz	application/x-gzip	freedesktop.org.xml
*.h	text/x-chdr	freedesktop.org.xml
*.h++	text/x-chdr	freedesktop.org.xml
*.hdf	application/x-hdf	freedesktop.org.xml
*.hh	text/x-c++hdr	freedesktop.org.xml
*.hp	text/x-chdr	freedesktop.org.xml
*.hpgl	application/vnd.hp-hpgl	freedesktop.org.xml
*.hpp	text/x-c++hdr	slix.xml
*.hs	text/x-haskell	freedesktop.org.xml
*.htm	text/html	freedesktop.org.xml
*.html	text/html	freedesktop.org.xml
*.hwp	application/x-hancomword	slix.xml
*.icb	image/x-icb	freedesktop.org.xml
*.ico	image/x-ico	freedesktop.org.xml
*.ics	text/calendar	freedesktop.org.xml
*.idl	text/x-idl	freedesktop.org.xml
*.ief	image/ief	freedesktop.org.xml
*.iff	image/x-iff	freedesktop.org.xml
*.ilbm	image/x-ilbm	freedesktop.org.xml
*.iso	application/x-cd-image	freedesktop.org.xml
*.iso	application/x-iso	slix.xml
*.it	audio/x-it	freedesktop.org.xml
*.it	audio/x-mod	slix.xml
*.jar	application/x-jar	freedesktop.org.xml
*.java	text/x-java	freedesktop.org.xml
*.jng	image/x-jng	freedesktop.org.xml
*.jp2	image/jp2	freedesktop.org.xml
*.jpe	image/jpeg	freedesktop.org.xml
*.jpeg	image/jpeg	freedesktop.org.xml
*.jpg	image/jpeg	freedesktop.org.xml
*.jpr	application/x-jbuilder-project	freedesktop.org.xml
*.jpx	application/x-jbuilder-project	freedesktop.org.xml
*.js	application/x-javascript	freedesktop.org.xml
*.k3b	application/x-k3b	slix.xml
*.kar	audio/x-karaoke	slix.xml
*.karbon	application/x-karbon	freedesktop.org.xml
*.katefl	text/x-katefilelist	slix.xml
*.kcsrc	application/x-kcsrc	slix.xml
*.kdelnk	application/x-desktop	freedesktop.org.xml
*.kdevelop	application/x-kdevelop	slix.xml
*.kexi	application/x-vnd.kde.kexi	slix.xml
*.kfo	application/x-kformula	freedesktop.org.xml
*.kgeo	application/x-kgeo	slix.xml
*.kgt	application/x-kgetlist	slix.xml
*.kig	application/x-kig	slix.xml
*.kil	application/x-killustrator	freedesktop.org.xml
*.kilepr	text/x-kilepr	slix.xml
*.kmdr	application/x-kommander	slix.xml
*.kolf	application/x-kourse	slix.xml
*.kolfgame	application/x-kolf	slix.xml
*.kon	application/x-kontour	freedesktop.org.xml
*.kourse	application/x-kourse	slix.xml
*.kplato	application/x-vnd.kde.kplato	slix.xml
*.kplatot	application/x-vnd.kde.kplato	slix.xml
*.kpm	application/x-kpovmodeler	freedesktop.org.xml
*.kpr	application/x-kpresenter	freedesktop.org.xml
*.kpt	application/x-kpresenter	freedesktop.org.xml
*.kra	application/x-krita	freedesktop.org.xml
*.ksp	application/x-kspread	freedesktop.org.xml
*.ksysv	application/x-ksysv-package	slix.xml
*.ksysv_log	text/x-ksysv-log	slix.xml
*.kud	application/x-kugar	freedesktop.org.xml
*.kug	application/x-vnd.kde.kugar.mixed	slix.xml
*.kut	application/x-kudesigner	slix.xml
*.kwd	application/x-kword	freedesktop.org.xml
*.kwl	application/x-kde-wallet	slix.xml
*.kwt	application/x-kword	freedesktop.org.xml
*.la	application/x-shared-library-la	freedesktop.org.xml
*.latex	text/x-latex	slix.xml
*.ldif	text/x-ldif	slix.xml
*.lha	application/x-lha	freedesktop.org.xml
*.lhs	text/x-literate-haskell	freedesktop.org.xml
*.lhz	application/x-lhz	freedesktop.org.xml
*.log	text/x-log	freedesktop.org.xml
*.ltx	text/x-tex	freedesktop.org.xml
*.lwo	image/x-lwo	freedesktop.org.xml
*.lwob	image/x-lwo	freedesktop.org.xml
*.lws	image/x-lws	freedesktop.org.xml
*.lyx	application/x-lyx	freedesktop.org.xml
*.lzh	application/x-lha	freedesktop.org.xml
*.lzo	application/x-lzop	freedesktop.org.xml
*.m	text/x-objcsrc	freedesktop.org.xml
*.m15	audio/x-mod	freedesktop.org.xml
*.m3u	audio/x-mpegurl	freedesktop.org.xml
*.m4a	audio/mp4	slix.xml
*.m4v	video/mp4	slix.xml
*.man	application/x-troff-man	freedesktop.org.xml
*.mas_zyn	application/x-zynaddsubfx-master	slix.ljudmila.org.xml
*.md	application/x-genesis-rom	freedesktop.org.xml
*.mda	application/x-msaccess	slix.xml
*.mdb	application/x-msaccess	slix.xml
*.mde	application/x-msaccess	slix.xml
*.me	text/x-troff-me	freedesktop.org.xml
*.med	text/x-muse+xml	slix.ljudmila.org.xml
*.mgp	application/x-magicpoint	freedesktop.org.xml
*.mid	audio/x-midi	freedesktop.org.xml
*.midi	audio/x-midi	freedesktop.org.xml
*.mif	application/x-mif	freedesktop.org.xml
*.mka	application/x-matroska	clashes.xml
*.mka	audio/x-matroska	slix.xml
*.mkv	application/x-matroska	freedesktop.org.xml
*.mkv	video/x-matroska	slix.xml
*.mm	text/x-troff-mm	freedesktop.org.xml
*.mml	application/mathml+xml	slix.xml
*.mml	text/mathml	freedesktop.org.xml
*.mng	video/x-mng	freedesktop.org.xml
*.moc	text/x-moc	freedesktop.org.xml
*.mod	audio/x-mod	freedesktop.org.xml
*.moov	video/quicktime	freedesktop.org.xml
*.mov	video/quicktime	freedesktop.org.xml
*.movie	video/x-sgi-movie	freedesktop.org.xml
*.mp2	video/mpeg	freedesktop.org.xml
*.mp3	audio/x-mp3	freedesktop.org.xml
*.mp4	video/mp4	slix.xml
*.mpe	video/mpeg	freedesktop.org.xml
*.mpeg	video/mpeg	freedesktop.org.xml
*.mpg	video/mpeg	freedesktop.org.xml
*.mrml	text/mrml	slix.xml
*.ms	text/x-troff-ms	freedesktop.org.xml
*.msod	image/x-msod	freedesktop.org.xml
*.msx	application/x-msx-rom	freedesktop.org.xml
*.mtm	audio/x-mod	freedesktop.org.xml
*.n64	application/x-n64-rom	freedesktop.org.xml
*.nb	application/mathematica	slix.ljudmila.org.xml
*.nc	application/x-netcdf	freedesktop.org.xml
*.nes	application/x-nes-rom	freedesktop.org.xml
*.nsv	video/x-nsv	freedesktop.org.xml
*.o	application/x-object	freedesktop.org.xml
*.obj	application/x-tgif	freedesktop.org.xml
*.oda	application/oda	freedesktop.org.xml
*.ogg	application/ogg	freedesktop.org.xml
*.ogm	video/x-ogm	slix.xml
*.old	application/x-trash	freedesktop.org.xml
*.oleo	application/x-oleo	freedesktop.org.xml
*.opml	text/opml+xml	slix.ljudmila.org.xml
*.otf	application/x-font-otf	slix.xml
*.p	text/x-pascal	freedesktop.org.xml
*.p10	application/pkcs10	slix.xml
*.p12	application/x-pkcs12	freedesktop.org.xml
*.p7c	application/pkcs7-mime	slix.xml
*.p7m	application/pkcs7-mime	slix.xml
*.p7s	application/pkcs7-signature	freedesktop.org.xml
*.pas	text/x-pascal	freedesktop.org.xml
*.patch	text/x-diff	slix.xml
*.patch	text/x-patch	freedesktop.org.xml
*.pbm	image/x-portable-bitmap	freedesktop.org.xml
*.pbmraw	image/x-portable-bitmap	slix.xml
*.pcd	image/x-photo-cd	freedesktop.org.xml
*.pcf	application/x-font-pcf	freedesktop.org.xml
*.pcf.Z	application/x-font-pcf	slix.xml
*.pcf.Z	application/x-font-type1	freedesktop.org.xml
*.pcf.gz	application/x-font-pcf	slix.xml
*.pcf.gz	application/x-font-type1	clashes.xml
*.pcl	application/vnd.hp-pcl	freedesktop.org.xml
*.pcx	image/x-pcx	slix.xml
*.pdb	application/vnd.palm	freedesktop.org.xml
*.pdf	application/pdf	freedesktop.org.xml
*.pem	application/x-x509-ca-cert	freedesktop.org.xml
*.perl	application/x-perl	freedesktop.org.xml
*.pfa	application/x-font-type1	freedesktop.org.xml
*.pfb	application/x-font-type1	freedesktop.org.xml
*.pfx	application/x-pkcs12	freedesktop.org.xml
*.pgm	image/x-portable-graymap	freedesktop.org.xml
*.pgm	image/x-portable-greymap	slix.xml
*.pgmraw	image/x-portable-graymap	clashes.xml
*.pgmraw	image/x-portable-greymap	slix.xml
*.pgn	application/x-chess-pgn	freedesktop.org.xml
*.pgp	application/pgp	freedesktop.org.xml
*.pgp	application/pgp-encrypted	slix.xml
*.pgp	application/pgp-keys	slix.xml
*.php	application/x-php	freedesktop.org.xml
*.php3	application/x-php	freedesktop.org.xml
*.php4	application/x-php	freedesktop.org.xml
*.pict	image/x-pict	freedesktop.org.xml
*.pict1	image/x-pict	freedesktop.org.xml
*.pict2	image/x-pict	freedesktop.org.xml
*.pl	application/x-perl	freedesktop.org.xml
*.pls	audio/x-scpls	freedesktop.org.xml
*.pm	application/x-perl	freedesktop.org.xml
*.pm	application/x-perl-module	slix.xml
*.png	image/png	freedesktop.org.xml
*.pnm	image/x-portable-anymap	freedesktop.org.xml
*.pnm	image/x-portable-pixmap	slix.xml
*.po	application/x-gettext	slix.xml
*.po	text/x-gettext-translation	freedesktop.org.xml
*.pot	application/vnd.ms-powerpoint	freedesktop.org.xml
*.pot	application/x-gettext	slix.xml
*.pot	application/x-gettext-translation-template	clashes.xml
*.pot	text/x-gettext-translation-template	freedesktop.org.xml
*.pp	text/x-pascal	slix.xml
*.ppm	image/x-portable-pixmap	freedesktop.org.xml
*.ppmraw	image/x-portable-pixmap	slix.xml
*.pps	application/mspowerpoint	slix.xml
*.pps	application/vnd.ms-powerpoint	freedesktop.org.xml
*.ppt	application/mspowerpoint	slix.xml
*.ppt	application/vnd.ms-powerpoint	freedesktop.org.xml
*.ppz	application/mspowerpoint	slix.xml
*.ppz	application/vnd.ms-powerpoint	freedesktop.org.xml
*.prc	application/vnd.palm	slix.xml
*.ps	application/postscript	freedesktop.org.xml
*.ps.gz	application/x-gzpostscript	freedesktop.org.xml
*.psd	image/x-psd	freedesktop.org.xml
*.psd	image/x-vnd.adobe.photoshop	slix.xml
*.psf	application/x-font-linux-psf	freedesktop.org.xml
*.psid	audio/prs.sid	freedesktop.org.xml
*.pw	application/x-pw	freedesktop.org.xml
*.py	application/x-python	freedesktop.org.xml
*.pyc	application/x-python-bytecode	freedesktop.org.xml
*.pyo	application/x-python-bytecode	freedesktop.org.xml
*.qif	application/x-qw	freedesktop.org.xml
*.qpic	image/x-vnd.trolltech.qpicture	slix.xml
*.qt	video/quicktime	freedesktop.org.xml
*.qtvr	video/quicktime	freedesktop.org.xml
*.ra	audio/vnd.rn-realaudio	slix.xml
*.ra	audio/x-pn-realaudio	freedesktop.org.xml
*.ram	audio/vnd.rn-realaudio	slix.xml
*.ram	audio/x-pn-realaudio	freedesktop.org.xml
*.rar	application/x-rar	freedesktop.org.xml
*.ras	image/x-cmu-raster	freedesktop.org.xml
*.rb	application/x-ruby	slix.xml
*.rdf	text/rdf	freedesktop.org.xml
*.rej	application/x-reject	freedesktop.org.xml
*.rg	audio/x-rosegarden	slix.xml
*.rgb	image/x-rgb	freedesktop.org.xml
*.rgd	audio/x-rosegarden-device	slix.xml
*.rle	image/rle	freedesktop.org.xml
*.rm	application/vnd.rn-realmedia	slix.xml
*.rm	audio/x-pn-realaudio	freedesktop.org.xml
*.roff	application/x-troff	freedesktop.org.xml
*.rose	audio/x-rosegarden21	slix.xml
*.rpm	application/x-rpm	freedesktop.org.xml
*.rss	text/rss	freedesktop.org.xml
*.rtf	application/rtf	freedesktop.org.xml
*.rtf	text/rtf	slix.xml
*.rtx	text/richtext	freedesktop.org.xml
*.ruby	application/x-ruby	slix.xml
*.rv	video/vnd.rn-realvideo	slix.xml
*.s3m	audio/x-mod	slix.xml
*.s3m	audio/x-s3m	freedesktop.org.xml
*.sam	application/x-amipro	freedesktop.org.xml
*.scd	application/x-scribus	slix.xml
*.scd.gz	application/x-scribus	slix.xml
*.scm	text/x-scheme	freedesktop.org.xml
*.sda	application/vnd.stardivision.draw	freedesktop.org.xml
*.sdc	application/vnd.stardivision.calc	freedesktop.org.xml
*.sdd	application/vnd.stardivision.impress	freedesktop.org.xml
*.sdp	application/vnd.stardivision.impress	freedesktop.org.xml
*.sds	application/vnd.stardivision.chart	freedesktop.org.xml
*.sdw	application/vnd.stardivision.writer	freedesktop.org.xml
*.seg	application/x-kseg	slix.xml
*.sf2	audio/x-soundfont	slix.xml
*.sgi	image/x-sgi	freedesktop.org.xml
*.sgl	application/vnd.stardivision.writer	freedesktop.org.xml
*.sgm	text/sgml	freedesktop.org.xml
*.sgml	text/sgml	freedesktop.org.xml
*.sgrd	application/x-ksysguard	slix.xml
*.sh	application/x-shellscript	freedesktop.org.xml
*.shar	application/x-shar	freedesktop.org.xml
*.shell	application/x-konsole	slix.xml
*.shtml	text/html	slix.xml
*.siag	application/x-siag	freedesktop.org.xml
*.sid	audio/prs.sid	freedesktop.org.xml
*.sid	audio/x-sid	slix.ljudmila.org.xml
*.sieve	application/sieve	slix.xml
*.sik	application/x-trash	freedesktop.org.xml
*.siv	application/sieve	slix.xml
*.sla	application/x-scribus	slix.xml
*.sla	text/x-scribus	slix.ljudmila.org.xml
*.sla.gz	application/x-scribus	slix.xml
*.slk	text/spreadsheet	freedesktop.org.xml
*.smd	application/vnd.stardivision.mail	freedesktop.org.xml
*.smf	application/vnd.stardivision.math	freedesktop.org.xml
*.smi	application/smil	freedesktop.org.xml
*.smil	application/smil	freedesktop.org.xml
*.sml	application/smil	freedesktop.org.xml
*.sms	application/x-sms-rom	freedesktop.org.xml
*.snd	audio/basic	freedesktop.org.xml
*.snf	application/x-font-snf	slix.xml
*.snf.Z	application/x-font-snf	slix.xml
*.snf.gz	application/x-font-snf	slix.xml
*.so	application/x-sharedlib	freedesktop.org.xml
*.spd	application/x-font-speedo	freedesktop.org.xml
*.spl	application/futuresplash	slix.xml
*.spx	audio/x-speex	slix.xml
*.sql	text/x-sql	freedesktop.org.xml
*.src	application/x-wais-source	freedesktop.org.xml
*.ssm	application/x-ssm	slix.xml
*.stc	application/vnd.sun.xml.calc.template	freedesktop.org.xml
*.std	application/vnd.sun.xml.draw.template	freedesktop.org.xml
*.sti	application/vnd.sun.xml.impress.template	freedesktop.org.xml
*.stm	audio/x-mod	slix.xml
*.stm	audio/x-stm	freedesktop.org.xml
*.stw	application/vnd.sun.xml.writer.template	freedesktop.org.xml
*.sty	text/x-tex	freedesktop.org.xml
*.sun	image/x-sun-raster	freedesktop.org.xml
*.sv4cpio	application/x-sv4cpio	freedesktop.org.xml
*.sv4crc	application/x-sv4crc	freedesktop.org.xml
*.svg	image/svg+xml	freedesktop.org.xml
*.svgz	image/svg+xml	slix.xml
*.swf	application/x-shockwave-flash	freedesktop.org.xml
*.sxc	application/vnd.sun.xml.calc	freedesktop.org.xml
*.sxd	application/vnd.sun.xml.draw	freedesktop.org.xml
*.sxg	application/vnd.sun.xml.writer.global	freedesktop.org.xml
*.sxi	application/vnd.sun.xml.impress	freedesktop.org.xml
*.sxm	application/vnd.sun.xml.math	freedesktop.org.xml
*.sxw	application/vnd.sun.xml.writer	freedesktop.org.xml
*.sylk	text/spreadsheet	freedesktop.org.xml
*.t	application/x-troff	freedesktop.org.xml
*.tar	application/x-tar	freedesktop.org.xml
*.tar.Z	application/x-tarz	freedesktop.org.xml
*.tar.bz	application/x-bzip-compressed-tar	freedesktop.org.xml
*.tar.bz	application/x-tbz	slix.xml
*.tar.bz2	application/x-bzip-compressed-tar	freedesktop.org.xml
*.tar.bz2	application/x-tbz	slix.xml
*.tar.gz	application/x-compressed-tar	freedesktop.org.xml
*.tar.gz	application/x-tgz	slix.xml
*.tar.lzo	application/x-tzo	freedesktop.org.xml
*.tcl	text/x-tcl	freedesktop.org.xml
*.tex	text/x-latex	slix.xml
*.tex	text/x-tex	freedesktop.org.xml
*.texi	text/x-texinfo	freedesktop.org.xml
*.texinfo	text/x-texinfo	freedesktop.org.xml
*.tga	image/x-targa	slix.xml
*.tga	image/x-tga	freedesktop.org.xml
*.tgz	application/x-compressed-tar	freedesktop.org.xml
*.tgz	application/x-gzip	slix.xml
*.tgz	application/x-tgz	slix.xml
*.theme	application/x-theme	freedesktop.org.xml
*.tif	image/tiff	freedesktop.org.xml
*.tiff	image/tiff	freedesktop.org.xml
*.tk	text/x-tcl	freedesktop.org.xml
*.tm	application/x-texmacs	slix.xml
*.tm	text/x-texmacs	slix.ljudmila.org.xml
*.tnf	application/ms-tnef	slix.xml
*.torrent	application/x-bittorrent	freedesktop.org.xml
*.tr	application/x-troff	freedesktop.org.xml
*.ts	application/x-linguist	freedesktop.org.xml
*.tsv	text/tab-separated-values	freedesktop.org.xml
*.ttc	application/x-font-ttc	slix.xml
*.ttf	application/x-font-ttf	freedesktop.org.xml
*.tuberling	application/x-tuberling	slix.xml
*.txt	text/plain	freedesktop.org.xml
*.tzo	application/x-tzo	freedesktop.org.xml
*.ui	application/x-designer	freedesktop.org.xml
*.uil	text/x-uil	freedesktop.org.xml
*.ult	audio/x-mod	freedesktop.org.xml
*.uni	audio/x-mod	freedesktop.org.xml
*.uri	text/x-uri	freedesktop.org.xml
*.url	text/x-mswinurl	slix.xml
*.url	text/x-uri	freedesktop.org.xml
*.ustar	application/x-ustar	freedesktop.org.xml
*.vcf	text/x-vcalendar	freedesktop.org.xml
*.vcf	text/x-vcard	slix.xml
*.vcs	text/x-vcalendar	freedesktop.org.xml
*.vct	text/x-vcard	freedesktop.org.xml
*.vob	video/mpeg	freedesktop.org.xml
*.voc	audio/x-voc	freedesktop.org.xml
*.vor	application/vnd.stardivision.writer	freedesktop.org.xml
*.war	application/x-webarchive	slix.xml
*.wav	audio/x-wav	freedesktop.org.xml
*.wb1	application/x-quattropro	freedesktop.org.xml
*.wb2	application/x-quattropro	freedesktop.org.xml
*.wb3	application/x-quattropro	freedesktop.org.xml
*.wk1	application/vnd.lotus-1-2-3	freedesktop.org.xml
*.wk3	application/vnd.lotus-1-2-3	freedesktop.org.xml
*.wk4	application/vnd.lotus-1-2-3	freedesktop.org.xml
*.wks	application/vnd.lotus-1-2-3	freedesktop.org.xml
*.wmf	image/x-wmf	freedesktop.org.xml
*.wml	text/vnd.wap.wml	freedesktop.org.xml
*.wmv	video/x-ms-wmv	freedesktop.org.xml
*.wpd	application/vnd.wordperfect	freedesktop.org.xml
*.wpd	application/wordperfect	slix.xml
*.wpg	application/x-wpg	freedesktop.org.xml
*.wri	application/x-mswrite	freedesktop.org.xml
*.wrl	model/vrml	freedesktop.org.xml
*.wrl.gz	model/vrml	slix.xml
*.wsz	interface/x-winamp-skin	slix.xml
*.xac	application/x-gnucash	freedesktop.org.xml
*.xbel	application/x-xbel	freedesktop.org.xml
*.xbm	image/x-xbitmap	freedesktop.org.xml
*.xbm	image/x-xbm	slix.xml
*.xcf	image/x-xcf	freedesktop.org.xml
*.xcf	image/x-xcf-gimp	slix.xml
*.xcf.bz2	image/x-compressed-xcf	freedesktop.org.xml
*.xcf.gz	image/x-compressed-xcf	freedesktop.org.xml
*.xhtml	application/xhtml+xml	freedesktop.org.xml
*.xi	audio/x-xi	freedesktop.org.xml
*.xla	application/vnd.ms-excel	freedesktop.org.xml
*.xlc	application/msexcel	slix.xml
*.xlc	application/vnd.ms-excel	freedesktop.org.xml
*.xld	application/vnd.ms-excel	freedesktop.org.xml
*.xll	application/msexcel	slix.xml
*.xll	application/vnd.ms-excel	freedesktop.org.xml
*.xlm	application/msexcel	slix.xml
*.xlm	application/vnd.ms-excel	freedesktop.org.xml
*.xls	application/msexcel	slix.xml
*.xls	application/vnd.ms-excel	freedesktop.org.xml
*.xlt	application/vnd.ms-excel	freedesktop.org.xml
*.xlw	application/msexcel	slix.xml
*.xlw	application/vnd.ms-excel	freedesktop.org.xml
*.xm	audio/x-mod	slix.xml
*.xm	audio/x-xm	freedesktop.org.xml
*.xmi	application/x-uml	slix.xml
*.xmi	text/x-xmi	freedesktop.org.xml
*.xml	text/xml	freedesktop.org.xml
*.xpm	image/x-xpixmap	freedesktop.org.xml
*.xpm	image/x-xpm	slix.xml
*.xsl	text/x-xslt	freedesktop.org.xml
*.xslfo	text/x-xslfo	freedesktop.org.xml
*.xslt	text/x-xslt	freedesktop.org.xml
*.xul	application/vnd.mozilla.xul+xml	slix.xml
*.xwd	image/x-xwindowdump	freedesktop.org.xml
*.zabw	application/x-abiword	freedesktop.org.xml
*.zip	application/x-zip	slix.xml
*.zip	application/zip	freedesktop.org.xml
*.zoo	application/x-zoo	freedesktop.org.xml
*PK	application/x-tex-pk	slix.xml
*README*	text/x-readme	slix.xml
*pk	application/x-tex-pk	freedesktop.org.xml
*~	application/x-trash	freedesktop.org.xml
.gtkrc	text/x-gtkrc	freedesktop.org.xml
AUTHORS	text/x-authors	freedesktop.org.xml
COPYING	text/x-copying	freedesktop.org.xml
CREDITS	text/x-credits	freedesktop.org.xml
GNUmakefile	text/x-makefile	slix.xml
INSTALL	text/x-install	freedesktop.org.xml
Makefile	text/x-makefile	slix.xml
Makefile.*	text/x-makefile	slix.xml
README*	text/x-readme	freedesktop.org.xml
RMAIL	message/x-gnu-rmail	freedesktop.org.xml
[Mm]akefile	text/x-makefile	freedesktop.org.xml
cachegrind.out*	application/x-kcachegrind	slix.xml
callgrind.out*	application/x-kcachegrind	slix.xml
core	application/x-core	freedesktop.org.xml
gmon.out	application/x-profile	freedesktop.org.xml
gtkrc	text/x-gtkrc	freedesktop.org.xml
makefile	text/x-makefile	slix.xml
makefile*	text/x-makefile	freedesktop.org.xml
makefile.*	text/x-makefile	slix.xml
*.ml	text/x-objective-caml	\N
\.


--
-- Data for TOC entry 571 (OID 2054634)
-- Name: apps; Type: TABLE DATA; Schema: public; Owner: postgres
--

COPY apps (fname, terminal, name, exec, registry, available, genericname, priority, must, may, "comment", project, plugin_for, gui_for) FROM stdin;
beast	\N	\N	beast	\N	t	\N	\N	\N	\N	\N	\N	\N	\N
celestia	\N	\N	celestia	\N	t	\N	\N	\N	\N	\N	\N	\N	\N
gnome-stones	\N	\N	gnome-stones	\N	t	\N	\N	\N	\N	\N	\N	\N	\N
iagno	\N	\N	iagno	\N	t	\N	\N	\N	\N	\N	\N	\N	\N
knx-live-inst.sh	\N	\N	knx-live-inst.sh	\N	t	\N	\N	\N	\N	\N	\N	\N	\N
krusader	\N	\N	krusader	\N	t	\N	\N	\N	\N	\N	\N	\N	\N
krandom.kss	\N	Random	krandom.kss	/usr/share/applnk/System/ScreenSavers/KRandom.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
kscience.kss	\N	Science	kscience.kss	/usr/share/applnk/System/ScreenSavers/KScience.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
kslideshow.kss	\N	Slide Show	kslideshow.kss	/usr/share/applnk/System/ScreenSavers/KSlideshow.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
ksolarwinds.kss	\N	Solar Winds (GL)	ksolarwinds.kss	/usr/share/applnk/System/ScreenSavers/KSolarWinds.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
kspace.kss	\N	Space (GL)	kspace.kss	/usr/share/applnk/System/ScreenSavers/KSpace.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
krandrtray	\N	Screen Resize & Rotate	krandrtray	/usr/share/applications/kde/krandrtray.desktop	t	\N	\N	\N	\N	A panel applet for resizing and reorientating X screens.	\N	\N	\N
kswarm.kss	\N	Swarm	kswarm.kss	/usr/share/applnk/System/ScreenSavers/KSwarm.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
octave	\N	GNU Octave	octave	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N
planner	\N	\N	planner	\N	t	\N	\N	\N	\N	\N	\N	\N	\N
xawtv.wrapper	\N	\N	xawtv.wrapper	\N	t	\N	\N	\N	\N	\N	\N	\N	\N
sudo	\N	XLogmaster	sudo	\N	t	Pregledovalnik dnevnikov	\N	\N	\N	\N	\N	\N	\N
oowriter	f	OpenOffice.org Writer	/usr/bin/oowriter %U	/usr/share/applications/ooo645writer.desktop	t	\N	\N	\N	\N	OpenOffice.org Text Document	OpenOffice.org	\N	\N
btdownloadgui	f	Bittorrent Download	btdownloadgui	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N
xspirograph	\N	XSpiroGraph	xspirograph	/usr/share/applnk/System/ScreenSavers/xspirograph.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
xsublim	\N	xsublim	xsublim	/usr/share/applnk/System/ScreenSavers/xsublim.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
xteevee	\N	XTeeVee	xteevee	/usr/share/applnk/System/ScreenSavers/xteevee.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
cupsconfig	\N	Tiskalniki	/usr/sbin/cupsconfig	/usr/share/applnk/Knoppix/Config/cupsconfig.desktop	t	Upravljalnik tiskanja	\N	\N	\N	Nastavitev Tiskalnikov (cupsconfig)	\N	\N	\N
zoom	\N	Zoom	zoom	/usr/share/applnk/System/ScreenSavers/zoom.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
gnome-cd	f	CD Player	gnome-cd	/usr/share/applications/gnome-cd.desktop	t	\N	\N	\N	\N	Play audio CDs	\N	\N	\N
kfax	f	KFax	kfax %f   -caption "%c" %i %m	/usr/share/applications/kde/kfax.desktop	t	Fax Viewer	\N	\N	\N	\N	\N	\N	\N
firefox	f	Mozilla Firefox	firefox	/usr/share/applications/mozilla-firefox.desktop	t	Web Browser	\N	\N	\N	Browse the World Wide Web	\N	\N	\N
slix-central	f	Slix Central	slix-central	/usr/share/applications/slix-central.desktop	t	\N	\N	\N	\N	Application and process manager	\N	\N	\N
gv4l	f	Gv4l	/usr/bin/gv4l	/usr/share/applications/gnome-gv4l.desktop	t	\N	\N	\N	\N	Gui frontend for the Video4Linux functions of transcode	\N	\N	\N
cyca-central	f	Cyca Central	cyca-central	/usr/share/applications/cyca-central.desktop	t	\N	\N	\N	\N	User Profile Manager	\N	\N	\N
anemone	\N	Anemone	anemone	/usr/share/applnk/System/ScreenSavers/anemone.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
ant	\N	Ant	ant	/usr/share/applnk/System/ScreenSavers/ant.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
antspotlight	\N	AntSpotlight	antspotlight	/usr/share/applnk/System/ScreenSavers/antspotlight.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
apollonian	\N	Apollonian	apollonian	/usr/share/applnk/System/ScreenSavers/apollonian.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
atlantis	\N	Atlantis (GL)	atlantis	/usr/share/applnk/System/ScreenSavers/atlantis.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
attraction	\N	Attraction	attraction	/usr/share/applnk/System/ScreenSavers/attraction.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
atunnel	\N	Atunnel	atunnel	/usr/share/applnk/System/ScreenSavers/atunnel.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
barcode	\N	Barcode	barcode	/usr/share/applnk/System/ScreenSavers/barcode.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
blaster	\N	Blaster	blaster	/usr/share/applnk/System/ScreenSavers/blaster.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
blitspin	\N	BlitSpin	blitspin	/usr/share/applnk/System/ScreenSavers/blitspin.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
blocktube	\N	BlockTube	blocktube	/usr/share/applnk/System/ScreenSavers/blocktube.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
bouboule	\N	Bouboule	bouboule	/usr/share/applnk/System/ScreenSavers/bouboule.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
bouncingcow	\N	BouncingCow	bouncingcow	/usr/share/applnk/System/ScreenSavers/bouncingcow.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
boxed	\N	Boxed	boxed	/usr/share/applnk/System/ScreenSavers/boxed.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
braid	\N	Braid	braid	/usr/share/applnk/System/ScreenSavers/braid.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
bsod	\N	BSOD	bsod	/usr/share/applnk/System/ScreenSavers/bsod.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
bubble3d	\N	Bubble 3D (GL)	bubble3d	/usr/share/applnk/System/ScreenSavers/bubble3d.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
bubbles	\N	Bubbles	bubbles	/usr/share/applnk/System/ScreenSavers/bubbles.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
bumps	\N	Bumps	bumps	/usr/share/applnk/System/ScreenSavers/bumps.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
cage	\N	Cage (GL)	cage	/usr/share/applnk/System/ScreenSavers/cage.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
ccurve	\N	C Curve	ccurve	/usr/share/applnk/System/ScreenSavers/ccurve.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
circuit	\N	Circuit	circuit	/usr/share/applnk/System/ScreenSavers/circuit.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
cloudlife	\N	CloudLife	cloudlife	/usr/share/applnk/System/ScreenSavers/cloudlife.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
compass	\N	Compass	compass	/usr/share/applnk/System/ScreenSavers/compass.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
coral	\N	Coral	coral	/usr/share/applnk/System/ScreenSavers/coral.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
critical	\N	Critical	critical	/usr/share/applnk/System/ScreenSavers/critical.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
crystal	\N	Crystal	crystal	/usr/share/applnk/System/ScreenSavers/crystal.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
cubenetic	\N	Cubenetic	cubenetic	/usr/share/applnk/System/ScreenSavers/cubenetic.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
cubestorm	\N	CubeStorm	cubestorm	/usr/share/applnk/System/ScreenSavers/cubestorm.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
cynosure	\N	Cynosure	cynosure	/usr/share/applnk/System/ScreenSavers/cynosure.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
dangerball	\N	DangerBall	dangerball	/usr/share/applnk/System/ScreenSavers/dangerball.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
decayscreen	\N	DecayScreen	decayscreen	/usr/share/applnk/System/ScreenSavers/decayscreen.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
deco	\N	Deco	deco	/usr/share/applnk/System/ScreenSavers/deco.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
deluxe	\N	Deluxe	deluxe	/usr/share/applnk/System/ScreenSavers/deluxe.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
blackjack	\N	\N	blackjack	\N	t	\N	\N	\N	\N	\N	\N	\N	\N
demon	\N	Demon	demon	/usr/share/applnk/System/ScreenSavers/demon.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
discrete	\N	Discrete	discrete	/usr/share/applnk/System/ScreenSavers/discrete.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
distort	\N	Distort	distort	/usr/share/applnk/System/ScreenSavers/distort.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
dotty	\N	Graphviz dotty	dotty	\N	\N	Graph viewer	\N	\N	\N	\N	\N	\N	\N
drift	\N	Drift	drift	/usr/share/applnk/System/ScreenSavers/drift.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
endgame	\N	Endgame	endgame	/usr/share/applnk/System/ScreenSavers/endgame.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
engine	\N	Engine	engine	/usr/share/applnk/System/ScreenSavers/engine.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
epicycle	\N	Epicycle	epicycle	/usr/share/applnk/System/ScreenSavers/epicycle.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
eruption	\N	Eruption	eruption	/usr/share/applnk/System/ScreenSavers/eruption.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
euler2d	\N	Euler2d	euler2d	/usr/share/applnk/System/ScreenSavers/euler2d.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
extrusion	\N	Extrusion	extrusion	/usr/share/applnk/System/ScreenSavers/extrusion.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
fadeplot	\N	Fade Plot	fadeplot	/usr/share/applnk/System/ScreenSavers/fadeplot.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
flag	\N	Flag	flag	/usr/share/applnk/System/ScreenSavers/flag.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
flame	\N	Flame	flame	/usr/share/applnk/System/ScreenSavers/flame.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
flipflop	\N	FlipFlop	flipflop	/usr/share/applnk/System/ScreenSavers/flipflop.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
flipscreen3d	\N	Flipscreen3d	flipscreen3d	/usr/share/applnk/System/ScreenSavers/flipscreen3d.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
flow	\N	Flow	flow	/usr/share/applnk/System/ScreenSavers/flow.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
fluidballs	\N	FluidBalls	fluidballs	/usr/share/applnk/System/ScreenSavers/fluidballs.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
flurry	\N	Flurry	flurry	/usr/share/applnk/System/ScreenSavers/flurry.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
flyingtoasters	\N	Flying Toasters	flyingtoasters	/usr/share/applnk/System/ScreenSavers/flyingtoasters.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
forest	\N	Forest	forest	/usr/share/applnk/System/ScreenSavers/forest.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
galaxy	\N	Galaxy	galaxy	/usr/share/applnk/System/ScreenSavers/galaxy.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
gears	\N	Gears (GL)	gears	/usr/share/applnk/System/ScreenSavers/gears.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
gflux	\N	GFlux	gflux	/usr/share/applnk/System/ScreenSavers/gflux.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
glblur	\N	GLBlur	glblur	/usr/share/applnk/System/ScreenSavers/glblur.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
glforestfire	\N	GLForestFire	glforestfire	/usr/share/applnk/System/ScreenSavers/glforestfire.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
glknots	\N	GLKnots	glknots	/usr/share/applnk/System/ScreenSavers/glknots.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
glmatrix	\N	GLMatrix	glmatrix	/usr/share/applnk/System/ScreenSavers/glmatrix.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
glplanet	\N	GL Planet (GL)	glplanet	/usr/share/applnk/System/ScreenSavers/glplanet.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
glslideshow	\N	GLSlideshow	glslideshow	/usr/share/applnk/System/ScreenSavers/glslideshow.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
glsnake	\N	GLSnake	glsnake	/usr/share/applnk/System/ScreenSavers/glsnake.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
gltext	\N	GLText	gltext	/usr/share/applnk/System/ScreenSavers/gltext.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
elinks	\N	\N	elinks	\N	t	\N	\N	\N	\N	\N	\N	\N	\N
goop	\N	Goop	goop	/usr/share/applnk/System/ScreenSavers/goop.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
grav	\N	Gravity	grav	/usr/share/applnk/System/ScreenSavers/grav.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
greynetic	\N	graynetic	greynetic	/usr/share/applnk/System/ScreenSavers/greynetic.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
halftone	\N	Halftone	halftone	/usr/share/applnk/System/ScreenSavers/halftone.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
halo	\N	Halo	halo	/usr/share/applnk/System/ScreenSavers/halo.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
helix	\N	Helix	helix	/usr/share/applnk/System/ScreenSavers/helix.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
hopalong	\N	Hopalong	hopalong	/usr/share/applnk/System/ScreenSavers/hopalong.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
hyperball	\N	Hyperball	hyperball	/usr/share/applnk/System/ScreenSavers/hyperball.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
hypercube	\N	Hypercube	hypercube	/usr/share/applnk/System/ScreenSavers/hypercube.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
hypertorus	\N	4D Hypertorus	hypertorus	/usr/share/applnk/System/ScreenSavers/hypertorus.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
ifs	\N	Iterated-function-system Images	ifs	/usr/share/applnk/System/ScreenSavers/ifs.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
imsmap	\N	Fractal Maps	imsmap	/usr/share/applnk/System/ScreenSavers/imsmap.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
interference	\N	Interference	interference	/usr/share/applnk/System/ScreenSavers/interference.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
jigglypuff	\N	JigglyPuff	jigglypuff	/usr/share/applnk/System/ScreenSavers/jigglypuff.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
jigsaw	\N	Jigsaw	jigsaw	/usr/share/applnk/System/ScreenSavers/jigsaw.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
juggle	\N	Juggle	juggle	/usr/share/applnk/System/ScreenSavers/juggle.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
julia	\N	Julia	julia	/usr/share/applnk/System/ScreenSavers/julia.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
kadd_konsole	f	add_konsole	kadd_konsole	/usr/share/applnk/Utilities/add_konsole.desktop	t	\N	\N	\N	\N	Add a remote login to konsole's menu	\N	\N	\N
kalarmd	f	Alarm Daemon	kalarmd	/usr/share/applnk/.hidden/kalarmd.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
kaleidescope	\N	Kaleidescope	kaleidescope	/usr/share/applnk/System/ScreenSavers/kaleidescope.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
kbanner.kss	\N	Banner	kbanner.kss	/usr/share/applnk/System/ScreenSavers/KBanner.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
kblankscrn.kss	\N	Blank Screen	kblankscrn.kss	/usr/share/applnk/System/ScreenSavers/KBlankscreen.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
kblob.kss	\N	Blob	kblob.kss	/usr/share/applnk/System/ScreenSavers/KBlob.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
kclock.kss	\N	Clock	kclock.kss	/usr/share/applnk/System/ScreenSavers/KClock.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
kdirstat	f	KDirStat - Directory Statistics	kdirstat -caption "%c" %i %m	/usr/share/applnk/Utilities/kdirstat.desktop	t	\N	\N	\N	\N	Directory statistics and disk usage	\N	\N	\N
keuphoria.kss	\N	Euphoria (GL)	keuphoria.kss	/usr/share/applnk/System/ScreenSavers/KEuphoria.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
kflux.kss	\N	Flux (GL)	kflux.kss	/usr/share/applnk/System/ScreenSavers/KFlux.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
kfountain.kss	\N	Particle Fountain (GL)	kfountain.kss	/usr/share/applnk/System/ScreenSavers/KFountain.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
kgravity.kss	\N	Gravity (GL)	kgravity.kss	/usr/share/applnk/System/ScreenSavers/KGravity.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
klein	\N	Klein	klein	/usr/share/applnk/System/ScreenSavers/klein.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
klines.kss	\N	Lines	klines.kss	/usr/share/applnk/System/ScreenSavers/KLines-saver.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
klorenz.kss	\N	Lorenz Attractor	klorenz.kss	/usr/share/applnk/System/ScreenSavers/KLorenz.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
gpdf	\N	\N	gpdf	\N	t	\N	\N	\N	\N	\N	\N	\N	\N
kmdr-executor	f	Kommander Executor	kmdr-executor %F	/usr/share/applnk/Applications/kmdr-executor.desktop	t	\N	\N	\N	\N	Executor for Kommander dialogs	\N	\N	\N
knewstickerstub	f	KNewsTicker config frontend	knewstickerstub -a %u	/usr/share/applnk/.hidden/knewstickerstub.desktop	t	\N	\N	\N	\N	A frontend for the KNewsTicker configuration	\N	\N	\N
kpartsaver.kss	\N	Media Screen Saver	kpartsaver.kss	/usr/share/applnk/System/ScreenSavers/kpartsaver.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
kplayer	f	KPlayer	kplayer %U	/usr/share/applnk/Multimedia/kplayer.desktop	t	Media Player	\N	\N	\N	Media player based on MPlayer	\N	\N	\N
kpolygon.kss	\N	Polygons	kpolygon.kss	/usr/share/applnk/System/ScreenSavers/KPolygon.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
/usr/bin/gvim	\N	gvim	/usr/bin/gvim	/usr/share/slix/apps/Aplikacije/Besedilo/gvim.desktop	f	vi text editor	\N	\N	\N	GVIM, graphical Vi IMproved	\N	\N	\N
kumppa	\N	Kumppa	kumppa	/usr/share/applnk/System/ScreenSavers/kumppa.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
kvm.kss	\N	Virtual Machine	kvm.kss	/usr/share/applnk/System/ScreenSavers/KVm.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
kwave.kss	\N	Bitmap Flag (GL)	kwave.kss	/usr/share/applnk/System/ScreenSavers/KWave.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
lyx	f	LyX	lyx	/usr/share/slix/apps/Aplikacije/Besedilo/lyx.desktop	t	Word Processor	\N	\N	\N	\N	\N	\N	\N
nedit	f	Nedit	nedit	/var/lib/menu-xdg/applications/menu-xdg/nedit.desktop	t	Text Editor	\N	\N	\N	\N	\N	\N	\N
lament	\N	Lament (GL)	lament	/usr/share/applnk/System/ScreenSavers/lament.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
laser	\N	Laser	laser	/usr/share/applnk/System/ScreenSavers/laser.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
lavalite	\N	LavaLite	lavalite	/usr/share/applnk/System/ScreenSavers/lavalite.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
lightning	\N	Lightning	lightning	/usr/share/applnk/System/ScreenSavers/lightning.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
lisa	\N	Lisa	lisa	/usr/share/applnk/System/ScreenSavers/lisa.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
quanta	\N	Quanta Plus	quanta	/usr/share/applnk/Development/quanta.desktop	t	Web Development	\N	\N	\N	Web Development Environment	\N	\N	\N
lissie	\N	Lissie	lissie	/usr/share/applnk/System/ScreenSavers/lissie.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
lmorph	\N	Morphing Lines	lmorph	/usr/share/applnk/System/ScreenSavers/lmorph.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
loop	\N	Loop	loop	/usr/share/applnk/System/ScreenSavers/loop.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
dia-normal	f	Dia	/usr/bin/dia-normal	/var/lib/menu-xdg/applications/menu-xdg/dia.desktop	t	Draw diagrams	\N	\N	\N	Draw diagrams	\N	\N	\N
maze	\N	Maze	maze	/usr/share/applnk/System/ScreenSavers/maze.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
menger	\N	Menger	menger	/usr/share/applnk/System/ScreenSavers/menger.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
metaballs	\N	MetaBalls	metaballs	/usr/share/applnk/System/ScreenSavers/metaballs.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
/usr/bin/qcad	\N	QCad	/usr/bin/qcad	/usr/share/slix/apps/Aplikacije/Grafika/QCad.desktop	f	\N	\N	\N	\N	QCad	\N	\N	\N
moebius	\N	Moebius (GL)	moebius	/usr/share/applnk/System/ScreenSavers/moebius.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
moire	\N	Moire	moire	/usr/share/applnk/System/ScreenSavers/moire.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
moire2	\N	Moire2	moire2	/usr/share/applnk/System/ScreenSavers/moire2.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
molecule	\N	Molecule	molecule	/usr/share/applnk/System/ScreenSavers/molecule.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
morph3d	\N	Morph3D	morph3d	/usr/share/applnk/System/ScreenSavers/morph3d.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
mountain	\N	Mountain	mountain	/usr/share/applnk/System/ScreenSavers/mountain.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
sketch	f	Sketch	/usr/bin/sketch	/var/lib/menu-xdg/applications/menu-xdg/sketch.desktop	t	Vector-based Drawing Program	\N	\N	\N	\N	\N	\N	\N
munch	\N	Munch	munch	/usr/share/applnk/System/ScreenSavers/munch.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
tgif	f	Tgif	/usr/bin/tgif	/var/lib/menu-xdg/applications/menu-xdg/tgif.desktop	t	Vector-based Drawing Program	\N	\N	\N	Tgif	\N	\N	\N
neato	\N	Graphviz lneato	lneato	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N
kgeo	f	KGeo	kgeo -caption "%c" %i %m	/usr/share/applnk/Edutainment/Mathematics/kgeo.desktop	t	Interaktivna geometrija	\N	\N	\N	\N	\N	\N	\N
nerverot	\N	NerveRot	nerverot	/usr/share/applnk/System/ScreenSavers/nerverot.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
noseguy	\N	Noseguy	noseguy	/usr/share/applnk/System/ScreenSavers/noseguy.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
/usr/bin/pfaedit	\N	PFAedit	/usr/bin/pfaedit	/usr/share/slix/apps/Aplikacije/Grafika/pfaedit.desktop	f	Font Editor	\N	\N	\N	\N	\N	\N	\N
xfig	f	xfig	/usr/bin/xfig	/var/lib/menu-xdg/applications/menu-xdg/xfig.desktop	t	Vector-based Drawing Program	\N	\N	\N	Facility for Interactive Generation of figures	\N	\N	\N
pspresent	\N	PSpresent	pspresent %f	/usr/share/slix/apps/Aplikacije/Prezentacija/pspresent.desktop	t	PostScript Viewer	\N	\N	\N	\N	\N	\N	\N
pedal	\N	Pedal	pedal	/usr/share/applnk/System/ScreenSavers/pedal.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
penetrate	\N	Penetrate	penetrate	/usr/share/applnk/System/ScreenSavers/penetrate.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
penrose	\N	Penrose	penrose	/usr/share/applnk/System/ScreenSavers/penrose.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
mysqlcc	f	MySQL CC	/usr/bin/mysqlcc	/var/lib/menu-xdg/applications/menu-xdg/mysql_cc.desktop	t	\N	\N	\N	\N	MySQL Control Center	\N	\N	\N
petri	\N	Petri	petri	/usr/share/applnk/System/ScreenSavers/petri.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
phosphor	\N	Phosphor	phosphor	/usr/share/applnk/System/ScreenSavers/phosphor.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
piecewise	\N	Piecewise	piecewise	/usr/share/applnk/System/ScreenSavers/piecewise.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
pipes	\N	Pipes - another (GL)	pipes	/usr/share/applnk/System/ScreenSavers/pipes.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
pixmaps	\N	pixmaps	pixmaps	/usr/share/applnk/System/ScreenSavers/pixmaps.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
polyominoes	\N	Polyominoes	polyominoes	/usr/share/applnk/System/ScreenSavers/polyominoes.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
polytopes	\N	Regular 4D Polytopes	polytopes	/usr/share/applnk/System/ScreenSavers/polytopes.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
popsquares	\N	Popsquares	popsquares	/usr/share/applnk/System/ScreenSavers/popsquares.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
pulsar	\N	Pulsar (GL)	pulsar	/usr/share/applnk/System/ScreenSavers/pulsar.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
pgadmin3	f	pgAdmin3	pgadmin3	/var/lib/menu-xdg/applications/menu-xdg/pgadmin_iii.desktop	t	PostgreSQL admin	\N	\N	\N	pgAdmin3	\N	\N	\N
pyro	\N	Pyro	pyro	/usr/share/applnk/System/ScreenSavers/pyro.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
kino	f	Kino	/usr/bin/kino	/var/lib/menu-xdg/applications/menu-xdg/kino.desktop	t	DV Video Editor	\N	\N	\N	Kino	\N	\N	\N
qix	\N	Qix	qix	/usr/share/applnk/System/ScreenSavers/qix.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
tvtime	f	TVtime Television Viewer	tvtime	/usr/share/slix/apps/Aplikacije/Video/net-tvtime.desktop	f	Television Viewer	\N	\N	\N	High quality video deinterlacer	\N	\N	\N
queens	\N	Queens	queens	/usr/share/applnk/System/ScreenSavers/queens.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
rd-bomb	\N	RD-Bomb	rd-bomb	/usr/share/applnk/System/ScreenSavers/rd-bomb.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
rekall	f	Rekall	rekall	/usr/share/applnk/Applications/rekall.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
rezound	f	ReZound	/usr/bin/rezound	/var/lib/menu-xdg/applications/menu-xdg/rezound.desktop	t	\N	\N	\N	\N	ReZound	\N	\N	\N
ripples	\N	Ripples	ripples	/usr/share/applnk/System/ScreenSavers/ripples.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
rocks	\N	Rocks	rocks	/usr/share/applnk/System/ScreenSavers/rocks.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
rorschach	\N	Rorschach	rorschach	/usr/share/applnk/System/ScreenSavers/rorschach.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
rotor	\N	Rotor	rotor	/usr/share/applnk/System/ScreenSavers/rotor.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
rotzoomer	\N	RotZoomer	rotzoomer	/usr/share/applnk/System/ScreenSavers/rotzoomer.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
rubik	\N	Rubik Cube (GL)	rubik	/usr/share/applnk/System/ScreenSavers/rubik.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
sballs	\N	Sballs	sballs	/usr/share/applnk/System/ScreenSavers/sballs.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
/usr/bin/spiralsynthmodular	\N	SpiralSynthModular	/usr/bin/spiralsynthmodular	/usr/share/slix/apps/Aplikacije/Zvok/SpiralSynthModular.desktop	f	Software Synthesizer	\N	\N	\N	\N	\N	\N	\N
shadebobs	\N	ShadeBobs	shadebobs	/usr/share/applnk/System/ScreenSavers/shadebobs.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
sierpinski	\N	Sierpinski	sierpinski	/usr/share/applnk/System/ScreenSavers/sierpinski.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
sierpinski3d	\N	Sierpinski3D	sierpinski3d	/usr/share/applnk/System/ScreenSavers/sierpinski3d.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
slicker	\N	slicker	slicker	/usr/share/applnk/Utilities/slicker.desktop	t	\N	\N	\N	\N	A kicker replacement	\N	\N	\N
slidescreen	\N	SlideScreen	slidescreen	/usr/share/applnk/System/ScreenSavers/slidescreen.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
slip	\N	Slip	slip	/usr/share/applnk/System/ScreenSavers/slip.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
noteedit	f	NoteEdit	noteedit %i %m -caption "%c"	/usr/share/applnk/Multimedia/noteedit.desktop	t	\N	\N	\N	\N	Note editor	\N	\N	\N
sweep	f	sweep	/usr/bin/sweep	/var/lib/menu-xdg/applications/menu-xdg/sweep.desktop	t	\N	\N	\N	\N	sweep	\N	\N	\N
sonar	\N	Sonar	sonar	/usr/share/applnk/System/ScreenSavers/sonar.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
speedmine	\N	SpeedMine	speedmine	/usr/share/applnk/System/ScreenSavers/speedmine.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
sphere	\N	Sphere	sphere	/usr/share/applnk/System/ScreenSavers/sphere.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
spheremonics	\N	Spheremonics	spheremonics	/usr/share/applnk/System/ScreenSavers/spheremonics.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
spiral	\N	Spiral	spiral	/usr/share/applnk/System/ScreenSavers/spiral.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
spotlight	\N	Spotlight	spotlight	/usr/share/applnk/System/ScreenSavers/spotlight.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
sproingies	\N	Sproingies (GL)	sproingies	/usr/share/applnk/System/ScreenSavers/sproingies.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
squiral	\N	Squiral	squiral	/usr/share/applnk/System/ScreenSavers/squiral.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
stairs	\N	Stairs (GL)	stairs	/usr/share/applnk/System/ScreenSavers/stairs.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
starfish	\N	Starfish	starfish	/usr/share/applnk/System/ScreenSavers/starfish.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
starwars	\N	StarWars	starwars	/usr/share/applnk/System/ScreenSavers/starwars.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
stonerview	\N	StonerView	stonerview	/usr/share/applnk/System/ScreenSavers/stonerview.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
strange	\N	Strange	strange	/usr/share/applnk/System/ScreenSavers/strange.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
superquadrics	\N	Superquadrics (GL)	superquadrics	/usr/share/applnk/System/ScreenSavers/superquadrics.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
swirl	\N	Swirl	swirl	/usr/share/applnk/System/ScreenSavers/swirl.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
t3d	\N	Time 3D	t3d	/usr/share/applnk/System/ScreenSavers/t3d.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
thornbird	\N	Thornbird	thornbird	/usr/share/applnk/System/ScreenSavers/thornbird.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
/usr/bin/gq	\N	gq	/usr/bin/gq	/usr/share/slix/apps/Internet/Network/gq.desktop	f	\N	\N	\N	\N	gq	\N	\N	\N
mtr	\N	mtr	mtr	/usr/share/slix/apps/Internet/Network/mtr.desktop	t	Traceroute	\N	\N	\N	mtr	\N	\N	\N
triangle	\N	Triangle	triangle	/usr/share/applnk/System/ScreenSavers/triangle.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
truchet	\N	Truchet	truchet	/usr/share/applnk/System/ScreenSavers/truchet.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
/usr/bin/gaim	\N	Gaim	/usr/bin/gaim	/usr/share/slix/apps/Internet/Gaim.desktop	f	Instant Messaging	\N	\N	\N	Multi-protocol Instant Messaging Client	\N	\N	\N
twang	\N	Twang	twang	/usr/share/applnk/System/ScreenSavers/twang.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
/usr/bin/evolution	\N	Evolution	/usr/bin/evolution	/usr/share/slix/apps/Internet/evolution.desktop	f	Mail	\N	\N	\N	Evolution	\N	\N	\N
vermiculate	\N	Vermiculate	vermiculate	/usr/share/applnk/System/ScreenSavers/vermiculate.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
vidwhacker	\N	vidwhacker	vidwhacker	/usr/share/applnk/System/ScreenSavers/vidwhacker.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
vines	\N	Vines	vines	/usr/share/applnk/System/ScreenSavers/vines.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
gtk-gnutella	f	gtk-gnutella	/usr/bin/gtk-gnutella	/var/lib/menu-xdg/applications/menu-xdg/gtk-gnutella.desktop	t	File Sharing	\N	\N	\N	Gnutella (GTK)	\N	\N	\N
wander	\N	Wander	wander	/usr/share/applnk/System/ScreenSavers/wander.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
webcollage	\N	Web Collage	webcollage	/usr/share/applnk/System/ScreenSavers/webcollage.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
whirlwindwarp	\N	WhirlwindWarp	whirlwindwarp	/usr/share/applnk/System/ScreenSavers/whirlwindwarp.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
whirlygig	\N	WhirlyGig	whirlygig	/usr/share/applnk/System/ScreenSavers/whirlygig.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
wine	f	WINE	wine %f	/usr/share/applnk/wine.desktop	t	\N	\N	\N	\N	WINE	\N	\N	\N
xrealvncviewer	f	xvncviewer	/usr/bin/xrealvncviewer	/var/lib/menu-xdg/applications/menu-xdg/xvncviewer.desktop	t	Remote desktop	\N	\N	\N	xvncviewer	\N	\N	\N
LinNeighborhood	f	LinNeigborhood	/usr/bin/LinNeighborhood	/var/lib/menu-xdg/applications/menu-xdg/linneighborhood.desktop	t	Windows file sharing	\N	\N	\N	Windows file sharing	\N	\N	\N
/usr/sbin/saveconfig	\N	Save KNOPPIX configuration	/usr/sbin/saveconfig	/usr/share/slix/apps/Nastavitve/saveconfig.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
worm	\N	Worm	worm	/usr/share/applnk/System/ScreenSavers/worm.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
/usr/bin/gpa	\N	The GNU Privacy Assistant	/usr/bin/gpa	/usr/share/slix/apps/Pripomo?ki/The_GNU_Privacy_Assistant.deskt	f	\N	\N	\N	\N	The GNU Privacy Assistant	\N	\N	\N
/usr/bin/usbview	\N	USB View	/usr/bin/usbview	/usr/share/slix/apps/Sistem/USB_View.desktop	f	\N	\N	\N	\N	USB View	\N	\N	\N
kinfocenter	\N	Info Center	kinfocenter -caption "%c" %i %m	/usr/share/applnk/System/kinfocenter.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
xflame	\N	XFlame	xflame	/usr/share/applnk/System/ScreenSavers/xflame.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
xjack	\N	XJack	xjack	/usr/share/applnk/System/ScreenSavers/xjack.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
xlyap	\N	Xlyap	xlyap	/usr/share/applnk/System/ScreenSavers/xlyap.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
xmatrix	\N	The Matrix	xmatrix	/usr/share/applnk/System/ScreenSavers/xmatrix.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
sh	t	Xaos	sh -c 'cd /tmp && /usr/bin/xaos -driver aa'	/var/lib/menu-xdg/applications/menu-xdg/text_xaos.desktop	t	\N	\N	\N	\N	Xaos	\N	\N	\N
/usr/games/bzflag	\N	bzflag	/usr/games/bzflag	/usr/share/slix/apps/Zabava/bzflag.desktop	f	\N	\N	\N	\N	bzflag	\N	\N	\N
abiword	f	AbiWord	/usr/bin/abiword	/usr/share/applnk/Editors/AbiWord.desktop	t	Word Processor	\N	\N	\N	\N	\N	\N	\N
xrayswarm	\N	XRaySwarm	xrayswarm	/usr/share/applnk/System/ScreenSavers/xrayswarm.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
Emacs	f	XEmacs	Emacs	/home/ziga/.kde/share/applnk/.hidden/Emacs.desktop	t	Text editor and more	\N	\N	\N	XEmacs21 client	\N	\N	\N
Browse	\N	Mozilla Navigator	Browse %U	/usr/share/slix/apps/Mozilla.desktop	t	Zbirka internet programov	\N	\N	\N	Web, Mail, Usenet, IRC	\N	\N	\N
xscreensaver.kss	\N	XScreensaver	xscreensaver.kss	/usr/share/applnk/System/ScreenSavers/XScreenSaver.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
xsane	f	XSane Image scanning program	xsane	/usr/share/applications/xsane.desktop	t	\N	\N	\N	\N	A program to work with scanner. Can be used as a scanning, copier, OCR, fax tools.	\N	\N	\N
gcmui	f	GNOME Clipboard Manager	gcmui	/usr/share/applications/gcm.desktop	t	\N	\N	\N	\N	A Clipboard Manager for GNOME	\N	\N	\N
gnumeric	f	Gnumeric Spreadsheet	gnumeric %F	/usr/share/applications/gnumeric.desktop	t	Spreadsheet	\N	\N	\N	The GNOME Spreadsheet	\N	\N	\N
dasher	f	Dasher	dasher	/usr/share/applications/dasher.desktop	t	Dasher Text Entry	\N	\N	\N	\N	\N	\N	\N
xchat	f	XChat IRC	xchat	/usr/share/applications/xchat.desktop	t	\N	\N	\N	\N	IRC Client	\N	\N	\N
sodipodi	f	Sodipodi	sodipodi %U	/usr/share/applications/sodipodi.desktop	t	\N	\N	\N	\N	SVG Vector Illustrator	\N	\N	\N
gucharmap	f	Character Map	gucharmap	/usr/share/applications/gucharmap.desktop	t	\N	\N	\N	\N	Insert special characters into documents	\N	\N	\N
gnomemeeting	f	GnomeMeeting	gnomemeeting	/usr/share/applications/gnomemeeting.desktop	t	Videoconferencing	\N	\N	\N	Talk to people over the Internet	\N	\N	\N
glade-2	f	Glade Interface Designer	glade-2 %F	/usr/share/applications/glade-2.desktop	t	\N	\N	\N	\N	Design user interfaces	\N	\N	\N
alc	\N	aLinkCreator	alc	/usr/share/applications/alc.desktop	f	\N	\N	\N	\N	aMule ed2k link creator	\N	\N	\N
xscreensaver-demo	f	Screensaver	xscreensaver-demo	/usr/share/applications/screensaver-properties.desktop	t	\N	\N	\N	\N	Change screensaver properties	\N	\N	\N
xplaymidi	\N	\N	xplaymidi	\N	t	\N	\N	\N	\N	\N	\N	\N	\N
eclipse	f	Eclipse	/usr/bin/eclipse	/usr/share/applications/eclipse.desktop	t	\N	\N	\N	\N	Integrated Development Environment	\N	\N	\N
gedit	f	Text Editor	gedit %U	/usr/share/applications/gedit.desktop	t	\N	\N	\N	\N	Edit text files	\N	\N	\N
gnome-dictionary	f	Dictionary	gnome-dictionary -a	/usr/share/applications/gnome-dictionary.desktop	t	\N	\N	\N	\N	Lookup words in an online dictionary	\N	\N	\N
ggv	f	GGV PostScript Viewer	ggv %U	/usr/share/applications/ggv.desktop	t	\N	\N	\N	\N	A Ghostscript frontend to visualize PostScript files	\N	\N	\N
gconf-editor	f	Configuration Editor	gconf-editor	/usr/share/applications/gconf-editor.desktop	t	\N	\N	\N	\N	Directly edit your entire configuration database	\N	\N	\N
dia-gnome	f	Dia	dia-gnome	/usr/share/applications/dia.desktop	t	\N	\N	\N	\N	Diagram editor	\N	\N	\N
filmgimp	f	Film Gimp	filmgimp	/usr/share/applications/filmgimp.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
wxcas	\N	wxCas	wxcas	/usr/share/applications/wxcas.desktop	f	\N	\N	\N	\N	aMule online statistics	\N	\N	\N
emacs21	f	Emacs 21 (X11)	/usr/bin/emacs21	/usr/share/applications/emacs21.desktop	t	Emacs	\N	\N	\N	GNU Emacs 21 Text Editor	\N	\N	\N
gnome-volume-control	f	Volume Control	gnome-volume-control	/usr/share/applications/gnome-volume-control.desktop	t	\N	\N	\N	\N	Adjust the volume level	\N	\N	\N
gnome-sound-recorder	f	Sound Recorder	gnome-sound-recorder	/usr/share/applications/gnome-sound-recorder.desktop	t	\N	\N	\N	\N	Record sound clips	\N	\N	\N
gcalctool	f	Calculator	gcalctool	/usr/share/applications/gcalctool.desktop	t	\N	\N	\N	\N	Perform calculations	\N	\N	\N
gimp-remote-2.0	f	GIMP Image Editor	gimp-remote-2.0 %U	/usr/share/applications/gimp-2.0.desktop	t	\N	\N	\N	\N	Create and edit images or photographs	\N	\N	\N
umbrello	f	Umbrello	umbrello -caption "%c" %i %m	/usr/share/applications/kde/umbrello.desktop	t	UML Modeller	\N	\N	\N	\N	\N	\N	\N
ark	f	Ark	ark -caption "%c" %i %m %U	/usr/share/applications/kde/ark.desktop	t	Archiving Tool	\N	\N	\N	\N	\N	\N	\N
appletproxy	f	KNewsTicker	appletproxy knewsticker.desktop	/usr/share/applications/kde/knewsticker-standalone.desktop	t	News Ticker	\N	\N	\N	\N	\N	\N	\N
kfmclient	f	Konqueror	kfmclient openProfile filemanagement	/usr/share/applications/kde/Home.desktop	t	Web Browser	\N	\N	\N	\N	\N	\N	\N
kate	f	Kate	kate %u	/usr/share/applications/kde/kate.desktop	t	Advanced Text Editor	\N	\N	\N	\N	\N	\N	\N
kwrite	f	KWrite	kwrite %u	/usr/share/applications/kde/kwrite.desktop	t	Text Editor	\N	\N	\N	\N	\N	\N	\N
kcalc	f	KCalc	kcalc  -caption "%c" %i %m	/usr/share/applications/kde/kcalc.desktop	t	Scientific Calculator	\N	\N	\N	\N	\N	\N	\N
kdict	f	Kdict	kdict -caption "%c" %i %m	/usr/share/applications/kde/kdict.desktop	t	Online Dictionary	\N	\N	\N	\N	\N	\N	\N
kget	f	KGet	kget -caption "%c" %i %m	/usr/share/applications/kde/kget.desktop	t	Download Manager	\N	\N	\N	\N	\N	\N	\N
kppplogview	\N	KPPP - Log Viewer	kppplogview	/usr/share/applications/kde/kppplogview.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
kppp	f	KPPP	kppp %i %m	/usr/share/applications/kde/Kppp.desktop	t	Internet Dial-up Tool	\N	\N	\N	\N	\N	\N	\N
kwifimanager	f	KWiFiManager	kwifimanager -caption "%c" %i %m	/usr/share/applications/kde/kwifimanager.desktop	t	Wireless LAN Manager	\N	\N	\N	A wireless LAN connection monitor	\N	\N	\N
krdc	f	Remote Desktop Connection	krdc -caption "%c" %i %m	/usr/share/applications/kde/krdc.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
krfb	f	Desktop Sharing	krfb -caption "%c" %i %m	/usr/share/applications/kde/krfb.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
ksirc	f	KSirc	ksirc %i %m	/usr/share/applications/kde/ksirc.desktop	t	IRC Client	\N	\N	\N	\N	\N	\N	\N
kedit	f	KEdit	kedit  -caption "%c" %i %m %u	/usr/share/applications/kde/KEdit.desktop	t	Simple Text Editor	\N	\N	\N	\N	\N	\N	\N
kwalletmanager	f	Wallet Management Tool	kwalletmanager %u	/usr/share/applications/kde/kwalletmanager.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
artsbuilder	f	aRts Builder	artsbuilder -caption "%c"	/usr/share/applications/kde/artsbuilder.desktop	t	Audio Filter Designer	\N	\N	\N	\N	\N	\N	\N
artscontrol	f	aRts Control Tool	artscontrol -caption "%c"	/usr/share/applications/kde/artscontrol.desktop	t	Sound Server Control	\N	\N	\N	\N	\N	\N	\N
juk	f	JuK	juk -caption "%c" %i %m	/usr/share/applications/kde/juk.desktop	t	Music Player	\N	\N	\N	\N	\N	\N	\N
kaboodle	f	Kaboodle	kaboodle %i %m -caption "%c" %U	/usr/share/applications/kde/kaboodle.desktop	t	Media Player	\N	\N	\N	\N	\N	\N	\N
kscd	f	KsCD	kscd -caption "%c" %i %m	/usr/share/applications/kde/kscd.desktop	t	CD Player	\N	\N	\N	\N	\N	\N	\N
kaudiocreator	f	KAudioCreator	kaudiocreator	/usr/share/applications/kde/kaudiocreator.desktop	t	CD Ripper	\N	\N	\N	Frontend for audio file creation	\N	\N	\N
kmid	f	KMid	kmid %u	/usr/share/applications/kde/kmid.desktop	t	Midi/Karaoke Player	\N	\N	\N	\N	\N	\N	\N
kmix	f	KMix	kmix -caption "%c" %i %m	/usr/share/applications/kde/kmix.desktop	t	Sound Mixer	\N	\N	\N	\N	\N	\N	\N
krec	f	KRec	krec %i %m -caption "%c"	/usr/share/applications/kde/krec.desktop	t	Recording Tool	\N	\N	\N	\N	\N	\N	\N
noatun	f	Noatun	noatun %i %m -caption "%c" %U	/usr/share/applications/kde/noatun.desktop	t	Media Player	\N	\N	\N	\N	\N	\N	\N
kig	f	KDE Interactive Geometry	kig %i %m -caption "%c"	/usr/share/applications/kde/kig.desktop	t	\N	\N	\N	\N	KDE Interactive Geometry	\N	\N	\N
kpilotDaemon	f	KPilotDaemon	kpilotDaemon	/usr/share/applications/kde/kpilotdaemon.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
kmail	f	KMail	kmail -caption "%c" %i %m	/usr/share/applications/kde/KMail.desktop	t	Mail Client	\N	\N	\N	\N	\N	\N	\N
knode	f	KNode	knode -caption "%c" %i %m	/usr/share/applications/kde/KNode.desktop	t	News Reader	\N	\N	\N	\N	\N	\N	\N
kdialog	f	KonsoleKalendar	kdialog --sorry "konsolekalendar is a command-line only program.  Please read the handbook at help:/konsolekalendar for more info."	/usr/share/applications/kde/konsolekalendar.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
kontact	f	Kontact	kontact	/usr/share/applications/kde/Kontact.desktop	t	Personal Information Manager	\N	\N	\N	\N	\N	\N	\N
korn	f	Korn	korn  -caption "%c" %i %m %f	/usr/share/applications/kde/KOrn.desktop	t	Mail Alert	\N	\N	\N	\N	\N	\N	\N
cervisia	f	Cervisia	cervisia -caption "%c" %i %m %u	/usr/share/applications/kde/cervisia.desktop	t	CVS Frontend	\N	\N	\N	\N	\N	\N	\N
flashkard	f	FlashKard	flashkard -caption "%c" %i %m	/usr/share/applications/kde/flashkard.desktop	t	Learning Tool	\N	\N	\N	\N	\N	\N	\N
kappfinder	f	Menu Updating Tool	kappfinder	/usr/share/applications/kde/kappfinder.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
kcontrol	\N	Control Center	kcontrol -caption "%c" %i %m	/usr/share/applications/kde/KControl.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
catalogmanager	f	KBabel - Catalog Manager	catalogmanager %i %m -caption "%c" %U	/usr/share/applications/kde/catalogmanager.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
kbabeldict	f	KBabel - Dictionary	kbabeldict %i %m -caption "%c"	/usr/share/applications/kde/kbabeldict.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
kbabel	f	KBabel	kbabel %i %m -caption "%c" %U	/usr/share/applications/kde/kbabel.desktop	t	Translation Tool	\N	\N	\N	\N	\N	\N	\N
kcolorchooser	f	KColorChooser	kcolorchooser %i %m	/usr/share/applications/kde/kcolorchooser.desktop	t	Color Chooser	\N	\N	\N	\N	\N	\N	\N
kbruch	f	KBruch	kbruch -caption "%c" %i %m	/usr/share/applications/kde/kbruch.desktop	t	Exercise Fractions	\N	\N	\N	Practice exercises with fractions	\N	\N	\N
kbugbuster	f	KBugBuster	kbugbuster -caption "%c" %i %m	/usr/share/applications/kde/kbugbuster.desktop	t	KDE Bug Management	\N	\N	\N	\N	\N	\N	\N
kcoloredit	f	KColorEdit	kcoloredit %i %m %U	/usr/share/applications/kde/kcoloredit.desktop	t	Color Palette Editor	\N	\N	\N	\N	\N	\N	\N
kdat	f	KDat	kdat %i %m -caption "%c"	/usr/share/applications/kde/kdat.desktop	t	Tape Backup Tool	\N	\N	\N	\N	\N	\N	\N
ksig	f	KSig	ksig -caption "%c" %i %m	/usr/share/applications/kde/ksig.desktop	t	Signature Editor	\N	\N	\N	\N	\N	\N	\N
kpackage	f	KPackage	kpackage -caption "%c" %i %m %u	/usr/share/applications/kde/kpackage.desktop	t	Package Manager	\N	\N	\N	\N	\N	\N	\N
kuser	f	KUser	kuser %i %m -caption "%c"	/usr/share/applications/kde/kuser.desktop	t	User Manager	\N	\N	\N	\N	\N	\N	\N
kdeprintfax	f	KdeprintFax	kdeprintfax -caption "%c" %i %m %u	/usr/share/applications/kde/kdeprintfax.desktop	t	Fax Utility	\N	\N	\N	\N	\N	\N	\N
kjobviewer	f	Print Jobs	kjobviewer --all --show %i %m	/usr/share/applications/kde/kjobviewer.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
klipper	f	Klipper	klipper	/usr/share/applications/kde/klipper.desktop	t	Clipboard Tool	\N	\N	\N	\N	\N	\N	\N
kmenuedit	\N	Menu Editor	kmenuedit	/usr/share/applications/kde/kmenuedit.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
kpager	f	KPager	kpager	/usr/share/applications/kde/kpager.desktop	t	Desktop Pager	\N	\N	\N	\N	\N	\N	\N
kiten	f	Kiten	kiten -caption "%c" %i %m	/usr/share/applications/kde/kiten.desktop	t	Japanese Reference/Study Tool	\N	\N	\N	\N	\N	\N	\N
klettres	f	KLettres	klettres -caption "%c" %i %m	/usr/share/applications/kde/klettres.desktop	t	Learn Alphabet	\N	\N	\N	\N	\N	\N	\N
kmplot	f	KmPlot	kmplot	/usr/share/applications/kde/kmplot.desktop	t	Function Plotter	\N	\N	\N	Function Plotter	\N	\N	\N
kpercentage	f	KPercentage	kpercentage	/usr/share/applications/kde/kpercentage.desktop	t	Exercise Percentages	\N	\N	\N	\N	\N	\N	\N
ktouch	f	KTouch	ktouch -caption "%c" %i %m	/usr/share/applications/kde/ktouch.desktop	t	Touch Typing Tutor	\N	\N	\N	\N	\N	\N	\N
kverbos	f	Kverbos	kverbos -caption "%c" %i %m	/usr/share/applications/kde/kverbos.desktop	t	Study Spanish Verbforms	\N	\N	\N	\N	\N	\N	\N
kvoctrain	f	KVocTrain	kvoctrain	/usr/share/applications/kde/kvoctrain.desktop	t	Vocabulary Trainer	\N	\N	\N	\N	\N	\N	\N
kreversi	f	KReversi	/usr/games/kreversi %i %m -caption "%c"	/usr/share/applications/kde/kreversi.desktop	t	Board Game	\N	\N	\N	\N	\N	\N	\N
ksame	\N	SameGame	/usr/games/ksame %i %m -caption "%c"	/usr/share/applications/kde/ksame.desktop	t	Board Game	\N	\N	\N	\N	\N	\N	\N
kshisen	\N	Shisen-Sho	/usr/games/kshisen %i %m -caption "%c"	/usr/share/applications/kde/kshisen.desktop	t	Tile Game	\N	\N	\N	\N	\N	\N	\N
ksirtet	\N	KSirtet	/usr/games/ksirtet -caption "%c" %i %m	/usr/share/applications/kde/ksirtet.desktop	t	Arcade Game	\N	\N	\N	\N	\N	\N	\N
ksmiletris	f	KSmileTris	/usr/games/ksmiletris -caption "%c" %i %m	/usr/share/applications/kde/ksmiletris.desktop	t	Arcade Game	\N	\N	\N	\N	\N	\N	\N
ksokoban	f	KSokoban	/usr/games/ksokoban %i %m -caption "%c"	/usr/share/applications/kde/ksokoban.desktop	t	Logic Game	\N	\N	\N	\N	\N	\N	\N
ktuberling	f	Potato Guy	/usr/games/ktuberling %i %m -caption "%c" %u	/usr/share/applications/kde/ktuberling.desktop	t	Game for Children	\N	\N	\N	\N	\N	\N	\N
kwin4	f	KWin4	/usr/games/kwin4	/usr/share/applications/kde/kwin4.desktop	t	Strategy Game	\N	\N	\N	\N	\N	\N	\N
lskat	f	Lieutnant Skat	/usr/games/lskat	/usr/share/applications/kde/lskat.desktop	t	Card Game	\N	\N	\N	\N	\N	\N	\N
kviewshell	f	KDVI	kviewshell dvi %f -caption "%c" %i %m	/usr/share/applications/kde/kdvi.desktop	t	DVI Viewer	\N	\N	\N	\N	\N	\N	\N
kiconedit	f	KIconEdit	kiconedit -caption "%c" %i %m %u	/usr/share/applications/kde/kiconedit.desktop	t	Icon Editor	\N	\N	\N	\N	\N	\N	\N
kooka	f	Kooka	kooka %i %m %U	/usr/share/applications/kde/kooka.desktop	t	Scan & OCR Program	\N	\N	\N	\N	\N	\N	\N
kpaint	f	KPaint	kpaint %u -caption "%c" %i %m	/usr/share/applications/kde/kpaint.desktop	t	Paint Program	\N	\N	\N	\N	\N	\N	\N
kpdf	f	KPDF	kpdf %i %m -caption "%c"	/usr/share/applications/kde/kpdf.desktop	t	PDF Viewer	\N	\N	\N	\N	\N	\N	\N
kpovmodeler	f	Povray Modeler	kpovmodeler -caption "%c" %i %m %f	/usr/share/applications/kde/kpovmodeler.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
kruler	f	KRuler	kruler %i %m	/usr/share/applications/kde/kruler.desktop	t	Screen Ruler	\N	\N	\N	\N	\N	\N	\N
ksnapshot	f	KSnapshot	ksnapshot -caption "%c" %i %m	/usr/share/applications/kde/ksnapshot.desktop	t	Screen Capture Program	\N	\N	\N	\N	\N	\N	\N
kuickshow	f	Kuickshow	kuickshow %i %m -caption "%c" %U	/usr/share/applications/kde/kuickshow.desktop	t	Image Viewer	\N	\N	\N	\N	\N	\N	\N
kompare	f	Kompare	kompare -caption "%c" %i %m -o %U	/usr/share/applications/kde/kompare.desktop	t	Diff/Patch Frontend	\N	\N	\N	\N	\N	\N	\N
kuiviewer	f	KUIViewer	kuiviewer %i %m -caption "%c"	/usr/share/applications/kde/kuiviewer.desktop	t	Qt Designer UI file Viewer	\N	\N	\N	\N	\N	\N	\N
kcmshell	\N	Boot Manager (LILO)	kcmshell khtml_plugins	/usr/share/applications/kde/khtml_plugins.desktop	t	\N	\N	\N	\N	Configure LILO (the Linux boot manager)	\N	\N	\N
kcachegrind	f	KCachegrind	kcachegrind -caption "%c" %i %m %u	/usr/share/applications/kde/kcachegrind.desktop	t	Profiler Frontend	\N	\N	\N	Visualization of Performance Profiling Data	\N	\N	\N
smb4k	f	Smb4K	smb4k	/usr/share/applications/kde/smb4k.desktop	t	The SMB Share Browser	\N	\N	\N	The SMB Share Browser	\N	\N	\N
gnome-remote-shell	f	Remote shell	gnome-remote-shell	/usr/share/applications/gnome-network-utilities.desktop	t	\N	\N	\N	\N	Open a shell on a remote server	\N	\N	\N
gnome-netinfo	f	Network information	gnome-netinfo	/usr/share/applications/gnome-netinfo.desktop	t	\N	\N	\N	\N	Network information tools	\N	\N	\N
grip	\N	Grip	grip	/usr/share/applications/grip.desktop	t	\N	\N	\N	\N	CD player/ripper	\N	\N	\N
gmfsk	f	gMFSK	gmfsk	/usr/share/applications/gmfsk.desktop	t	\N	\N	\N	\N	HF digital mode terminal	\N	\N	\N
tsclient	f	Terminal Server Client	tsclient	/usr/share/applications/tsclient.desktop	t	\N	\N	\N	\N	Connect to a remote computer	\N	\N	\N
mlv	f	MlView XML Editor	mlv %F	/usr/share/applications/mlview.desktop	t	MlView Generic XML Editor	\N	\N	\N	A generic simple and powerfull XML editor for GNOME	\N	\N	\N
conglomerate	f	Conglomerate XML Editor	conglomerate %U	/usr/share/applications/conglomerate.desktop	t	\N	\N	\N	\N	Edit XML files	\N	\N	\N
nautilus	f	Computer	nautilus network:	/usr/share/applications/network-scheme.desktop	t	\N	\N	\N	\N	View your computer storage	\N	\N	\N
mozilla-thunderbird	f	Thunderbird Mail Client	mozilla-thunderbird -P	/usr/share/applications/mozilla-thunderbird-pm.desktop	t	\N	\N	\N	\N	Read and write your email	\N	\N	\N
amule	f	aMule	amule	/usr/share/applications/amule.desktop	t	\N	\N	\N	\N	aMule	\N	\N	\N
dbishell	t	dbishell	/usr/bin/dbishell	/var/lib/menu-xdg/applications/menu-xdg/dbishell.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
gnomedb-fe	f	GNOME-DB frontend	/usr/bin/gnomedb-fe	/var/lib/menu-xdg/applications/menu-xdg/gnome-db_frontend.deskt	t	\N	\N	\N	\N	\N	\N	\N	\N
/usr/bin/X11/pgaccess	f	PgAccess	/usr/bin/X11/pgaccess	/var/lib/menu-xdg/applications/menu-xdg/pgaccess.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
/usr/lib/postgresql/bin/psql-wm	t	PostgreSQL interactive terminal (psql)	/usr/lib/postgresql/bin/psql-wm	/var/lib/menu-xdg/applications/menu-xdg/postgresql_interactive_	f	\N	\N	\N	\N	\N	\N	\N	\N
quicklist	f	quicklist	/usr/bin/quicklist	/var/lib/menu-xdg/applications/menu-xdg/quicklist.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
sqlr-config-gtk	f	SQL Relay Configuration	/usr/bin/sqlr-config-gtk	/var/lib/menu-xdg/applications/menu-xdg/sql_relay_configuration	t	\N	\N	\N	\N	\N	\N	\N	\N
tora	f	TOra	tora	/usr/share/applnk/Development/tora.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
/usr/bin/X11/axe	f	aXe	/usr/bin/X11/axe	/var/lib/menu-xdg/applications/menu-xdg/axe.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
fontforge	\N	fontforge	fontforge	\N	\N	\N	\N	\N	\N	\N	\N	\N	\N
joe	t	Joe	/usr/bin/joe	/var/lib/menu-xdg/applications/menu-xdg/joe.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
kvim	f	KVim	kvim -f %F	/usr/share/applnk/Editors/KVim.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
kword	\N	KWord	kword	/usr/share/applnk/Office/kword.desktop	t	\N	\N	\N	\N	KWord (Word Processing)	\N	\N	\N
kxmleditor	f	kxmleditor	kxmleditor -caption "%c" %i %m	/usr/share/applnk/Applications/kxmleditor.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
lyx-qt	f	LyX (Qt)	/usr/bin/lyx-qt	/var/lib/menu-xdg/applications/menu-xdg/lyx_(qt).desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
nano	t	Nano	/bin/nano	/var/lib/menu-xdg/applications/menu-xdg/nano.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
pw	f	Pathetic Writer	/usr/bin/pw	/var/lib/menu-xdg/applications/menu-xdg/pathetic_writer.desktop	t	\N	\N	\N	\N	Siag Office Pathetic Writer	\N	\N	\N
vim	t	Vim	/usr/bin/vim	/var/lib/menu-xdg/applications/menu-xdg/vim.desktop	t	\N	\N	\N	\N	VIM, Vi IMproved	\N	\N	\N
xedit	f	Xedit	xedit	/var/lib/menu-xdg/applications/menu-xdg/xedit.desktop	t	\N	\N	\N	\N	Xedit: simple text editor for X	\N	\N	\N
xemacs21-mule	f	XEmacs21-mule	/usr/bin/xemacs21-mule	/var/lib/menu-xdg/applications/menu-xdg/xemacs21-mule.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
yudit	f	yudit	/usr/bin/yudit	/var/lib/menu-xdg/applications/menu-xdg/yudit.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
BasiliskII	f	BasiliskII	/usr/bin/BasiliskII	/var/lib/menu-xdg/applications/menu-xdg/basiliskii.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
x128	f	Commodore 128	/usr/bin/x128	/var/lib/menu-xdg/applications/menu-xdg/commodore_128.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
x64	f	Commodore 64	/usr/bin/x64	/var/lib/menu-xdg/applications/menu-xdg/commodore_64.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
xcbm2	f	Commodore CBM-II	/usr/bin/xcbm2	/var/lib/menu-xdg/applications/menu-xdg/commodore_cbm-ii.deskto	t	\N	\N	\N	\N	\N	\N	\N	\N
xpet	f	Commodore PET	/usr/bin/xpet	/var/lib/menu-xdg/applications/menu-xdg/commodore_pet.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
xvic	f	Commodore VIC-20	/usr/bin/xvic	/var/lib/menu-xdg/applications/menu-xdg/commodore_vic-20.deskto	t	\N	\N	\N	\N	\N	\N	\N	\N
dosemu	t	Dos Emulator (tty)	/usr/bin/dosemu	/var/lib/menu-xdg/applications/menu-xdg/dos_emulator_(tty).desk	t	\N	\N	\N	\N	The Linux DOS Emulator	\N	\N	\N
xdosemu	f	Dos Emulator (X11)	/usr/bin/xdosemu	/var/lib/menu-xdg/applications/menu-xdg/dos_emulator_(x11).desk	t	\N	\N	\N	\N	The Linux DOS Emulator	\N	\N	\N
GSnes9x	f	gsnes9x	/usr/bin/GSnes9x	/var/lib/menu-xdg/applications/menu-xdg/gsnes9x.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
uae-x	f	UAE	/usr/bin/uae-x	/var/lib/menu-xdg/applications/menu-xdg/uae.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
bitmap	f	Bitmap	bitmap	/var/lib/menu-xdg/applications/menu-xdg/bitmap.desktop	t	\N	\N	\N	\N	Bitmap: editor for X bitmap files	\N	\N	\N
cenon	f	Cenon	/usr/bin/cenon	/var/lib/menu-xdg/applications/menu-xdg/cenon.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
cinelerra	f	cinelerra	/usr/bin/cinelerra	/var/lib/menu-xdg/applications/menu-xdg/cinelerra.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
egon	f	Egon	/usr/bin/egon	/var/lib/menu-xdg/applications/menu-xdg/egon.desktop	t	\N	\N	\N	\N	Siag Office Egon Animator	\N	\N	\N
giram	f	giram	/usr/bin/giram	/var/lib/menu-xdg/applications/menu-xdg/giram.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
ganso	f	Gnome Animation Studio	/usr/bin/ganso	/var/lib/menu-xdg/applications/menu-xdg/gnome_animation_studio.	t	\N	\N	\N	\N	\N	\N	\N	\N
gqcam	f	gqcam	/usr/bin/gqcam	/var/lib/menu-xdg/applications/menu-xdg/gqcam.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
gtk-ocr	f	GTK Gocr	/usr/bin/gtk-ocr	/var/lib/menu-xdg/applications/menu-xdg/gtk_gocr.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
innovation3d	f	Innovation3D modeler	/usr/bin/innovation3d	/var/lib/menu-xdg/applications/menu-xdg/innovation3d_modeler.de	t	\N	\N	\N	\N	\N	\N	\N	\N
ivview	f	ivview	/usr/bin/ivview	/var/lib/menu-xdg/applications/menu-xdg/ivview.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
karbon	\N	Karbon	karbon	/usr/share/applnk/Office/karbon.desktop	t	\N	\N	\N	\N	Karbon (Scalable Graphics)	\N	\N	\N
krita	\N	Krita	krita	/usr/share/applnk/Office/krita.desktop	t	\N	\N	\N	\N	Krita (Image Manipulation)	\N	\N	\N
motion	t	motion	/usr/bin/motion	/var/lib/menu-xdg/applications/menu-xdg/motion.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
picview	f	Picview	/usr/bin/picview	/var/lib/menu-xdg/applications/menu-xdg/picview.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
pixmap	f	Pixmap	/usr/X11R6/bin/pixmap	/var/lib/menu-xdg/applications/menu-xdg/pixmap.desktop	t	\N	\N	\N	\N	Pixmap editor	\N	\N	\N
price	f	PRICE	/usr/bin/price	/var/lib/menu-xdg/applications/menu-xdg/price.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
sced	f	ScEd	/usr/bin/sced	/var/lib/menu-xdg/applications/menu-xdg/sced.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
SceneViewer	f	SceneViewer	/usr/bin/SceneViewer	/var/lib/menu-xdg/applications/menu-xdg/sceneviewer.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
snowflake	f	snowflake	/usr/bin/snowflake	/var/lib/menu-xdg/applications/menu-xdg/snowflake.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
terraform	f	Terraform	/usr/bin/terraform	/var/lib/menu-xdg/applications/menu-xdg/terraform.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
gimp-2.0	f	The GIMP (v2.0)	/usr/bin/gimp-2.0	/var/lib/menu-xdg/applications/menu-xdg/the_gimp_(v2.0).desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
tulip	f	tulip	/usr/bin/tulip	/var/lib/menu-xdg/applications/menu-xdg/tulip.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
tuxpaint	f	tuxpaint	tuxpaint	/usr/share/applnk/Graphics/tuxpaint.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
vertex	f	vertex	/usr/bin/vertex	/var/lib/menu-xdg/applications/menu-xdg/vertex.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
xmorph	f	xmorph	/usr/bin/xmorph	/var/lib/menu-xdg/applications/menu-xdg/xmorph.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
xmps	f	XMPS (GNOME)	xmps	/var/lib/menu-xdg/applications/menu-xdg/xmps.desktop	t	\N	\N	\N	\N	X MPEG Player System, GNOME frontend	\N	\N	\N
/usr/bin/X11/xpaint	f	Xpaint	/usr/bin/X11/xpaint	/var/lib/menu-xdg/applications/menu-xdg/xpaint.desktop	t	\N	\N	\N	\N	Xpaint: JPEG/TIFF/PNG/etc. editor	\N	\N	\N
gworldclock	f	gworldclock	/usr/bin/gworldclock	/var/lib/menu-xdg/applications/menu-xdg/gworldclock.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
hamfax	f	hamfax	/usr/bin/hamfax	/var/lib/menu-xdg/applications/menu-xdg/hamfax.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
linpac	t	linpac	/usr/bin/linpac	/var/lib/menu-xdg/applications/menu-xdg/linpac.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
twclock	f	Twclock	/usr/bin/twclock	/var/lib/menu-xdg/applications/menu-xdg/twclock.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
xastir	f	xastir	/usr/bin/xastir	/var/lib/menu-xdg/applications/menu-xdg/xastir.desktop	t	\N	\N	\N	\N	Xastir	\N	\N	\N
xcall	f	Xcall	/usr/bin/xcall	/var/lib/menu-xdg/applications/menu-xdg/xcall.desktop	t	\N	\N	\N	\N	Xcall: packet radio program	\N	\N	\N
bc	t	bc	/usr/bin/bc	/var/lib/menu-xdg/applications/menu-xdg/bc.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
burlap	t	Burlap	/usr/bin/burlap	/var/lib/menu-xdg/applications/menu-xdg/burlap.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
dc	t	dc	/usr/bin/dc	/var/lib/menu-xdg/applications/menu-xdg/dc.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
fudgit	t	Fudgit	/usr/bin/fudgit	/var/lib/menu-xdg/applications/menu-xdg/fudgit.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
geomview	f	geomview	/usr/bin/geomview	/var/lib/menu-xdg/applications/menu-xdg/geomview.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
gstar	f	gstar	/usr/bin/gstar	/var/lib/menu-xdg/applications/menu-xdg/gstar.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
kchart	\N	KChart	kchart	/usr/share/applnk/Office/kchart.desktop	t	\N	\N	\N	\N	KChart (Charting)	\N	\N	\N
kformula	\N	KFormula	kformula	/usr/share/applnk/Office/kformula.desktop	t	\N	\N	\N	\N	KFormula (Formula Editor)	\N	\N	\N
kspread	\N	KSpread	kspread	/usr/share/applnk/Office/kspread.desktop	t	\N	\N	\N	\N	KSpread (Spreadsheets)	\N	\N	\N
openuniverse	f	openuniverse	/usr/bin/openuniverse	/var/lib/menu-xdg/applications/menu-xdg/openuniverse.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
perldl	t	PerlDl	/usr/bin/perldl	/var/lib/menu-xdg/applications/menu-xdg/perldl.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
rcalc	f	rCalc (text)	/usr/bin/rcalc	/var/lib/menu-xdg/applications/menu-xdg/rcalc.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
siag	f	Siag	/usr/bin/siag	/var/lib/menu-xdg/applications/menu-xdg/siag.desktop	t	\N	\N	\N	\N	Siag Office Scheme-in-a-Grid	\N	\N	\N
tsiag	t	Siag (text mode)	/usr/bin/tsiag	/var/lib/menu-xdg/applications/menu-xdg/siag_(text_mode).deskto	t	\N	\N	\N	\N	Siag Office Scheme-in-a-Grid (text mode)	\N	\N	\N
velvet	f	Velvet	/usr/bin/velvet	/var/lib/menu-xdg/applications/menu-xdg/velvet.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
xabacus	f	xabacus	/usr/games/xabacus	/var/lib/menu-xdg/applications/menu-xdg/xabacus.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
xcalc	f	Xcalc	xcalc	/var/lib/menu-xdg/applications/menu-xdg/xcalc.desktop	t	\N	\N	\N	\N	Xcalc: scientific calculator for X	\N	\N	\N
xmaxima	f	xmaxima	/usr/bin/xmaxima	/var/lib/menu-xdg/applications/menu-xdg/xmaxima.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
amaya	f	Amaya	/usr/bin/amaya	/var/lib/menu-xdg/applications/menu-xdg/amaya.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
amulewebDLG	f	aMule webserver control	/usr/bin/amulewebDLG	/var/lib/menu-xdg/applications/menu-xdg/amule_webserver_control	t	\N	\N	\N	\N	\N	\N	\N	\N
dillo	f	Dillo	/usr/bin/dillo	/var/lib/menu-xdg/applications/menu-xdg/dillo.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
driftnet	f	Driftnet	/usr/bin/driftnet	/var/lib/menu-xdg/applications/menu-xdg/driftnet.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
everybuddy	f	EveryBuddy	/usr/bin/everybuddy	/var/lib/menu-xdg/applications/menu-xdg/everybuddy.desktop	t	\N	\N	\N	\N	EveryBuddy: Unified Messaging Client	\N	\N	\N
fwbuilder	f	Firewall Builder	/usr/bin/fwbuilder	/var/lib/menu-xdg/applications/menu-xdg/firewall_builder.deskto	t	\N	\N	\N	\N	\N	\N	\N	\N
gipsc	f	Gipsc	/usr/X11R6/bin/gipsc	/var/lib/menu-xdg/applications/menu-xdg/gipsc.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
gnapster	f	Gnapster	/usr/bin/gnapster	/var/lib/menu-xdg/applications/menu-xdg/gnapster.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
kit	f	Kit	kit	/usr/share/applnk/Internet/kit.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
kmailcvt	f	KMail/KAB Import Tool	/usr/bin/kmailcvt	/var/lib/menu-xdg/applications/menu-xdg/kmail_kab_import_tool.d	t	\N	\N	\N	\N	\N	\N	\N	\N
kopete	f	Kopete	kopete %i %m -caption "%c"	/usr/share/applnk/Internet/kopete.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
lynx	t	Lynx	/usr/bin/lynx %u	/usr/share/applnk/Internet/lynx.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
minicom	t	Minicom	/usr/bin/minicom	/var/lib/menu-xdg/applications/menu-xdg/minicom.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
xminicom	f	Minicom (X11)	/usr/bin/xminicom	/var/lib/menu-xdg/applications/menu-xdg/minicom_(x11).desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
mutt	t	Mutt	/usr/bin/mutt	/var/lib/menu-xdg/applications/menu-xdg/mutt.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
ncftp3	t	ncftp	/usr/bin/ncftp3	/var/lib/menu-xdg/applications/menu-xdg/ncftp.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
pan	f	Pan	/usr/bin/pan	/var/lib/menu-xdg/applications/menu-xdg/pan.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
gnome-remote-desktop	f	Remote Desktop	/usr/bin/gnome-remote-desktop	/var/lib/menu-xdg/applications/menu-xdg/remote_desktop.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
sdr	f	Sdr	sdr	/var/lib/menu-xdg/applications/menu-xdg/sdr.desktop	t	\N	\N	\N	\N	MBONE Session Directory	\N	\N	\N
telnet	t	Telnet	telnet	/var/lib/menu-xdg/applications/menu-xdg/telnet.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
tkchooser	f	TkChooser	/usr/bin/tkchooser	/var/lib/menu-xdg/applications/menu-xdg/tkchooser.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
vrwave	f	VRwave VRML browser	/usr/bin/vrwave	/var/lib/menu-xdg/applications/menu-xdg/vrwave_vrml_browser.des	t	\N	\N	\N	\N	\N	\N	\N	\N
w3m	t	w3m	/usr/bin/w3m /usr/share/doc/w3m/MANUAL.html	/var/lib/menu-xdg/applications/menu-xdg/w3m.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
xbiff	f	Xbiff	xbiff	/var/lib/menu-xdg/applications/menu-xdg/xbiff.desktop	t	\N	\N	\N	\N	Xbiff: mailbox flag for X	\N	\N	\N
argouml	f	ArgoUML	/usr/bin/argouml	/var/lib/menu-xdg/applications/menu-xdg/argouml.desktop	t	\N	\N	\N	\N	UML Modelling tool	\N	\N	\N
autoproject	t	autoproject	/usr/bin/autoproject	/var/lib/menu-xdg/applications/menu-xdg/autoproject.desktop	t	\N	\N	\N	\N	create a skeleton source package for a new program	\N	\N	\N
lisp	t	CMUCL Normal Image	/usr/bin/lisp -core /usr/lib/cmucl/lisp.core	/var/lib/menu-xdg/applications/menu-xdg/cmucl_normal_image.desk	t	\N	\N	\N	\N	\N	\N	\N	\N
ddd	f	Data Display Debugger	/usr/bin/ddd	/var/lib/menu-xdg/applications/menu-xdg/data_display_debugger.d	t	\N	\N	\N	\N	\N	\N	\N	\N
elk	t	elk	/usr/bin/elk	/var/lib/menu-xdg/applications/menu-xdg/elk.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
fluid	f	Fluid	/usr/bin/fluid	/var/lib/menu-xdg/applications/menu-xdg/fluid.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
gide	f	gIDE	/usr/bin/gide	/var/lib/menu-xdg/applications/menu-xdg/gide.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
guile-1.6	t	Guile 1.6	/usr/bin/guile-1.6	/var/lib/menu-xdg/applications/menu-xdg/guile_1.6.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
guile1.4	t	Guile Scheme 1.4	guile1.4	/var/lib/menu-xdg/applications/menu-xdg/guile_scheme_1.4.deskto	t	\N	\N	\N	\N	\N	\N	\N	\N
insight	f	Insight	/usr/bin/insight	/var/lib/menu-xdg/applications/menu-xdg/insight.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
jython	t	Jython	/usr/bin/jython	/var/lib/menu-xdg/applications/menu-xdg/jython.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
kdevelop3	f	KDevelop 3.0	kdevelop3 %u	/usr/share/applnk/Development/kdevelop3.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
kodos	f	Kodos	/usr/bin/kodos	/var/lib/menu-xdg/applications/menu-xdg/kodos.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
pike7.2	t	Pike 7.2 HILFE	/usr/bin/pike7.2	/var/lib/menu-xdg/applications/menu-xdg/pike_7.2_hilfe.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
pycrust	f	pycrust	/usr/bin/pycrust	/var/lib/menu-xdg/applications/menu-xdg/pycrust.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
pyshell	f	pyshell	/usr/bin/pyshell	/var/lib/menu-xdg/applications/menu-xdg/pyshell.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
python2.1	t	Python (v2.1)	/usr/bin/python2.1	/var/lib/menu-xdg/applications/menu-xdg/python_(v2.1).desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
python2.2	t	Python (v2.2)	/usr/bin/python2.2	/var/lib/menu-xdg/applications/menu-xdg/python_(v2.2).desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
python2.3	t	Python (v2.3)	/usr/bin/python2.3	/var/lib/menu-xdg/applications/menu-xdg/python_(v2.3).desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
designer-qt3	f	Qt Designer	designer-qt3	/usr/share/applnk/Development/designer-qt3.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
irb1.8	t	Ruby (irb1.8)	/usr/bin/irb1.8	/var/lib/menu-xdg/applications/menu-xdg/ruby_(irb1.8).desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
tclsh8.0	t	Tclsh8.0	/usr/bin/tclsh8.0	/var/lib/menu-xdg/applications/menu-xdg/tclsh8.0.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
tclsh8.2	t	Tclsh8.2	/usr/bin/tclsh8.2	/var/lib/menu-xdg/applications/menu-xdg/tclsh8.2.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
tclsh8.3	t	Tclsh8.3	/usr/bin/tclsh8.3	/var/lib/menu-xdg/applications/menu-xdg/tclsh8.3.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
kalzium	f	Kalzium	kalzium -caption "%c" %i %m	/usr/share/applications/kde/kalzium.desktop	t	Periodic Table of Elements	\N	\N	\N	\N	\N	\N	\N
kstars	f	KStars	kstars -caption "%c" %i %m	/usr/share/applications/kde/kstars.desktop	t	Desktop Planetarium	\N	\N	\N	Desktop Planetarium	\N	\N	\N
njplot	f	NJPlot	/usr/bin/njplot	/var/lib/menu-xdg/applications/menu-xdg/njplot.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
unrooted	f	NJPlot unrooted	/usr/bin/unrooted	/var/lib/menu-xdg/applications/menu-xdg/njplot_unrooted.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
rasmol	t	Rasmol	/usr/bin/rasmol	/var/lib/menu-xdg/applications/menu-xdg/rasmol.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
Psequin	f	Sequin	/usr/bin/Psequin	/var/lib/menu-xdg/applications/menu-xdg/sequin.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
starplot	f	StarPlot	/usr/bin/starplot	/var/lib/menu-xdg/applications/menu-xdg/starplot.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
udv	f	udv	/usr/bin/udv	/var/lib/menu-xdg/applications/menu-xdg/udv.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
vibrate	f	vecscreen	/usr/bin/vibrate /usr/bin/asn2asn	/var/lib/menu-xdg/applications/menu-xdg/asn2asn.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
bash	t	Bash	/bin/bash --login	/var/lib/menu-xdg/applications/menu-xdg/bash.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
ksh	t	Ksh	/bin/ksh -l	/var/lib/menu-xdg/applications/menu-xdg/ksh.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
tcsh	t	tcsh	/bin/tcsh	/var/lib/menu-xdg/applications/menu-xdg/tcsh.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
aconnectgui	f	aconnectgui	/usr/bin/aconnectgui	/var/lib/menu-xdg/applications/menu-xdg/aconnectgui.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
vkeybd	f	AWE Virtual Keyboard	/usr/bin/vkeybd	/var/lib/menu-xdg/applications/menu-xdg/awe_virtual_keyboard.de	t	\N	\N	\N	\N	AWE32 driver based Virtual Keyboard program	\N	\N	\N
bcast2000	f	Broadcast2000	/usr/bin/bcast2000	/var/lib/menu-xdg/applications/menu-xdg/broadcast2000.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
/usr/bin/X11/xterm	f	cam	/usr/bin/X11/xterm -hold -e /usr/bin/ardour	/var/lib/menu-xdg/applications/menu-xdg/ardour_gtk.desktop	t	\N	\N	\N	\N	Cpu's Audio Mixer	\N	\N	\N
cecilia	f	Cecilia	/usr/bin/cecilia	/var/lib/menu-xdg/applications/menu-xdg/cecilia.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
ceres3	f	ceres3	/usr/bin/ceres3	/var/lib/menu-xdg/applications/menu-xdg/ceres3.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
cglame	t	cglame	/usr/bin/cglame	/var/lib/menu-xdg/applications/menu-xdg/cglame.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
ecasound	t	ecasound	/usr/bin/ecasound	/var/lib/menu-xdg/applications/menu-xdg/ecasound.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
extace	f	extace	/usr/bin/extace	/var/lib/menu-xdg/applications/menu-xdg/extace.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
freebirth	f	freebirth	/usr/bin/freebirth	/var/lib/menu-xdg/applications/menu-xdg/freebirth.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
gamix	f	gamix	gamix	/var/lib/menu-xdg/applications/menu-xdg/gamix.desktop	t	\N	\N	\N	\N	ALSA mixer	\N	\N	\N
glcthugha	f	GL Cthugha	glcthugha	/var/lib/menu-xdg/applications/menu-xdg/gl_cthugha.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
glame	f	glame	/usr/bin/glame	/var/lib/menu-xdg/applications/menu-xdg/glame.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
gnomp3	f	gnomp3	/usr/bin/gnomp3	/var/lib/menu-xdg/applications/menu-xdg/gnomp3.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
gom-ct	t	Gom (terminal)	/usr/bin/gom-ct --interface=t	/var/lib/menu-xdg/applications/menu-xdg/gom_(terminal).desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
gsox	f	gsox	/usr/bin/gsox	/var/lib/menu-xdg/applications/menu-xdg/gsox.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
gtick	f	gtick	/usr/bin/gtick	/var/lib/menu-xdg/applications/menu-xdg/gtick.desktop	t	\N	\N	\N	\N	GTick, a GTK-based metronome	\N	\N	\N
horgand	f	Horgand	/usr/bin/horgand -b /usr/share/horgand/Default.horeb	/var/lib/menu-xdg/applications/menu-xdg/horgand.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
id3ren	t	id3ren	/usr/bin/id3ren	/var/lib/menu-xdg/applications/menu-xdg/id3ren.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
kmidi	f	KMidi	kmidi %m %i %f	/usr/share/applnk/Multimedia/More/kmidi.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
mammut	f	mammut	/usr/bin/mammut	/var/lib/menu-xdg/applications/menu-xdg/mammut.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
/usr/bin/X11/mix	f	Mix	/usr/bin/X11/mix	/var/lib/menu-xdg/applications/menu-xdg/mix.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
/usr/X11R6/bin/Mixer.app	f	Mixer.app	/usr/X11R6/bin/Mixer.app	/var/lib/menu-xdg/applications/menu-xdg/mixer.app.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
mixmagic	f	MixMagic	/usr/bin/mixmagic	/var/lib/menu-xdg/applications/menu-xdg/mixmagic.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
mxv	f	MixViews	/usr/X11R6/bin/mxv	/var/lib/menu-xdg/applications/menu-xdg/mixviews.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
music-librarian	f	Music Librarian	/usr/bin/music-librarian	/var/lib/menu-xdg/applications/menu-xdg/music_librarian.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
qrt	f	qrt	/usr/bin/qrt	/var/lib/menu-xdg/applications/menu-xdg/qrt.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
qsynth	f	qsynth	/usr/bin/qsynth	/var/lib/menu-xdg/applications/menu-xdg/qsynth.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
rosegarden4	f	Rosegarden4	rosegarden4 -caption "%c" %i %m	/usr/share/applnk/Multimedia/rosegarden.desktop	t	\N	\N	\N	\N	Rosegarden4 Music Editor	\N	\N	\N
shaketracker	f	ShackeTracker	shaketracker	/var/lib/menu-xdg/applications/menu-xdg/shacketracker.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
smurf	f	smurf	/usr/bin/smurf	/var/lib/menu-xdg/applications/menu-xdg/smurf.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
snd	f	Snd	/usr/bin/snd	/var/lib/menu-xdg/applications/menu-xdg/snd.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
GUIBowedBar	f	BowedBar	/usr/bin/GUIBowedBar	/var/lib/menu-xdg/applications/menu-xdg/bowedbar.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
GUIDrums	f	Drums	/usr/bin/GUIDrums	/var/lib/menu-xdg/applications/menu-xdg/drums.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
GUIeffects	f	Effects	/usr/bin/GUIeffects	/var/lib/menu-xdg/applications/menu-xdg/effects.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
GUIModal	f	Modal	/usr/bin/GUIModal	/var/lib/menu-xdg/applications/menu-xdg/modal.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
GUIPhysical	f	Physical	/usr/bin/GUIPhysical	/var/lib/menu-xdg/applications/menu-xdg/physical.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
GUIRaga	f	Ragamatic	/usr/bin/GUIRaga	/var/lib/menu-xdg/applications/menu-xdg/ragamatic.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
GUIShakers	f	Shakers	/usr/bin/GUIShakers	/var/lib/menu-xdg/applications/menu-xdg/shakers.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
GUIVoice	f	Voice	/usr/bin/GUIVoice	/var/lib/menu-xdg/applications/menu-xdg/voice.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
wmxmms	f	wmXMMS	wmxmms	/var/lib/menu-xdg/applications/menu-xdg/wmxmms.desktop	t	\N	\N	\N	\N	X MultiMedia System in 64x64 box	\N	\N	\N
workman	f	Workman	/usr/bin/workman	/var/lib/menu-xdg/applications/menu-xdg/workman.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
fsview	f	FSView	/usr/bin/fsview	/var/lib/menu-xdg/applications/menu-xdg/fsview.desktop	t	\N	\N	\N	\N	FSView (Graphical Disk Usage / Filesystem Viewer)	\N	\N	\N
gnome-system-monitor	f	System Monitor	gnome-system-monitor	/usr/share/applications/gnome-system-monitor.desktop	t	\N	\N	\N	\N	View current processes and monitor system state	\N	\N	\N
gdmphotosetup	f	GDM Photo Setup	gdmphotosetup	/var/lib/menu-xdg/applications/menu-xdg/gdm_photo_setup.desktop	t	\N	\N	\N	\N	Select a photo for GDM	\N	\N	\N
gdmflexiserver	f	New Login	gdmflexiserver --xnest	/usr/share/applications/gdmflexiserver-xnest.desktop	t	New Login	\N	\N	\N	Log in as another user without logging out	\N	\N	\N
gnome-system-log	f	System Log	gnome-system-log	/usr/share/applications/gnome-system-log.desktop	t	\N	\N	\N	\N	View the system log file	\N	\N	\N
gfloppy	f	Floppy Formatter	gfloppy	/usr/share/applications/gfloppy.desktop	t	\N	\N	\N	\N	Format Floppy Disks	\N	\N	\N
bug-buddy	f	Bug Report Tool	bug-buddy	/usr/share/applications/bug-buddy.desktop	t	\N	\N	\N	\N	Report a bug in GNOME-based applications	\N	\N	\N
gps	f	Gps	/usr/bin/gps	/var/lib/menu-xdg/applications/menu-xdg/gps.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
gxset	f	GTK xset	/usr/bin/gxset	/var/lib/menu-xdg/applications/menu-xdg/gtk_xset.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
gtkrecover	f	gtkrecover	/usr/sbin/gtkrecover	/var/lib/menu-xdg/applications/menu-xdg/gtkrecover.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
openapp	f	GWorkspace.app	openapp GWorkspace	/var/lib/menu-xdg/applications/menu-xdg/gworkspace.app.desktop	t	\N	\N	\N	\N	GNUstep Workspace Manager	\N	\N	\N
gxproc	f	GXproc	/usr/bin/gxproc	/var/lib/menu-xdg/applications/menu-xdg/gxproc.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
kdcop	f	KDCOP	/usr/bin/kdcop	/var/lib/menu-xdg/applications/menu-xdg/kdcop.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
ksysguard	f	KDE System Guard	ksysguard %U	/usr/share/applications/kde/ksysguard.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
secpolicy	f	KDE PAM Security Policy Editor	/usr/bin/secpolicy	/var/lib/menu-xdg/applications/menu-xdg/kde_pam_security_policy	t	\N	\N	\N	\N	\N	\N	\N	\N
kpm	f	KDE System Guard - Process Table	/usr/bin/kpm	/var/lib/menu-xdg/applications/menu-xdg/kde_system_guard_-_proc	t	\N	\N	\N	\N	\N	\N	\N	\N
kdepasswd	f	Change Password	kdepasswd	/usr/share/applications/kde/kdepasswd.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
kdebugdialog	f	KDebugDialog	/usr/bin/kdebugdialog	/var/lib/menu-xdg/applications/menu-xdg/kdebugdialog.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
kdf	f	KDiskFree	kdf -caption "%c"	/usr/share/applications/kde/kdf.desktop	t	View Disk Usage	\N	\N	\N	\N	\N	\N	\N
kfloppy	f	KFloppy	kfloppy -caption "%c" %i %m	/usr/share/applications/kde/KFloppy.desktop	t	Floppy Formatter	\N	\N	\N	\N	\N	\N	\N
kfind	f	Find Files	kfind %f	/usr/share/applications/kde/Kfind.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
keditbookmarks	f	KEditBookmarks	/usr/bin/keditbookmarks	/var/lib/menu-xdg/applications/menu-xdg/keditbookmarks.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
kcron	f	KCron	kcron %i %m -caption "%c"	/usr/share/applications/kde/kcron.desktop	t	Task Scheduler	\N	\N	\N	\N	\N	\N	\N
ksysv	f	SysV-Init Editor	ksysv -caption "%c" %i %m	/usr/share/applications/kde/ksysv.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
kicker	f	Kicker	/usr/bin/kicker	/var/lib/menu-xdg/applications/menu-xdg/kicker.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
kdesu	\N	Synaptic Package Manager	kdesu kxconfig	/usr/share/applnk/Settings/Peripherals/kxconfig.desktop	t	\N	\N	\N	\N	Synaptic Package Manager	\N	\N	\N
kprinter	f	KPrinter	/usr/bin/kprinter	/var/lib/menu-xdg/applications/menu-xdg/kprinter.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
konqueror	\N	File Manager - Super User Mode	konqueror --profile filemanagement	/usr/share/applications/kde/konquerorsu.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
loadmeter	f	Loadmeter	/usr/bin/loadmeter	/var/lib/menu-xdg/applications/menu-xdg/loadmeter.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
moodss	f	moodss	/usr/bin/moodss	/var/lib/menu-xdg/applications/menu-xdg/moodss.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
kwikdisk	f	KwikDisk	kwikdisk -caption "%c"	/usr/share/applications/kde/kwikdisk.desktop	t	Removable Media Utility	\N	\N	\N	\N	\N	\N	\N
mount.app	f	mountapp	/usr/bin/mount.app	/var/lib/menu-xdg/applications/menu-xdg/mountapp.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
kpersonalizer	f	Desktop Settings Wizard	kpersonalizer -caption "%c" %i %m	/usr/share/applications/kde/kpersonalizer.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
netwatch	t	netwatch	/usr/sbin/netwatch	/var/lib/menu-xdg/applications/menu-xdg/netwatch.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
netload	t	Network load on ppp0	/usr/bin/netload ppp0	/var/lib/menu-xdg/applications/menu-xdg/network_load_on_ppp0.de	t	\N	\N	\N	\N	\N	\N	\N	\N
xvidtune	f	Xvidtune	xvidtune	/var/lib/menu-xdg/applications/menu-xdg/xvidtune.desktop	t	\N	\N	\N	\N	Xvidtune: tool for customizing X server modelines	\N	\N	\N
gpsman	f	GPSMan	/usr/bin/gpsman	/var/lib/menu-xdg/applications/menu-xdg/gpsman.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
tkgate	f	TkGate	/usr/X11R6/bin/tkgate	/var/lib/menu-xdg/applications/menu-xdg/tkgate.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
wordinspect	f	Dict Client	/usr/bin/wordinspect	/var/lib/menu-xdg/applications/menu-xdg/dict_client.desktop	t	\N	\N	\N	\N	GTK-based Dictionary Client	\N	\N	\N
htmldoc	f	HTMLDoc	/usr/bin/htmldoc	/var/lib/menu-xdg/applications/menu-xdg/htmldoc.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
DataManager	f	DataManager	DataManager	/var/lib/menu-xdg/applications/menu-xdg/datamanager.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
dclock	f	dclock	/usr/bin/dclock	/var/lib/menu-xdg/applications/menu-xdg/dclock.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
dfm	f	Desktop File Manager	/usr/bin/dfm	/var/lib/menu-xdg/applications/menu-xdg/desktop_file_manager.de	t	\N	\N	\N	\N	\N	\N	\N	\N
gnucash	f	GnuCash	gnucash	/var/lib/menu-xdg/applications/menu-xdg/gnucash.desktop	t	\N	\N	\N	\N	GnuCash personal finance tracking program	\N	\N	\N
gtktrain	f	gtktrain	/usr/bin/gtktrain	/var/lib/menu-xdg/applications/menu-xdg/gtktrain.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
guitar	f	guitar	/usr/bin/guitar	/var/lib/menu-xdg/applications/menu-xdg/guitar.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
kgpg	f	KGpg	kgpg %U	/usr/share/applications/kde/kgpg.desktop	t	Encryption Tool	\N	\N	\N	A GnuPG frontend	\N	\N	\N
iceconf	f	iceconf	/usr/bin/iceconf	/var/lib/menu-xdg/applications/menu-xdg/iceconf.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
kalarm	f	KAlarm	kalarm -caption "%c" %i	/usr/share/applications/kde/kalarm.desktop	t	Personal Alarm Scheduler	\N	\N	\N	\N	\N	\N	\N
jscalibrator	f	Joystick Calibration	/usr/bin/jscalibrator	/var/lib/menu-xdg/applications/menu-xdg/joystick_calibration.de	t	\N	\N	\N	\N	\N	\N	\N	\N
kaddressbook	f	Address Manager	kaddressbook %u	/usr/share/applications/kde/kaddressbook.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
kandy	f	Kandy	kandy %i %m -caption "%c"	/usr/share/applications/kde/kandy.desktop	t	Mobile Phone Tool	\N	\N	\N	\N	\N	\N	\N
karm	f	KArm	karm  -caption "%c" %i %m	/usr/share/applications/kde/karm.desktop	t	Personal Time Tracker	\N	\N	\N	\N	\N	\N	\N
kivio	\N	Kivio	kivio	/usr/share/applnk/Office/kivio.desktop	t	\N	\N	\N	\N	Kivio (Flowchart and Diagram Editing)	\N	\N	\N
khexedit	f	KHexEdit	khexedit -caption "%c" %i %m %f	/usr/share/applications/kde/khexedit.desktop	t	Binary Editor	\N	\N	\N	\N	\N	\N	\N
koshell	\N	KOffice Workspace	koshell	/usr/share/applnk/Office/koshell.desktop	t	\N	\N	\N	\N	KOffice Workspace (Office Suite)	\N	\N	\N
kjots	f	KJots	kjots  -caption "%c" %i %m	/usr/share/applications/kde/Kjots.desktop	t	Note Taker	\N	\N	\N	\N	\N	\N	\N
kmdr-editor	\N	Kommander Editor	kmdr-editor %F	/usr/share/applnk/Development/kmdr-editor.desktop	t	\N	\N	\N	\N	Kommander Editor (Dynamic Dialog Editor)	\N	\N	\N
kpalmdoc	f	KPalmDOC	kpalmdoc	/usr/share/applications/kde/kpalmdoc.desktop	t	PalmDOC Converter	\N	\N	\N	\N	\N	\N	\N
kpilot	f	KPilot	kpilot	/usr/share/applications/kde/kpilot.desktop	t	PalmPilot Tool	\N	\N	\N	\N	\N	\N	\N
korganizer	f	KOrganizer	korganizer	/usr/share/applications/kde/korganizer.desktop	t	Personal Organizer	\N	\N	\N	Calendar and Scheduling Program	\N	\N	\N
knotes	f	KNotes	knotes	/usr/share/applications/kde/knotes.desktop	t	Popup Notes	\N	\N	\N	\N	\N	\N	\N
kpresenter	\N	KPresenter	kpresenter	/usr/share/applnk/Office/kpresenter.desktop	t	\N	\N	\N	\N	KPresenter (Slide Presentations)	\N	\N	\N
ktnef	f	TNEF File Viewer	ktnef %i %m -caption "%c"	/usr/share/applications/kde/ktnef.desktop	t	\N	\N	\N	\N	A viewer/extractor for TNEF files	\N	\N	\N
kudesigner	f	Kugar Designer	kudesigner	/usr/share/applnk/Office/kudesigner.desktop	t	\N	\N	\N	\N	Kugar Designer (Report Template Designer)	\N	\N	\N
ktip	f	Kandalf's Tips	ktip	/usr/share/applications/kde/ktip.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
nonlock	f	nonlock	nonlock	/var/lib/menu-xdg/applications/menu-xdg/nonlock.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
oclock	f	Oclock	oclock	/var/lib/menu-xdg/applications/menu-xdg/oclock.desktop	t	\N	\N	\N	\N	Oclock: analog clock for X	\N	\N	\N
ODBCConfig	f	ODBCConfig	ODBCConfig	/var/lib/menu-xdg/applications/menu-xdg/odbcconfig.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
odbctest	f	odbctest	odbctest	/var/lib/menu-xdg/applications/menu-xdg/odbctest.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
xwd	f	X Window Snapshot	xwd | xwud	/var/lib/menu-xdg/applications/menu-xdg/x_window_snapshot.deskt	t	\N	\N	\N	\N	X Window Snapshot: take snapshot of any X window (xwd|xwud)	\N	\N	\N
xclipboard	f	Xclipboard	xclipboard	/var/lib/menu-xdg/applications/menu-xdg/xclipboard.desktop	t	\N	\N	\N	\N	Xclipboard: clipboard for text cut and paste operations in X	\N	\N	\N
xcutsel	f	Xcutsel	xcutsel	/var/lib/menu-xdg/applications/menu-xdg/xcutsel.desktop	t	\N	\N	\N	\N	Xcutsel: interchange between cut buffer and selection in X	\N	\N	\N
x-terminal-emulator	f	Xev	x-terminal-emulator -T spectemu -e /usr/bin/xspect	/var/lib/menu-xdg/applications/menu-xdg/spectemu.desktop	t	\N	\N	\N	\N	Xev: display X events	\N	\N	\N
xkill	f	Xkill	xkill	/var/lib/menu-xdg/applications/menu-xdg/xkill.desktop	t	Kill a window	\N	\N	\N	Xkill: tool to kill X clients by clicking on their windows	\N	\N	\N
xfe	f	Xfe File Manager	/usr/bin/xfe	/var/lib/menu-xdg/applications/menu-xdg/xfe_file_manager.deskto	t	\N	\N	\N	\N	\N	\N	\N	\N
xclock	f	X Clock	xclock -analog	/var/lib/menu-xdg/applications/menu-xdg/xclock_(analog).desktop	t	Clock	\N	\N	\N	\N	\N	\N	\N
xfontsel	f	Xfontsel	xfontsel	/var/lib/menu-xdg/applications/menu-xdg/xfontsel.desktop	t	\N	\N	\N	\N	Xfontsel: font viewer/selector for X	\N	\N	\N
/usr/bin/X11/xkbsel-aw	f	xkbsel	/usr/bin/X11/xkbsel-aw	/var/lib/menu-xdg/applications/menu-xdg/xkbsel.desktop	t	\N	\N	\N	\N	XKB keyboard selector.	\N	\N	\N
kview	f	KView	kview -caption "%c" %i %m %U	/usr/share/applications/kde/kview.desktop	t	Image Viewer	\N	\N	\N	\N	\N	\N	\N
gmplayer	f	MPlayer	gmplayer	/usr/share/applications/mplayer.desktop	t	\N	\N	\N	\N	Video player	\N	\N	\N
wordview	f	Wordview	/usr/X11R6/bin/wordview	/var/lib/menu-xdg/applications/menu-xdg/wordview.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
xbmbrowser	f	xbmbrowser	/usr/bin/xbmbrowser	/var/lib/menu-xdg/applications/menu-xdg/xbmbrowser.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
xditview	f	Xditview	xditview	/var/lib/menu-xdg/applications/menu-xdg/xditview.desktop	t	\N	\N	\N	\N	Xditview: a ditroff file viewer for X	\N	\N	\N
xfileview	f	Xfv File Viewer	/usr/bin/xfileview	/var/lib/menu-xdg/applications/menu-xdg/xfv_file_viewer.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
kasteroids	f	KAsteroids	/usr/games/kasteroids %i %m -caption "%c"	/usr/share/applications/kde/kasteroids.desktop	t	Arcade Game	\N	\N	\N	\N	\N	\N	\N
xine	f	xine media player	xine	/usr/share/applnk/Multimedia/xine.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
kbounce	\N	KBounce	/usr/games/kbounce %i %m -caption "%c"	/usr/share/applications/kde/kbounce.desktop	t	Arcade Game	\N	\N	\N	\N	\N	\N	\N
xmovie	f	XMovie	/usr/bin/xmovie	/var/lib/menu-xdg/applications/menu-xdg/xmovie.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
kgoldrunner	f	KGoldrunner	/usr/games/kgoldrunner	/usr/share/applications/kde/KGoldrunner.desktop	t	Arcade Game	\N	\N	\N	A game of action and puzzle-solving	\N	\N	\N
kolf	\N	Kolf	/usr/games/kolf %U	/usr/share/applications/kde/kolf.desktop	t	Miniature Golf	\N	\N	\N	\N	\N	\N	\N
ksnake	f	KSnakeRace	/usr/games/ksnake %i %m -caption "%c"	/usr/share/applications/kde/ksnake.desktop	t	Arcade Game	\N	\N	\N	\N	\N	\N	\N
kspaceduel	f	KSpaceDuel	/usr/games/kspaceduel %i %m -caption "%c"	/usr/share/applications/kde/kspaceduel.desktop	t	Arcade Game	\N	\N	\N	\N	\N	\N	\N
ktron	f	KTron	/usr/games/ktron -caption "%c" %i %m	/usr/share/applications/kde/ktron.desktop	t	Arcade Game	\N	\N	\N	\N	\N	\N	\N
xasteroids	f	Xasteroids	/usr/games/xasteroids	/var/lib/menu-xdg/applications/menu-xdg/xasteroids.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
atlantikdesigner	f	Atlantik Designer	atlantikdesigner -caption "%c" %i %m	/usr/share/applications/kde/atlantikdesigner.desktop	t	\N	\N	\N	\N	Game board designer for Atlantik	\N	\N	\N
gnubg	t	GNU backgammon	/usr/bin/gnubg	/var/lib/menu-xdg/applications/menu-xdg/gnu_backgammon.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
atlantik	f	Atlantik	/usr/games/atlantik -caption "%c" %i %m	/usr/share/applications/kde/atlantik.desktop	t	Monopoly®-like Board Games	\N	\N	\N	\N	\N	\N	\N
kbackgammon	f	KBackgammon	/usr/games/kbackgammon %i %m -caption "%c"	/usr/share/applications/kde/kbackgammon.desktop	t	Board Game	\N	\N	\N	\N	\N	\N	\N
kbattleship	f	KBattleship	/usr/games/kbattleship %i %m -caption "%c"	/usr/share/applications/kde/kbattleship.desktop	t	Strategy Game	\N	\N	\N	\N	\N	\N	\N
kenolaba	\N	Kenolaba	/usr/games/kenolaba %i %m -caption "%c"	/usr/share/applications/kde/kenolaba.desktop	t	Board Game	\N	\N	\N	\N	\N	\N	\N
klines	f	Kolor Lines	/usr/games/klines -caption "%c" %i %m	/usr/share/applications/kde/klines.desktop	t	Tactical Game	\N	\N	\N	\N	\N	\N	\N
kmahjongg	f	KMahjongg	/usr/games/kmahjongg %i %m -caption "%c"	/usr/share/applications/kde/kmahjongg.desktop	t	Tile Game	\N	\N	\N	\N	\N	\N	\N
gnome-freecell	f	Gnome FreeCell	/usr/games/gnome-freecell	/var/lib/menu-xdg/applications/menu-xdg/gnome_freecell.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
megami	\N	KDE Blackjack	/usr/games/megami	/usr/share/applnk/Games/Card/megami.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
katomic	\N	KAtomic	/usr/games/katomic %i %m -caption "%c"	/usr/share/applications/kde/katomic.desktop	t	Logic Game	\N	\N	\N	\N	\N	\N	\N
kblackbox	f	KBlackBox	/usr/games/kblackbox %i %m -caption "%c"	/usr/share/applications/kde/kblackbox.desktop	t	Logic Game	\N	\N	\N	\N	\N	\N	\N
khangman	f	KHangMan	khangman -caption "%c" %i %m	/usr/share/applications/kde/khangman.desktop	t	Hangman Game	\N	\N	\N	\N	\N	\N	\N
kmessedwords	f	KMessedWords	kmessedwords -caption "%c" %i %m	/usr/share/applications/kde/kmessedwords.desktop	t	Letter Order Game	\N	\N	\N	\N	\N	\N	\N
klickety	\N	Klickety	/usr/games/klickety -caption "%c" %i %m	/usr/share/applications/kde/klickety.desktop	t	Board Game	\N	\N	\N	\N	\N	\N	\N
kpat	\N	Patience	/usr/games/kpat %i %m -caption "%c"	/usr/share/applications/kde/kpat.desktop	t	Patience Card Game	\N	\N	\N	\N	\N	\N	\N
kpoker	f	KPoker	/usr/games/kpoker %i %m -caption "%c"	/usr/share/applications/kde/kpoker.desktop	t	Card Game	\N	\N	\N	\N	\N	\N	\N
amor	f	AMOR	amor	/usr/share/applications/kde/amor.desktop	t	Amusing Misuse of Resources	\N	\N	\N	\N	\N	\N	\N
kmoon	\N	MoonPhase	kmoon	/usr/share/applications/kde/kmoon.desktop	t	Moon Phase Indicator	\N	\N	\N	\N	\N	\N	\N
kodo	f	Mouspedometa	kodo	/usr/share/applications/kde/kodo.desktop	t	Measure Your Desktop Mileage!	\N	\N	\N	\N	\N	\N	\N
kfouleggs	\N	KFoulEggs	/usr/games/kfouleggs -caption "%c" %i %m	/usr/share/applications/kde/kfouleggs.desktop	t	Arcade Game	\N	\N	\N	\N	\N	\N	\N
kjumpingcube	f	KJumpingCube	/usr/games/kjumpingcube -caption "%c" %i %m	/usr/share/applications/kde/kjumpingcube.desktop	t	Tactical Game	\N	\N	\N	\N	\N	\N	\N
kaphorism	\N	K Aphorisms	kaphorism	/usr/share/applnk/Toys/kaphorism.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
kmines	\N	KMines	/usr/games/kmines -caption "%c" %i %m	/usr/share/applications/kde/kmines.desktop	t	Logic Game	\N	\N	\N	\N	\N	\N	\N
konquest	f	Konquest	/usr/games/konquest %i %m -caption %c	/usr/share/applications/kde/konquest.desktop	t	Strategy Game	\N	\N	\N	\N	\N	\N	\N
powershell	f	PowerShell	/usr/bin/powershell	/var/lib/menu-xdg/applications/menu-xdg/powershell.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
xexec	f	xexec	/usr/bin/xexec	/var/lib/menu-xdg/applications/menu-xdg/xexec.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
xterm	f	XTerm	xterm	/var/lib/menu-xdg/applications/menu-xdg/xterm.desktop	t	\N	\N	\N	\N	XTerm: terminal emulator for X	\N	\N	\N
uxterm	f	XTerm (Unicode)	uxterm	/var/lib/menu-xdg/applications/menu-xdg/xterm_(unicode).desktop	t	\N	\N	\N	\N	XTerm: terminal emulator for X with Unicode support	\N	\N	\N
acroread	f	Acrobat Reader	acroread	/home/ziga/.kde/share/applnk/.hidden/acroread.desktop	t	PDF Viewer	\N	\N	\N	\N	\N	\N	\N
perl	t	perl	perl	/home/ziga/.kde/share/applnk/.hidden/perl.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
gvim	f	gvim	gvim	/home/ziga/.kde/share/applnk/.hidden/gvim-2.desktop	f	\N	\N	\N	\N	\N	\N	\N	\N
gv	f	gv	gv	/home/ziga/.kde/share/applnk/.hidden/gv-2.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
sol	\N	Gnome Solitaire Games	sol	\N	t	\N	\N	\N	\N	\N	\N	\N	\N
blender	t	Blender 3D modeller	blender	/usr/share/applications/blender.desktop	t	\N	\N	\N	\N	Create and edit 3D models and animations	\N	\N	\N
scribus	f	Scribus	scribus %f	/usr/share/applications/scribus.desktop	t	\N	\N	\N	\N	Desktop Publishing	Scribus	\N	\N
mozilla	\N	Mozilla	mozilla	\N	\N	World Wide Web	\N	\N	\N	\N	Mozilla	\N	\N
inkscape	f	Inkscape SVG Vector Illustrator	inkscape %U	/usr/share/applications/inkscape.desktop	t	\N	\N	\N	\N	SVG Vector Illustrator	Inkscape	\N	\N
openoffice	\N	openoffice	openoffice	freshmeat.net	\N	\N	\N	\N	\N	\N	OpenOffice.org	\N	\N
staroffice	\N	staroffice	staroffice	freshmeat.net	\N	\N	\N	\N	\N	\N	StarOffice	\N	\N
oocalc	f	OpenOffice.org Calc	/usr/bin/oocalc %U	/usr/share/applications/ooo645calc.desktop	t	\N	\N	\N	\N	OpenOffice.org Spreadsheet	OpenOffice.org	\N	\N
oodraw	f	OpenOffice.org Draw	/usr/bin/oodraw %U	/usr/share/applications/ooo645draw.desktop	t	\N	\N	\N	\N	OpenOffice.org Drawing	OpenOffice.org	\N	\N
ooffice	f	OpenOffice.org From Template	/usr/bin/ooffice slot:5500	/usr/share/applications/ooo645template.desktop	t	\N	\N	\N	\N	\N	OpenOffice.org	\N	\N
oofromtemplate	f	Openoffice.org From Template	/usr/bin/oofromtemplate	/usr/share/applnk/OpenOffice.org1.1/template.desktop	t	\N	\N	\N	\N	\N	OpenOffice.org	\N	\N
ooimpress	f	OpenOffice.org Impress	/usr/bin/ooimpress %U	/usr/share/applications/ooo645impress.desktop	t	\N	\N	\N	\N	\N	OpenOffice.org	\N	\N
oomath	f	OpenOffice.org Math	/usr/bin/oomath %U	/usr/share/applications/ooo645math.desktop	t	\N	\N	\N	\N	OpenOffice.org Formula	OpenOffice.org	\N	\N
ooweb	f	OpenOffice.org Writer/Web	/usr/bin/ooweb %U	/usr/share/applications/ooo645web.desktop	t	\N	\N	\N	\N	OpenOffice.org HTML Document	OpenOffice.org	\N	\N
"/opt/openoffice/program/fromtemplate"	\N	\N	"/opt/openoffice/program/fromtemplate"	\N	f	\N	\N	\N	\N	\N	\N	\N	\N
"/opt/openoffice/program/scalc"	\N	\N	"/opt/openoffice/program/scalc"	\N	f	\N	\N	\N	\N	\N	\N	\N	\N
"/opt/openoffice/program/sdraw"	\N	\N	"/opt/openoffice/program/sdraw"	\N	f	\N	\N	\N	\N	\N	\N	\N	\N
"/opt/openoffice/program/simpress"	\N	\N	"/opt/openoffice/program/simpress"	\N	f	\N	\N	\N	\N	\N	\N	\N	\N
"/opt/openoffice/program/smath"	\N	\N	"/opt/openoffice/program/smath"	\N	f	\N	\N	\N	\N	\N	\N	\N	\N
"/opt/openoffice/program/spadmin"	\N	\N	"/opt/openoffice/program/spadmin"	\N	f	\N	\N	\N	\N	\N	\N	\N	\N
"/opt/openoffice/program/sweb"	\N	\N	"/opt/openoffice/program/sweb"	\N	f	\N	\N	\N	\N	\N	\N	\N	\N
"/opt/openoffice/program/swriter"	\N	\N	"/opt/openoffice/program/swriter"	\N	f	\N	\N	\N	\N	\N	\N	\N	\N
/opt/openoffice/program/setup	\N	\N	/opt/openoffice/program/setup	\N	f	\N	\N	\N	\N	\N	\N	\N	\N
/opt/openoffice/program/spadmin	\N	\N	/opt/openoffice/program/spadmin	\N	f	\N	\N	\N	\N	\N	\N	\N	\N
bluefish	\N	\N	bluefish	\N	t	\N	\N	\N	\N	\N	\N	\N	\N
cheesetracker	\N	\N	cheesetracker	\N	t	\N	\N	\N	\N	\N	\N	\N	\N
cinepaint	\N	\N	cinepaint	\N	t	\N	\N	\N	\N	\N	\N	\N	\N
enigma	\N	\N	enigma	\N	t	\N	\N	\N	\N	\N	\N	\N	\N
eog	\N	\N	eog	\N	t	\N	\N	\N	\N	\N	\N	\N	\N
ethereal	\N	\N	ethereal	\N	t	\N	\N	\N	\N	\N	\N	\N	\N
evolution	\N	\N	evolution	\N	f	\N	\N	\N	\N	\N	\N	\N	\N
evolution-1.5	\N	\N	evolution-1.5	\N	t	\N	\N	\N	\N	\N	\N	\N	\N
filelight	\N	\N	filelight	\N	t	\N	\N	\N	\N	\N	\N	\N	\N
gaim	\N	\N	gaim	\N	t	\N	\N	\N	\N	\N	\N	\N	\N
gataxx	\N	\N	gataxx	\N	t	\N	\N	\N	\N	\N	\N	\N	\N
glines	\N	\N	glines	\N	t	\N	\N	\N	\N	\N	\N	\N	\N
gnect	\N	\N	gnect	\N	t	\N	\N	\N	\N	\N	\N	\N	\N
gnibbles	\N	\N	gnibbles	\N	t	\N	\N	\N	\N	\N	\N	\N	\N
gnobots2	\N	\N	gnobots2	\N	t	\N	\N	\N	\N	\N	\N	\N	\N
gnometris	\N	\N	gnometris	\N	t	\N	\N	\N	\N	\N	\N	\N	\N
gnomine	\N	\N	gnomine	\N	t	\N	\N	\N	\N	\N	\N	\N	\N
gnotravex	\N	\N	gnotravex	\N	t	\N	\N	\N	\N	\N	\N	\N	\N
gnotski	\N	\N	gnotski	\N	t	\N	\N	\N	\N	\N	\N	\N	\N
gpsdrive	\N	\N	gpsdrive	\N	t	\N	\N	\N	\N	\N	\N	\N	\N
gtali	\N	\N	gtali	\N	t	\N	\N	\N	\N	\N	\N	\N	\N
dia	\N	Dia Diagram editor	dia	\N	\N	\N	\N	\N	\N	\N	Dia	\N	\N
tetex	\N	tetex	tetex	freshmeat.net	\N	\N	\N	\N	\N	\N	teTeX	\N	\N
latex	\N	LaTeX	latex	\N	\N	\N	\N	\N	\N	LaTeX typesetter	LaTeX	\N	\N
kile	f	Kile	kile	/usr/share/applications/kde/kile.desktop	t	\N	\N	\N	\N	(La)TeX development environment	Kile	\N	\N
graphviz	\N	graphviz	graphviz	freshmeat.net	\N	\N	\N	\N	\N	\N	graphviz	\N	\N
audacity	t	Audacity	audacity	/home/ziga/.kde/share/applnk/.hidden/audacity-2.desktop	t	\N	\N	\N	\N	Audacity	Audacity	\N	\N
hugin	\N	hugin	hugin	freshmeat.net	\N	\N	\N	\N	\N	hugin is a tool for assembling a mosaic of\nphotographs into a complete immersive panorama by\nstitching any series of overlapping pictures. It\nuses the powerful but difficult to use Panorama\nTools as its backend.\n	hugin	\N	\N
gtkam	\N	\N	gtkam	\N	t	\N	\N	\N	\N	\N	\N	\N	\N
jack-rack	\N	\N	jack-rack	\N	t	\N	\N	\N	\N	\N	\N	\N	\N
k3bsetup	\N	\N	k3bsetup	\N	t	\N	\N	\N	\N	\N	\N	\N	\N
kaffeine	\N	\N	kaffeine	\N	t	\N	\N	\N	\N	\N	\N	\N	\N
kcdlabel	\N	\N	kcdlabel	\N	t	\N	\N	\N	\N	\N	\N	\N	\N
kdiff3	\N	\N	kdiff3	\N	t	\N	\N	\N	\N	\N	\N	\N	\N
keduca	\N	\N	keduca	\N	t	\N	\N	\N	\N	\N	\N	\N	\N
keducabuilder	\N	\N	keducabuilder	\N	t	\N	\N	\N	\N	\N	\N	\N	\N
kover	\N	\N	kover	\N	t	\N	\N	\N	\N	\N	\N	\N	\N
kxsldbg	\N	\N	kxsldbg	\N	t	\N	\N	\N	\N	\N	\N	\N	\N
liferea	\N	\N	liferea	\N	t	\N	\N	\N	\N	\N	\N	\N	\N
Gimp	\N	The GIMP	Gimp	\N	t	Bitmap graphics	\N	\N	\N	Create and edit images or photographs	\N	\N	\N
mahjongg	\N	\N	mahjongg	\N	t	\N	\N	\N	\N	\N	\N	\N	\N
mergeant	\N	\N	mergeant	\N	t	\N	\N	\N	\N	\N	\N	\N	\N
mozilla-1.7.1	\N	\N	mozilla-1.7.1	\N	t	\N	\N	\N	\N	\N	\N	\N	\N
myrtille	\N	\N	myrtille	\N	t	\N	\N	\N	\N	\N	\N	\N	\N
myrtilledv	\N	\N	myrtilledv	\N	t	\N	\N	\N	\N	\N	\N	\N	\N
pppoeconf	\N	\N	pppoeconf	\N	t	\N	\N	\N	\N	\N	\N	\N	\N
pybliographic	\N	\N	pybliographic	\N	t	\N	\N	\N	\N	\N	\N	\N	\N
muse	\N	MusE	muse	\N	t	\N	\N	\N	\N	MusE	\N	\N	\N
rhythmbox	\N	\N	rhythmbox	\N	t	\N	\N	\N	\N	\N	\N	\N	\N
soundtracker	\N	SoundTracker	soundtracker	\N	t	\N	\N	\N	\N	SoundTracker	\N	\N	\N
same-gnome	\N	\N	same-gnome	\N	t	\N	\N	\N	\N	\N	\N	\N	\N
screem	\N	\N	screem	\N	t	\N	\N	\N	\N	\N	\N	\N	\N
soffice	\N	Open Office	soffice	\N	t	\N	\N	\N	\N	Open Office	\N	\N	\N
k3b	\N	K3b	k3b	\N	t	\N	\N	\N	\N	CD writing program	\N	\N	\N
avidemux	\N	avidemux	avidemux	\N	t	\N	\N	\N	\N	\N	\N	\N	\N
xffm	\N	XFfm4	xffm	\N	t	\N	\N	\N	\N	XFce4 file manager	\N	\N	\N
streamtuner	\N	streamtuner	streamtuner	\N	t	Stream Directory Browser	\N	\N	\N	Browse Internet stream directories	streamtuner	\N	\N
akregator	\N	aKregator	akregator	\N	t	Feed Reader	\N	\N	\N	A KDE RSS Aggregator	aKregator	\N	\N
tclsh8.4	t	Tclsh8.4	/usr/bin/tclsh8.4	/var/lib/menu-xdg/applications/menu-xdg/tclsh8.4.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
tkcvs	f	TkCVS	/usr/bin/tkcvs	/var/lib/menu-xdg/applications/menu-xdg/tkcvs.desktop	t	\N	\N	\N	\N	TkCVS - Graphical CVS Frontend	\N	\N	\N
tkdiff	f	Tkdiff	/usr/bin/tkdiff	/var/lib/menu-xdg/applications/menu-xdg/tkdiff.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
wish8.0	t	TkWish8.0	/usr/bin/wish8.0	/var/lib/menu-xdg/applications/menu-xdg/tkwish8.0.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
wish8.2	f	TkWish8.2	/usr/bin/wish8.2	/var/lib/menu-xdg/applications/menu-xdg/tkwish8.2.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
xrced	f	xrced	/usr/bin/xrced	/var/lib/menu-xdg/applications/menu-xdg/xrced.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
Cn3D-3.0	f	Cn3D-3.0	/usr/bin/Cn3D-3.0	/var/lib/menu-xdg/applications/menu-xdg/cn3d-3.0.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
ddv	f	ddv	/usr/bin/ddv	/var/lib/menu-xdg/applications/menu-xdg/ddv.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
Nentrez	f	Entrez	/usr/bin/Nentrez	/var/lib/menu-xdg/applications/menu-xdg/entrez.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
netentcf	f	Entrez net config	/usr/bin/netentcf	/var/lib/menu-xdg/applications/menu-xdg/entrez_net_config.deskt	t	\N	\N	\N	\N	\N	\N	\N	\N
entrez2	f	entrez2	/usr/bin/entrez2	/var/lib/menu-xdg/applications/menu-xdg/entrez2.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
garlic	f	garlic	/usr/bin/garlic	/var/lib/menu-xdg/applications/menu-xdg/garlic.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
gperiodic	f	Gperiodic	gperiodic	/usr/share/applications/gperiodic.desktop	t	\N	\N	\N	\N	A program for looking up data of elements from the periodic table.	\N	\N	\N
kxterm	f	KXterm	kxterm	/var/lib/menu-xdg/applications/menu-xdg/kxterm.desktop	t	\N	\N	\N	\N	The Cernlib KUIP terminal emulator	\N	\N	\N
gcd	f	gcd	/usr/bin/gcd	/var/lib/menu-xdg/applications/menu-xdg/gcd.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
synaesthesia	f	Synaesthesia (line input)	synaesthesia cd	/var/lib/menu-xdg/applications/menu-xdg/synaesthesia_(cd_input)	t	\N	\N	\N	\N	\N	\N	\N	\N
timidity	f	TiMidity++	timidity -ia	/var/lib/menu-xdg/applications/menu-xdg/timidity++.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
tk707	f	TK-707	/usr/bin/tk707	/var/lib/menu-xdg/applications/menu-xdg/tk-707.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
terminatorX	f	terminatorX	/usr/bin/terminatorX	/var/lib/menu-xdg/applications/menu-xdg/terminatorx.desktop	t	\N	\N	\N	\N	terminatorX	\N	\N	\N
tkmixer	f	TkMixer	/usr/bin/tkmixer	/var/lib/menu-xdg/applications/menu-xdg/tkmixer.desktop	t	\N	\N	\N	\N	Tk Audio Mixer	\N	\N	\N
wavesurfer	f	wavesurfer	/usr/bin/wavesurfer	/var/lib/menu-xdg/applications/menu-xdg/wavesurfer.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
vumeter	f	Volume monitor	vumeter -r	/usr/share/applications/reclevel.desktop	t	\N	\N	\N	\N	Monitor the sound output volume	\N	\N	\N
wmmixer	f	WMMixer (Docked)	/usr/bin/wmmixer	/var/lib/menu-xdg/applications/menu-xdg/wmmixer.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
xcthugha	f	X Cthugha	xcthugha	/var/lib/menu-xdg/applications/menu-xdg/x_cthugha.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
xfreecd	f	XfreeCD	/usr/bin/xfreecd	/var/lib/menu-xdg/applications/menu-xdg/xfreecd.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
xmms	f	XMMS	xmms	/var/lib/menu-xdg/applications/menu-xdg/xmms.desktop	t	Multimedia Player	\N	\N	\N	\N	\N	\N	\N
xmcd	f	Xmcd	/usr/bin/xmcd	/var/lib/menu-xdg/applications/menu-xdg/xmcd.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
/usr/bin/X11/xmix	f	xmix	/usr/bin/X11/xmix	/var/lib/menu-xdg/applications/menu-xdg/xmix.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
xmixer	f	Xmixer	xmixer	/var/lib/menu-xdg/applications/menu-xdg/xmixer.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
xplaycd	f	Xplaycd	xplaycd	/var/lib/menu-xdg/applications/menu-xdg/xplaycd.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
xwave	f	XWave	/usr/bin/xwave	/var/lib/menu-xdg/applications/menu-xdg/xwave.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
aptitude	t	aptitude	/usr/bin/aptitude	/var/lib/menu-xdg/applications/menu-xdg/aptitude.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
gvidm	f	Change X11 resolution (gvidm)	/usr/bin/gvidm	/var/lib/menu-xdg/applications/menu-xdg/change_x11_resolution_(	t	\N	\N	\N	\N	\N	\N	\N	\N
gnome-control-center	f	GNOME Control Center	gnome-control-center	/usr/share/applications/gnomecc.desktop	t	\N	\N	\N	\N	The GNOME configuration tool	\N	\N	\N
oopadmin	f	OpenOffice.org Printer Administration	/usr/bin/oopadmin	/usr/share/applications/ooo645printeradmin.desktop	t	\N	\N	\N	\N	\N	OpenOffice.org	\N	\N
su-to-root	\N	Task selector	su-to-root	\N	t	\N	\N	\N	\N	\N	\N	\N	\N
/usr/lib/openoffice/program/setup	f	Openoffice.org Setup	/usr/lib/openoffice/program/setup	/var/lib/menu-xdg/applications/menu-xdg/openoffice.org_setup.de	f	\N	\N	\N	\N	\N	\N	\N	\N
gksuexec	f	Run as different user	gksuexec	/usr/share/applications/gksuexec.desktop	t	\N	\N	\N	\N	Opens a dialog where you can type a command to be run as a given user	\N	\N	\N
reportbug	t	reportbug	/usr/bin/reportbug --exit-prompt	/var/lib/menu-xdg/applications/menu-xdg/reportbug.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
si	t	si	/usr/bin/si	/var/lib/menu-xdg/applications/menu-xdg/si.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
statnet	t	statnet	/usr/sbin/statnet	/var/lib/menu-xdg/applications/menu-xdg/statnet.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
/usr/bin/texconfig	t	TeXconfig	/usr/bin/texconfig	/var/lib/menu-xdg/applications/menu-xdg/texconfig.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
top	t	Top	/usr/bin/top	/var/lib/menu-xdg/applications/menu-xdg/top.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
trafshow	t	trafshow	/usr/sbin/trafshow	/var/lib/menu-xdg/applications/menu-xdg/trafshow.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
wmbubble	f	wmbubble	wmbubble	/var/lib/menu-xdg/applications/menu-xdg/wmbubble.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
wmsensors	f	wmsensors	/usr/X11R6/bin/wmsensors	/var/lib/menu-xdg/applications/menu-xdg/wmsensors.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
wmsmpmon	f	wmsmpmon	/usr/bin/wmsmpmon	/var/lib/menu-xdg/applications/menu-xdg/wmsmpmon.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
wmtop	f	wmtop	/usr/bin/wmtop	/var/lib/menu-xdg/applications/menu-xdg/wmtop.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
gksu	f	Root Terminal	gksu -u root /usr/sbin/synaptic	/usr/share/applications/synaptic.desktop	t	\N	\N	\N	\N	Opens a terminal as the root user, using gksu to ask for the password	\N	\N	\N
xconsole	f	Xconsole	xconsole	/var/lib/menu-xdg/applications/menu-xdg/xconsole.desktop	t	\N	\N	\N	\N	Xconsole: monitor system console messages with X	\N	\N	\N
xfilequery	f	Xfq RPM Manager	/usr/bin/xfilequery	/var/lib/menu-xdg/applications/menu-xdg/xfq_rpm_manager.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
xload	f	Xload	xload	/var/lib/menu-xdg/applications/menu-xdg/xload.desktop	t	\N	\N	\N	\N	Xload: system load average display for X	\N	\N	\N
xlogmaster	f	xlogmaster (system)	/usr/X11R6/bin/xlogmaster -terse	/var/lib/menu-xdg/applications/menu-xdg/xlogmaster.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
xtraceroute	f	xt	/usr/bin/xtraceroute	/var/lib/menu-xdg/applications/menu-xdg/xt.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
ding	f	ding	/usr/bin/ding	/var/lib/menu-xdg/applications/menu-xdg/ding.desktop	t	\N	\N	\N	\N	dictionary lookup program	\N	\N	\N
editres	f	Editres	editres	/var/lib/menu-xdg/applications/menu-xdg/editres.desktop	t	\N	\N	\N	\N	Editres: resource editor for X Toolkit applications	\N	\N	\N
gcombust	f	gcombust	gcombust	/usr/share/applications/gcombust.desktop	t	\N	\N	\N	\N	A frontend for mkisofs/mkhybrid/cdda2wav/cdrecord/cdlabelgen	\N	\N	\N
emelfm	f	emelFM	/usr/X11R6/bin/emelfm	/var/lib/menu-xdg/applications/menu-xdg/emelfm.desktop	t	\N	\N	\N	\N	user-friendly file manager	\N	\N	\N
file-roller	f	Archive Manager	file-roller	/usr/share/applications/file-roller.desktop	t	\N	\N	\N	\N	Create and modify an archive	\N	\N	\N
fookb-wmaker	f	fookb-wmaker	/usr/bin/fookb-wmaker	/var/lib/menu-xdg/applications/menu-xdg/fookb-wmaker.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
gnome-search-tool	f	Search for Files	gnome-search-tool	/usr/share/applications/gnome-search-tool.desktop	t	\N	\N	\N	\N	Search your disk for files	\N	\N	\N
gcrontab	f	gcrontab	/usr/bin/gcrontab	/var/lib/menu-xdg/applications/menu-xdg/gcrontab.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
gnomecard	f	GNOME Address Book	/usr/bin/gnomecard	/var/lib/menu-xdg/applications/menu-xdg/gnome_address_book.desk	t	\N	\N	\N	\N	\N	\N	\N	\N
gnomecal	f	GNOME Calendar	/usr/bin/gnomecal	/var/lib/menu-xdg/applications/menu-xdg/gnome_calendar.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
gcm	f	GNOME Clipboard Manager	/usr/bin/gcm	/var/lib/menu-xdg/applications/menu-xdg/gnome_clipboard_manager	t	\N	\N	\N	\N	\N	\N	\N	\N
gODBCConfig	f	gODBCConfig	gODBCConfig	/var/lib/menu-xdg/applications/menu-xdg/godbcconfig.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
gramps	f	gramps	/usr/bin/gramps	/var/lib/menu-xdg/applications/menu-xdg/gramps.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
kcharselect	f	KCharSelect	kcharselect -caption "%c" %i %m	/usr/share/applications/kde/KCharSelect.desktop	t	Character Selector	\N	\N	\N	\N	\N	\N	\N
ksync	f	KSync	/usr/bin/ksync	/var/lib/menu-xdg/applications/menu-xdg/ksync.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
kthesaurus	\N	KThesaurus	kthesaurus	/usr/share/applnk/Office/KThesaurus.desktop	t	\N	\N	\N	\N	KThesaurus (Related Words)	\N	\N	\N
mc	t	Midnight Commander	/usr/bin/mc	/var/lib/menu-xdg/applications/menu-xdg/mc.desktop	t	\N	\N	\N	\N	Midnight Commander	\N	\N	\N
kregexpeditor	f	KRegExpEditor	kregexpeditor	/usr/share/applications/kde/kregexpeditor.desktop	t	Regular Expression Editor	\N	\N	\N	\N	\N	\N	\N
ktimer	f	KTimer	ktimer	/usr/share/applications/kde/ktimer.desktop	t	Task Scheduler	\N	\N	\N	\N	\N	\N	\N
kugar	f	Kugar	kugar	/usr/share/applnk/Office/kugar.desktop	t	\N	\N	\N	\N	Kugar (Report Generator)	\N	\N	\N
/usr/bin/X11/regexplorer	f	RegExplorer	/usr/bin/X11/regexplorer	/var/lib/menu-xdg/applications/menu-xdg/regexplorer.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
texfind	f	TeXfind	/usr/bin/texfind	/var/lib/menu-xdg/applications/menu-xdg/texfind.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
qps	f	QPS	/usr/bin/qps	/var/lib/menu-xdg/applications/menu-xdg/qps.desktop	t	Process manager	\N	\N	\N	\N	\N	\N	\N
dotfile	f	The Dotfile Generator	/usr/bin/dotfile	/var/lib/menu-xdg/applications/menu-xdg/the_dotfile_generator.d	t	\N	\N	\N	\N	\N	\N	\N	\N
unclutter	f	unclutter - start	unclutter	/var/lib/menu-xdg/applications/menu-xdg/unclutter_-_start.deskt	t	\N	\N	\N	\N	\N	\N	\N	\N
killall	f	unclutter - stop	killall -TERM unclutter	/var/lib/menu-xdg/applications/menu-xdg/unclutter_-_stop.deskto	t	\N	\N	\N	\N	\N	\N	\N	\N
wmcalc	f	wmcalc	/usr/bin/wmcalc	/var/lib/menu-xdg/applications/menu-xdg/wmcalc.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
wmCalClock	f	wmcalclock	/usr/bin/wmCalClock	/var/lib/menu-xdg/applications/menu-xdg/wmcalclock.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
wmGrabImage	f	wmGrabImage	wmGrabImage	/var/lib/menu-xdg/applications/menu-xdg/wmgrabimage.desktop	t	\N	\N	\N	\N	wmGrabImage	\N	\N	\N
wmMoonClock	f	wmMoonClock	/usr/bin/wmMoonClock	/var/lib/menu-xdg/applications/menu-xdg/wmmoonclock.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
wmpinboard	f	wmPinboard	/usr/bin/wmpinboard	/var/lib/menu-xdg/applications/menu-xdg/wmpinboard.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
worker	f	Worker	/usr/bin/worker	/var/lib/menu-xdg/applications/menu-xdg/worker.desktop	t	\N	\N	\N	\N	File manager for X	\N	\N	\N
xcalendar	f	xcalendar-i18n	/usr/X11R6/bin/xcalendar	/var/lib/menu-xdg/applications/menu-xdg/xcalendar-i18n.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
gliv	\N	gliv	gliv	\N	t	\N	\N	\N	\N	\N	\N	\N	\N
xmag	f	Xmag	xmag	/var/lib/menu-xdg/applications/menu-xdg/xmag.desktop	t	\N	\N	\N	\N	Xmag: magnify parts of the X screen	\N	\N	\N
/usr/bin/X11/gv	f	GV	/usr/bin/X11/gv	/var/lib/menu-xdg/applications/menu-xdg/gv.desktop	t	PostScript Viewer	\N	\N	\N	\N	\N	\N	\N
xrefresh	f	Xrefresh	xrefresh	/var/lib/menu-xdg/applications/menu-xdg/xrefresh.desktop	t	\N	\N	\N	\N	Xrefresh: redraw X screen	\N	\N	\N
zclock	f	ZClock	/usr/bin/zclock	/var/lib/menu-xdg/applications/menu-xdg/zclock.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
effectv	f	EffectTV	/usr/bin/effectv	/var/lib/menu-xdg/applications/menu-xdg/effectv.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
gfontview	f	gfontview	gfontview	/var/lib/menu-xdg/applications/menu-xdg/gfontview.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
alevt	f	AleVT	/usr/bin/alevt	/var/lib/menu-xdg/applications/menu-xdg/alevt.desktop	t	\N	\N	\N	\N	AleVT, X11 Teletext/Videotext browser	\N	\N	\N
endeavour2	f	Endeavour2 Viewer	/usr/bin/endeavour2	/var/lib/menu-xdg/applications/menu-xdg/endeavour2_viewer.deskt	t	\N	\N	\N	\N	\N	\N	\N	\N
gnome-gv	f	GNOME Ghostscript/PDF Viewer	/usr/bin/gnome-gv	/var/lib/menu-xdg/applications/menu-xdg/gnome_ghostscript_pdf_v	t	\N	\N	\N	\N	A GNOME Ghostscript frontend to visualize PostScript files	\N	\N	\N
gqview	f	GQview	/usr/bin/gqview	/var/lib/menu-xdg/applications/menu-xdg/gqview.desktop	t	\N	\N	\N	\N	The GQview image viewer	\N	\N	\N
gtv	f	gtv MPEG player	/usr/bin/gtv	/var/lib/menu-xdg/applications/menu-xdg/gtv_mpeg_player.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
display	f	ImageMagick	/usr/bin/display	/var/lib/menu-xdg/applications/menu-xdg/imagemagick.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
xawtv	f	XawTV	/usr/bin/xawtv	/var/lib/menu-xdg/applications/menu-xdg/xawtv.desktop	t	Watch TV!	\N	\N	\N	\N	\N	\N	\N
kdvi	f	kdvi	/usr/bin/kdvi	/var/lib/menu-xdg/applications/menu-xdg/kdvi.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
realplayer	f	realplayer	realplayer	/usr/share/applications/realplayer.desktop	t	\N	\N	\N	\N	Video player	\N	\N	\N
kghostview	f	KGhostView	kghostview %u -caption "%c" %i %m	/usr/share/applications/kde/kghostview.desktop	t	PS/PDF Viewer	\N	\N	\N	\N	\N	\N	\N
paul	f	Paul	/usr/bin/paul	/var/lib/menu-xdg/applications/menu-xdg/paul.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
pornview	f	PornView	/usr/bin/pornview	/var/lib/menu-xdg/applications/menu-xdg/pornview.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
xdvi	f	XDvi	/usr/bin/xdvi	/var/lib/menu-xdg/applications/menu-xdg/xdvi.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
foobillard	f	Foobillard	/usr/games/foobillard	/var/lib/menu-xdg/applications/menu-xdg/foobillard.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
xeyes	f	X Eyes	xeyes	/var/lib/menu-xdg/applications/menu-xdg/xeyes.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
lightspeed	f	Light Speed	/usr/bin/lightspeed	/var/lib/menu-xdg/applications/menu-xdg/light_speed.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
kteatime	f	Tea Cooker	kteatime	/usr/share/applications/kde/kteatime.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
penguineyes	f	Penguineyes	/usr/games/penguineyes	/var/lib/menu-xdg/applications/menu-xdg/penguineyes.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
kworldclock	\N	World Clock	kworldclock	/usr/share/applications/kde/kworldclock.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
tdfsb	f	tdfsb	/usr/games/tdfsb	/var/lib/menu-xdg/applications/menu-xdg/tdfsb.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
wmtictactoe	f	wmtictactoe	/usr/games/wmtictactoe -q	/var/lib/menu-xdg/applications/menu-xdg/wmtictactoe.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
khelpcenter	f	Help	khelpcenter	/usr/share/applications/kde/Help.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
xcruiser	f	xcruiser	/usr/games/xcruiser	/var/lib/menu-xdg/applications/menu-xdg/xcruiser.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
xlogo	f	Xlogo	xlogo	/var/lib/menu-xdg/applications/menu-xdg/xlogo.desktop	t	\N	\N	\N	\N	Xlogo: demo which displays the X logo	\N	\N	\N
dwww	f	Dwww	/usr/bin/dwww	/var/lib/menu-xdg/applications/menu-xdg/dwww.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
info	t	Info	info	/var/lib/menu-xdg/applications/menu-xdg/info.desktop	t	\N	\N	\N	\N	GNU Info browser	\N	\N	\N
hman	f	Man2html	hman -P sensible-browser	/var/lib/menu-xdg/applications/menu-xdg/man2html.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
texdoctk	f	Texdoctk	/usr/bin/texdoctk	/var/lib/menu-xdg/applications/menu-xdg/texdoctk.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
yelp	f	Help	yelp	/usr/share/applications/yelp.desktop	t	\N	\N	\N	\N	Get help with GNOME	\N	\N	\N
texshow	f	TeXshow	/usr/bin/texshow	/var/lib/menu-xdg/applications/menu-xdg/texshow.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
xman	f	Xman	xman	/var/lib/menu-xdg/applications/menu-xdg/xman.desktop	t	\N	\N	\N	\N	Xman: manual page browser for X	\N	\N	\N
ktux	f	KTux	ktux %i %m -caption "%c"	/usr/share/applnk/System/ScreenSavers/ktux.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
xplanet	f	xplanet	/usr/bin/xplanet	/var/lib/menu-xdg/applications/menu-xdg/xplanet.desktop	t	\N	\N	\N	\N	xplanet: render an image of a planet in the root window	\N	\N	\N
xsetroot	f	Xsetroot	xsetroot	/var/lib/menu-xdg/applications/menu-xdg/xsetroot.desktop	t	\N	\N	\N	\N	Xsetroot: set root window to default pattern	\N	\N	\N
beforelight	f	Beforelight	beforelight	/var/lib/menu-xdg/applications/menu-xdg/beforelight.desktop	t	\N	\N	\N	\N	Beforelight: simple screen saver	\N	\N	\N
gnome-terminal	\N	Terminal	gnome-terminal	/usr/share/applications/gnome-terminal.desktop	t	\N	\N	\N	\N	Command line	\N	\N	\N
xscreensaver	f	Enable XScreenSaver	/usr/bin/xscreensaver	/var/lib/menu-xdg/applications/menu-xdg/enable_xscreensaver.des	t	\N	\N	\N	\N	\N	\N	\N	\N
xscreensaver-command	f	ScreenSaver Preferences	/usr/bin/xscreensaver-command -lock	/var/lib/menu-xdg/applications/menu-xdg/lock_screen_(xscreensav	t	\N	\N	\N	\N	\N	\N	\N	\N
konsole	f	Terminal Program - Super User Mode	konsole	/usr/share/applications/kde/konsole.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
aafire	t	AA Fire	aafire -driver slang	/var/lib/menu-xdg/applications/menu-xdg/aa_fire.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
Eterm	f	Eterm	/usr/bin/Eterm	/var/lib/menu-xdg/applications/menu-xdg/eterm.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
multi-gnome-terminal	f	Multi GNOME Terminal	/usr/bin/multi-gnome-terminal	/var/lib/menu-xdg/applications/menu-xdg/multi_gnome_terminal.de	t	\N	\N	\N	\N	\N	\N	\N	\N
oneliner	f	OneLiner	/usr/X11R6/bin/oneliner	/var/lib/menu-xdg/applications/menu-xdg/oneliner.desktop	t	\N	\N	\N	\N	\N	\N	\N	\N
texmacs	f	GNU TeXmacs	/usr/bin/texmacs %f	/usr/share/applnk/Editors/texmacs.desktop	t	Scientific word processor	\N	\N	\N	GNU TeXmacs	GNU TeXmacs	\N	\N
\.


--
-- Data for TOC entry 572 (OID 2061960)
-- Name: app_mime; Type: TABLE DATA; Schema: public; Owner: postgres
--

COPY app_mime (app, mime, registry, glob, "action", flags) FROM stdin;
btdownloadgui	application/x-bittorrent	\N	\N	open	\N
kwrite	text/x-diff	/usr/share/slix/apps/Aplikacije/Besedilo/kwrite.desktop	\N	open	\N
kwrite	text/rdf	/usr/share/slix/apps/Aplikacije/Besedilo/kwrite.desktop	\N	open	\N
lyx	application/x-lyx	/usr/share/slix/apps/Aplikacije/Besedilo/lyx.desktop	\N	open	\N
nedit	text/plain	/usr/share/slix/apps/Aplikacije/Besedilo/nedit.desktop	\N	open	\N
nedit	text/x-makefile	/usr/share/slix/apps/Aplikacije/Besedilo/nedit.desktop	\N	open	\N
nedit	text/x-c++hdr	/usr/share/slix/apps/Aplikacije/Besedilo/nedit.desktop	\N	open	\N
nedit	text/x-c++src	/usr/share/slix/apps/Aplikacije/Besedilo/nedit.desktop	\N	open	\N
nedit	text/x-chdr	/usr/share/slix/apps/Aplikacije/Besedilo/nedit.desktop	\N	open	\N
nedit	text/x-csrc	/usr/share/slix/apps/Aplikacije/Besedilo/nedit.desktop	\N	open	\N
nedit	text/x-java	/usr/share/slix/apps/Aplikacije/Besedilo/nedit.desktop	\N	open	\N
nedit	text/x-moc	/usr/share/slix/apps/Aplikacije/Besedilo/nedit.desktop	\N	open	\N
nedit	text/x-pascal	/usr/share/slix/apps/Aplikacije/Besedilo/nedit.desktop	\N	open	\N
nedit	text/x-tcl	/usr/share/slix/apps/Aplikacije/Besedilo/nedit.desktop	\N	open	\N
nedit	text/x-tex	/usr/share/slix/apps/Aplikacije/Besedilo/nedit.desktop	\N	open	\N
nedit	application/x-shellscript	/usr/share/slix/apps/Aplikacije/Besedilo/nedit.desktop	\N	open	\N
dia-normal	application/x-dia	/usr/share/slix/apps/Aplikacije/Grafika/Dia.desktop	\N	open	\N
Gimp	application/illustrator	/usr/share/slix/apps/Aplikacije/Grafika/Gimp.desktop	\N	open	\N
Gimp	application/postscript	/usr/share/slix/apps/Aplikacije/Grafika/Gimp.desktop	\N	open	\N
Gimp	image/cgm	/usr/share/slix/apps/Aplikacije/Grafika/Gimp.desktop	\N	open	\N
Gimp	image/fax-g3	/usr/share/slix/apps/Aplikacije/Grafika/Gimp.desktop	\N	open	\N
Gimp	image/jpeg	/usr/share/slix/apps/Aplikacije/Grafika/Gimp.desktop	\N	open	\N
Gimp	image/x-cmu-raster	/usr/share/slix/apps/Aplikacije/Grafika/Gimp.desktop	\N	open	\N
Gimp	image/x-ico	/usr/share/slix/apps/Aplikacije/Grafika/Gimp.desktop	\N	open	\N
Gimp	image/x-iff	/usr/share/slix/apps/Aplikacije/Grafika/Gimp.desktop	\N	open	\N
Gimp	image/x-ilbm	/usr/share/slix/apps/Aplikacije/Grafika/Gimp.desktop	\N	open	\N
Gimp	image/x-jng	/usr/share/slix/apps/Aplikacije/Grafika/Gimp.desktop	\N	open	\N
ark	application/x-gzip	/usr/share/applications/kde/ark.desktop	\N	open	\N
ark	application/x-lha	/usr/share/applications/kde/ark.desktop	\N	open	\N
ark	application/x-tar	/usr/share/applications/kde/ark.desktop	\N	open	\N
ark	application/x-tgz	/usr/share/applications/kde/ark.desktop	\N	open	\N
ark	application/x-tbz	/usr/share/applications/kde/ark.desktop	\N	open	\N
ark	application/x-zip	/usr/share/applications/kde/ark.desktop	\N	open	\N
ark	application/x-bzip	/usr/share/applications/kde/ark.desktop	\N	open	\N
ark	application/x-tzo	/usr/share/applications/kde/ark.desktop	\N	open	\N
ark	application/x-lzop	/usr/share/applications/kde/ark.desktop	\N	open	\N
ark	application/x-rar	/usr/share/applications/kde/ark.desktop	\N	open	\N
ark	application/x-zoo	/usr/share/applications/kde/ark.desktop	\N	open	\N
ark	application/x-tarz	/usr/share/applications/kde/ark.desktop	\N	open	\N
ark	application/x-archive	/usr/share/applications/kde/ark.desktop	\N	open	\N
ark	application/x-bzip2	/usr/share/applications/kde/ark.desktop	\N	open	\N
ark	application/x-jar	/usr/share/applications/kde/ark.desktop	\N	open	\N
ark	application/x-deb	/usr/share/applications/kde/ark.desktop	\N	open	\N
kfmclient	inode/directory	/usr/share/applications/kde/kfmclient_dir.desktop	\N	open	\N
kfmclient	text/html	/usr/share/applications/kde/kfmclient_html.desktop	\N	open	\N
kfmclient	application/xhtml+xml	/usr/share/applications/kde/kfmclient_html.desktop	\N	open	\N
kfmclient	application/x-webarchive	/usr/share/applications/kde/kfmclient_war.desktop	\N	open	\N
ksysguard	application/x-ksysguard	/usr/share/applications/kde/ksysguard.desktop	\N	open	\N
kate	text/plain	/usr/share/applications/kde/kate.desktop	\N	open	\N
kwrite	text/plain	/usr/share/applications/kde/kwrite.desktop	\N	open	\N
kedit	text/plain	/usr/share/applications/kde/KEdit.desktop	\N	open	\N
kgpg	application/pgp-encrypted	/usr/share/applications/kde/kgpg.desktop	\N	open	\N
kgpg	application/pgp-signature	/usr/share/applications/kde/kgpg.desktop	\N	open	\N
kgpg	application/pgp-keys	/usr/share/applications/kde/kgpg.desktop	\N	open	\N
kwalletmanager	application/x-kde-wallet	/usr/share/applications/kde/kwalletmanager.desktop	\N	open	\N
artsbuilder	application/x-artsbuilder	/usr/share/applications/kde/artsbuilder.desktop	\N	open	\N
kaboodle	audio/x-mp3	/usr/share/applications/kde/kaboodle.desktop	\N	open	\N
kaboodle	application/ogg	/usr/share/applications/kde/kaboodle.desktop	\N	open	\N
kaboodle	audio/x-mp2	/usr/share/applications/kde/kaboodle.desktop	\N	open	\N
kaboodle	video/mpeg	/usr/share/applications/kde/kaboodle.desktop	\N	open	\N
kaboodle	audio/x-wav	/usr/share/applications/kde/kaboodle.desktop	\N	open	\N
kaboodle	audio/x-mod	/usr/share/applications/kde/kaboodle.desktop	\N	open	\N
kaboodle	video/x-msvideo	/usr/share/applications/kde/kaboodle.desktop	\N	open	\N
kaboodle	video/quicktime	/usr/share/applications/kde/kaboodle.desktop	\N	open	\N
kaboodle	video/x-flic	/usr/share/applications/kde/kaboodle.desktop	\N	open	\N
kaboodle	audio/basic	/usr/share/applications/kde/kaboodle.desktop	\N	open	\N
kaboodle	video/x-ms-asf	/usr/share/applications/kde/kaboodle.desktop	\N	open	\N
kmid	audio/x-karaoke	/usr/share/applications/kde/kmid.desktop	\N	open	\N
kmid	audio/x-midi	/usr/share/applications/kde/kmid.desktop	\N	open	\N
noatun	audio/x-mp3	/usr/share/applications/kde/noatun.desktop	\N	open	\N
noatun	audio/x-mp2	/usr/share/applications/kde/noatun.desktop	\N	open	\N
noatun	audio/vorbis	/usr/share/applications/kde/noatun.desktop	\N	open	\N
noatun	video/mpeg	/usr/share/applications/kde/noatun.desktop	\N	open	\N
noatun	audio/x-mpegurl	/usr/share/applications/kde/noatun.desktop	\N	open	\N
noatun	audio/x-wav	/usr/share/applications/kde/noatun.desktop	\N	open	\N
noatun	audio/x-mod	/usr/share/applications/kde/noatun.desktop	\N	open	\N
noatun	video/x-msvideo	/usr/share/applications/kde/noatun.desktop	\N	open	\N
noatun	video/quicktime	/usr/share/applications/kde/noatun.desktop	\N	open	\N
noatun	video/mp4	/usr/share/applications/kde/noatun.desktop	\N	open	\N
noatun	video/x-flic	/usr/share/applications/kde/noatun.desktop	\N	open	\N
noatun	video/x-theora	/usr/share/applications/kde/noatun.desktop	\N	open	\N
noatun	video/x-ogm	/usr/share/applications/kde/noatun.desktop	\N	open	\N
noatun	audio/basic	/usr/share/applications/kde/noatun.desktop	\N	open	\N
noatun	audio/mp4	/usr/share/applications/kde/noatun.desktop	\N	open	\N
noatun	audio/ac3	/usr/share/applications/kde/noatun.desktop	\N	open	\N
noatun	audio/aac	/usr/share/applications/kde/noatun.desktop	\N	open	\N
noatun	audio/x-flac	/usr/share/applications/kde/noatun.desktop	\N	open	\N
noatun	audio/x-speex	/usr/share/applications/kde/noatun.desktop	\N	open	\N
kig	application/x-kig	/usr/share/applications/kde/kig.desktop	\N	open	\N
kig	application/x-kgeo	/usr/share/applications/kde/kig.desktop	\N	open	\N
korganizer	text/calendar	/usr/share/applications/kde/korganizer.desktop	\N	open	\N
korganizer	text/x-vcalendar	/usr/share/applications/kde/korganizer.desktop	\N	open	\N
kaddressbook	text/x-vcard	/usr/share/applications/kde/kaddressbook.desktop	\N	open	\N
kaddressbook	text/x-ldif	/usr/share/applications/kde/kaddressbook.desktop	\N	open	\N
ktnef	application/ms-tnef	/usr/share/applications/kde/ktnef.desktop	\N	open	\N
cervisia	inode/directory	/usr/share/applications/kde/cervisia.desktop	\N	open	\N
konsole	application/x-konsole	/usr/share/applications/kde/konsolesu.desktop	\N	open	\N
kbabel	application/x-gettext	/usr/share/applications/kde/kbabel.desktop	\N	open	\N
kpackage	application/x-rpm	/usr/share/applications/kde/kpackage.desktop	\N	open	\N
kpackage	application/x-debian-package	/usr/share/applications/kde/kpackage.desktop	\N	open	\N
kcmshell	print/manager	/usr/share/applications/kde/printers.desktop	\N	open	\N
kolf	application/x-kourse	/usr/share/applications/kde/kolf.desktop	\N	open	\N
kolf	application/x-kolf	/usr/share/applications/kde/kolf.desktop	\N	open	\N
ktuberling	application/x-tuberling	/usr/share/applications/kde/ktuberling.desktop	\N	open	\N
kviewshell	application/x-dvi	/usr/share/applications/kde/kdvi.desktop	\N	open	\N
kviewshell	application/x-gzdvi	/usr/share/applications/kde/kdvi.desktop	\N	open	\N
kviewshell	application/x-bz2dvi	/usr/share/applications/kde/kdvi.desktop	\N	open	\N
kfax	image/fax-g3	/usr/share/applications/kde/kfax.desktop	\N	open	\N
kghostview	application/pdf	/usr/share/applications/kde/kghostview.desktop	\N	open	\N
kghostview	application/postscript	/usr/share/applications/kde/kghostview.desktop	\N	open	\N
kghostview	image/x-eps	/usr/share/applications/kde/kghostview.desktop	\N	open	\N
kghostview	application/x-gzpostscript	/usr/share/applications/kde/kghostview.desktop	\N	open	\N
kghostview	application/illustrator	/usr/share/applications/kde/kghostview.desktop	\N	open	\N
kiconedit	image/x-xpm	/usr/share/applications/kde/kiconedit.desktop	\N	open	\N
kiconedit	image/x-ico	/usr/share/applications/kde/kiconedit.desktop	\N	open	\N
kiconedit	image/png	/usr/share/applications/kde/kiconedit.desktop	\N	open	\N
kiconedit	image/jpeg	/usr/share/applications/kde/kiconedit.desktop	\N	open	\N
kpdf	application/pdf	/usr/share/applications/kde/kpdf.desktop	\N	open	\N
kpovmodeler	application/x-kpovmodeler	/usr/share/applications/kde/kpovmodeler.desktop	\N	open	\N
kuickshow	image/gif	/usr/share/applications/kde/kuickshow.desktop	\N	open	\N
kuickshow	image/x-xpm	/usr/share/applications/kde/kuickshow.desktop	\N	open	\N
kuickshow	image/x-xbm	/usr/share/applications/kde/kuickshow.desktop	\N	open	\N
kuickshow	image/jpeg	/usr/share/applications/kde/kuickshow.desktop	\N	open	\N
kuickshow	image/png	/usr/share/applications/kde/kuickshow.desktop	\N	open	\N
kuickshow	image/tiff	/usr/share/applications/kde/kuickshow.desktop	\N	open	\N
kuickshow	image/x-bmp	/usr/share/applications/kde/kuickshow.desktop	\N	open	\N
kuickshow	image/x-psd	/usr/share/applications/kde/kuickshow.desktop	\N	open	\N
kuickshow	image/x-portable-bitmap	/usr/share/applications/kde/kuickshow.desktop	\N	open	\N
kuickshow	image/x-portable-pixmap	/usr/share/applications/kde/kuickshow.desktop	\N	open	\N
kuickshow	image/x-portable-greymap	/usr/share/applications/kde/kuickshow.desktop	\N	open	\N
kview	image/gif	/usr/share/applications/kde/kview.desktop	\N	open	\N
kview	image/x-xpm	/usr/share/applications/kde/kview.desktop	\N	open	\N
kview	image/x-xbm	/usr/share/applications/kde/kview.desktop	\N	open	\N
kview	image/jpeg	/usr/share/applications/kde/kview.desktop	\N	open	\N
kview	image/x-bmp	/usr/share/applications/kde/kview.desktop	\N	open	\N
kview	image/png	/usr/share/applications/kde/kview.desktop	\N	open	\N
kview	image/x-ico	/usr/share/applications/kde/kview.desktop	\N	open	\N
kview	image/x-portable-bitmap	/usr/share/applications/kde/kview.desktop	\N	open	\N
kview	image/x-portable-pixmap	/usr/share/applications/kde/kview.desktop	\N	open	\N
kview	image/x-portable-greymap	/usr/share/applications/kde/kview.desktop	\N	open	\N
kview	image/tiff	/usr/share/applications/kde/kview.desktop	\N	open	\N
kview	image/jp2	/usr/share/applications/kde/kview.desktop	\N	open	\N
kompare	text/x-diff	/usr/share/applications/kde/kompare.desktop	\N	open	\N
kuiviewer	application/x-designer	/usr/share/applications/kde/kuiviewer.desktop	\N	open	\N
kcachegrind	application/x-kcachegrind	/usr/share/applications/kde/kcachegrind.desktop	\N	open	\N
kile	text/x-tex	/usr/share/applications/kde/kile.desktop	\N	open	\N
kile	text/x-kilepr	/usr/share/applications/kde/kile.desktop	\N	open	\N
kmdr-executor	application/x-kommander	/usr/share/applnk/Applications/kmdr-executor.desktop	\N	open	\N
kxmleditor	text/xml	/usr/share/applnk/Applications/kxmleditor.desktop	\N	open	\N
kdirstat	inode/directory	/usr/share/applnk/Utilities/kdirstat.desktop	\N	open	\N
kvim	application/mathml+xml	/usr/share/applnk/Editors/KVim.desktop	\N	open	\N
kvim	application/xhtml+xml	/usr/share/applnk/Editors/KVim.desktop	\N	open	\N
kvim	application/x-perl	/usr/share/applnk/Editors/KVim.desktop	\N	open	\N
kvim	application/x-python	/usr/share/applnk/Editors/KVim.desktop	\N	open	\N
kvim	application/x-shellscript	/usr/share/applnk/Editors/KVim.desktop	\N	open	\N
kvim	audio/x-mpegurl	/usr/share/applnk/Editors/KVim.desktop	\N	open	\N
kvim	audio/x-scpls	/usr/share/applnk/Editors/KVim.desktop	\N	open	\N
kvim	image/svg+xml	/usr/share/applnk/Editors/KVim.desktop	\N	open	\N
kvim	message/news	/usr/share/applnk/Editors/KVim.desktop	\N	open	\N
kvim	message/rfc822	/usr/share/applnk/Editors/KVim.desktop	\N	open	\N
kvim	text/calendar	/usr/share/applnk/Editors/KVim.desktop	\N	open	\N
kvim	text/css	/usr/share/applnk/Editors/KVim.desktop	\N	open	\N
kvim	text/html	/usr/share/applnk/Editors/KVim.desktop	\N	open	\N
kvim	text/mrml	/usr/share/applnk/Editors/KVim.desktop	\N	open	\N
kvim	text/plain	/usr/share/applnk/Editors/KVim.desktop	\N	open	\N
kvim	text/rdf	/usr/share/applnk/Editors/KVim.desktop	\N	open	\N
kvim	text/rss	/usr/share/applnk/Editors/KVim.desktop	\N	open	\N
kvim	text/rtf	/usr/share/applnk/Editors/KVim.desktop	\N	open	\N
kvim	text/sgml	/usr/share/applnk/Editors/KVim.desktop	\N	open	\N
kvim	text/vnd.wap.wml	/usr/share/applnk/Editors/KVim.desktop	\N	open	\N
kvim	text/x-adasrc	/usr/share/applnk/Editors/KVim.desktop	\N	open	\N
kvim	text/x-bibtex	/usr/share/applnk/Editors/KVim.desktop	\N	open	\N
kvim	text/x-chdr	/usr/share/applnk/Editors/KVim.desktop	\N	open	\N
kvim	text/x-c++hdr	/usr/share/applnk/Editors/KVim.desktop	\N	open	\N
kvim	text/x-csrc	/usr/share/applnk/Editors/KVim.desktop	\N	open	\N
kvim	text/x-c++src	/usr/share/applnk/Editors/KVim.desktop	\N	open	\N
kvim	text/x-csv	/usr/share/applnk/Editors/KVim.desktop	\N	open	\N
kvim	text/x-diff	/usr/share/applnk/Editors/KVim.desktop	\N	open	\N
kvim	text/x-java	/usr/share/applnk/Editors/KVim.desktop	\N	open	\N
kvim	text/x-katefilelist	/usr/share/applnk/Editors/KVim.desktop	\N	open	\N
kvim	text/x-latex	/usr/share/applnk/Editors/KVim.desktop	\N	open	\N
kvim	text/x-log	/usr/share/applnk/Editors/KVim.desktop	\N	open	\N
kvim	text/x-makefile	/usr/share/applnk/Editors/KVim.desktop	\N	open	\N
kvim	text/xmcd	/usr/share/applnk/Editors/KVim.desktop	\N	open	\N
kvim	text/xml	/usr/share/applnk/Editors/KVim.desktop	\N	open	\N
kvim	text/x-moc	/usr/share/applnk/Editors/KVim.desktop	\N	open	\N
kvim	text/x-mswinurl	/usr/share/applnk/Editors/KVim.desktop	\N	open	\N
kvim	text/x-objcsrc	/usr/share/applnk/Editors/KVim.desktop	\N	open	\N
kvim	text/x-pascal	/usr/share/applnk/Editors/KVim.desktop	\N	open	\N
kvim	text/x-tcl	/usr/share/applnk/Editors/KVim.desktop	\N	open	\N
kvim	text/x-tex	/usr/share/applnk/Editors/KVim.desktop	\N	open	\N
kvim	text/x-vcalendar	/usr/share/applnk/Editors/KVim.desktop	\N	open	\N
kvim	text/x-vcard	/usr/share/applnk/Editors/KVim.desktop	\N	open	\N
kvim	text/x-xslfo	/usr/share/applnk/Editors/KVim.desktop	\N	open	\N
kvim	text/x-xslt	/usr/share/applnk/Editors/KVim.desktop	\N	open	\N
abiword	application/x-executable	/usr/share/applnk/Editors/AbiWord.desktop	\N	open	\N
kmidi	audio/x-midi	/usr/share/applnk/Multimedia/More/kmidi.desktop	\N	open	\N
kmidi	audio/x-karaoke	/usr/share/applnk/Multimedia/More/kmidi.desktop	\N	open	\N
xine	video/mpeg	/usr/share/applnk/Multimedia/xine.desktop	\N	open	\N
xine	video/quicktime	/usr/share/applnk/Multimedia/xine.desktop	\N	open	\N
xine	video/x-msvideo	/usr/share/applnk/Multimedia/xine.desktop	\N	open	\N
xine	audio/x-mp3	/usr/share/applnk/Multimedia/xine.desktop	\N	open	\N
xine	audio/x-mp2	/usr/share/applnk/Multimedia/xine.desktop	\N	open	\N
kplayer	audio/x-pn-realaudio	/usr/share/applnk/Multimedia/kplayer.desktop	\N	open	\N
kplayer	audio/vnd.rn-realaudio	/usr/share/applnk/Multimedia/kplayer.desktop	\N	open	\N
kplayer	audio/x-scpls	/usr/share/applnk/Multimedia/kplayer.desktop	\N	open	\N
kplayer	audio/x-mp3	/usr/share/applnk/Multimedia/kplayer.desktop	\N	open	\N
kplayer	audio/x-vorbis	/usr/share/applnk/Multimedia/kplayer.desktop	\N	open	\N
kplayer	application/ogg	/usr/share/applnk/Multimedia/kplayer.desktop	\N	open	\N
kplayer	audio/x-mp2	/usr/share/applnk/Multimedia/kplayer.desktop	\N	open	\N
kplayer	video/mpeg	/usr/share/applnk/Multimedia/kplayer.desktop	\N	open	\N
kplayer	audio/x-mpegurl	/usr/share/applnk/Multimedia/kplayer.desktop	\N	open	\N
kplayer	audio/x-wav	/usr/share/applnk/Multimedia/kplayer.desktop	\N	open	\N
kplayer	audio/x-mod	/usr/share/applnk/Multimedia/kplayer.desktop	\N	open	\N
kplayer	video/x-avi	/usr/share/applnk/Multimedia/kplayer.desktop	\N	open	\N
kplayer	video/x-ms-asf	/usr/share/applnk/Multimedia/kplayer.desktop	\N	open	\N
kplayer	video/x-ms-wmv	/usr/share/applnk/Multimedia/kplayer.desktop	\N	open	\N
kplayer	video/x-msvideo	/usr/share/applnk/Multimedia/kplayer.desktop	\N	open	\N
kplayer	video/quicktime	/usr/share/applnk/Multimedia/kplayer.desktop	\N	open	\N
kplayer	video/x-flic	/usr/share/applnk/Multimedia/kplayer.desktop	\N	open	\N
kplayer	application/vnd.ms-asf	/usr/share/applnk/Multimedia/kplayer.desktop	\N	open	\N
kplayer	application/x-ogg	/usr/share/applnk/Multimedia/kplayer.desktop	\N	open	\N
kplayer	audio/basic	/usr/share/applnk/Multimedia/kplayer.desktop	\N	open	\N
rosegarden4	audio/x-rosegarden	/usr/share/applnk/Multimedia/rosegarden.desktop	\N	open	\N
rosegarden4	audio/x-rosegarden-device	/usr/share/applnk/Multimedia/rosegarden.desktop	\N	open	\N
kformula	application/x-kformula	/usr/share/applnk/Office/kformula.desktop	\N	open	\N
karbon	application/x-karbon	/usr/share/applnk/Office/karbon.desktop	\N	open	\N
karbon	application/illustrator	/usr/share/applnk/Office/karbon.desktop	\N	open	\N
karbon	image/x-eps	/usr/share/applnk/Office/karbon.desktop	\N	open	\N
karbon	application/postscript	/usr/share/applnk/Office/karbon.desktop	\N	open	\N
kchart	application/x-kchart	/usr/share/applnk/Office/kchart.desktop	\N	open	\N
kpresenter	application/x-kpresenter	/usr/share/applnk/Office/kpresenter.desktop	\N	open	\N
kpresenter	application/mspowerpoint	/usr/share/applnk/Office/kpresenter.desktop	\N	open	\N
kivio	application/x-kivio	/usr/share/applnk/Office/kivio.desktop	\N	open	\N
kudesigner	application/x-kudesigner	/usr/share/applnk/Office/kudesigner.desktop	\N	open	\N
kspread	application/x-kspread	/usr/share/applnk/Office/kspread.desktop	\N	open	\N
kspread	application/msexcel	/usr/share/applnk/Office/kspread.desktop	\N	open	\N
kspread	text/x-csv	/usr/share/applnk/Office/kspread.desktop	\N	open	\N
kspread	application/x-quattropro	/usr/share/applnk/Office/kspread.desktop	\N	open	\N
kugar	application/x-kugar	/usr/share/applnk/Office/kugar.desktop	\N	open	\N
kugar	application/x-vnd.kde.kugar.mixed	/usr/share/applnk/Office/kugar.desktop	\N	open	\N
kword	application/x-kword	/usr/share/applnk/Office/kword.desktop	\N	open	\N
kword	application/msword	/usr/share/applnk/Office/kword.desktop	\N	open	\N
kword	text/rtf	/usr/share/applnk/Office/kword.desktop	\N	open	\N
kword	text/plain	/usr/share/applnk/Office/kword.desktop	\N	open	\N
kword	application/x-mswrite	/usr/share/applnk/Office/kword.desktop	\N	open	\N
krita	application/x-krita	/usr/share/applnk/Office/krita.desktop	\N	open	\N
lynx	text/html	/usr/share/applnk/Internet/lynx.desktop	\N	open	\N
kate	text/x-katefilelist	/usr/share/applnk/.hidden/katefll.desktop	\N	open	\N
knewstickerstub	text/rdf	/usr/share/applnk/.hidden/knewstickerstub.desktop	\N	open	\N
knewstickerstub	text/rss	/usr/share/applnk/.hidden/knewstickerstub.desktop	\N	open	\N
ooweb	application/vnd.sun.xml.writer.global	/usr/share/applnk/OpenOffice.org1.1/web.desktop	\N	open	\N
oowriter	application/vnd.sun.xml.writer	/usr/share/applnk/OpenOffice.org1.1/writer.desktop	\N	open	\N
oowriter	application/vnd.sun.xml.writer.template	/usr/share/applnk/OpenOffice.org1.1/writer.desktop	\N	open	\N
oowriter	application/vnd.sun.xml.writer.global	/usr/share/applnk/OpenOffice.org1.1/writer.desktop	\N	open	\N
oowriter	application/vnd.stardivision.writer	/usr/share/applnk/OpenOffice.org1.1/writer.desktop	\N	open	\N
oowriter	application/msword	/usr/share/applnk/OpenOffice.org1.1/writer.desktop	\N	open	\N
oowriter	application/vnd.ms-word	/usr/share/applnk/OpenOffice.org1.1/writer.desktop	\N	open	\N
oowriter	text/rtf	/usr/share/applnk/OpenOffice.org1.1/writer.desktop	\N	open	\N
oocalc	application/vnd.sun.xml.calc	/usr/share/applnk/OpenOffice.org1.1/calc.desktop	\N	open	\N
oocalc	application/msexcel	/usr/share/applnk/OpenOffice.org1.1/calc.desktop	\N	open	\N
oocalc	application/vnd.ms-excel	/usr/share/applnk/OpenOffice.org1.1/calc.desktop	\N	open	\N
oomath	application/vnd.stardivision.math	/usr/share/applnk/OpenOffice.org1.1/math.desktop	\N	open	\N
ooimpress	application/vnd.sun.xml.impress	/usr/share/applnk/OpenOffice.org1.1/impress.desktop	\N	open	\N
ooimpress	application/vnd.sun.xml.impress.template	/usr/share/applnk/OpenOffice.org1.1/impress.desktop	\N	open	\N
ooimpress	application/vnd.stardivision.impress	/usr/share/applnk/OpenOffice.org1.1/impress.desktop	\N	open	\N
ooimpress	application/mspowerpoint	/usr/share/applnk/OpenOffice.org1.1/impress.desktop	\N	open	\N
oodraw	application/vnd.sun.xml.draw	/usr/share/applnk/OpenOffice.org1.1/draw.desktop	\N	open	\N
oodraw	application/vnd.sun.xml.draw.template	/usr/share/applnk/OpenOffice.org1.1/draw.desktop	\N	open	\N
oodraw	application/vnd.stardivision.draw	/usr/share/applnk/OpenOffice.org1.1/draw.desktop	\N	open	\N
kmdr-editor	application/x-kommander	/usr/share/applnk/Development/kmdr-editor.desktop	\N	open	\N
quanta	text/html	/usr/share/applnk/Development/quanta.desktop	\N	open	\N
kdevelop3	application/x-kdevelop	/usr/share/applnk/Development/kdevelop3.desktop	\N	open	\N
designer-qt3	application/x-designer	/usr/share/applnk/Development/designer-qt3.desktop	\N	open	\N
wine	application/x-executable	/usr/share/applnk/wine.desktop	\N	open	\N
acroread	application/pdf	/home/ziga/.kde/share/applnk/.hidden/acroread.desktop	\N	open	\N
mlv	text/plain	/home/ziga/.kde/share/applnk/.hidden/mlv.desktop	\N	open	\N
Emacs	image/x-eps	/home/ziga/.kde/share/applnk/.hidden/Emacs.desktop	\N	open	\N
Emacs	text/plain	/home/ziga/.kde/share/applnk/.hidden/Emacs.desktop	\N	open	\N
Emacs	text/x-sql	/home/ziga/.kde/share/applnk/.hidden/Emacs.desktop	\N	open	\N
Emacs	application/x-desktop	/home/ziga/.kde/share/applnk/.hidden/Emacs.desktop	\N	open	\N
Emacs	text/xml	/home/ziga/.kde/share/applnk/.hidden/Emacs.desktop	\N	open	\N
perl	application/x-perl	/home/ziga/.kde/share/applnk/.hidden/perl.desktop	\N	open	\N
gvim	application/x-desktop	/home/ziga/.kde/share/applnk/.hidden/gvim-2.desktop	\N	open	\N
gvim	text/plain	/home/ziga/.kde/share/applnk/.hidden/gvim-2.desktop	\N	open	\N
audacity	audio/vorbis	/home/ziga/.kde/share/applnk/.hidden/audacity-2.desktop	\N	open	\N
gv	application/postscript	/home/ziga/.kde/share/applnk/.hidden/gv-2.desktop	\N	open	\N
abiword	text/rtf	/home/ziga/.kde/share/applnk/.hidden/abiword-2.desktop	\N	open	\N
texmacs	application/x-texmacs	/home/ziga/.kde/share/applnk/Editors/texmacs.desktop	\N	open	\N
blender	application/x-blender	/home/ziga/.kde/share/applnk/Graphics/Blender.desktop	\N	open	\N
keducabuilder	application/x-edugallery	/usr/share/applications/kde/keducabuilder.desktop	\N	open	\N
celestia	application/x-celestia-script	/usr/share/applnk/Edutainment/Science/celestia.desktop	\N	open	\N
elinks	text/html	/usr/share/applnk/Internet/elinks.desktop	\N	open	\N
k3b	application/x-k3b	/usr/share/applnk/Multimedia/k3b.desktop	\N	open	\N
kaffeine	application/x-ogg	/usr/share/applnk/Multimedia/kaffeine.desktop	\N	open	\N
kaffeine	audio/basic	/usr/share/applnk/Multimedia/kaffeine.desktop	\N	open	\N
kaffeine	audio/vnd.rn-realaudio	/usr/share/applnk/Multimedia/kaffeine.desktop	\N	open	\N
kaffeine	audio/x-aiff	/usr/share/applnk/Multimedia/kaffeine.desktop	\N	open	\N
kaffeine	audio/x-mp3	/usr/share/applnk/Multimedia/kaffeine.desktop	\N	open	\N
kaffeine	audio/x-mpeg	/usr/share/applnk/Multimedia/kaffeine.desktop	\N	open	\N
kaffeine	audio/x-mpegurl	/usr/share/applnk/Multimedia/kaffeine.desktop	\N	open	\N
kaffeine	audio/x-pn-realaudio	/usr/share/applnk/Multimedia/kaffeine.desktop	\N	open	\N
kaffeine	audio/x-pn-realaudio-plugin	/usr/share/applnk/Multimedia/kaffeine.desktop	\N	open	\N
kaffeine	audio/x-scpls	/usr/share/applnk/Multimedia/kaffeine.desktop	\N	open	\N
kaffeine	audio/x-wav	/usr/share/applnk/Multimedia/kaffeine.desktop	\N	open	\N
kaffeine	video/x-matroska	/usr/share/applnk/Multimedia/kaffeine.desktop	\N	open	\N
kaffeine	audio/x-matroska	/usr/share/applnk/Multimedia/kaffeine.desktop	\N	open	\N
kaffeine	video/mpeg	/usr/share/applnk/Multimedia/kaffeine.desktop	\N	open	\N
kaffeine	video/quicktime	/usr/share/applnk/Multimedia/kaffeine.desktop	\N	open	\N
kaffeine	video/vnd.rn-realvideo	/usr/share/applnk/Multimedia/kaffeine.desktop	\N	open	\N
kaffeine	video/x-avi	/usr/share/applnk/Multimedia/kaffeine.desktop	\N	open	\N
kaffeine	video/x-flic	/usr/share/applnk/Multimedia/kaffeine.desktop	\N	open	\N
kaffeine	video/x-ms-asf	/usr/share/applnk/Multimedia/kaffeine.desktop	\N	open	\N
kaffeine	video/x-ms-wmv	/usr/share/applnk/Multimedia/kaffeine.desktop	\N	open	\N
kaffeine	video/x-msvideo	/usr/share/applnk/Multimedia/kaffeine.desktop	\N	open	\N
kaffeine	application/smil	/usr/share/applnk/Multimedia/kaffeine.desktop	\N	open	\N
soffice	application/vnd.sun.xml.draw	/usr/share/applnk/Office/OpenOffice/drawing.desktop	\N	open	\N
soffice	application/vnd.stardivision.draw	/usr/share/applnk/Office/OpenOffice/drawing.desktop	\N	open	\N
soffice	application/vnd.stardivision.math	/usr/share/applnk/Office/OpenOffice/mathdoc.desktop	\N	open	\N
soffice	application/vnd.sun.xml.impress	/usr/share/applnk/Office/OpenOffice/presentation.desktop	\N	open	\N
soffice	application/vnd.stardivision.impress	/usr/share/applnk/Office/OpenOffice/presentation.desktop	\N	open	\N
soffice	application/mspowerpoint	/usr/share/applnk/Office/OpenOffice/presentation.desktop	\N	open	\N
soffice	application/vnd.sun.xml.calc	/usr/share/applnk/Office/OpenOffice/spreadsheet.desktop	\N	open	\N
soffice	application/vnd.stardivision.calc	/usr/share/applnk/Office/OpenOffice/spreadsheet.desktop	\N	open	\N
soffice	application/vnd.stardivision.chart	/usr/share/applnk/Office/OpenOffice/spreadsheet.desktop	\N	open	\N
soffice	application/msexcel	/usr/share/applnk/Office/OpenOffice/spreadsheet.desktop	\N	open	\N
soffice	application/vnd.ms-excel	/usr/share/applnk/Office/OpenOffice/spreadsheet.desktop	\N	open	\N
soffice	application/vnd.sun.xml.writer	/usr/share/applnk/Office/OpenOffice/textdoc.desktop	\N	open	\N
soffice	application/vnd.stardivision.writer	/usr/share/applnk/Office/OpenOffice/textdoc.desktop	\N	open	\N
soffice	application/msword	/usr/share/applnk/Office/OpenOffice/textdoc.desktop	\N	open	\N
soffice	application/vnd.ms-word	/usr/share/applnk/Office/OpenOffice/textdoc.desktop	\N	open	\N
soffice	text/rtf	/usr/share/applnk/Office/OpenOffice/textdoc.desktop	\N	open	\N
filelight	inode/directory	/usr/share/applnk/Utilities/filelight.desktop	\N	open	\N
Gimp	image/x-vnd.adobe.photoshop	/home/ziga/.kde/share/applnk/.hidden/Gimp.desktop	\N	open	\N
avidemux	video/x-msvideo	/home/ziga/.kde/share/applnk/.hidden/avidemux.desktop	\N	open	\N
avidemux	video/mpeg	/home/ziga/.kde/share/applnk/.hidden/avidemux.desktop	\N	open	\N
soundtracker	audio/x-mod	/home/ziga/.kde/share/applnk/.hidden/soundtracker-2.desktop	\N	open	\N
evolution	text/calendar	/home/ziga/.kde/share/applnk/.hidden/evolution-2.desktop	\N	open	\N
gliv	image/png	/home/ziga/.kde/share/applnk/.hidden/gliv-2.desktop	\N	open	\N
Emacs	text/x-tex	/home/ziga/.kde/share/applnk/.hidden/Emacs.desktop	\N	open	\N
muse	text/x-muse+xml	/home/ziga/.kde/share/applnk/.hidden/muse-2.desktop	\N	open	\N
abiword	application/msword	/home/ziga/.kde/share/applnk/Editors/AbiWord.desktop	\N	open	\N
xine	video/mp4	/home/ziga/.kde/share/applnk/Multimedia/xine.desktop	\N	open	\N
"/opt/openoffice/program/simpress"	application/vnd.sun.xml.impress	/home/ziga/.kde/share/applnk/OpenOffice.org 1.1.1/impress.desktop	\N	open	\N
"/opt/openoffice/program/simpress"	application/vnd.sun.xml.impress.template	/home/ziga/.kde/share/applnk/OpenOffice.org 1.1.1/impress.desktop	\N	open	\N
"/opt/openoffice/program/simpress"	application/vnd.stardivision.impress	/home/ziga/.kde/share/applnk/OpenOffice.org 1.1.1/impress.desktop	\N	open	\N
"/opt/openoffice/program/simpress"	application/mspowerpoint	/home/ziga/.kde/share/applnk/OpenOffice.org 1.1.1/impress.desktop	\N	open	\N
"/opt/openoffice/program/scalc"	application/vnd.sun.xml.calc	/home/ziga/.kde/share/applnk/OpenOffice.org 1.1.1/calc.desktop	\N	open	\N
"/opt/openoffice/program/scalc"	application/vnd.sun.xml.calc.template	/home/ziga/.kde/share/applnk/OpenOffice.org 1.1.1/calc.desktop	\N	open	\N
"/opt/openoffice/program/scalc"	application/vnd.stardivision.calc	/home/ziga/.kde/share/applnk/OpenOffice.org 1.1.1/calc.desktop	\N	open	\N
"/opt/openoffice/program/scalc"	application/vnd.stardivision.chart	/home/ziga/.kde/share/applnk/OpenOffice.org 1.1.1/calc.desktop	\N	open	\N
"/opt/openoffice/program/scalc"	application/msexcel	/home/ziga/.kde/share/applnk/OpenOffice.org 1.1.1/calc.desktop	\N	open	\N
"/opt/openoffice/program/swriter"	application/vnd.sun.xml.writer	/home/ziga/.kde/share/applnk/OpenOffice.org 1.1.1/writer.desktop	\N	open	\N
"/opt/openoffice/program/swriter"	application/vnd.sun.xml.writer.template	/home/ziga/.kde/share/applnk/OpenOffice.org 1.1.1/writer.desktop	\N	open	\N
"/opt/openoffice/program/swriter"	application/vnd.sun.xml.writer.global	/home/ziga/.kde/share/applnk/OpenOffice.org 1.1.1/writer.desktop	\N	open	\N
"/opt/openoffice/program/swriter"	application/vnd.stardivision.writer	/home/ziga/.kde/share/applnk/OpenOffice.org 1.1.1/writer.desktop	\N	open	\N
"/opt/openoffice/program/swriter"	application/msword	/home/ziga/.kde/share/applnk/OpenOffice.org 1.1.1/writer.desktop	\N	open	\N
"/opt/openoffice/program/swriter"	application/vnd.ms-word	/home/ziga/.kde/share/applnk/OpenOffice.org 1.1.1/writer.desktop	\N	open	\N
"/opt/openoffice/program/swriter"	text/rtf	/home/ziga/.kde/share/applnk/OpenOffice.org 1.1.1/writer.desktop	\N	open	\N
kaffeine	audio/vorbis	/home/ziga/.kde/share/applnk/kaffeine_part.desktop	\N	open	\N
Gimp	image/x-tga	\N	\N	open	\N
Gimp	image/x-pcx	\N	\N	open	\N
Gimp	image/svg+xml	\N	\N	open	\N
Gimp	image/x-eps	\N	\N	open	\N
Gimp	image/x-bmp	\N	\N	open	\N
Gimp	image/gif	\N	\N	open	\N
Gimp	image/png	\N	\N	open	\N
Emacs	text/x-csrc	\N	\N	open	\N
Emacs	text/x-chdr	\N	\N	open	\N
Emacs	application/x-perl	\N	\N	open	\N
Emacs	application/x-php	\N	\N	open	\N
Emacs	application/x-python	\N	\N	open	\N
abiword	application/rtf	\N	\N	open	\N
abiword	text/plain	\N	\N	open	\N
abiword	text/html	\N	\N	open	\N
abiword	application/xhtml+xml	\N	\N	open	\N
oowriter	application/rtf	\N	\N	open	\N
oowriter	text/html	\N	\N	open	\N
oocalc	application/x-dbase	\N	\N	open	\N
sodipodi	image/svg+xml	/usr/share/applications/sodipodi.desktop	\N	open	\N
inkscape	image/svg+xml	/usr/share/applications/inkscape.desktop	\N	open	\N
umbrello	application/x-uml	/usr/share/applications/kde/umbrello.desktop	\N	open	\N
gv	image/x-eps	\N	\N	open	\N
gv	application/pdf	\N	\N	open	\N
kxmleditor	text/x-xmi	\N	\N	open	\N
Gimp	image/x-portable-anymap	\N	\N	open	\N
Emacs	text/x-emacs-lisp	\N	\N	open	\N
audacity	audio/x-aiff	\N	\N	open	\N
audacity	audio/basic	\N	\N	open	\N
audacity	audio/x-mp3	\N	\N	open	\N
audacity	application/x-aup	\N	\N	open	\N
oomath	text/x-mathml	\N	\N	open	\N
Gimp	image/x-xcf	\N	\N	open	\N
Gimp	image/tiff	\N	\N	open	\N
Gimp	video/x-flic	\N	\N	open	\N
Gimp	image/g3fax	\N	\N	open	\N
Emacs	text/directory	\N	\N	open	\N
Emacs	text/enriched	\N	\N	open	\N
Emacs	text/htmlh	\N	\N	open	\N
Emacs	text/opml+xml	\N	\N	open	\N
Emacs	text/rfc822-headers	\N	\N	open	\N
Emacs	text/richtext	\N	\N	open	\N
Emacs	text/tab-separated-values	\N	\N	open	\N
Emacs	text/x-aiml+xml	\N	\N	open	\N
Emacs	text/x-authors	\N	\N	open	\N
Emacs	text/x-copying	\N	\N	open	\N
Emacs	text/x-credits	\N	\N	open	\N
Emacs	text/x-csharp	\N	\N	open	\N
Emacs	text/x-dcl	\N	\N	open	\N
Emacs	text/x-dsl	\N	\N	open	\N
Emacs	text/x-dtd	\N	\N	open	\N
Emacs	text/x-fortran	\N	\N	open	\N
oocalc	application/vnd.sun.xml.calc.template	/usr/share/applnk/OpenOffice.org1.1/calc.desktop	\N	open	\N
oocalc	application/vnd.stardivision.calc	/usr/share/applnk/OpenOffice.org1.1/calc.desktop	\N	open	\N
oocalc	application/vnd.stardivision.chart	/usr/share/applnk/OpenOffice.org1.1/calc.desktop	\N	open	\N
inkscape	application/illustrator	\N	\N	open	\N
audacity	application/ogg	\N	\N	open	\N
audacity	audio/x-wav	\N	\N	open	\N
keduca	application/x-edu	/usr/share/applications/kde/keduca.desktop	\N	open	\N
keduca	application/x-edugallery	/usr/share/applications/kde/keduca.desktop	\N	open	\N
keducabuilder	application/x-edu	/usr/share/applications/kde/keducabuilder.desktop	\N	open	\N
Emacs	text/x-gettext-translation-template	\N	\N	open	\N
"/opt/openoffice/program/scalc"	application/vnd.ms-excel	/home/ziga/.kde/share/applnk/OpenOffice.org 1.1.1/calc.desktop	\N	open	\N
"/opt/openoffice/program/scalc"	application/x-gnumeric	/home/ziga/.kde/share/applnk/OpenOffice.org 1.1.1/calc.desktop	\N	open	\N
"/opt/openoffice/program/sdraw"	application/vnd.sun.xml.draw	/home/ziga/.kde/share/applnk/OpenOffice.org 1.1.1/draw.desktop	\N	open	\N
"/opt/openoffice/program/sdraw"	application/vnd.sun.xml.draw.template	/home/ziga/.kde/share/applnk/OpenOffice.org 1.1.1/draw.desktop	\N	open	\N
"/opt/openoffice/program/sdraw"	application/vnd.stardivision.draw	/home/ziga/.kde/share/applnk/OpenOffice.org 1.1.1/draw.desktop	\N	open	\N
"/opt/openoffice/program/smath"	application/vnd.sun.xml.writer	/home/ziga/.kde/share/applnk/OpenOffice.org 1.1.1/math.desktop	\N	open	\N
"/opt/openoffice/program/smath"	application/vnd.stardivision.writer	/home/ziga/.kde/share/applnk/OpenOffice.org 1.1.1/math.desktop	\N	open	\N
"/opt/openoffice/program/smath"	application/msword	/home/ziga/.kde/share/applnk/OpenOffice.org 1.1.1/math.desktop	\N	open	\N
"/opt/openoffice/program/smath"	application/vnd.ms-word	/home/ziga/.kde/share/applnk/OpenOffice.org 1.1.1/math.desktop	\N	open	\N
"/opt/openoffice/program/smath"	text/rtf	/home/ziga/.kde/share/applnk/OpenOffice.org 1.1.1/math.desktop	\N	open	\N
"/opt/openoffice/program/sweb"	application/vnd.sun.xml.writer.global	/home/ziga/.kde/share/applnk/OpenOffice.org 1.1.1/web.desktop	\N	open	\N
"/opt/openoffice/program/sweb"	text/html	/home/ziga/.kde/share/applnk/OpenOffice.org 1.1.1/web.desktop	\N	open	\N
conglomerate	text/xml	\N	\N	open	\N
scribus	text/x-scribus	\N	\N	open	\N
conglomerate	application/vnd.mozilla.xul+xml	\N	\N	open	\N
abiword	application/x-abiword	\N	\N	open	\N
conglomerate	text/docbook	\N	\N	open	\N
abiword	text/docbook	\N	\N	open	\N
gnumeric	application/vnd.sun.xml.calc	\N	\N	open	\N
gnumeric	text/html	\N	\N	open	\N
gnumeric	application/vnd.lotus-1-2-3	\N	\N	open	\N
gnumeric	text/spreadsheet	\N	\N	open	\N
gnumeric	text/x-comma-separated-values	\N	\N	open	\N
Emacs	text/x-graphviz	\N	\N	open	\N
Emacs	text/x-gtkrc	\N	\N	open	\N
Emacs	text/x-install	\N	\N	open	\N
Emacs	text/x-ksh	\N	\N	open	\N
Emacs	text/x-ksysv-log	\N	\N	open	\N
Emacs	text/x-readme	\N	\N	open	\N
Emacs	text/x-setext	\N	\N	open	\N
Gimp	image/x-lwo	/usr/share/slix/apps/Aplikacije/Grafika/Gimp.desktop	\N	open	\N
Gimp	image/x-lws	/usr/share/slix/apps/Aplikacije/Grafika/Gimp.desktop	\N	open	\N
Gimp	image/x-msod	/usr/share/slix/apps/Aplikacije/Grafika/Gimp.desktop	\N	open	\N
Gimp	image/x-niff	/usr/share/slix/apps/Aplikacije/Grafika/Gimp.desktop	\N	open	\N
Gimp	image/x-photo-cd	/usr/share/slix/apps/Aplikacije/Grafika/Gimp.desktop	\N	open	\N
Gimp	image/x-portable-bitmap	/usr/share/slix/apps/Aplikacije/Grafika/Gimp.desktop	\N	open	\N
Gimp	image/x-portable-graymap	/usr/share/slix/apps/Aplikacije/Grafika/Gimp.desktop	\N	open	\N
Gimp	image/x-portable-pixmap	/usr/share/slix/apps/Aplikacije/Grafika/Gimp.desktop	\N	open	\N
gnumeric	application/x-gnumeric	\N	\N	open	\N
gnumeric	application/x-oleo	\N	\N	open	\N
gnumeric	application/x-dbase	\N	\N	open	\N
fontforge	application/x-font-ttf	\N	\N	open	\N
fontforge	application/x-font-type1	\N	\N	open	\N
dotty	text/x-graphviz	\N	\N	open	\N
neato	text/x-graphviz	\N	\N	open	\N
texmacs	text/x-tex	\N	\N	open	\N
gnumeric	application/x-applix-spreadsheet	\N	\N	open	\N
dia-gnome	application/x-dia-diagram	\N	\N	open	\N
inkscape	image/x-eps	\N	\N	open	\N
texmacs	text/x-texmacs	\N	\N	open	\N
umbrello	text/x-xmi	\N	\N	open	\N
oocalc	text/spreadsheet	\N	\N	open	\N
oocalc	text/x-comma-separated-values	\N	\N	open	\N
ooimpress	application/vnd.ms-powerpoint	\N	\N	open	\N
ooimpress	application/vnd.sun.xml.draw	\N	\N	open	\N
ooimpress	application/vnd.stardivision.draw	\N	\N	open	\N
ooimpress	image/cgm	\N	\N	open	\N
oodraw	image/vnd.dxf	\N	\N	open	\N
oodraw	image/x-eps	\N	\N	open	\N
oodraw	image/x-wmf	\N	\N	open	\N
oodraw	image/jpeg	\N	\N	open	\N
oodraw	image/x-psd	\N	\N	open	\N
oodraw	image/tiff	\N	\N	open	\N
oodraw	image/png	\N	\N	open	\N
oodraw	image/x-tga	\N	\N	open	\N
soundtracker	audio/x-it	\N	\N	open	\N
Gimp	image/x-compressed-xcf	\N	\N	open	\N
Gimp	image/x-psd	\N	\N	open	\N
Gimp	image/x-xwindowdump	\N	\N	open	\N
mozilla	application/vnd.mozilla.xul+xml	\N	\N	open	\N
tgif	application/x-tgif	\N	\N	open	\N
Emacs	text/x-scheme	\N	\N	open	\N
Emacs	text/x-idl	\N	\N	open	\N
Emacs	text/x-haskell	\N	\N	open	\N
Emacs	text/x-literate-haskell	\N	\N	open	\N
quanta	application/x-php	\N	\N	open	\N
Emacs	application/x-asp	\N	\N	open	\N
Emacs	text/x-speech	\N	\N	open	\N
Emacs	text/x-texinfo	\N	\N	open	\N
Emacs	text/x-troff-me	\N	\N	open	\N
Emacs	text/x-troff-mm	\N	\N	open	\N
Emacs	text/x-troff-ms	\N	\N	open	\N
Emacs	text/x-uil	\N	\N	open	\N
kate	text/x-makefile	/usr/share/slix/apps/Aplikacije/Besedilo/kate.desktop	\N	open	\N
kate	text/x-c++hdr	/usr/share/slix/apps/Aplikacije/Besedilo/kate.desktop	\N	open	\N
kate	text/x-c++src	/usr/share/slix/apps/Aplikacije/Besedilo/kate.desktop	\N	open	\N
kate	text/x-chdr	/usr/share/slix/apps/Aplikacije/Besedilo/kate.desktop	\N	open	\N
kate	text/x-csrc	/usr/share/slix/apps/Aplikacije/Besedilo/kate.desktop	\N	open	\N
kate	text/x-java	/usr/share/slix/apps/Aplikacije/Besedilo/kate.desktop	\N	open	\N
kate	text/x-moc	/usr/share/slix/apps/Aplikacije/Besedilo/kate.desktop	\N	open	\N
kate	text/x-pascal	/usr/share/slix/apps/Aplikacije/Besedilo/kate.desktop	\N	open	\N
kate	text/x-tcl	/usr/share/slix/apps/Aplikacije/Besedilo/kate.desktop	\N	open	\N
kate	text/x-tex	/usr/share/slix/apps/Aplikacije/Besedilo/kate.desktop	\N	open	\N
kate	application/x-shellscript	/usr/share/slix/apps/Aplikacije/Besedilo/kate.desktop	\N	open	\N
kate	text/rdf	/usr/share/slix/apps/Aplikacije/Besedilo/kate.desktop	\N	open	\N
kwrite	text/x-makefile	/usr/share/slix/apps/Aplikacije/Besedilo/kwrite.desktop	\N	open	\N
kwrite	text/x-c++hdr	/usr/share/slix/apps/Aplikacije/Besedilo/kwrite.desktop	\N	open	\N
kwrite	text/x-c++src	/usr/share/slix/apps/Aplikacije/Besedilo/kwrite.desktop	\N	open	\N
kwrite	text/x-chdr	/usr/share/slix/apps/Aplikacije/Besedilo/kwrite.desktop	\N	open	\N
kwrite	text/x-csrc	/usr/share/slix/apps/Aplikacije/Besedilo/kwrite.desktop	\N	open	\N
kwrite	text/x-java	/usr/share/slix/apps/Aplikacije/Besedilo/kwrite.desktop	\N	open	\N
kwrite	text/x-moc	/usr/share/slix/apps/Aplikacije/Besedilo/kwrite.desktop	\N	open	\N
kwrite	text/x-pascal	/usr/share/slix/apps/Aplikacije/Besedilo/kwrite.desktop	\N	open	\N
sketch	image/svg+xml	\N	\N	open	\N
sketch	application/illustrator	\N	\N	open	\N
sketch	image/x-wmf	\N	\N	open	\N
sketch	image/x-xfig	\N	\N	open	\N
sketch	image/cgm	\N	\N	open	\N
xfig	image/x-xfig	\N	\N	open	\N
dia	application/x-dia-diagram	\N	\N	open	\N
dia	image/vnd.dxf	\N	\N	open	\N
dia	image/x-bmp	\N	\N	open	\N
dia	image/gif	\N	\N	open	\N
dia	image/jpeg	\N	\N	open	\N
dia	image/png	\N	\N	open	\N
dia	image/x-portable-anymap	\N	\N	open	\N
dia	image/x-cmu-raster	\N	\N	open	\N
dia	image/tiff	\N	\N	open	\N
mozilla	text/xml	\N	\N	open	\N
mozilla	text/html	\N	\N	open	\N
kwrite	text/x-tcl	/usr/share/slix/apps/Aplikacije/Besedilo/kwrite.desktop	\N	open	\N
kwrite	text/x-tex	/usr/share/slix/apps/Aplikacije/Besedilo/kwrite.desktop	\N	open	\N
kwrite	application/x-shellscript	/usr/share/slix/apps/Aplikacije/Besedilo/kwrite.desktop	\N	open	\N
Gimp	image/x-rgb	/usr/share/slix/apps/Aplikacije/Grafika/Gimp.desktop	\N	open	\N
Gimp	image/x-xbitmap	/usr/share/slix/apps/Aplikacije/Grafika/Gimp.desktop	\N	open	\N
Gimp	image/x-xcf-gimp	/usr/share/slix/apps/Aplikacije/Grafika/Gimp.desktop	\N	open	\N
Gimp	image/x-xpixmap	/usr/share/slix/apps/Aplikacije/Grafika/Gimp.desktop	\N	open	\N
Gimp	image/x-targa	/usr/share/slix/apps/Aplikacije/Grafika/Gimp.desktop	\N	open	\N
/usr/bin/qcad	image/vnd.dxf	/usr/share/slix/apps/Aplikacije/Grafika/QCad.desktop	\N	open	\N
scribus	application/x-scribus	/usr/share/slix/apps/Aplikacije/Grafika/Scribus.desktop	\N	open	\N
/usr/bin/pfaedit	application/x-font-ttf	/usr/share/slix/apps/Aplikacije/Grafika/pfaedit.desktop	\N	open	\N
/usr/bin/pfaedit	application/x-font-type1	/usr/share/slix/apps/Aplikacije/Grafika/pfaedit.desktop	\N	open	\N
/usr/bin/X11/gv	application/pdf	/usr/share/slix/apps/Aplikacije/Prezentacija/GV.desktop	\N	open	\N
/usr/bin/X11/gv	application/postscript	/usr/share/slix/apps/Aplikacije/Prezentacija/GV.desktop	\N	open	\N
/usr/bin/X11/gv	image/x-eps	/usr/share/slix/apps/Aplikacije/Prezentacija/GV.desktop	\N	open	\N
/usr/bin/X11/gv	application/illustrator	/usr/share/slix/apps/Aplikacije/Prezentacija/GV.desktop	\N	open	\N
pspresent	application/postscript	/usr/share/slix/apps/Aplikacije/Prezentacija/pspresent.desktop	\N	open	\N
pspresent	image/x-eps	/usr/share/slix/apps/Aplikacije/Prezentacija/pspresent.desktop	\N	open	\N
gnumeric	application/vnd.stardivision.calc	/usr/share/slix/apps/Aplikacije/Tabele/gnumeric.desktop	\N	open	\N
gnumeric	application/msexcel	/usr/share/slix/apps/Aplikacije/Tabele/gnumeric.desktop	\N	open	\N
gnumeric	application/vnd.ms-excel	/usr/share/slix/apps/Aplikacije/Tabele/gnumeric.desktop	\N	open	\N
gnumeric	text/plain	/usr/share/slix/apps/Aplikacije/Tabele/gnumeric.desktop	\N	open	\N
gnumeric	text/x-csv	/usr/share/slix/apps/Aplikacije/Tabele/gnumeric.desktop	\N	open	\N
audacity	application/x-ogg	/usr/share/slix/apps/Aplikacije/Zvok/Audacity.desktop	\N	open	\N
/usr/bin/spiralsynthmodular	application/x-ssm	/usr/share/slix/apps/Aplikacije/Zvok/SpiralSynthModular.desktop	\N	open	\N
oowriter	application/msexcel	/usr/share/slix/apps/Aplikacije/OOo.desktop	\N	open	\N
oowriter	application/vnd.ms-excel	/usr/share/slix/apps/Aplikacije/OOo.desktop	\N	open	\N
oowriter	application/vnd.stardivision.calc	/usr/share/slix/apps/Aplikacije/OOo.desktop	\N	open	\N
oowriter	application/x-applixword	/usr/share/slix/apps/Aplikacije/OOo.desktop	\N	open	\N
oowriter	application/x-hancomword	/usr/share/slix/apps/Aplikacije/OOo.desktop	\N	open	\N
oowriter	application/x-kword	/usr/share/slix/apps/Aplikacije/OOo.desktop	\N	open	\N
oowriter	application/xhtml+xml	/usr/share/slix/apps/Aplikacije/OOo.desktop	\N	open	\N
oowriter	text/plain	/usr/share/slix/apps/Aplikacije/OOo.desktop	\N	open	\N
oowriter	text/spreadsheet	/usr/share/slix/apps/Aplikacije/OOo.desktop	\N	open	\N
oowriter	text/vnd.wap.wml	/usr/share/slix/apps/Aplikacije/OOo.desktop	\N	open	\N
oowriter	text/x-csv	/usr/share/slix/apps/Aplikacije/OOo.desktop	\N	open	\N
oowriter	image/x-eps	/usr/share/slix/apps/Aplikacije/OOo.desktop	\N	open	\N
oowriter	image/vnd.dxf	/usr/share/slix/apps/Aplikacije/OOo.desktop	\N	open	\N
oowriter	image/x-wmf	/usr/share/slix/apps/Aplikacije/OOo.desktop	\N	open	\N
Emacs	text/html	/usr/share/slix/apps/Aplikacije/Emacs.desktop	\N	open	\N
Emacs	text/x-makefile	/usr/share/slix/apps/Aplikacije/Emacs.desktop	\N	open	\N
Emacs	text/x-c++hdr	/usr/share/slix/apps/Aplikacije/Emacs.desktop	\N	open	\N
Emacs	text/x-c++src	/usr/share/slix/apps/Aplikacije/Emacs.desktop	\N	open	\N
Emacs	text/x-java	/usr/share/slix/apps/Aplikacije/Emacs.desktop	\N	open	\N
Emacs	text/x-moc	/usr/share/slix/apps/Aplikacije/Emacs.desktop	\N	open	\N
Emacs	text/x-pascal	/usr/share/slix/apps/Aplikacije/Emacs.desktop	\N	open	\N
Emacs	text/x-tcl	/usr/share/slix/apps/Aplikacije/Emacs.desktop	\N	open	\N
Emacs	application/x-shellscript	/usr/share/slix/apps/Aplikacije/Emacs.desktop	\N	open	\N
Emacs	text/rdf	/usr/share/slix/apps/Aplikacije/Emacs.desktop	\N	open	\N
abiword	application/vnd.ms-word	/usr/share/slix/apps/Aplikacije/AbiWord.desktop	\N	open	\N
abiword	application/vnd.stardivision.writer	/usr/share/slix/apps/Aplikacije/AbiWord.desktop	\N	open	\N
abiword	application/vnd.sun.xml.writer	/usr/share/slix/apps/Aplikacije/AbiWord.desktop	\N	open	\N
abiword	application/x-kword	/usr/share/slix/apps/Aplikacije/AbiWord.desktop	\N	open	\N
abiword	application/x-applixword	/usr/share/slix/apps/Aplikacije/AbiWord.desktop	\N	open	\N
abiword	application/x-hancomword	/usr/share/slix/apps/Aplikacije/AbiWord.desktop	\N	open	\N
abiword	text/vnd.wap.wml	/usr/share/slix/apps/Aplikacije/AbiWord.desktop	\N	open	\N
gfontview	application/x-font-ttf	/usr/share/slix/apps/Pripomo?ki/gfontview.desktop	\N	open	\N
gfontview	application/x-font-type1	/usr/share/slix/apps/Pripomo?ki/gfontview.desktop	\N	open	\N
gmplayer	video/mpeg	/usr/share/slix/apps/Pripomo?ki/mplayer.desktop	\N	open	\N
gmplayer	video/quicktime	/usr/share/slix/apps/Pripomo?ki/mplayer.desktop	\N	open	\N
gmplayer	video/x-flic	/usr/share/slix/apps/Pripomo?ki/mplayer.desktop	\N	open	\N
gmplayer	video/x-msvideo	/usr/share/slix/apps/Pripomo?ki/mplayer.desktop	\N	open	\N
gmplayer	video/x-ms-asf	/usr/share/slix/apps/Pripomo?ki/mplayer.desktop	\N	open	\N
gmplayer	application/vnd.ms-asf	/usr/share/slix/apps/Pripomo?ki/mplayer.desktop	\N	open	\N
gmplayer	video/x-ms-wmv	/usr/share/slix/apps/Pripomo?ki/mplayer.desktop	\N	open	\N
xmms	audio/x-mp3	/usr/share/slix/apps/Pripomo?ki/xmms.desktop	\N	open	\N
xmms	audio/x-mod	/usr/share/slix/apps/Pripomo?ki/xmms.desktop	\N	open	\N
xmms	audio/x-wav	/usr/share/slix/apps/Pripomo?ki/xmms.desktop	\N	open	\N
xmms	audio/x-mpegurl	/usr/share/slix/apps/Pripomo?ki/xmms.desktop	\N	open	\N
xmms	audio/x-scpls	/usr/share/slix/apps/Pripomo?ki/xmms.desktop	\N	open	\N
xmms	application/ogg	/usr/share/slix/apps/Pripomo?ki/xmms.desktop	\N	open	\N
xmms	application/x-ogg	/usr/share/slix/apps/Pripomo?ki/xmms.desktop	\N	open	\N
xmms	video/mpeg	/usr/share/slix/apps/Pripomo?ki/xmms.desktop	\N	open	\N
Browse	text/html	/usr/share/slix/apps/Mozilla.desktop	\N	open	\N
Browse	text/xml	/usr/share/slix/apps/Mozilla.desktop	\N	open	\N
blender	application/x-executable	/home/ziga/.kde/share/applnk/Graphics/Blender.desktop	\N	open	x
gv	application/illustrator	\N	\N	view	\N
\.


--
-- Data for TOC entry 573 (OID 2062795)
-- Name: app_category; Type: TABLE DATA; Schema: public; Owner: postgres
--

COPY app_category (app, category, registry) FROM stdin;
nautilus	Application	/usr/share/applications/network-scheme.desktop
nautilus	Core	/usr/share/applications/network-scheme.desktop
xsane	GTK	/usr/share/applications/xsane.desktop
xsane	Application	/usr/share/applications/xsane.desktop
xsane	Graphics	/usr/share/applications/xsane.desktop
xsane	RasterGraphics	/usr/share/applications/xsane.desktop
xsane	Scanning	/usr/share/applications/xsane.desktop
xsane	OCR	/usr/share/applications/xsane.desktop
gnome-control-center	GNOME	/usr/share/applications/gnomecc.desktop
gnome-control-center	Application	/usr/share/applications/gnomecc.desktop
gnome-control-center	Settings	/usr/share/applications/gnomecc.desktop
gnome-system-monitor	Application	/usr/share/applications/gnome-system-monitor.desktop
gnome-system-monitor	System	/usr/share/applications/gnome-system-monitor.desktop
gcmui	Application	/usr/share/applications/gcm.desktop
gcmui	Office	/usr/share/applications/gcm.desktop
gcmui	Clipboard Manager	/usr/share/applications/gcm.desktop
gdmflexiserver	Application	/usr/share/applications/gdmflexiserver-xnest.desktop
gdmflexiserver	System	/usr/share/applications/gdmflexiserver-xnest.desktop
gnumeric	Application	/usr/share/applications/gnumeric.desktop
gnumeric	Office	/usr/share/applications/gnumeric.desktop
gnumeric	Spreadsheet	/usr/share/applications/gnumeric.desktop
dasher	Application	/usr/share/applications/dasher.desktop
dasher	Accessibility	/usr/share/applications/dasher.desktop
xchat	Application	/usr/share/applications/xchat.desktop
xchat	Network	/usr/share/applications/xchat.desktop
sodipodi	Application	/usr/share/applications/sodipodi.desktop
sodipodi	Graphics	/usr/share/applications/sodipodi.desktop
gucharmap	Application	/usr/share/applications/gucharmap.desktop
gucharmap	Utility	/usr/share/applications/gucharmap.desktop
gksu	PackageManager	/usr/share/applications/synaptic.desktop
gksu	GTK	/usr/share/applications/synaptic.desktop
gksu	System	/usr/share/applications/synaptic.desktop
gksu	Application	/usr/share/applications/synaptic.desktop
gnomemeeting	Application	/usr/share/applications/gnomemeeting.desktop
gnomemeeting	Network	/usr/share/applications/gnomemeeting.desktop
yelp	GNOME	/usr/share/applications/yelp.desktop
yelp	Application	/usr/share/applications/yelp.desktop
yelp	Core	/usr/share/applications/yelp.desktop
glade-2	Application	/usr/share/applications/glade-2.desktop
glade-2	Development	/usr/share/applications/glade-2.desktop
gcombust	Application	/usr/share/applications/gcombust.desktop
gcombust	System	/usr/share/applications/gcombust.desktop
gksu	SystemSetup	/usr/share/applications/gdmsetup.desktop
gksu	X-Red-Hat-Base	/usr/share/applications/gdmsetup.desktop
file-roller	GNOME	/usr/share/applications/file-roller.desktop
file-roller	Application	/usr/share/applications/file-roller.desktop
file-roller	System	/usr/share/applications/file-roller.desktop
file-roller	Utility	/usr/share/applications/file-roller.desktop
alc	Application	/usr/share/applications/alc.desktop
alc	Network	/usr/share/applications/alc.desktop
xscreensaver-demo	Application	/usr/share/applications/screensaver-properties.desktop
xscreensaver-demo	Settings	/usr/share/applications/screensaver-properties.desktop
xscreensaver-demo	Appearance	/usr/share/applications/screensaver-properties.desktop
xscreensaver-demo	AdvancedSettings	/usr/share/applications/screensaver-properties.desktop
eclipse	Application	/usr/share/applications/eclipse.desktop
eclipse	Development	/usr/share/applications/eclipse.desktop
inkscape	Application	/usr/share/applications/inkscape.desktop
inkscape	Graphics	/usr/share/applications/inkscape.desktop
inkscape	VectorGraphics	/usr/share/applications/inkscape.desktop
inkscape	GTK	/usr/share/applications/inkscape.desktop
gedit	Application	/usr/share/applications/gedit.desktop
gedit	Utility	/usr/share/applications/gedit.desktop
gedit	TextEditor	/usr/share/applications/gedit.desktop
gnome-system-log	GNOME	/usr/share/applications/gnome-system-log.desktop
gnome-system-log	Application	/usr/share/applications/gnome-system-log.desktop
gnome-system-log	System	/usr/share/applications/gnome-system-log.desktop
oowriter	Application	/usr/share/applications/ooo645writer.desktop
oowriter	Office	/usr/share/applications/ooo645writer.desktop
ooweb	Application	/usr/share/applications/ooo645web.desktop
ooweb	Office	/usr/share/applications/ooo645web.desktop
gnome-search-tool	GNOME	/usr/share/applications/gnome-search-tool.desktop
gnome-search-tool	Application	/usr/share/applications/gnome-search-tool.desktop
gnome-search-tool	Core	/usr/share/applications/gnome-search-tool.desktop
gnome-dictionary	GNOME	/usr/share/applications/gnome-dictionary.desktop
gnome-dictionary	Application	/usr/share/applications/gnome-dictionary.desktop
gnome-dictionary	Utility	/usr/share/applications/gnome-dictionary.desktop
gfloppy	GNOME	/usr/share/applications/gfloppy.desktop
gfloppy	Application	/usr/share/applications/gfloppy.desktop
gfloppy	System	/usr/share/applications/gfloppy.desktop
bug-buddy	GNOME	/usr/share/applications/bug-buddy.desktop
bug-buddy	Application	/usr/share/applications/bug-buddy.desktop
bug-buddy	Development	/usr/share/applications/bug-buddy.desktop
ggv	GNOME	/usr/share/applications/ggv.desktop
ggv	Application	/usr/share/applications/ggv.desktop
ggv	Graphics	/usr/share/applications/ggv.desktop
ggv	VectorGraphics	/usr/share/applications/ggv.desktop
ggv	Viewer	/usr/share/applications/ggv.desktop
gconf-editor	GNOME	/usr/share/applications/gconf-editor.desktop
gconf-editor	Application	/usr/share/applications/gconf-editor.desktop
gconf-editor	System	/usr/share/applications/gconf-editor.desktop
dia-gnome	GNOME	/usr/share/applications/dia.desktop
dia-gnome	Application	/usr/share/applications/dia.desktop
dia-gnome	Graphics	/usr/share/applications/dia.desktop
filmgimp	Application	/usr/share/applications/filmgimp.desktop
filmgimp	Graphics	/usr/share/applications/filmgimp.desktop
filmgimp	RasterGraphics	/usr/share/applications/filmgimp.desktop
wxcas	Application	/usr/share/applications/wxcas.desktop
wxcas	Network	/usr/share/applications/wxcas.desktop
gnome-terminal	GNOME	/usr/share/applications/gnome-terminal.desktop
gnome-terminal	Application	/usr/share/applications/gnome-terminal.desktop
gnome-terminal	System	/usr/share/applications/gnome-terminal.desktop
gnome-terminal	Utility	/usr/share/applications/gnome-terminal.desktop
gnome-terminal	TerminalEmulator	/usr/share/applications/gnome-terminal.desktop
emacs21	Application	/usr/share/applications/emacs21.desktop
emacs21	Utility	/usr/share/applications/emacs21.desktop
emacs21	TextEditor	/usr/share/applications/emacs21.desktop
vumeter	GNOME	/usr/share/applications/reclevel.desktop
vumeter	Application	/usr/share/applications/reclevel.desktop
vumeter	AudioVideo	/usr/share/applications/reclevel.desktop
gperiodic	Application	/usr/share/applications/gperiodic.desktop
gperiodic	Education	/usr/share/applications/gperiodic.desktop
gperiodic	Chemestry	/usr/share/applications/gperiodic.desktop
gperiodic	Physics	/usr/share/applications/gperiodic.desktop
gnome-volume-control	Application	/usr/share/applications/gnome-volume-control.desktop
gnome-volume-control	AudioVideo	/usr/share/applications/gnome-volume-control.desktop
gnome-volume-control	X-Ximian-Main	/usr/share/applications/gnome-volume-control.desktop
gnome-volume-control	X-Red-Hat-Base	/usr/share/applications/gnome-volume-control.desktop
gnome-cd	GNOME	/usr/share/applications/gnome-cd.desktop
gnome-cd	Application	/usr/share/applications/gnome-cd.desktop
gnome-cd	AudioVideo	/usr/share/applications/gnome-cd.desktop
gnome-cd	X-Ximian-Main	/usr/share/applications/gnome-cd.desktop
gnome-cd	X-Red-Hat-Base	/usr/share/applications/gnome-cd.desktop
gnome-sound-recorder	GNOME	/usr/share/applications/gnome-sound-recorder.desktop
gnome-sound-recorder	Application	/usr/share/applications/gnome-sound-recorder.desktop
gnome-sound-recorder	AudioVideo	/usr/share/applications/gnome-sound-recorder.desktop
gcalctool	GNOME	/usr/share/applications/gcalctool.desktop
gcalctool	Application	/usr/share/applications/gcalctool.desktop
gcalctool	Utility	/usr/share/applications/gcalctool.desktop
ooimpress	Application	/usr/share/applications/ooo645impress.desktop
ooimpress	Office	/usr/share/applications/ooo645impress.desktop
realplayer	Application	/usr/share/applications/realplayer.desktop
realplayer	AudioVideo	/usr/share/applications/realplayer.desktop
gimp-remote-2.0	Application	/usr/share/applications/gimp-2.0.desktop
gimp-remote-2.0	Graphics	/usr/share/applications/gimp-2.0.desktop
gimp-remote-2.0	RasterGraphics	/usr/share/applications/gimp-2.0.desktop
kcmshell	Qt	/usr/share/applications/kde/khtml_plugins.desktop
kcmshell	KDE	/usr/share/applications/kde/khtml_plugins.desktop
kcmshell	X-KDE-settings-webbrowsing	/usr/share/applications/kde/khtml_plugins.desktop
kcmshell	X-KDE-settings-components	/usr/share/applications/kde/kresources.desktop
umbrello	Qt	/usr/share/applications/kde/umbrello.desktop
umbrello	KDE	/usr/share/applications/kde/umbrello.desktop
umbrello	Development	/usr/share/applications/kde/umbrello.desktop
amor	Qt	/usr/share/applications/kde/amor.desktop
amor	KDE	/usr/share/applications/kde/amor.desktop
amor	Amusement	/usr/share/applications/kde/amor.desktop
ark	Qt	/usr/share/applications/kde/ark.desktop
ark	KDE	/usr/share/applications/kde/ark.desktop
ark	Utility	/usr/share/applications/kde/ark.desktop
kcmshell	Settings	/usr/share/applications/kde/kcmkicker.desktop
kfmclient	Qt	/usr/share/applications/kde/Home.desktop
kfmclient	KDE	/usr/share/applications/kde/Home.desktop
kfmclient	Core	/usr/share/applications/kde/Home.desktop
kfmclient	System	/usr/share/applications/kde/kfmclient_dir.desktop
appletproxy	Qt	/usr/share/applications/kde/knewsticker-standalone.desktop
appletproxy	KDE	/usr/share/applications/kde/knewsticker-standalone.desktop
appletproxy	Network	/usr/share/applications/kde/knewsticker-standalone.desktop
appletproxy	X-KDE-More	/usr/share/applications/kde/knewsticker-standalone.desktop
kfmclient	Network	/usr/share/applications/kde/konqbrowser.desktop
konqueror	Qt	/usr/share/applications/kde/konquerorsu.desktop
konqueror	KDE	/usr/share/applications/kde/konquerorsu.desktop
konqueror	System	/usr/share/applications/kde/konquerorsu.desktop
konqueror	X-KDE-More	/usr/share/applications/kde/konquerorsu.desktop
ksysguard	Qt	/usr/share/applications/kde/ksysguard.desktop
ksysguard	KDE	/usr/share/applications/kde/ksysguard.desktop
ksysguard	System	/usr/share/applications/kde/ksysguard.desktop
kate	Qt	/usr/share/applications/kde/kate.desktop
kate	KDE	/usr/share/applications/kde/kate.desktop
kate	TextEditor	/usr/share/applications/kde/kate.desktop
kwrite	Qt	/usr/share/applications/kde/kwrite.desktop
kwrite	KDE	/usr/share/applications/kde/kwrite.desktop
kwrite	TextEditor	/usr/share/applications/kde/kwrite.desktop
kcalc	Qt	/usr/share/applications/kde/kcalc.desktop
kcalc	KDE	/usr/share/applications/kde/kcalc.desktop
kcalc	Utility	/usr/share/applications/kde/kcalc.desktop
kcharselect	Qt	/usr/share/applications/kde/KCharSelect.desktop
kcharselect	KDE	/usr/share/applications/kde/KCharSelect.desktop
kcharselect	Utility	/usr/share/applications/kde/KCharSelect.desktop
kcharselect	X-KDE-More	/usr/share/applications/kde/KCharSelect.desktop
kcmshell	X-KDE-settings-peripherals	/usr/share/applications/kde/kcmlirc.desktop
kdict	Qt	/usr/share/applications/kde/kdict.desktop
kdict	KDE	/usr/share/applications/kde/kdict.desktop
kdict	Utility	/usr/share/applications/kde/kdict.desktop
kget	Qt	/usr/share/applications/kde/kget.desktop
kget	KDE	/usr/share/applications/kde/kget.desktop
kget	Network	/usr/share/applications/kde/kget.desktop
kppplogview	Qt	/usr/share/applications/kde/kppplogview.desktop
kppplogview	KDE	/usr/share/applications/kde/kppplogview.desktop
kppplogview	Network	/usr/share/applications/kde/kppplogview.desktop
kppplogview	X-KDE-More	/usr/share/applications/kde/kppplogview.desktop
kppp	Qt	/usr/share/applications/kde/Kppp.desktop
kppp	KDE	/usr/share/applications/kde/Kppp.desktop
kppp	Network	/usr/share/applications/kde/Kppp.desktop
kwifimanager	Qt	/usr/share/applications/kde/kwifimanager.desktop
kwifimanager	KDE	/usr/share/applications/kde/kwifimanager.desktop
kwifimanager	Network	/usr/share/applications/kde/kwifimanager.desktop
kwifimanager	X-KDE-More	/usr/share/applications/kde/kwifimanager.desktop
krdc	Qt	/usr/share/applications/kde/krdc.desktop
krdc	KDE	/usr/share/applications/kde/krdc.desktop
krdc	Network	/usr/share/applications/kde/krdc.desktop
kcmshell	X-KDE-settings-network	/usr/share/applications/kde/kcmkrfb.desktop
krfb	Qt	/usr/share/applications/kde/krfb.desktop
krfb	KDE	/usr/share/applications/kde/krfb.desktop
krfb	System	/usr/share/applications/kde/krfb.desktop
ksirc	Qt	/usr/share/applications/kde/ksirc.desktop
ksirc	KDE	/usr/share/applications/kde/ksirc.desktop
ksirc	Network	/usr/share/applications/kde/ksirc.desktop
kregexpeditor	Qt	/usr/share/applications/kde/kregexpeditor.desktop
kregexpeditor	KDE	/usr/share/applications/kde/kregexpeditor.desktop
kregexpeditor	Utility	/usr/share/applications/kde/kregexpeditor.desktop
kregexpeditor	X-KDE-More	/usr/share/applications/kde/kregexpeditor.desktop
kdepasswd	Qt	/usr/share/applications/kde/kdepasswd.desktop
kdepasswd	KDE	/usr/share/applications/kde/kdepasswd.desktop
kdepasswd	Settings	/usr/share/applications/kde/kdepasswd.desktop
kcmshell	X-KDE-settings-system	/usr/share/applications/kde/userinfo.desktop
kmoon	Qt	/usr/share/applications/kde/kmoon.desktop
kmoon	KDE	/usr/share/applications/kde/kmoon.desktop
kmoon	Amusement	/usr/share/applications/kde/kmoon.desktop
kodo	Qt	/usr/share/applications/kde/kodo.desktop
kodo	KDE	/usr/share/applications/kde/kodo.desktop
kodo	Amusement	/usr/share/applications/kde/kodo.desktop
kteatime	Qt	/usr/share/applications/kde/kteatime.desktop
kteatime	KDE	/usr/share/applications/kde/kteatime.desktop
kteatime	Amusement	/usr/share/applications/kde/kteatime.desktop
kworldclock	Qt	/usr/share/applications/kde/kworldclock.desktop
kworldclock	KDE	/usr/share/applications/kde/kworldclock.desktop
kworldclock	Amusement	/usr/share/applications/kde/kworldclock.desktop
kcmshell	X-KDE-information	/usr/share/applications/kde/kcmdf.desktop
kdf	Qt	/usr/share/applications/kde/kdf.desktop
kdf	KDE	/usr/share/applications/kde/kdf.desktop
kdf	System	/usr/share/applications/kde/kdf.desktop
kdf	X-KDE-More	/usr/share/applications/kde/kdf.desktop
kwikdisk	Qt	/usr/share/applications/kde/kwikdisk.desktop
kwikdisk	KDE	/usr/share/applications/kde/kwikdisk.desktop
kwikdisk	System	/usr/share/applications/kde/kwikdisk.desktop
kwikdisk	X-KDE-More	/usr/share/applications/kde/kwikdisk.desktop
kedit	Qt	/usr/share/applications/kde/KEdit.desktop
kedit	KDE	/usr/share/applications/kde/KEdit.desktop
kedit	TextEditor	/usr/share/applications/kde/KEdit.desktop
kfloppy	Qt	/usr/share/applications/kde/KFloppy.desktop
kfloppy	KDE	/usr/share/applications/kde/KFloppy.desktop
kfloppy	Utility	/usr/share/applications/kde/KFloppy.desktop
kgpg	Qt	/usr/share/applications/kde/kgpg.desktop
kgpg	KDE	/usr/share/applications/kde/kgpg.desktop
kgpg	Utility	/usr/share/applications/kde/kgpg.desktop
khexedit	Qt	/usr/share/applications/kde/khexedit.desktop
khexedit	KDE	/usr/share/applications/kde/khexedit.desktop
khexedit	Utility	/usr/share/applications/kde/khexedit.desktop
khexedit	X-KDE-More	/usr/share/applications/kde/khexedit.desktop
kjots	Qt	/usr/share/applications/kde/Kjots.desktop
kjots	KDE	/usr/share/applications/kde/Kjots.desktop
kjots	Utility	/usr/share/applications/kde/Kjots.desktop
kjots	X-KDE-More	/usr/share/applications/kde/Kjots.desktop
kcmshell	X-KDE-settings-power	/usr/share/applications/kde/laptop.desktop
kcmshell	X-KDE-settings-security	/usr/share/applications/kde/kwalletconfig.desktop
ktimer	Qt	/usr/share/applications/kde/ktimer.desktop
ktimer	KDE	/usr/share/applications/kde/ktimer.desktop
ktimer	Utility	/usr/share/applications/kde/ktimer.desktop
ktimer	X-KDE-More	/usr/share/applications/kde/ktimer.desktop
atlantikdesigner	Qt	/usr/share/applications/kde/atlantikdesigner.desktop
atlantikdesigner	KDE	/usr/share/applications/kde/atlantikdesigner.desktop
atlantikdesigner	Game	/usr/share/applications/kde/atlantikdesigner.desktop
atlantikdesigner	BoardGame	/usr/share/applications/kde/atlantikdesigner.desktop
kwalletmanager	Qt	/usr/share/applications/kde/kwalletmanager.desktop
kwalletmanager	KDE	/usr/share/applications/kde/kwalletmanager.desktop
kwalletmanager	Settings	/usr/share/applications/kde/kwalletmanager.desktop
artsbuilder	Qt	/usr/share/applications/kde/artsbuilder.desktop
artsbuilder	KDE	/usr/share/applications/kde/artsbuilder.desktop
artsbuilder	AudioVideo	/usr/share/applications/kde/artsbuilder.desktop
artsbuilder	X-KDE-More	/usr/share/applications/kde/artsbuilder.desktop
artscontrol	Qt	/usr/share/applications/kde/artscontrol.desktop
artscontrol	KDE	/usr/share/applications/kde/artscontrol.desktop
artscontrol	AudioVideo	/usr/share/applications/kde/artscontrol.desktop
artscontrol	X-KDE-More	/usr/share/applications/kde/artscontrol.desktop
juk	Qt	/usr/share/applications/kde/juk.desktop
juk	KDE	/usr/share/applications/kde/juk.desktop
juk	AudioVideo	/usr/share/applications/kde/juk.desktop
kaboodle	Qt	/usr/share/applications/kde/kaboodle.desktop
kaboodle	KDE	/usr/share/applications/kde/kaboodle.desktop
kaboodle	AudioVideo	/usr/share/applications/kde/kaboodle.desktop
kcmshell	X-KDE-settings-sound	/usr/share/applications/kde/libkcddb.desktop
kscd	Qt	/usr/share/applications/kde/kscd.desktop
kscd	KDE	/usr/share/applications/kde/kscd.desktop
kscd	AudioVideo	/usr/share/applications/kde/kscd.desktop
kaudiocreator	Qt	/usr/share/applications/kde/kaudiocreator.desktop
kaudiocreator	KDE	/usr/share/applications/kde/kaudiocreator.desktop
kaudiocreator	AudioVideo	/usr/share/applications/kde/kaudiocreator.desktop
kcmshell	X-KDE-settings-looknfeel	/usr/share/applications/kde/kwindecoration.desktop
kcmshell	X-KDE-settings-desktop	/usr/share/applications/kde/kwinoptions.desktop
kmid	Qt	/usr/share/applications/kde/kmid.desktop
kmid	KDE	/usr/share/applications/kde/kmid.desktop
kmid	AudioVideo	/usr/share/applications/kde/kmid.desktop
kmid	X-KDE-More	/usr/share/applications/kde/kmid.desktop
kmix	Qt	/usr/share/applications/kde/kmix.desktop
kmix	KDE	/usr/share/applications/kde/kmix.desktop
kmix	AudioVideo	/usr/share/applications/kde/kmix.desktop
krec	Qt	/usr/share/applications/kde/krec.desktop
krec	KDE	/usr/share/applications/kde/krec.desktop
krec	AudioVideo	/usr/share/applications/kde/krec.desktop
noatun	Qt	/usr/share/applications/kde/noatun.desktop
noatun	KDE	/usr/share/applications/kde/noatun.desktop
noatun	AudioVideo	/usr/share/applications/kde/noatun.desktop
kig	Qt	/usr/share/applications/kde/kig.desktop
kig	KDE	/usr/share/applications/kde/kig.desktop
kig	Education	/usr/share/applications/kde/kig.desktop
kig	Math	/usr/share/applications/kde/kig.desktop
kpalmdoc	Qt	/usr/share/applications/kde/kpalmdoc.desktop
kpalmdoc	KDE	/usr/share/applications/kde/kpalmdoc.desktop
kpalmdoc	Utility	/usr/share/applications/kde/kpalmdoc.desktop
kpalmdoc	X-KDE-More	/usr/share/applications/kde/kpalmdoc.desktop
kpilot	Qt	/usr/share/applications/kde/kpilot.desktop
kpilot	KDE	/usr/share/applications/kde/kpilot.desktop
kpilot	Utility	/usr/share/applications/kde/kpilot.desktop
kpilotDaemon	Qt	/usr/share/applications/kde/kpilotdaemon.desktop
kpilotDaemon	KDE	/usr/share/applications/kde/kpilotdaemon.desktop
kpilotDaemon	Utility	/usr/share/applications/kde/kpilotdaemon.desktop
korganizer	Qt	/usr/share/applications/kde/korganizer.desktop
korganizer	KDE	/usr/share/applications/kde/korganizer.desktop
korganizer	Office	/usr/share/applications/kde/korganizer.desktop
kalarm	Qt	/usr/share/applications/kde/kalarm.desktop
kalarm	KDE	/usr/share/applications/kde/kalarm.desktop
kalarm	Utility	/usr/share/applications/kde/kalarm.desktop
kalarm	X-KDE-More	/usr/share/applications/kde/kalarm.desktop
kaddressbook	Qt	/usr/share/applications/kde/kaddressbook.desktop
kaddressbook	KDE	/usr/share/applications/kde/kaddressbook.desktop
kaddressbook	Office	/usr/share/applications/kde/kaddressbook.desktop
kandy	Qt	/usr/share/applications/kde/kandy.desktop
kandy	KDE	/usr/share/applications/kde/kandy.desktop
kandy	Utility	/usr/share/applications/kde/kandy.desktop
kandy	X-KDE-More	/usr/share/applications/kde/kandy.desktop
karm	Qt	/usr/share/applications/kde/karm.desktop
karm	KDE	/usr/share/applications/kde/karm.desktop
karm	Utility	/usr/share/applications/kde/karm.desktop
karm	X-KDE-More	/usr/share/applications/kde/karm.desktop
ktnef	Qt	/usr/share/applications/kde/ktnef.desktop
ktnef	KDE	/usr/share/applications/kde/ktnef.desktop
ktnef	Utility	/usr/share/applications/kde/ktnef.desktop
ktnef	X-KDE-More	/usr/share/applications/kde/ktnef.desktop
kmail	Qt	/usr/share/applications/kde/KMail.desktop
kmail	KDE	/usr/share/applications/kde/KMail.desktop
kmail	Network	/usr/share/applications/kde/KMail.desktop
knode	Qt	/usr/share/applications/kde/KNode.desktop
knode	KDE	/usr/share/applications/kde/KNode.desktop
knode	Network	/usr/share/applications/kde/KNode.desktop
knotes	Qt	/usr/share/applications/kde/knotes.desktop
knotes	KDE	/usr/share/applications/kde/knotes.desktop
knotes	Utility	/usr/share/applications/kde/knotes.desktop
kdialog	Qt	/usr/share/applications/kde/konsolekalendar.desktop
kdialog	KDE	/usr/share/applications/kde/konsolekalendar.desktop
kdialog	Utility	/usr/share/applications/kde/konsolekalendar.desktop
kdialog	X-KDE-More	/usr/share/applications/kde/konsolekalendar.desktop
kontact	Qt	/usr/share/applications/kde/Kontact.desktop
kontact	KDE	/usr/share/applications/kde/Kontact.desktop
kontact	Office	/usr/share/applications/kde/Kontact.desktop
korn	Qt	/usr/share/applications/kde/KOrn.desktop
korn	KDE	/usr/share/applications/kde/KOrn.desktop
korn	Network	/usr/share/applications/kde/KOrn.desktop
korn	X-KDE-More	/usr/share/applications/kde/KOrn.desktop
atlantik	Qt	/usr/share/applications/kde/atlantik.desktop
atlantik	KDE	/usr/share/applications/kde/atlantik.desktop
atlantik	Game	/usr/share/applications/kde/atlantik.desktop
atlantik	BoardGame	/usr/share/applications/kde/atlantik.desktop
kcmshell	X-KDE-settings-accessibility	/usr/share/applications/kde/keyboard_layout.desktop
cervisia	Qt	/usr/share/applications/kde/cervisia.desktop
cervisia	KDE	/usr/share/applications/kde/cervisia.desktop
cervisia	Development	/usr/share/applications/kde/cervisia.desktop
flashkard	Qt	/usr/share/applications/kde/flashkard.desktop
flashkard	KDE	/usr/share/applications/kde/flashkard.desktop
flashkard	Education	/usr/share/applications/kde/flashkard.desktop
konsole	Qt	/usr/share/applications/kde/konsole.desktop
konsole	KDE	/usr/share/applications/kde/konsole.desktop
konsole	System	/usr/share/applications/kde/konsole.desktop
konsole	TerminalEmulator	/usr/share/applications/kde/konsole.desktop
konsole	X-KDE-More	/usr/share/applications/kde/konsolesu.desktop
kalzium	Qt	/usr/share/applications/kde/kalzium.desktop
kalzium	KDE	/usr/share/applications/kde/kalzium.desktop
kalzium	Education	/usr/share/applications/kde/kalzium.desktop
kalzium	Science	/usr/share/applications/kde/kalzium.desktop
kappfinder	Qt	/usr/share/applications/kde/kappfinder.desktop
kappfinder	KDE	/usr/share/applications/kde/kappfinder.desktop
kappfinder	Settings	/usr/share/applications/kde/kappfinder.desktop
kasteroids	Qt	/usr/share/applications/kde/kasteroids.desktop
kasteroids	KDE	/usr/share/applications/kde/kasteroids.desktop
kasteroids	Game	/usr/share/applications/kde/kasteroids.desktop
kasteroids	ArcadeGame	/usr/share/applications/kde/kasteroids.desktop
kcontrol	Qt	/usr/share/applications/kde/KControl.desktop
kcontrol	KDE	/usr/share/applications/kde/KControl.desktop
kcontrol	Settings	/usr/share/applications/kde/KControl.desktop
krandrtray	Qt	/usr/share/applications/kde/krandrtray.desktop
krandrtray	KDE	/usr/share/applications/kde/krandrtray.desktop
krandrtray	System	/usr/share/applications/kde/krandrtray.desktop
catalogmanager	Qt	/usr/share/applications/kde/catalogmanager.desktop
catalogmanager	KDE	/usr/share/applications/kde/catalogmanager.desktop
catalogmanager	Development	/usr/share/applications/kde/catalogmanager.desktop
kfind	Qt	/usr/share/applications/kde/Kfind.desktop
kfind	KDE	/usr/share/applications/kde/Kfind.desktop
kfind	Core	/usr/share/applications/kde/Kfind.desktop
katomic	Qt	/usr/share/applications/kde/katomic.desktop
katomic	KDE	/usr/share/applications/kde/katomic.desktop
katomic	Game	/usr/share/applications/kde/katomic.desktop
katomic	StrategyGame	/usr/share/applications/kde/katomic.desktop
kbabeldict	Qt	/usr/share/applications/kde/kbabeldict.desktop
kbabeldict	KDE	/usr/share/applications/kde/kbabeldict.desktop
kbabeldict	Development	/usr/share/applications/kde/kbabeldict.desktop
kbabel	Qt	/usr/share/applications/kde/kbabel.desktop
kbabel	KDE	/usr/share/applications/kde/kbabel.desktop
kbabel	Development	/usr/share/applications/kde/kbabel.desktop
kcolorchooser	Qt	/usr/share/applications/kde/kcolorchooser.desktop
kcolorchooser	KDE	/usr/share/applications/kde/kcolorchooser.desktop
kcolorchooser	Graphics	/usr/share/applications/kde/kcolorchooser.desktop
kcolorchooser	X-KDE-More	/usr/share/applications/kde/kcolorchooser.desktop
kbackgammon	Qt	/usr/share/applications/kde/kbackgammon.desktop
kbackgammon	KDE	/usr/share/applications/kde/kbackgammon.desktop
kbackgammon	Game	/usr/share/applications/kde/kbackgammon.desktop
kbackgammon	BoardGame	/usr/share/applications/kde/kbackgammon.desktop
kbattleship	Qt	/usr/share/applications/kde/kbattleship.desktop
kbattleship	KDE	/usr/share/applications/kde/kbattleship.desktop
kbattleship	Game	/usr/share/applications/kde/kbattleship.desktop
kbattleship	StrategyGame	/usr/share/applications/kde/kbattleship.desktop
kblackbox	Qt	/usr/share/applications/kde/kblackbox.desktop
kblackbox	KDE	/usr/share/applications/kde/kblackbox.desktop
kblackbox	Game	/usr/share/applications/kde/kblackbox.desktop
kblackbox	BoardGame	/usr/share/applications/kde/kblackbox.desktop
kbounce	Qt	/usr/share/applications/kde/kbounce.desktop
kbounce	KDE	/usr/share/applications/kde/kbounce.desktop
kbounce	Game	/usr/share/applications/kde/kbounce.desktop
kbounce	ArcadeGame	/usr/share/applications/kde/kbounce.desktop
kbruch	Qt	/usr/share/applications/kde/kbruch.desktop
kbruch	KDE	/usr/share/applications/kde/kbruch.desktop
kbruch	Education	/usr/share/applications/kde/kbruch.desktop
kbruch	Math	/usr/share/applications/kde/kbruch.desktop
kbugbuster	Qt	/usr/share/applications/kde/kbugbuster.desktop
kbugbuster	KDE	/usr/share/applications/kde/kbugbuster.desktop
kbugbuster	Development	/usr/share/applications/kde/kbugbuster.desktop
kpersonalizer	Qt	/usr/share/applications/kde/kpersonalizer.desktop
kpersonalizer	KDE	/usr/share/applications/kde/kpersonalizer.desktop
kpersonalizer	Settings	/usr/share/applications/kde/kpersonalizer.desktop
kcoloredit	Qt	/usr/share/applications/kde/kcoloredit.desktop
kcoloredit	KDE	/usr/share/applications/kde/kcoloredit.desktop
kcoloredit	Graphics	/usr/share/applications/kde/kcoloredit.desktop
kcoloredit	X-KDE-More	/usr/share/applications/kde/kcoloredit.desktop
kcron	Qt	/usr/share/applications/kde/kcron.desktop
kcron	KDE	/usr/share/applications/kde/kcron.desktop
kcron	System	/usr/share/applications/kde/kcron.desktop
kdat	Qt	/usr/share/applications/kde/kdat.desktop
kdat	KDE	/usr/share/applications/kde/kdat.desktop
kdat	System	/usr/share/applications/kde/kdat.desktop
kdat	X-KDE-More	/usr/share/applications/kde/kdat.desktop
ksig	Qt	/usr/share/applications/kde/ksig.desktop
ksig	KDE	/usr/share/applications/kde/ksig.desktop
ksig	Utility	/usr/share/applications/kde/ksig.desktop
ksig	X-KDE-More	/usr/share/applications/kde/ksig.desktop
kpackage	Qt	/usr/share/applications/kde/kpackage.desktop
kpackage	KDE	/usr/share/applications/kde/kpackage.desktop
kpackage	System	/usr/share/applications/kde/kpackage.desktop
ksysv	Qt	/usr/share/applications/kde/ksysv.desktop
ksysv	KDE	/usr/share/applications/kde/ksysv.desktop
ksysv	System	/usr/share/applications/kde/ksysv.desktop
kuser	Qt	/usr/share/applications/kde/kuser.desktop
kuser	KDE	/usr/share/applications/kde/kuser.desktop
kuser	System	/usr/share/applications/kde/kuser.desktop
kdeprintfax	Qt	/usr/share/applications/kde/kdeprintfax.desktop
kdeprintfax	KDE	/usr/share/applications/kde/kdeprintfax.desktop
kdeprintfax	Utility	/usr/share/applications/kde/kdeprintfax.desktop
kjobviewer	Qt	/usr/share/applications/kde/kjobviewer.desktop
kjobviewer	KDE	/usr/share/applications/kde/kjobviewer.desktop
kjobviewer	Utility	/usr/share/applications/kde/kjobviewer.desktop
khelpcenter	Qt	/usr/share/applications/kde/Help.desktop
khelpcenter	KDE	/usr/share/applications/kde/Help.desktop
khelpcenter	Core	/usr/share/applications/kde/Help.desktop
klipper	Qt	/usr/share/applications/kde/klipper.desktop
klipper	KDE	/usr/share/applications/kde/klipper.desktop
klipper	Utility	/usr/share/applications/kde/klipper.desktop
kmenuedit	Qt	/usr/share/applications/kde/kmenuedit.desktop
kmenuedit	KDE	/usr/share/applications/kde/kmenuedit.desktop
kmenuedit	Settings	/usr/share/applications/kde/kmenuedit.desktop
kpager	Qt	/usr/share/applications/kde/kpager.desktop
kpager	KDE	/usr/share/applications/kde/kpager.desktop
kpager	Utility	/usr/share/applications/kde/kpager.desktop
kpager	X-KDE-More	/usr/share/applications/kde/kpager.desktop
ktip	Qt	/usr/share/applications/kde/ktip.desktop
ktip	KDE	/usr/share/applications/kde/ktip.desktop
ktip	Utility	/usr/share/applications/kde/ktip.desktop
ktip	X-KDE-More	/usr/share/applications/kde/ktip.desktop
khangman	Qt	/usr/share/applications/kde/khangman.desktop
khangman	KDE	/usr/share/applications/kde/khangman.desktop
khangman	Education	/usr/share/applications/kde/khangman.desktop
khangman	X-KDE-Edu-Language	/usr/share/applications/kde/khangman.desktop
kiten	Qt	/usr/share/applications/kde/kiten.desktop
kiten	KDE	/usr/share/applications/kde/kiten.desktop
kiten	Education	/usr/share/applications/kde/kiten.desktop
kiten	X-KDE-Edu-Language	/usr/share/applications/kde/kiten.desktop
klettres	Qt	/usr/share/applications/kde/klettres.desktop
klettres	KDE	/usr/share/applications/kde/klettres.desktop
klettres	Education	/usr/share/applications/kde/klettres.desktop
klettres	X-KDE-Edu-Language	/usr/share/applications/kde/klettres.desktop
kmessedwords	Qt	/usr/share/applications/kde/kmessedwords.desktop
kmessedwords	KDE	/usr/share/applications/kde/kmessedwords.desktop
kmessedwords	Education	/usr/share/applications/kde/kmessedwords.desktop
kmessedwords	X-KDE-Edu-Language	/usr/share/applications/kde/kmessedwords.desktop
kmplot	Qt	/usr/share/applications/kde/kmplot.desktop
kmplot	KDE	/usr/share/applications/kde/kmplot.desktop
kmplot	Education	/usr/share/applications/kde/kmplot.desktop
kmplot	Math	/usr/share/applications/kde/kmplot.desktop
kpercentage	Qt	/usr/share/applications/kde/kpercentage.desktop
kpercentage	KDE	/usr/share/applications/kde/kpercentage.desktop
kpercentage	Education	/usr/share/applications/kde/kpercentage.desktop
kpercentage	Math	/usr/share/applications/kde/kpercentage.desktop
kstars	Qt	/usr/share/applications/kde/kstars.desktop
kstars	KDE	/usr/share/applications/kde/kstars.desktop
kstars	Education	/usr/share/applications/kde/kstars.desktop
kstars	Science	/usr/share/applications/kde/kstars.desktop
kstars	Astronomy	/usr/share/applications/kde/kstars.desktop
ktouch	Qt	/usr/share/applications/kde/ktouch.desktop
ktouch	KDE	/usr/share/applications/kde/ktouch.desktop
ktouch	Education	/usr/share/applications/kde/ktouch.desktop
kverbos	Qt	/usr/share/applications/kde/kverbos.desktop
kverbos	KDE	/usr/share/applications/kde/kverbos.desktop
kverbos	Education	/usr/share/applications/kde/kverbos.desktop
kverbos	X-KDE-Edu-Language	/usr/share/applications/kde/kverbos.desktop
kvoctrain	Qt	/usr/share/applications/kde/kvoctrain.desktop
kvoctrain	KDE	/usr/share/applications/kde/kvoctrain.desktop
kvoctrain	Education	/usr/share/applications/kde/kvoctrain.desktop
kvoctrain	X-KDE-Edu-Language	/usr/share/applications/kde/kvoctrain.desktop
kenolaba	Qt	/usr/share/applications/kde/kenolaba.desktop
kenolaba	KDE	/usr/share/applications/kde/kenolaba.desktop
kenolaba	Game	/usr/share/applications/kde/kenolaba.desktop
kenolaba	BoardGame	/usr/share/applications/kde/kenolaba.desktop
kfouleggs	Qt	/usr/share/applications/kde/kfouleggs.desktop
kfouleggs	KDE	/usr/share/applications/kde/kfouleggs.desktop
kfouleggs	Game	/usr/share/applications/kde/kfouleggs.desktop
kfouleggs	ArcadeGame	/usr/share/applications/kde/kfouleggs.desktop
kgoldrunner	Qt	/usr/share/applications/kde/KGoldrunner.desktop
kgoldrunner	KDE	/usr/share/applications/kde/KGoldrunner.desktop
kgoldrunner	Game	/usr/share/applications/kde/KGoldrunner.desktop
kgoldrunner	ArcadeGame	/usr/share/applications/kde/KGoldrunner.desktop
kjumpingcube	Qt	/usr/share/applications/kde/kjumpingcube.desktop
kjumpingcube	KDE	/usr/share/applications/kde/kjumpingcube.desktop
kjumpingcube	Game	/usr/share/applications/kde/kjumpingcube.desktop
kjumpingcube	StrategyGame	/usr/share/applications/kde/kjumpingcube.desktop
klickety	Qt	/usr/share/applications/kde/klickety.desktop
klickety	KDE	/usr/share/applications/kde/klickety.desktop
klickety	Game	/usr/share/applications/kde/klickety.desktop
klickety	StrategyGame	/usr/share/applications/kde/klickety.desktop
klines	Qt	/usr/share/applications/kde/klines.desktop
klines	KDE	/usr/share/applications/kde/klines.desktop
klines	Game	/usr/share/applications/kde/klines.desktop
klines	StrategyGame	/usr/share/applications/kde/klines.desktop
kmahjongg	Qt	/usr/share/applications/kde/kmahjongg.desktop
kmahjongg	KDE	/usr/share/applications/kde/kmahjongg.desktop
kmahjongg	Game	/usr/share/applications/kde/kmahjongg.desktop
kmahjongg	BoardGame	/usr/share/applications/kde/kmahjongg.desktop
kmines	Qt	/usr/share/applications/kde/kmines.desktop
kmines	KDE	/usr/share/applications/kde/kmines.desktop
kmines	Game	/usr/share/applications/kde/kmines.desktop
kmines	StrategyGame	/usr/share/applications/kde/kmines.desktop
kolf	Qt	/usr/share/applications/kde/kolf.desktop
kolf	KDE	/usr/share/applications/kde/kolf.desktop
kolf	Game	/usr/share/applications/kde/kolf.desktop
kolf	ArcadeGame	/usr/share/applications/kde/kolf.desktop
konquest	Qt	/usr/share/applications/kde/konquest.desktop
konquest	KDE	/usr/share/applications/kde/konquest.desktop
konquest	Game	/usr/share/applications/kde/konquest.desktop
konquest	StrategyGame	/usr/share/applications/kde/konquest.desktop
kpat	Qt	/usr/share/applications/kde/kpat.desktop
kpat	KDE	/usr/share/applications/kde/kpat.desktop
kpat	Game	/usr/share/applications/kde/kpat.desktop
kpat	CardGame	/usr/share/applications/kde/kpat.desktop
kpoker	Qt	/usr/share/applications/kde/kpoker.desktop
kpoker	KDE	/usr/share/applications/kde/kpoker.desktop
kpoker	Game	/usr/share/applications/kde/kpoker.desktop
kpoker	CardGame	/usr/share/applications/kde/kpoker.desktop
kreversi	Qt	/usr/share/applications/kde/kreversi.desktop
kreversi	KDE	/usr/share/applications/kde/kreversi.desktop
kreversi	Game	/usr/share/applications/kde/kreversi.desktop
kreversi	BoardGame	/usr/share/applications/kde/kreversi.desktop
ksame	Qt	/usr/share/applications/kde/ksame.desktop
ksame	KDE	/usr/share/applications/kde/ksame.desktop
ksame	Game	/usr/share/applications/kde/ksame.desktop
ksame	StrategyGame	/usr/share/applications/kde/ksame.desktop
kshisen	Qt	/usr/share/applications/kde/kshisen.desktop
kshisen	KDE	/usr/share/applications/kde/kshisen.desktop
kshisen	Game	/usr/share/applications/kde/kshisen.desktop
kshisen	BoardGame	/usr/share/applications/kde/kshisen.desktop
ksirtet	Qt	/usr/share/applications/kde/ksirtet.desktop
ksirtet	KDE	/usr/share/applications/kde/ksirtet.desktop
ksirtet	Game	/usr/share/applications/kde/ksirtet.desktop
ksirtet	ArcadeGame	/usr/share/applications/kde/ksirtet.desktop
ksmiletris	Qt	/usr/share/applications/kde/ksmiletris.desktop
ksmiletris	KDE	/usr/share/applications/kde/ksmiletris.desktop
ksmiletris	Game	/usr/share/applications/kde/ksmiletris.desktop
ksmiletris	ArcadeGame	/usr/share/applications/kde/ksmiletris.desktop
ksnake	Qt	/usr/share/applications/kde/ksnake.desktop
ksnake	KDE	/usr/share/applications/kde/ksnake.desktop
ksnake	Game	/usr/share/applications/kde/ksnake.desktop
ksnake	ArcadeGame	/usr/share/applications/kde/ksnake.desktop
ksokoban	Qt	/usr/share/applications/kde/ksokoban.desktop
ksokoban	KDE	/usr/share/applications/kde/ksokoban.desktop
ksokoban	Game	/usr/share/applications/kde/ksokoban.desktop
ksokoban	StrategyGame	/usr/share/applications/kde/ksokoban.desktop
kspaceduel	Qt	/usr/share/applications/kde/kspaceduel.desktop
kspaceduel	KDE	/usr/share/applications/kde/kspaceduel.desktop
kspaceduel	Game	/usr/share/applications/kde/kspaceduel.desktop
kspaceduel	ArcadeGame	/usr/share/applications/kde/kspaceduel.desktop
ktron	Qt	/usr/share/applications/kde/ktron.desktop
ktron	KDE	/usr/share/applications/kde/ktron.desktop
ktron	Game	/usr/share/applications/kde/ktron.desktop
ktron	ArcadeGame	/usr/share/applications/kde/ktron.desktop
ktuberling	Qt	/usr/share/applications/kde/ktuberling.desktop
ktuberling	KDE	/usr/share/applications/kde/ktuberling.desktop
ktuberling	Game	/usr/share/applications/kde/ktuberling.desktop
ktuberling	X-KDE-KidsGame	/usr/share/applications/kde/ktuberling.desktop
kwin4	Qt	/usr/share/applications/kde/kwin4.desktop
kwin4	KDE	/usr/share/applications/kde/kwin4.desktop
kwin4	Game	/usr/share/applications/kde/kwin4.desktop
kwin4	BoardGame	/usr/share/applications/kde/kwin4.desktop
lskat	Qt	/usr/share/applications/kde/lskat.desktop
lskat	KDE	/usr/share/applications/kde/lskat.desktop
lskat	Game	/usr/share/applications/kde/lskat.desktop
lskat	CardGame	/usr/share/applications/kde/lskat.desktop
kviewshell	Qt	/usr/share/applications/kde/kdvi.desktop
kviewshell	KDE	/usr/share/applications/kde/kdvi.desktop
kviewshell	Graphics	/usr/share/applications/kde/kdvi.desktop
kfax	Qt	/usr/share/applications/kde/kfax.desktop
kfax	KDE	/usr/share/applications/kde/kfax.desktop
kfax	Graphics	/usr/share/applications/kde/kfax.desktop
kghostview	Qt	/usr/share/applications/kde/kghostview.desktop
kghostview	KDE	/usr/share/applications/kde/kghostview.desktop
kghostview	Graphics	/usr/share/applications/kde/kghostview.desktop
kiconedit	Qt	/usr/share/applications/kde/kiconedit.desktop
kiconedit	KDE	/usr/share/applications/kde/kiconedit.desktop
kiconedit	Graphics	/usr/share/applications/kde/kiconedit.desktop
kiconedit	X-KDE-More	/usr/share/applications/kde/kiconedit.desktop
kooka	Qt	/usr/share/applications/kde/kooka.desktop
kooka	KDE	/usr/share/applications/kde/kooka.desktop
kooka	Graphics	/usr/share/applications/kde/kooka.desktop
kpaint	Qt	/usr/share/applications/kde/kpaint.desktop
kpaint	KDE	/usr/share/applications/kde/kpaint.desktop
kpaint	Graphics	/usr/share/applications/kde/kpaint.desktop
kpdf	Qt	/usr/share/applications/kde/kpdf.desktop
kpdf	KDE	/usr/share/applications/kde/kpdf.desktop
kpdf	Graphics	/usr/share/applications/kde/kpdf.desktop
kpdf	PDFViewer	/usr/share/applications/kde/kpdf.desktop
kpovmodeler	Qt	/usr/share/applications/kde/kpovmodeler.desktop
kpovmodeler	KDE	/usr/share/applications/kde/kpovmodeler.desktop
kpovmodeler	Graphics	/usr/share/applications/kde/kpovmodeler.desktop
kruler	Qt	/usr/share/applications/kde/kruler.desktop
kruler	KDE	/usr/share/applications/kde/kruler.desktop
kruler	Graphics	/usr/share/applications/kde/kruler.desktop
kruler	X-KDE-More	/usr/share/applications/kde/kruler.desktop
ksnapshot	Qt	/usr/share/applications/kde/ksnapshot.desktop
ksnapshot	KDE	/usr/share/applications/kde/ksnapshot.desktop
ksnapshot	Graphics	/usr/share/applications/kde/ksnapshot.desktop
ksnapshot	X-KDE-More	/usr/share/applications/kde/ksnapshot.desktop
kuickshow	Qt	/usr/share/applications/kde/kuickshow.desktop
kuickshow	KDE	/usr/share/applications/kde/kuickshow.desktop
kuickshow	Graphics	/usr/share/applications/kde/kuickshow.desktop
kview	Qt	/usr/share/applications/kde/kview.desktop
kview	KDE	/usr/share/applications/kde/kview.desktop
kview	Graphics	/usr/share/applications/kde/kview.desktop
kompare	Qt	/usr/share/applications/kde/kompare.desktop
kompare	KDE	/usr/share/applications/kde/kompare.desktop
kompare	Development	/usr/share/applications/kde/kompare.desktop
kuiviewer	Qt	/usr/share/applications/kde/kuiviewer.desktop
kuiviewer	KDE	/usr/share/applications/kde/kuiviewer.desktop
kuiviewer	Development	/usr/share/applications/kde/kuiviewer.desktop
kcachegrind	Qt	/usr/share/applications/kde/kcachegrind.desktop
kcachegrind	KDE	/usr/share/applications/kde/kcachegrind.desktop
kcachegrind	Development	/usr/share/applications/kde/kcachegrind.desktop
kile	Qt	/usr/share/applications/kde/kile.desktop
kile	KDE	/usr/share/applications/kde/kile.desktop
kile	Office	/usr/share/applications/kde/kile.desktop
smb4k	Qt	/usr/share/applications/kde/smb4k.desktop
smb4k	KDE	/usr/share/applications/kde/smb4k.desktop
smb4k	Utility	/usr/share/applications/kde/smb4k.desktop
gnome-remote-shell	Application	/usr/share/applications/gnome-network-utilities.desktop
gnome-remote-shell	Network	/usr/share/applications/gnome-network-utilities.desktop
gnome-netinfo	Application	/usr/share/applications/gnome-netinfo.desktop
gnome-netinfo	Network	/usr/share/applications/gnome-netinfo.desktop
grip	Application	/usr/share/applications/grip.desktop
grip	AudioVideo	/usr/share/applications/grip.desktop
oocalc	Application	/usr/share/applications/ooo645calc.desktop
oocalc	Office	/usr/share/applications/ooo645calc.desktop
oomath	Application	/usr/share/applications/ooo645math.desktop
oomath	Office	/usr/share/applications/ooo645math.desktop
oopadmin	Application	/usr/share/applications/ooo645printeradmin.desktop
oopadmin	Office	/usr/share/applications/ooo645printeradmin.desktop
oodraw	Application	/usr/share/applications/ooo645draw.desktop
oodraw	Office	/usr/share/applications/ooo645draw.desktop
ooffice	Application	/usr/share/applications/ooo645template.desktop
ooffice	Office	/usr/share/applications/ooo645template.desktop
gmfsk	Application	/usr/share/applications/gmfsk.desktop
gmfsk	Ham Radio	/usr/share/applications/gmfsk.desktop
tsclient	Application	/usr/share/applications/tsclient.desktop
tsclient	Network	/usr/share/applications/tsclient.desktop
tsclient	X-Red-Hat-Base	/usr/share/applications/tsclient.desktop
blender	Application	/usr/share/applications/blender.desktop
blender	Graphics	/usr/share/applications/blender.desktop
mlv	GNOME	/usr/share/applications/mlview.desktop
mlv	Application	/usr/share/applications/mlview.desktop
mlv	Office	/usr/share/applications/mlview.desktop
mlv	TextEditor	/usr/share/applications/mlview.desktop
conglomerate	Application	/usr/share/applications/conglomerate.desktop
conglomerate	Office	/usr/share/applications/conglomerate.desktop
conglomerate	TextEditor	/usr/share/applications/conglomerate.desktop
mozilla-thunderbird	Application	/usr/share/applications/mozilla-thunderbird-pm.desktop
mozilla-thunderbird	Network	/usr/share/applications/mozilla-thunderbird-pm.desktop
amule	Application	/usr/share/applications/amule.desktop
amule	Network	/usr/share/applications/amule.desktop
scribus	Office	/usr/share/applications/scribus.desktop
scribus	Application	/usr/share/applications/scribus.desktop
gksuexec	Application	/usr/share/applications/gksuexec.desktop
gksuexec	System	/usr/share/applications/gksuexec.desktop
firefox	Application	/usr/share/applications/mozilla-firefox.desktop
firefox	Network	/usr/share/applications/mozilla-firefox.desktop
gmplayer	Application	/usr/share/applications/mplayer.desktop
gmplayer	AudioVideo	/usr/share/applications/mplayer.desktop
slix-central	System	/usr/share/applications/slix-central.desktop
slix-central	Utility	/usr/share/applications/slix-central.desktop
slix-central	Monitor	/usr/share/applications/slix-central.desktop
slix-central	TerminalEmulator	/usr/share/applications/slix-central.desktop
gv4l	GNOME	/usr/share/applications/gnome-gv4l.desktop
gv4l	Application	/usr/share/applications/gnome-gv4l.desktop
gv4l	AudioVideo	/usr/share/applications/gnome-gv4l.desktop
cyca-central	System	/usr/share/applications/cyca-central.desktop
cyca-central	Utility	/usr/share/applications/cyca-central.desktop
cyca-central	Monitor	/usr/share/applications/cyca-central.desktop
cyca-central	TerminalEmulator	/usr/share/applications/cyca-central.desktop
kxmleditor	Application	/usr/share/applnk/Applications/kxmleditor.desktop
kxmleditor	Development	/usr/share/applnk/Applications/kxmleditor.desktop
kxmleditor	TextEditor	/usr/share/applnk/Applications/kxmleditor.desktop
kxmleditor	KDE	/usr/share/applnk/Applications/kxmleditor.desktop
kinfocenter	Qt	/usr/share/applnk/System/kinfocenter.desktop
kinfocenter	KDE	/usr/share/applnk/System/kinfocenter.desktop
kinfocenter	System	/usr/share/applnk/System/kinfocenter.desktop
kplayer	AudioVideo	/usr/share/applnk/Multimedia/kplayer.desktop
kplayer	Player	/usr/share/applnk/Multimedia/kplayer.desktop
kplayer	Music	/usr/share/applnk/Multimedia/kplayer.desktop
kplayer	KDE	/usr/share/applnk/Multimedia/kplayer.desktop
rosegarden4	AudioVideo	/usr/share/applnk/Multimedia/rosegarden.desktop
rosegarden4	Application	/usr/share/applnk/Multimedia/rosegarden.desktop
rosegarden4	X-SuSE-Sequencer	/usr/share/applnk/Multimedia/rosegarden.desktop
rosegarden4	X-Red-Hat-Base	/usr/share/applnk/Multimedia/rosegarden.desktop
kthesaurus	Qt	/usr/share/applnk/Office/KThesaurus.desktop
kthesaurus	KDE	/usr/share/applnk/Office/KThesaurus.desktop
kthesaurus	Office	/usr/share/applnk/Office/KThesaurus.desktop
kformula	Qt	/usr/share/applnk/Office/kformula.desktop
kformula	KDE	/usr/share/applnk/Office/kformula.desktop
kformula	Office	/usr/share/applnk/Office/kformula.desktop
karbon	Qt	/usr/share/applnk/Office/karbon.desktop
karbon	KDE	/usr/share/applnk/Office/karbon.desktop
karbon	Office	/usr/share/applnk/Office/karbon.desktop
kchart	Qt	/usr/share/applnk/Office/kchart.desktop
kchart	KDE	/usr/share/applnk/Office/kchart.desktop
kchart	Office	/usr/share/applnk/Office/kchart.desktop
kpresenter	Qt	/usr/share/applnk/Office/kpresenter.desktop
kpresenter	KDE	/usr/share/applnk/Office/kpresenter.desktop
kpresenter	Office	/usr/share/applnk/Office/kpresenter.desktop
kivio	Qt	/usr/share/applnk/Office/kivio.desktop
kivio	KDE	/usr/share/applnk/Office/kivio.desktop
kivio	Office	/usr/share/applnk/Office/kivio.desktop
koshell	Qt	/usr/share/applnk/Office/koshell.desktop
koshell	KDE	/usr/share/applnk/Office/koshell.desktop
koshell	Office	/usr/share/applnk/Office/koshell.desktop
kudesigner	Qt	/usr/share/applnk/Office/kudesigner.desktop
kudesigner	KDE	/usr/share/applnk/Office/kudesigner.desktop
kudesigner	Office	/usr/share/applnk/Office/kudesigner.desktop
kspread	Qt	/usr/share/applnk/Office/kspread.desktop
kspread	KDE	/usr/share/applnk/Office/kspread.desktop
kspread	Office	/usr/share/applnk/Office/kspread.desktop
kugar	Qt	/usr/share/applnk/Office/kugar.desktop
kugar	KDE	/usr/share/applnk/Office/kugar.desktop
kugar	Office	/usr/share/applnk/Office/kugar.desktop
kword	Qt	/usr/share/applnk/Office/kword.desktop
kword	KDE	/usr/share/applnk/Office/kword.desktop
kword	Office	/usr/share/applnk/Office/kword.desktop
kopete	Qt	/usr/share/applnk/Internet/kopete.desktop
kopete	KDE	/usr/share/applnk/Internet/kopete.desktop
kopete	Network	/usr/share/applnk/Internet/kopete.desktop
kmdr-editor	Qt	/usr/share/applnk/Development/kmdr-editor.desktop
kmdr-editor	KDE	/usr/share/applnk/Development/kmdr-editor.desktop
kmdr-editor	Development	/usr/share/applnk/Development/kmdr-editor.desktop
quanta	Qt	/usr/share/applnk/Development/quanta.desktop
quanta	KDE	/usr/share/applnk/Development/quanta.desktop
quanta	Development	/usr/share/applnk/Development/quanta.desktop
kdevelop3	Qt	/usr/share/applnk/Development/kdevelop3.desktop
kdevelop3	KDE	/usr/share/applnk/Development/kdevelop3.desktop
kdevelop3	Development	/usr/share/applnk/Development/kdevelop3.desktop
designer-qt3	Qt	/usr/share/applnk/Development/designer-qt3.desktop
designer-qt3	GUIDesigner	/usr/share/applnk/Development/designer-qt3.desktop
ethereal	GNOME	/usr/share/applications/Ethereal.desktop
ethereal	Application	/usr/share/applications/Ethereal.desktop
ethereal	Network	/usr/share/applications/Ethereal.desktop
gksu	GNOME	/usr/share/applications/EtherealAsRoot.desktop
gksu	Network	/usr/share/applications/EtherealAsRoot.desktop
myrtille	Application	/usr/share/applications/myrtille.desktop
myrtille	Graphics	/usr/share/applications/myrtille.desktop
enigma	Application	/usr/share/applications/enigma.desktop
enigma	Game	/usr/share/applications/enigma.desktop
enigma	PuzzleGame	/usr/share/applications/enigma.desktop
gaim	Application	/usr/share/applications/gaim.desktop
gaim	Network	/usr/share/applications/gaim.desktop
gpsdrive	Application	/usr/share/applications/gpsdrive.desktop
gpsdrive	Network	/usr/share/applications/gpsdrive.desktop
keduca	Qt	/usr/share/applications/kde/keduca.desktop
keduca	KDE	/usr/share/applications/kde/keduca.desktop
keduca	Education	/usr/share/applications/kde/keduca.desktop
keduca	X-KDE-Edu-Teaching	/usr/share/applications/kde/keduca.desktop
keducabuilder	Qt	/usr/share/applications/kde/keducabuilder.desktop
keducabuilder	KDE	/usr/share/applications/kde/keducabuilder.desktop
keducabuilder	Education	/usr/share/applications/kde/keducabuilder.desktop
keducabuilder	X-KDE-Edu-Teaching	/usr/share/applications/kde/keducabuilder.desktop
su-to-root	Application	/usr/share/applications/qtparted.desktop
su-to-root	System	/usr/share/applications/qtparted.desktop
su-to-root	QT	/usr/share/applications/qtparted.desktop
bluefish	Application	/usr/share/applications/bluefish.desktop
bluefish	Development	/usr/share/applications/bluefish.desktop
gtkam	GNOME	/usr/share/applications/gtkam.desktop
gtkam	Application	/usr/share/applications/gtkam.desktop
gtkam	Graphics	/usr/share/applications/gtkam.desktop
gtkam	RasterGraphics	/usr/share/applications/gtkam.desktop
gtkam	Viewer	/usr/share/applications/gtkam.desktop
abiword	Application	/usr/share/applications/abiword.desktop
abiword	Office	/usr/share/applications/abiword.desktop
abiword	WordProcessor	/usr/share/applications/abiword.desktop
abiword	X-Red-Hat-Base	/usr/share/applications/abiword.desktop
eog	GNOME	/usr/share/applications/eog.desktop
eog	Application	/usr/share/applications/eog.desktop
eog	Graphics	/usr/share/applications/eog.desktop
eog	RasterGraphics	/usr/share/applications/eog.desktop
eog	Viewer	/usr/share/applications/eog.desktop
mozilla-1.7.1	Application	/usr/share/applications/Mozilla-editor.desktop
mozilla-1.7.1	Network	/usr/share/applications/Mozilla-editor.desktop
gnect	GNOME	/usr/share/applications/gnect.desktop
gnect	Application	/usr/share/applications/gnect.desktop
gnect	Game	/usr/share/applications/gnect.desktop
gnect	PuzzleGame	/usr/share/applications/gnect.desktop
same-gnome	GNOME	/usr/share/applications/same-gnome.desktop
same-gnome	Application	/usr/share/applications/same-gnome.desktop
same-gnome	Game	/usr/share/applications/same-gnome.desktop
same-gnome	PuzzleGame	/usr/share/applications/same-gnome.desktop
gnomine	GNOME	/usr/share/applications/gnomine.desktop
gnomine	Application	/usr/share/applications/gnomine.desktop
gnomine	Game	/usr/share/applications/gnomine.desktop
gnomine	PuzzleGame	/usr/share/applications/gnomine.desktop
gnome-stones	GNOME	/usr/share/applications/gnome-stones.desktop
gnome-stones	Application	/usr/share/applications/gnome-stones.desktop
gnome-stones	Game	/usr/share/applications/gnome-stones.desktop
gnome-stones	PuzzleGame	/usr/share/applications/gnome-stones.desktop
mahjongg	GNOME	/usr/share/applications/mahjongg.desktop
mahjongg	Application	/usr/share/applications/mahjongg.desktop
mahjongg	Game	/usr/share/applications/mahjongg.desktop
mahjongg	BoardGame	/usr/share/applications/mahjongg.desktop
gtali	GNOME	/usr/share/applications/gtali.desktop
gtali	Application	/usr/share/applications/gtali.desktop
gtali	Game	/usr/share/applications/gtali.desktop
gnotravex	GNOME	/usr/share/applications/gnotravex.desktop
gnotravex	Application	/usr/share/applications/gnotravex.desktop
gnotravex	Game	/usr/share/applications/gnotravex.desktop
gnotravex	PuzzleGame	/usr/share/applications/gnotravex.desktop
gataxx	GNOME	/usr/share/applications/gataxx.desktop
gataxx	Application	/usr/share/applications/gataxx.desktop
gataxx	Game	/usr/share/applications/gataxx.desktop
gataxx	BoardGame	/usr/share/applications/gataxx.desktop
gnobots2	GNOME	/usr/share/applications/gnobots2.desktop
gnobots2	Application	/usr/share/applications/gnobots2.desktop
gnobots2	Game	/usr/share/applications/gnobots2.desktop
gnobots2	ArcadeGame	/usr/share/applications/gnobots2.desktop
gnotski	GNOME	/usr/share/applications/gnotski.desktop
gnotski	Application	/usr/share/applications/gnotski.desktop
gnotski	Game	/usr/share/applications/gnotski.desktop
gnotski	PuzzleGame	/usr/share/applications/gnotski.desktop
glines	GNOME	/usr/share/applications/glines.desktop
glines	Application	/usr/share/applications/glines.desktop
glines	Game	/usr/share/applications/glines.desktop
glines	PuzzleGame	/usr/share/applications/glines.desktop
iagno	GNOME	/usr/share/applications/iagno.desktop
iagno	Application	/usr/share/applications/iagno.desktop
iagno	Game	/usr/share/applications/iagno.desktop
gnibbles	GNOME	/usr/share/applications/gnibbles.desktop
gnibbles	Application	/usr/share/applications/gnibbles.desktop
gnibbles	Game	/usr/share/applications/gnibbles.desktop
gnibbles	ArcadeGame	/usr/share/applications/gnibbles.desktop
gnometris	GNOME	/usr/share/applications/gnometris.desktop
gnometris	Application	/usr/share/applications/gnometris.desktop
gnometris	Game	/usr/share/applications/gnometris.desktop
gnometris	BlocksGame	/usr/share/applications/gnometris.desktop
blackjack	GNOME	/usr/share/applications/blackjack.desktop
blackjack	Application	/usr/share/applications/blackjack.desktop
blackjack	Game	/usr/share/applications/blackjack.desktop
blackjack	CardGame	/usr/share/applications/blackjack.desktop
sol	GNOME	/usr/share/applications/sol.desktop
sol	Application	/usr/share/applications/sol.desktop
sol	Game	/usr/share/applications/sol.desktop
sol	CardGame	/usr/share/applications/sol.desktop
gpdf	GNOME	/usr/share/applications/gpdf.desktop
gpdf	Application	/usr/share/applications/gpdf.desktop
gpdf	Graphics	/usr/share/applications/gpdf.desktop
gpdf	VectorGraphics	/usr/share/applications/gpdf.desktop
gpdf	Viewer	/usr/share/applications/gpdf.desktop
planner	Application	/usr/share/applications/planner.desktop
planner	Office	/usr/share/applications/planner.desktop
planner	ProjectManagement	/usr/share/applications/planner.desktop
rhythmbox	GNOME	/usr/share/applications/rhythmbox.desktop
rhythmbox	Application	/usr/share/applications/rhythmbox.desktop
rhythmbox	AudioVideo	/usr/share/applications/rhythmbox.desktop
rhythmbox	X-Ximian-Main	/usr/share/applications/rhythmbox.desktop
rhythmbox	X-Red-Hat-Base	/usr/share/applications/rhythmbox.desktop
cinepaint	Application	/usr/share/applications/cinepaint.desktop
cinepaint	Graphics	/usr/share/applications/cinepaint.desktop
cinepaint	RasterGraphics	/usr/share/applications/cinepaint.desktop
liferea	Application	/usr/share/applications/liferea.desktop
liferea	Network	/usr/share/applications/liferea.desktop
mergeant	Application	/usr/share/applications/mergeant.desktop
mergeant	Office	/usr/share/applications/mergeant.desktop
pybliographic	GNOME	/usr/share/applications/pybliographic.desktop
pybliographic	Application	/usr/share/applications/pybliographic.desktop
pybliographic	Office	/usr/share/applications/pybliographic.desktop
screem	Application	/usr/share/applications/screem.desktop
screem	Development	/usr/share/applications/screem.desktop
beast	GTK	/usr/share/applications/beast.desktop
beast	GNOME	/usr/share/applications/beast.desktop
beast	Application	/usr/share/applications/beast.desktop
beast	AudioVideo	/usr/share/applications/beast.desktop
beast	AudioVideoEditing	/usr/share/applications/beast.desktop
beast	Music	/usr/share/applications/beast.desktop
beast	Player	/usr/share/applications/beast.desktop
jack-rack	GNOME	/usr/share/applications/jack-rack.desktop
jack-rack	Application	/usr/share/applications/jack-rack.desktop
jack-rack	AudioVideo	/usr/share/applications/jack-rack.desktop
evolution-1.5	GNOME	/usr/share/applications/evolution-1.5.desktop
evolution-1.5	Application	/usr/share/applications/evolution-1.5.desktop
evolution-1.5	Office	/usr/share/applications/evolution-1.5.desktop
evolution-1.5	X-Red-Hat-Base	/usr/share/applications/evolution-1.5.desktop
myrtilledv	Application	/usr/share/applications/myrtilledv.desktop
myrtilledv	Graphics	/usr/share/applications/myrtilledv.desktop
streamtuner	Application	/usr/share/applications/streamtuner.desktop
streamtuner	AudioVideo	/usr/share/applications/streamtuner.desktop
streamtuner	GTK	/usr/share/applications/streamtuner.desktop
streamtuner	Tuner	/usr/share/applications/streamtuner.desktop
k3b	KDE	/usr/share/applnk/Multimedia/k3b.desktop
k3b	Application	/usr/share/applnk/Multimedia/k3b.desktop
k3b	AudioVideo	/usr/share/applnk/Multimedia/k3b.desktop
k3b	DiscBurning	/usr/share/applnk/Multimedia/k3b.desktop
kaffeine	Application	/usr/share/applnk/Multimedia/kaffeine.desktop
kaffeine	AudioVideo	/usr/share/applnk/Multimedia/kaffeine.desktop
kaffeine	Player	/usr/share/applnk/Multimedia/kaffeine.desktop
kaffeine	Music	/usr/share/applnk/Multimedia/kaffeine.desktop
kaffeine	KDE	/usr/share/applnk/Multimedia/kaffeine.desktop
k3bsetup	Application	/usr/share/applnk/Settings/System/k3bsetup2.desktop
k3bsetup	System	/usr/share/applnk/Settings/System/k3bsetup2.desktop
k3bsetup	X-KDE-System	/usr/share/applnk/Settings/System/k3bsetup2.desktop
filelight	Qt	/usr/share/applnk/Utilities/filelight.desktop
filelight	KDE	/usr/share/applnk/Utilities/filelight.desktop
filelight	Utility	/usr/share/applnk/Utilities/filelight.desktop
xffm	X-Debian-Apps-Tools	/var/lib/menu-xdg/applications/menu-xdg/xffm4.desktop
Gimp	Application	/usr/share/slix/apps/Aplikacije/Grafika/Gimp.desktop
Gimp	Graphics	/usr/share/slix/apps/Aplikacije/Grafika/Gimp.desktop
Gimp	RasterGraphics	/usr/share/slix/apps/Aplikacije/Grafika/Gimp.desktop
tvtime	Application	/usr/share/slix/apps/Aplikacije/Video/net-tvtime.desktop
tvtime	AudioVideo	/usr/share/slix/apps/Aplikacije/Video/net-tvtime.desktop
k3b	Qt	/usr/share/slix/apps/Pripomo?ki/Arhiviranje/k3b.desktop
dbishell	X-Debian-Apps-Databases	/var/lib/menu-xdg/applications/menu-xdg/dbishell.desktop
gnomedb-fe	X-Debian-Apps-Databases	/var/lib/menu-xdg/applications/menu-xdg/gnome-db_frontend.desktop
mysqlcc	X-Debian-Apps-Databases	/var/lib/menu-xdg/applications/menu-xdg/mysql_cc.desktop
/usr/bin/X11/pgaccess	X-Debian-Apps-Databases	/var/lib/menu-xdg/applications/menu-xdg/pgaccess.desktop
pgadmin3	X-Debian-Apps-Databases	/var/lib/menu-xdg/applications/menu-xdg/pgadmin_iii.desktop
/usr/lib/postgresql/bin/psql-wm	X-Debian-Apps-Databases	/var/lib/menu-xdg/applications/menu-xdg/postgresql_interactive_terminal_(psql).desktop
quicklist	X-Debian-Apps-Databases	/var/lib/menu-xdg/applications/menu-xdg/quicklist.desktop
sqlr-config-gtk	X-Debian-Apps-Databases	/var/lib/menu-xdg/applications/menu-xdg/sql_relay_configuration.desktop
tora	X-Debian-Apps-Databases	/var/lib/menu-xdg/applications/menu-xdg/tora.desktop
abiword	X-Debian-Apps-Editors	/var/lib/menu-xdg/applications/menu-xdg/abiword_word_processor.desktop
/usr/bin/X11/axe	X-Debian-Apps-Editors	/var/lib/menu-xdg/applications/menu-xdg/axe.desktop
conglomerate	X-Debian-Apps-Editors	/var/lib/menu-xdg/applications/menu-xdg/conglomerate_xml_editor.desktop
emacs21	X-Debian-Apps-Editors	/var/lib/menu-xdg/applications/menu-xdg/emacs_21_(text).desktop
fontforge	X-Debian-Apps-Editors	/var/lib/menu-xdg/applications/menu-xdg/fontforge.desktop
gedit	X-Debian-Apps-Editors	/var/lib/menu-xdg/applications/menu-xdg/gedit.desktop
texmacs	X-Debian-Apps-Editors	/var/lib/menu-xdg/applications/menu-xdg/gnu_texmacs.desktop
joe	X-Debian-Apps-Editors	/var/lib/menu-xdg/applications/menu-xdg/joe.desktop
kate	X-Debian-Apps-Editors	/var/lib/menu-xdg/applications/menu-xdg/kate.desktop
kedit	X-Debian-Apps-Editors	/var/lib/menu-xdg/applications/menu-xdg/kedit.desktop
kile	X-Debian-Apps-Editors	/var/lib/menu-xdg/applications/menu-xdg/kile.desktop
kvim	X-Debian-Apps-Editors	/var/lib/menu-xdg/applications/menu-xdg/kvim.desktop
kword	X-Debian-Apps-Editors	/var/lib/menu-xdg/applications/menu-xdg/kword.desktop
kwrite	X-Debian-Apps-Editors	/var/lib/menu-xdg/applications/menu-xdg/kwrite.desktop
kxmleditor	X-Debian-Apps-Editors	/var/lib/menu-xdg/applications/menu-xdg/kxmleditor.desktop
lyx-qt	X-Debian-Apps-Editors	/var/lib/menu-xdg/applications/menu-xdg/lyx_(qt).desktop
mlv	X-Debian-Apps-Editors	/var/lib/menu-xdg/applications/menu-xdg/mlview_xml_editor.desktop
nano	X-Debian-Apps-Editors	/var/lib/menu-xdg/applications/menu-xdg/nano.desktop
nedit	X-Debian-Apps-Editors	/var/lib/menu-xdg/applications/menu-xdg/nedit.desktop
oofromtemplate	X-Debian-Apps-Editors	/var/lib/menu-xdg/applications/menu-xdg/openoffice.org_from_template.desktop
ooweb	X-Debian-Apps-Editors	/var/lib/menu-xdg/applications/menu-xdg/openoffice.org_html_document.desktop
oowriter	X-Debian-Apps-Editors	/var/lib/menu-xdg/applications/menu-xdg/openoffice.org_writer.desktop
pw	X-Debian-Apps-Editors	/var/lib/menu-xdg/applications/menu-xdg/pathetic_writer.desktop
quanta	X-Debian-Apps-Editors	/var/lib/menu-xdg/applications/menu-xdg/quanta_plus.desktop
vim	X-Debian-Apps-Editors	/var/lib/menu-xdg/applications/menu-xdg/vim.desktop
xedit	X-Debian-Apps-Editors	/var/lib/menu-xdg/applications/menu-xdg/xedit.desktop
xemacs21-mule	X-Debian-Apps-Editors	/var/lib/menu-xdg/applications/menu-xdg/xemacs21-mule.desktop
yudit	X-Debian-Apps-Editors	/var/lib/menu-xdg/applications/menu-xdg/yudit.desktop
flashkard	X-Debian-Apps-Education	/var/lib/menu-xdg/applications/menu-xdg/flashkard.desktop
kiten	X-Debian-Apps-Education	/var/lib/menu-xdg/applications/menu-xdg/kiten.desktop
klettres	X-Debian-Apps-Education	/var/lib/menu-xdg/applications/menu-xdg/klettres.desktop
ktouch	X-Debian-Apps-Education	/var/lib/menu-xdg/applications/menu-xdg/ktouch.desktop
kverbos	X-Debian-Apps-Education	/var/lib/menu-xdg/applications/menu-xdg/kverbos.desktop
kvoctrain	X-Debian-Apps-Education	/var/lib/menu-xdg/applications/menu-xdg/kvoctrain.desktop
BasiliskII	X-Debian-Apps-Emulators	/var/lib/menu-xdg/applications/menu-xdg/basiliskii.desktop
x128	X-Debian-Apps-Emulators	/var/lib/menu-xdg/applications/menu-xdg/commodore_128.desktop
x64	X-Debian-Apps-Emulators	/var/lib/menu-xdg/applications/menu-xdg/commodore_64.desktop
xcbm2	X-Debian-Apps-Emulators	/var/lib/menu-xdg/applications/menu-xdg/commodore_cbm-ii.desktop
xpet	X-Debian-Apps-Emulators	/var/lib/menu-xdg/applications/menu-xdg/commodore_pet.desktop
xvic	X-Debian-Apps-Emulators	/var/lib/menu-xdg/applications/menu-xdg/commodore_vic-20.desktop
dosemu	X-Debian-Apps-Emulators	/var/lib/menu-xdg/applications/menu-xdg/dos_emulator_(tty).desktop
xdosemu	X-Debian-Apps-Emulators	/var/lib/menu-xdg/applications/menu-xdg/dos_emulator_(x11).desktop
GSnes9x	X-Debian-Apps-Emulators	/var/lib/menu-xdg/applications/menu-xdg/gsnes9x.desktop
x-terminal-emulator	X-Debian-Apps-Emulators	/var/lib/menu-xdg/applications/menu-xdg/spectemu.desktop
uae-x	X-Debian-Apps-Emulators	/var/lib/menu-xdg/applications/menu-xdg/uae.desktop
avidemux	X-Debian-Apps-Graphics	/var/lib/menu-xdg/applications/menu-xdg/avidemux.desktop
bitmap	X-Debian-Apps-Graphics	/var/lib/menu-xdg/applications/menu-xdg/bitmap.desktop
blender	X-Debian-Apps-Graphics	/var/lib/menu-xdg/applications/menu-xdg/blender_(full_screen).desktop
cenon	X-Debian-Apps-Graphics	/var/lib/menu-xdg/applications/menu-xdg/cenon.desktop
cinelerra	X-Debian-Apps-Graphics	/var/lib/menu-xdg/applications/menu-xdg/cinelerra.desktop
dia-normal	X-Debian-Apps-Graphics	/var/lib/menu-xdg/applications/menu-xdg/dia.desktop
dia-gnome	X-Debian-Apps-Graphics	/var/lib/menu-xdg/applications/menu-xdg/dia_(gnome).desktop
egon	X-Debian-Apps-Graphics	/var/lib/menu-xdg/applications/menu-xdg/egon.desktop
filmgimp	X-Debian-Apps-Graphics	/var/lib/menu-xdg/applications/menu-xdg/film_gimp.desktop
giram	X-Debian-Apps-Graphics	/var/lib/menu-xdg/applications/menu-xdg/giram.desktop
ganso	X-Debian-Apps-Graphics	/var/lib/menu-xdg/applications/menu-xdg/gnome_animation_studio.desktop
gqcam	X-Debian-Apps-Graphics	/var/lib/menu-xdg/applications/menu-xdg/gqcam.desktop
gtk-ocr	X-Debian-Apps-Graphics	/var/lib/menu-xdg/applications/menu-xdg/gtk_gocr.desktop
inkscape	X-Debian-Apps-Graphics	/var/lib/menu-xdg/applications/menu-xdg/inkscape.desktop
innovation3d	X-Debian-Apps-Graphics	/var/lib/menu-xdg/applications/menu-xdg/innovation3d_modeler.desktop
x-terminal-emulator	X-Debian-Apps-Graphics	/var/lib/menu-xdg/applications/menu-xdg/ivtools.desktop
ivview	X-Debian-Apps-Graphics	/var/lib/menu-xdg/applications/menu-xdg/ivview.desktop
karbon	X-Debian-Apps-Graphics	/var/lib/menu-xdg/applications/menu-xdg/karbon.desktop
kcolorchooser	X-Debian-Apps-Graphics	/var/lib/menu-xdg/applications/menu-xdg/kcolorchooser.desktop
kcoloredit	X-Debian-Apps-Graphics	/var/lib/menu-xdg/applications/menu-xdg/kcoloredit.desktop
kfax	X-Debian-Apps-Graphics	/var/lib/menu-xdg/applications/menu-xdg/kfax.desktop
kiconedit	X-Debian-Apps-Graphics	/var/lib/menu-xdg/applications/menu-xdg/kiconedit.desktop
kino	X-Debian-Apps-Graphics	/var/lib/menu-xdg/applications/menu-xdg/kino.desktop
kooka	X-Debian-Apps-Graphics	/var/lib/menu-xdg/applications/menu-xdg/kooka.desktop
kpaint	X-Debian-Apps-Graphics	/var/lib/menu-xdg/applications/menu-xdg/kpaint.desktop
kpdf	X-Debian-Apps-Graphics	/var/lib/menu-xdg/applications/menu-xdg/kpdf.desktop
kpovmodeler	X-Debian-Apps-Graphics	/var/lib/menu-xdg/applications/menu-xdg/kpovmodeler.desktop
krita	X-Debian-Apps-Graphics	/var/lib/menu-xdg/applications/menu-xdg/krita.desktop
kruler	X-Debian-Apps-Graphics	/var/lib/menu-xdg/applications/menu-xdg/kruler.desktop
ksnapshot	X-Debian-Apps-Graphics	/var/lib/menu-xdg/applications/menu-xdg/ksnapshot.desktop
kuickshow	X-Debian-Apps-Graphics	/var/lib/menu-xdg/applications/menu-xdg/kuickshow.desktop
motion	X-Debian-Apps-Graphics	/var/lib/menu-xdg/applications/menu-xdg/motion.desktop
oodraw	X-Debian-Apps-Graphics	/var/lib/menu-xdg/applications/menu-xdg/openoffice.org_draw.desktop
ooimpress	X-Debian-Apps-Graphics	/var/lib/menu-xdg/applications/menu-xdg/openoffice.org_impress.desktop
picview	X-Debian-Apps-Graphics	/var/lib/menu-xdg/applications/menu-xdg/picview.desktop
pixmap	X-Debian-Apps-Graphics	/var/lib/menu-xdg/applications/menu-xdg/pixmap.desktop
price	X-Debian-Apps-Graphics	/var/lib/menu-xdg/applications/menu-xdg/price.desktop
sced	X-Debian-Apps-Graphics	/var/lib/menu-xdg/applications/menu-xdg/sced.desktop
SceneViewer	X-Debian-Apps-Graphics	/var/lib/menu-xdg/applications/menu-xdg/sceneviewer.desktop
scribus	X-Debian-Apps-Graphics	/var/lib/menu-xdg/applications/menu-xdg/scribus.desktop
sketch	X-Debian-Apps-Graphics	/var/lib/menu-xdg/applications/menu-xdg/sketch.desktop
snowflake	X-Debian-Apps-Graphics	/var/lib/menu-xdg/applications/menu-xdg/snowflake.desktop
sodipodi	X-Debian-Apps-Graphics	/var/lib/menu-xdg/applications/menu-xdg/sodipodi.desktop
terraform	X-Debian-Apps-Graphics	/var/lib/menu-xdg/applications/menu-xdg/terraform.desktop
sh	X-Debian-Apps-Graphics	/var/lib/menu-xdg/applications/menu-xdg/text_xaos.desktop
tgif	X-Debian-Apps-Graphics	/var/lib/menu-xdg/applications/menu-xdg/tgif.desktop
gimp-2.0	X-Debian-Apps-Graphics	/var/lib/menu-xdg/applications/menu-xdg/the_gimp_(v2.0).desktop
tulip	X-Debian-Apps-Graphics	/var/lib/menu-xdg/applications/menu-xdg/tulip.desktop
tuxpaint	X-Debian-Apps-Graphics	/var/lib/menu-xdg/applications/menu-xdg/tuxpaint.desktop
vertex	X-Debian-Apps-Graphics	/var/lib/menu-xdg/applications/menu-xdg/vertex.desktop
xfig	X-Debian-Apps-Graphics	/var/lib/menu-xdg/applications/menu-xdg/xfig.desktop
xmorph	X-Debian-Apps-Graphics	/var/lib/menu-xdg/applications/menu-xdg/xmorph.desktop
xmps	X-Debian-Apps-Graphics	/var/lib/menu-xdg/applications/menu-xdg/xmps.desktop
/usr/bin/X11/xpaint	X-Debian-Apps-Graphics	/var/lib/menu-xdg/applications/menu-xdg/xpaint.desktop
xsane	X-Debian-Apps-Graphics	/var/lib/menu-xdg/applications/menu-xdg/xsane.desktop
gmfsk	X-Debian-Apps-Hamradio	/var/lib/menu-xdg/applications/menu-xdg/gmfsk.desktop
gworldclock	X-Debian-Apps-Hamradio	/var/lib/menu-xdg/applications/menu-xdg/gworldclock.desktop
hamfax	X-Debian-Apps-Hamradio	/var/lib/menu-xdg/applications/menu-xdg/hamfax.desktop
linpac	X-Debian-Apps-Hamradio	/var/lib/menu-xdg/applications/menu-xdg/linpac.desktop
twclock	X-Debian-Apps-Hamradio	/var/lib/menu-xdg/applications/menu-xdg/twclock.desktop
xastir	X-Debian-Apps-Hamradio	/var/lib/menu-xdg/applications/menu-xdg/xastir.desktop
xcall	X-Debian-Apps-Hamradio	/var/lib/menu-xdg/applications/menu-xdg/xcall.desktop
bc	X-Debian-Apps-Math	/var/lib/menu-xdg/applications/menu-xdg/bc.desktop
burlap	X-Debian-Apps-Math	/var/lib/menu-xdg/applications/menu-xdg/burlap.desktop
gcalctool	X-Debian-Apps-Math	/var/lib/menu-xdg/applications/menu-xdg/calctool.desktop
dc	X-Debian-Apps-Math	/var/lib/menu-xdg/applications/menu-xdg/dc.desktop
fudgit	X-Debian-Apps-Math	/var/lib/menu-xdg/applications/menu-xdg/fudgit.desktop
geomview	X-Debian-Apps-Math	/var/lib/menu-xdg/applications/menu-xdg/geomview.desktop
gnumeric	X-Debian-Apps-Math	/var/lib/menu-xdg/applications/menu-xdg/gnumeric.desktop
gstar	X-Debian-Apps-Math	/var/lib/menu-xdg/applications/menu-xdg/gstar.desktop
kbruch	X-Debian-Apps-Math	/var/lib/menu-xdg/applications/menu-xdg/kbruch.desktop
kcalc	X-Debian-Apps-Math	/var/lib/menu-xdg/applications/menu-xdg/kcalc.desktop
kchart	X-Debian-Apps-Math	/var/lib/menu-xdg/applications/menu-xdg/kchart.desktop
kformula	X-Debian-Apps-Math	/var/lib/menu-xdg/applications/menu-xdg/kformula.desktop
kgeo	X-Debian-Apps-Math	/var/lib/menu-xdg/applications/menu-xdg/kgeo.desktop
kig	X-Debian-Apps-Math	/var/lib/menu-xdg/applications/menu-xdg/kig.desktop
kmplot	X-Debian-Apps-Math	/var/lib/menu-xdg/applications/menu-xdg/kmplot.desktop
kpercentage	X-Debian-Apps-Math	/var/lib/menu-xdg/applications/menu-xdg/kpercentage.desktop
kspread	X-Debian-Apps-Math	/var/lib/menu-xdg/applications/menu-xdg/kspread.desktop
oocalc	X-Debian-Apps-Math	/var/lib/menu-xdg/applications/menu-xdg/openoffice.org_calc.desktop
oomath	X-Debian-Apps-Math	/var/lib/menu-xdg/applications/menu-xdg/openoffice.org_math.desktop
openuniverse	X-Debian-Apps-Math	/var/lib/menu-xdg/applications/menu-xdg/openuniverse.desktop
perldl	X-Debian-Apps-Math	/var/lib/menu-xdg/applications/menu-xdg/perldl.desktop
rcalc	X-Debian-Apps-Math	/var/lib/menu-xdg/applications/menu-xdg/rcalc.desktop
siag	X-Debian-Apps-Math	/var/lib/menu-xdg/applications/menu-xdg/siag.desktop
tsiag	X-Debian-Apps-Math	/var/lib/menu-xdg/applications/menu-xdg/siag_(text_mode).desktop
velvet	X-Debian-Apps-Math	/var/lib/menu-xdg/applications/menu-xdg/velvet.desktop
xabacus	X-Debian-Apps-Math	/var/lib/menu-xdg/applications/menu-xdg/xabacus.desktop
xcalc	X-Debian-Apps-Math	/var/lib/menu-xdg/applications/menu-xdg/xcalc.desktop
xmaxima	X-Debian-Apps-Math	/var/lib/menu-xdg/applications/menu-xdg/xmaxima.desktop
amaya	X-Debian-Apps-Net	/var/lib/menu-xdg/applications/menu-xdg/amaya.desktop
amule	X-Debian-Apps-Net	/var/lib/menu-xdg/applications/menu-xdg/amule.desktop
amulewebDLG	X-Debian-Apps-Net	/var/lib/menu-xdg/applications/menu-xdg/amule_webserver_control.desktop
dillo	X-Debian-Apps-Net	/var/lib/menu-xdg/applications/menu-xdg/dillo.desktop
driftnet	X-Debian-Apps-Net	/var/lib/menu-xdg/applications/menu-xdg/driftnet.desktop
everybuddy	X-Debian-Apps-Net	/var/lib/menu-xdg/applications/menu-xdg/everybuddy.desktop
fwbuilder	X-Debian-Apps-Net	/var/lib/menu-xdg/applications/menu-xdg/firewall_builder.desktop
gipsc	X-Debian-Apps-Net	/var/lib/menu-xdg/applications/menu-xdg/gipsc.desktop
gnapster	X-Debian-Apps-Net	/var/lib/menu-xdg/applications/menu-xdg/gnapster.desktop
gnomemeeting	X-Debian-Apps-Net	/var/lib/menu-xdg/applications/menu-xdg/gnomemeeting.desktop
gtk-gnutella	X-Debian-Apps-Net	/var/lib/menu-xdg/applications/menu-xdg/gtk-gnutella.desktop
su-to-root	X-Debian-Apps-Net	/var/lib/menu-xdg/applications/menu-xdg/iptraf.desktop
kdict	X-Debian-Apps-Net	/var/lib/menu-xdg/applications/menu-xdg/kdict.desktop
kget	X-Debian-Apps-Net	/var/lib/menu-xdg/applications/menu-xdg/kget.desktop
kit	X-Debian-Apps-Net	/var/lib/menu-xdg/applications/menu-xdg/kit.desktop
kmail	X-Debian-Apps-Net	/var/lib/menu-xdg/applications/menu-xdg/kmail.desktop
kmailcvt	X-Debian-Apps-Net	/var/lib/menu-xdg/applications/menu-xdg/kmail_kab_import_tool.desktop
appletproxy	X-Debian-Apps-Net	/var/lib/menu-xdg/applications/menu-xdg/knewsticker.desktop
knode	X-Debian-Apps-Net	/var/lib/menu-xdg/applications/menu-xdg/knode.desktop
konqueror	X-Debian-Apps-System	/var/lib/menu-xdg/applications/menu-xdg/konqueror.desktop
kopete	X-Debian-Apps-Net	/var/lib/menu-xdg/applications/menu-xdg/kopete.desktop
korn	X-Debian-Apps-Net	/var/lib/menu-xdg/applications/menu-xdg/korn.desktop
kppp	X-Debian-Apps-Net	/var/lib/menu-xdg/applications/menu-xdg/kppp.desktop
kppplogview	X-Debian-Apps-Net	/var/lib/menu-xdg/applications/menu-xdg/kppp_-_logview.desktop
krdc	X-Debian-Apps-Net	/var/lib/menu-xdg/applications/menu-xdg/krdc.desktop
krfb	X-Debian-Apps-Net	/var/lib/menu-xdg/applications/menu-xdg/krfb.desktop
ksig	X-Debian-Apps-Net	/var/lib/menu-xdg/applications/menu-xdg/ksig.desktop
ksirc	X-Debian-Apps-Net	/var/lib/menu-xdg/applications/menu-xdg/ksirc.desktop
kwifimanager	X-Debian-Apps-Net	/var/lib/menu-xdg/applications/menu-xdg/kwifimanager.desktop
LinNeighborhood	X-Debian-Apps-Net	/var/lib/menu-xdg/applications/menu-xdg/linneighborhood.desktop
lynx	X-Debian-Apps-Net	/var/lib/menu-xdg/applications/menu-xdg/lynx.desktop
minicom	X-Debian-Apps-Net	/var/lib/menu-xdg/applications/menu-xdg/minicom.desktop
xminicom	X-Debian-Apps-Net	/var/lib/menu-xdg/applications/menu-xdg/minicom_(x11).desktop
firefox	X-Debian-Apps-Net	/var/lib/menu-xdg/applications/menu-xdg/mozilla_firefox.desktop
mozilla-thunderbird	X-Debian-Apps-Net	/var/lib/menu-xdg/applications/menu-xdg/mozilla_thunderbird.desktop
mutt	X-Debian-Apps-Net	/var/lib/menu-xdg/applications/menu-xdg/mutt.desktop
ncftp3	X-Debian-Apps-Net	/var/lib/menu-xdg/applications/menu-xdg/ncftp.desktop
gnome-netinfo	X-Debian-Apps-Net	/var/lib/menu-xdg/applications/menu-xdg/network_information.desktop
pan	X-Debian-Apps-Net	/var/lib/menu-xdg/applications/menu-xdg/pan.desktop
gnome-remote-desktop	X-Debian-Apps-Net	/var/lib/menu-xdg/applications/menu-xdg/remote_desktop.desktop
gnome-remote-shell	X-Debian-Apps-Net	/var/lib/menu-xdg/applications/menu-xdg/remote_shell.desktop
smb4k	X-Debian-Apps-Net	/var/lib/menu-xdg/applications/menu-xdg/samba_for_kde.desktop
sdr	X-Debian-Apps-Net	/var/lib/menu-xdg/applications/menu-xdg/sdr.desktop
telnet	X-Debian-Apps-Net	/var/lib/menu-xdg/applications/menu-xdg/telnet.desktop
tsclient	X-Debian-Apps-Net	/var/lib/menu-xdg/applications/menu-xdg/terminal_server_client.desktop
tkchooser	X-Debian-Apps-Net	/var/lib/menu-xdg/applications/menu-xdg/tkchooser.desktop
vrwave	X-Debian-Apps-Net	/var/lib/menu-xdg/applications/menu-xdg/vrwave_vrml_browser.desktop
w3m	X-Debian-Apps-Net	/var/lib/menu-xdg/applications/menu-xdg/w3m.desktop
xchat	X-Debian-Apps-Net	/var/lib/menu-xdg/applications/menu-xdg/x_chat.desktop
xbiff	X-Debian-Apps-Net	/var/lib/menu-xdg/applications/menu-xdg/xbiff.desktop
xrealvncviewer	X-Debian-Apps-Net	/var/lib/menu-xdg/applications/menu-xdg/xvncviewer.desktop
argouml	X-Debian-Apps-Programming	/var/lib/menu-xdg/applications/menu-xdg/argouml.desktop
autoproject	X-Debian-Apps-Programming	/var/lib/menu-xdg/applications/menu-xdg/autoproject.desktop
cervisia	X-Debian-Apps-Programming	/var/lib/menu-xdg/applications/menu-xdg/cervisia.desktop
lisp	X-Debian-Apps-Programming	/var/lib/menu-xdg/applications/menu-xdg/cmucl_normal_image.desktop
ddd	X-Debian-Apps-Programming	/var/lib/menu-xdg/applications/menu-xdg/data_display_debugger.desktop
eclipse	X-Debian-Apps-Programming	/var/lib/menu-xdg/applications/menu-xdg/eclipse.desktop
elk	X-Debian-Apps-Programming	/var/lib/menu-xdg/applications/menu-xdg/elk.desktop
fluid	X-Debian-Apps-Programming	/var/lib/menu-xdg/applications/menu-xdg/fluid.desktop
gide	X-Debian-Apps-Programming	/var/lib/menu-xdg/applications/menu-xdg/gide.desktop
glade-2	X-Debian-Apps-Programming	/var/lib/menu-xdg/applications/menu-xdg/glade_2.desktop
sh	X-Debian-Apps-Programming	/var/lib/menu-xdg/applications/menu-xdg/gorm.desktop
guile-1.6	X-Debian-Apps-Programming	/var/lib/menu-xdg/applications/menu-xdg/guile_1.6.desktop
guile1.4	X-Debian-Apps-Programming	/var/lib/menu-xdg/applications/menu-xdg/guile_scheme_1.4.desktop
insight	X-Debian-Apps-Programming	/var/lib/menu-xdg/applications/menu-xdg/insight.desktop
jython	X-Debian-Apps-Programming	/var/lib/menu-xdg/applications/menu-xdg/jython.desktop
kbabel	X-Debian-Apps-Programming	/var/lib/menu-xdg/applications/menu-xdg/kbabel.desktop
catalogmanager	X-Debian-Apps-Programming	/var/lib/menu-xdg/applications/menu-xdg/kbabel_catalog_manager.desktop
kbabeldict	X-Debian-Apps-Programming	/var/lib/menu-xdg/applications/menu-xdg/kbabel_dictionary.desktop
kbugbuster	X-Debian-Apps-Programming	/var/lib/menu-xdg/applications/menu-xdg/kbugbuster.desktop
kcachegrind	X-Debian-Apps-Programming	/var/lib/menu-xdg/applications/menu-xdg/kcachegrind.desktop
kdevelop3	X-Debian-Apps-Programming	/var/lib/menu-xdg/applications/menu-xdg/kdevelop_3.0.desktop
kodos	X-Debian-Apps-Programming	/var/lib/menu-xdg/applications/menu-xdg/kodos.desktop
kompare	X-Debian-Apps-Programming	/var/lib/menu-xdg/applications/menu-xdg/kompare.desktop
kuiviewer	X-Debian-Apps-Programming	/var/lib/menu-xdg/applications/menu-xdg/kuiviewer.desktop
pike7.2	X-Debian-Apps-Programming	/var/lib/menu-xdg/applications/menu-xdg/pike_7.2_hilfe.desktop
pycrust	X-Debian-Apps-Programming	/var/lib/menu-xdg/applications/menu-xdg/pycrust.desktop
pyshell	X-Debian-Apps-Programming	/var/lib/menu-xdg/applications/menu-xdg/pyshell.desktop
python2.1	X-Debian-Apps-Programming	/var/lib/menu-xdg/applications/menu-xdg/python_(v2.1).desktop
python2.2	X-Debian-Apps-Programming	/var/lib/menu-xdg/applications/menu-xdg/python_(v2.2).desktop
python2.3	X-Debian-Apps-Programming	/var/lib/menu-xdg/applications/menu-xdg/python_(v2.3).desktop
designer-qt3	X-Debian-Apps-Programming	/var/lib/menu-xdg/applications/menu-xdg/qt_designer.desktop
irb1.8	X-Debian-Apps-Programming	/var/lib/menu-xdg/applications/menu-xdg/ruby_(irb1.8).desktop
tclsh8.0	X-Debian-Apps-Programming	/var/lib/menu-xdg/applications/menu-xdg/tclsh8.0.desktop
tclsh8.2	X-Debian-Apps-Programming	/var/lib/menu-xdg/applications/menu-xdg/tclsh8.2.desktop
tclsh8.3	X-Debian-Apps-Programming	/var/lib/menu-xdg/applications/menu-xdg/tclsh8.3.desktop
tclsh8.4	X-Debian-Apps-Programming	/var/lib/menu-xdg/applications/menu-xdg/tclsh8.4.desktop
tkcvs	X-Debian-Apps-Programming	/var/lib/menu-xdg/applications/menu-xdg/tkcvs.desktop
tkdiff	X-Debian-Apps-Programming	/var/lib/menu-xdg/applications/menu-xdg/tkdiff.desktop
wish8.0	X-Debian-Apps-Programming	/var/lib/menu-xdg/applications/menu-xdg/tkwish8.0.desktop
wish8.2	X-Debian-Apps-Programming	/var/lib/menu-xdg/applications/menu-xdg/tkwish8.2.desktop
x-terminal-emulator	X-Debian-Apps-Programming	/var/lib/menu-xdg/applications/menu-xdg/tkwish8.3.desktop
umbrello	X-Debian-Apps-Programming	/var/lib/menu-xdg/applications/menu-xdg/umbrello.desktop
xrced	X-Debian-Apps-Programming	/var/lib/menu-xdg/applications/menu-xdg/xrced.desktop
vibrate	X-Debian-Apps-Science	/var/lib/menu-xdg/applications/menu-xdg/asn2asn.desktop
Cn3D-3.0	X-Debian-Apps-Science	/var/lib/menu-xdg/applications/menu-xdg/cn3d-3.0.desktop
ddv	X-Debian-Apps-Science	/var/lib/menu-xdg/applications/menu-xdg/ddv.desktop
Nentrez	X-Debian-Apps-Science	/var/lib/menu-xdg/applications/menu-xdg/entrez.desktop
netentcf	X-Debian-Apps-Science	/var/lib/menu-xdg/applications/menu-xdg/entrez_net_config.desktop
entrez2	X-Debian-Apps-Science	/var/lib/menu-xdg/applications/menu-xdg/entrez2.desktop
garlic	X-Debian-Apps-Science	/var/lib/menu-xdg/applications/menu-xdg/garlic.desktop
gperiodic	X-Debian-Apps-Science	/var/lib/menu-xdg/applications/menu-xdg/gperiodic.desktop
kalzium	X-Debian-Apps-Science	/var/lib/menu-xdg/applications/menu-xdg/kalzium.desktop
kstars	X-Debian-Apps-Science	/var/lib/menu-xdg/applications/menu-xdg/kstars.desktop
kxterm	X-Debian-Apps-Science	/var/lib/menu-xdg/applications/menu-xdg/kxterm.desktop
njplot	X-Debian-Apps-Science	/var/lib/menu-xdg/applications/menu-xdg/njplot.desktop
unrooted	X-Debian-Apps-Science	/var/lib/menu-xdg/applications/menu-xdg/njplot_unrooted.desktop
rasmol	X-Debian-Apps-Science	/var/lib/menu-xdg/applications/menu-xdg/rasmol.desktop
Psequin	X-Debian-Apps-Science	/var/lib/menu-xdg/applications/menu-xdg/sequin.desktop
starplot	X-Debian-Apps-Science	/var/lib/menu-xdg/applications/menu-xdg/starplot.desktop
udv	X-Debian-Apps-Science	/var/lib/menu-xdg/applications/menu-xdg/udv.desktop
bash	X-Debian-Apps-Shells	/var/lib/menu-xdg/applications/menu-xdg/bash.desktop
ksh	X-Debian-Apps-Shells	/var/lib/menu-xdg/applications/menu-xdg/ksh.desktop
sh	X-Debian-Apps-Shells	/var/lib/menu-xdg/applications/menu-xdg/sh.desktop
tcsh	X-Debian-Apps-Shells	/var/lib/menu-xdg/applications/menu-xdg/tcsh.desktop
aconnectgui	X-Debian-Apps-Sound	/var/lib/menu-xdg/applications/menu-xdg/aconnectgui.desktop
/usr/bin/X11/xterm	X-Debian-Apps-Sound	/var/lib/menu-xdg/applications/menu-xdg/ardour_gtk.desktop
artsbuilder	X-Debian-Apps-Sound	/var/lib/menu-xdg/applications/menu-xdg/arts_builder.desktop
artscontrol	X-Debian-Apps-Sound	/var/lib/menu-xdg/applications/menu-xdg/arts_control.desktop
audacity	X-Debian-Apps-Sound	/var/lib/menu-xdg/applications/menu-xdg/audacity.desktop
vkeybd	X-Debian-Apps-Sound	/var/lib/menu-xdg/applications/menu-xdg/awe_virtual_keyboard.desktop
bcast2000	X-Debian-Apps-Sound	/var/lib/menu-xdg/applications/menu-xdg/broadcast2000.desktop
cecilia	X-Debian-Apps-Sound	/var/lib/menu-xdg/applications/menu-xdg/cecilia.desktop
ceres3	X-Debian-Apps-Sound	/var/lib/menu-xdg/applications/menu-xdg/ceres3.desktop
cglame	X-Debian-Apps-Sound	/var/lib/menu-xdg/applications/menu-xdg/cglame.desktop
ecasound	X-Debian-Apps-Sound	/var/lib/menu-xdg/applications/menu-xdg/ecasound.desktop
extace	X-Debian-Apps-Sound	/var/lib/menu-xdg/applications/menu-xdg/extace.desktop
freebirth	X-Debian-Apps-Sound	/var/lib/menu-xdg/applications/menu-xdg/freebirth.desktop
gamix	X-Debian-Apps-Sound	/var/lib/menu-xdg/applications/menu-xdg/gamix.desktop
gcd	X-Debian-Apps-Sound	/var/lib/menu-xdg/applications/menu-xdg/gcd.desktop
glcthugha	X-Debian-Apps-Sound	/var/lib/menu-xdg/applications/menu-xdg/gl_cthugha.desktop
glame	X-Debian-Apps-Sound	/var/lib/menu-xdg/applications/menu-xdg/glame.desktop
gnome-volume-control	X-Debian-Apps-Sound	/var/lib/menu-xdg/applications/menu-xdg/gmix_(gnome_2.0_mixer).desktop
gnome-cd	X-Debian-Apps-Sound	/var/lib/menu-xdg/applications/menu-xdg/gnome-cd_(gnome_2.0_cd_player).desktop
gnomp3	X-Debian-Apps-Sound	/var/lib/menu-xdg/applications/menu-xdg/gnomp3.desktop
gom-ct	X-Debian-Apps-Sound	/var/lib/menu-xdg/applications/menu-xdg/gom_(terminal).desktop
gnome-sound-recorder	X-Debian-Apps-Sound	/var/lib/menu-xdg/applications/menu-xdg/grecord_(gnome_2.0_recorder).desktop
grip	X-Debian-Apps-Sound	/var/lib/menu-xdg/applications/menu-xdg/grip.desktop
gsox	X-Debian-Apps-Sound	/var/lib/menu-xdg/applications/menu-xdg/gsox.desktop
gtick	X-Debian-Apps-Sound	/var/lib/menu-xdg/applications/menu-xdg/gtick.desktop
horgand	X-Debian-Apps-Sound	/var/lib/menu-xdg/applications/menu-xdg/horgand.desktop
id3ren	X-Debian-Apps-Sound	/var/lib/menu-xdg/applications/menu-xdg/id3ren.desktop
juk	X-Debian-Apps-Sound	/var/lib/menu-xdg/applications/menu-xdg/juk_music_player.desktop
kaboodle	X-Debian-Apps-Sound	/var/lib/menu-xdg/applications/menu-xdg/kaboodle.desktop
kaudiocreator	X-Debian-Apps-Sound	/var/lib/menu-xdg/applications/menu-xdg/kaudiocreator.desktop
kmid	X-Debian-Apps-Sound	/var/lib/menu-xdg/applications/menu-xdg/kmid.desktop
kmidi	X-Debian-Apps-Sound	/var/lib/menu-xdg/applications/menu-xdg/kmidi.desktop
kmix	X-Debian-Apps-Sound	/var/lib/menu-xdg/applications/menu-xdg/kmix.desktop
krec	X-Debian-Apps-Sound	/var/lib/menu-xdg/applications/menu-xdg/krec.desktop
kscd	X-Debian-Apps-Sound	/var/lib/menu-xdg/applications/menu-xdg/kscd.desktop
mammut	X-Debian-Apps-Sound	/var/lib/menu-xdg/applications/menu-xdg/mammut.desktop
/usr/bin/X11/mix	X-Debian-Apps-Sound	/var/lib/menu-xdg/applications/menu-xdg/mix.desktop
/usr/X11R6/bin/Mixer.app	X-Debian-Apps-Sound	/var/lib/menu-xdg/applications/menu-xdg/mixer.app.desktop
mixmagic	X-Debian-Apps-Sound	/var/lib/menu-xdg/applications/menu-xdg/mixmagic.desktop
mxv	X-Debian-Apps-Sound	/var/lib/menu-xdg/applications/menu-xdg/mixviews.desktop
muse	X-Debian-Apps-Sound	/var/lib/menu-xdg/applications/menu-xdg/muse.desktop
music-librarian	X-Debian-Apps-Sound	/var/lib/menu-xdg/applications/menu-xdg/music_librarian.desktop
noatun	X-Debian-Apps-Sound	/var/lib/menu-xdg/applications/menu-xdg/noatun.desktop
noteedit	X-Debian-Apps-Sound	/var/lib/menu-xdg/applications/menu-xdg/noteedit.desktop
qrt	X-Debian-Apps-Sound	/var/lib/menu-xdg/applications/menu-xdg/qrt.desktop
qsynth	X-Debian-Apps-Sound	/var/lib/menu-xdg/applications/menu-xdg/qsynth.desktop
rezound	X-Debian-Apps-Sound	/var/lib/menu-xdg/applications/menu-xdg/rezound.desktop
rosegarden4	X-Debian-Apps-Sound	/var/lib/menu-xdg/applications/menu-xdg/rosegarden4.desktop
shaketracker	X-Debian-Apps-Sound	/var/lib/menu-xdg/applications/menu-xdg/shacketracker.desktop
smurf	X-Debian-Apps-Sound	/var/lib/menu-xdg/applications/menu-xdg/smurf.desktop
snd	X-Debian-Apps-Sound	/var/lib/menu-xdg/applications/menu-xdg/snd.desktop
soundtracker	X-Debian-Apps-Sound	/var/lib/menu-xdg/applications/menu-xdg/soundtracker.desktop
GUIBowedBar	X-Debian-Apps-Sound-STK	/var/lib/menu-xdg/applications/menu-xdg/bowedbar.desktop
GUIDrums	X-Debian-Apps-Sound-STK	/var/lib/menu-xdg/applications/menu-xdg/drums.desktop
GUIeffects	X-Debian-Apps-Sound-STK	/var/lib/menu-xdg/applications/menu-xdg/effects.desktop
GUIModal	X-Debian-Apps-Sound-STK	/var/lib/menu-xdg/applications/menu-xdg/modal.desktop
GUIPhysical	X-Debian-Apps-Sound-STK	/var/lib/menu-xdg/applications/menu-xdg/physical.desktop
GUIRaga	X-Debian-Apps-Sound-STK	/var/lib/menu-xdg/applications/menu-xdg/ragamatic.desktop
GUIShakers	X-Debian-Apps-Sound-STK	/var/lib/menu-xdg/applications/menu-xdg/shakers.desktop
GUIVoice	X-Debian-Apps-Sound-STK	/var/lib/menu-xdg/applications/menu-xdg/voice.desktop
sweep	X-Debian-Apps-Sound	/var/lib/menu-xdg/applications/menu-xdg/sweep.desktop
synaesthesia	X-Debian-Apps-Sound	/var/lib/menu-xdg/applications/menu-xdg/synaesthesia_(cd_input).desktop
terminatorX	X-Debian-Apps-Sound	/var/lib/menu-xdg/applications/menu-xdg/terminatorx.desktop
timidity	X-Debian-Apps-Sound	/var/lib/menu-xdg/applications/menu-xdg/timidity++.desktop
tk707	X-Debian-Apps-Sound	/var/lib/menu-xdg/applications/menu-xdg/tk-707.desktop
tkmixer	X-Debian-Apps-Sound	/var/lib/menu-xdg/applications/menu-xdg/tkmixer.desktop
vumeter	X-Debian-Apps-Sound	/var/lib/menu-xdg/applications/menu-xdg/vumeter_(gnome_2.0_volume_meter).desktop
wavesurfer	X-Debian-Apps-Sound	/var/lib/menu-xdg/applications/menu-xdg/wavesurfer.desktop
wmmixer	X-Debian-Apps-Sound	/var/lib/menu-xdg/applications/menu-xdg/wmmixer.desktop
wmxmms	X-Debian-Apps-Sound	/var/lib/menu-xdg/applications/menu-xdg/wmxmms.desktop
workman	X-Debian-Apps-Sound	/var/lib/menu-xdg/applications/menu-xdg/workman.desktop
xcthugha	X-Debian-Apps-Sound	/var/lib/menu-xdg/applications/menu-xdg/x_cthugha.desktop
xfreecd	X-Debian-Apps-Sound	/var/lib/menu-xdg/applications/menu-xdg/xfreecd.desktop
xmcd	X-Debian-Apps-Sound	/var/lib/menu-xdg/applications/menu-xdg/xmcd.desktop
/usr/bin/X11/xmix	X-Debian-Apps-Sound	/var/lib/menu-xdg/applications/menu-xdg/xmix.desktop
xmixer	X-Debian-Apps-Sound	/var/lib/menu-xdg/applications/menu-xdg/xmixer.desktop
xmms	X-Debian-Apps-Sound	/var/lib/menu-xdg/applications/menu-xdg/xmms.desktop
xplaycd	X-Debian-Apps-Sound	/var/lib/menu-xdg/applications/menu-xdg/xplaycd.desktop
xwave	X-Debian-Apps-Sound	/var/lib/menu-xdg/applications/menu-xdg/xwave.desktop
su-to-root	X-Debian-Apps-System-Admin	/var/lib/menu-xdg/applications/menu-xdg/alsaconf.desktop
kdesu	X-Debian-Apps-System	/var/lib/menu-xdg/applications/menu-xdg/lilo-config.desktop
aptitude	X-Debian-Apps-System	/var/lib/menu-xdg/applications/menu-xdg/aptitude.desktop
gvidm	X-Debian-Apps-System	/var/lib/menu-xdg/applications/menu-xdg/change_x11_resolution_(gvidm).desktop
fsview	X-Debian-Apps-System	/var/lib/menu-xdg/applications/menu-xdg/fsview.desktop
gdmflexiserver	X-Debian-Apps-System	/var/lib/menu-xdg/applications/menu-xdg/gdm_flexiserver.desktop
gdmphotosetup	X-Debian-Apps-System	/var/lib/menu-xdg/applications/menu-xdg/gdm_photo_setup.desktop
gksu	X-Debian-Apps-System	/var/lib/menu-xdg/applications/menu-xdg/gdm_setup.desktop
gnome-control-center	X-Debian-Apps-System-Gnome	/var/lib/menu-xdg/applications/menu-xdg/gnome_control_center.desktop
bug-buddy	X-Debian-Apps-System	/var/lib/menu-xdg/applications/menu-xdg/gnome_bug_report_tool.desktop
gfloppy	X-Debian-Apps-System	/var/lib/menu-xdg/applications/menu-xdg/gnome_floppy_formatter.desktop
gnome-system-log	X-Debian-Apps-System	/var/lib/menu-xdg/applications/menu-xdg/gnome_log_viewer.desktop
gnome-system-monitor	X-Debian-Apps-System	/var/lib/menu-xdg/applications/menu-xdg/gnome_system_monitor.desktop
gps	X-Debian-Apps-System	/var/lib/menu-xdg/applications/menu-xdg/gps.desktop
gxset	X-Debian-Apps-System	/var/lib/menu-xdg/applications/menu-xdg/gtk_xset.desktop
gtkrecover	X-Debian-Apps-System	/var/lib/menu-xdg/applications/menu-xdg/gtkrecover.desktop
openapp	X-Debian-Apps-System	/var/lib/menu-xdg/applications/menu-xdg/gworkspace.app.desktop
gxproc	X-Debian-Apps-System	/var/lib/menu-xdg/applications/menu-xdg/gxproc.desktop
kappfinder	X-Debian-Apps-System	/var/lib/menu-xdg/applications/menu-xdg/kappfinder.desktop
kcmshell	X-Debian-Apps-System	/var/lib/menu-xdg/applications/menu-xdg/kcmlinuz.desktop
kcontrol	X-Debian-Apps-System	/var/lib/menu-xdg/applications/menu-xdg/kcontrol.desktop
kdat	X-Debian-Apps-System	/var/lib/menu-xdg/applications/menu-xdg/kdat.desktop
kdcop	X-Debian-Apps-System	/var/lib/menu-xdg/applications/menu-xdg/kdcop.desktop
kpackage	X-Debian-Apps-System	/var/lib/menu-xdg/applications/menu-xdg/kde_package_manager.desktop
secpolicy	X-Debian-Apps-System	/var/lib/menu-xdg/applications/menu-xdg/kde_pam_security_policy_editor.desktop
ksysguard	X-Debian-Apps-System	/var/lib/menu-xdg/applications/menu-xdg/kde_system_guard.desktop
kpm	X-Debian-Apps-System	/var/lib/menu-xdg/applications/menu-xdg/kde_system_guard_-_process_table.desktop
ksysv	X-Debian-Apps-System	/var/lib/menu-xdg/applications/menu-xdg/kde_sysv-init_editor.desktop
kcron	X-Debian-Apps-System	/var/lib/menu-xdg/applications/menu-xdg/kde_task_scheduler.desktop
kuser	X-Debian-Apps-System	/var/lib/menu-xdg/applications/menu-xdg/kde_user_manager.desktop
kdebugdialog	X-Debian-Apps-System	/var/lib/menu-xdg/applications/menu-xdg/kdebugdialog.desktop
kdepasswd	X-Debian-Apps-System	/var/lib/menu-xdg/applications/menu-xdg/kdepasswd.desktop
kdeprintfax	X-Debian-Apps-System	/var/lib/menu-xdg/applications/menu-xdg/kdeprintfax.desktop
kdf	X-Debian-Apps-System	/var/lib/menu-xdg/applications/menu-xdg/kdiskfree.desktop
keditbookmarks	X-Debian-Apps-System	/var/lib/menu-xdg/applications/menu-xdg/keditbookmarks.desktop
kfind	X-Debian-Apps-System	/var/lib/menu-xdg/applications/menu-xdg/kfind.desktop
kfloppy	X-Debian-Apps-System	/var/lib/menu-xdg/applications/menu-xdg/kfloppy.desktop
kicker	X-Debian-Apps-System	/var/lib/menu-xdg/applications/menu-xdg/kicker.desktop
kjobviewer	X-Debian-Apps-System	/var/lib/menu-xdg/applications/menu-xdg/kjobviewer.desktop
kmenuedit	X-Debian-Apps-System	/var/lib/menu-xdg/applications/menu-xdg/kmenuedit.desktop
kpersonalizer	X-Debian-Apps-System	/var/lib/menu-xdg/applications/menu-xdg/kpersonalizer.desktop
kprinter	X-Debian-Apps-System	/var/lib/menu-xdg/applications/menu-xdg/kprinter.desktop
kwikdisk	X-Debian-Apps-System	/var/lib/menu-xdg/applications/menu-xdg/kwikdisk.desktop
loadmeter	X-Debian-Apps-System	/var/lib/menu-xdg/applications/menu-xdg/loadmeter.desktop
moodss	X-Debian-Apps-System	/var/lib/menu-xdg/applications/menu-xdg/moodss.desktop
mount.app	X-Debian-Apps-System	/var/lib/menu-xdg/applications/menu-xdg/mountapp.desktop
nautilus	X-Debian-Apps-System	/var/lib/menu-xdg/applications/menu-xdg/nautilus.desktop
netwatch	X-Debian-Apps-System	/var/lib/menu-xdg/applications/menu-xdg/netwatch.desktop
netload	X-Debian-Apps-System	/var/lib/menu-xdg/applications/menu-xdg/network_load_on_ppp0.desktop
oopadmin	X-Debian-Apps-System	/var/lib/menu-xdg/applications/menu-xdg/openoffice.org_printer_administration.desktop
/usr/lib/openoffice/program/setup	X-Debian-Apps-System	/var/lib/menu-xdg/applications/menu-xdg/openoffice.org_setup.desktop
x-terminal-emulator	X-Debian-Apps-System	/var/lib/menu-xdg/applications/menu-xdg/pstree.desktop
su-to-root	X-Debian-Apps-System	/var/lib/menu-xdg/applications/menu-xdg/recover.desktop
reportbug	X-Debian-Apps-System	/var/lib/menu-xdg/applications/menu-xdg/reportbug.desktop
gksuexec	X-Debian-Apps-System	/var/lib/menu-xdg/applications/menu-xdg/run_as_different_user_(gksu).desktop
si	X-Debian-Apps-System	/var/lib/menu-xdg/applications/menu-xdg/si.desktop
statnet	X-Debian-Apps-System	/var/lib/menu-xdg/applications/menu-xdg/statnet.desktop
/usr/bin/texconfig	X-Debian-Apps-System	/var/lib/menu-xdg/applications/menu-xdg/texconfig.desktop
top	X-Debian-Apps-System	/var/lib/menu-xdg/applications/menu-xdg/top.desktop
trafshow	X-Debian-Apps-System	/var/lib/menu-xdg/applications/menu-xdg/trafshow.desktop
wmbubble	X-Debian-Apps-System	/var/lib/menu-xdg/applications/menu-xdg/wmbubble.desktop
wmsensors	X-Debian-Apps-System	/var/lib/menu-xdg/applications/menu-xdg/wmsensors.desktop
wmsmpmon	X-Debian-Apps-System	/var/lib/menu-xdg/applications/menu-xdg/wmsmpmon.desktop
wmtop	X-Debian-Apps-System	/var/lib/menu-xdg/applications/menu-xdg/wmtop.desktop
xconsole	X-Debian-Apps-System	/var/lib/menu-xdg/applications/menu-xdg/xconsole.desktop
sh	X-Debian-Apps-System	/var/lib/menu-xdg/applications/menu-xdg/xdiskusage.desktop
xfilequery	X-Debian-Apps-System	/var/lib/menu-xdg/applications/menu-xdg/xfq_rpm_manager.desktop
xload	X-Debian-Apps-System	/var/lib/menu-xdg/applications/menu-xdg/xload.desktop
xlogmaster	X-Debian-Apps-System	/var/lib/menu-xdg/applications/menu-xdg/xlogmaster.desktop
xtraceroute	X-Debian-Apps-System	/var/lib/menu-xdg/applications/menu-xdg/xt.desktop
xvidtune	X-Debian-Apps-System	/var/lib/menu-xdg/applications/menu-xdg/xvidtune.desktop
gpsman	X-Debian-Apps-Technical	/var/lib/menu-xdg/applications/menu-xdg/gpsman.desktop
tkgate	X-Debian-Apps-Technical	/var/lib/menu-xdg/applications/menu-xdg/tkgate.desktop
wordinspect	X-Debian-Apps-Text	/var/lib/menu-xdg/applications/menu-xdg/dict_client.desktop
sh	X-Debian-Apps-Text	/var/lib/menu-xdg/applications/menu-xdg/fortune.desktop
gnome-dictionary	X-Debian-Apps-Text	/var/lib/menu-xdg/applications/menu-xdg/gnome_dictionary.desktop
htmldoc	X-Debian-Apps-Text	/var/lib/menu-xdg/applications/menu-xdg/htmldoc.desktop
gucharmap	X-Debian-Apps-Text	/var/lib/menu-xdg/applications/menu-xdg/unicode_character_map.desktop
ark	X-Debian-Apps-Tools	/var/lib/menu-xdg/applications/menu-xdg/ark.desktop
dasher	X-Debian-Apps-Tools	/var/lib/menu-xdg/applications/menu-xdg/dasher_text_entry.desktop
DataManager	X-Debian-Apps-Tools	/var/lib/menu-xdg/applications/menu-xdg/datamanager.desktop
dclock	X-Debian-Apps-Tools	/var/lib/menu-xdg/applications/menu-xdg/dclock.desktop
dfm	X-Debian-Apps-Tools	/var/lib/menu-xdg/applications/menu-xdg/desktop_file_manager.desktop
ding	X-Debian-Apps-Tools	/var/lib/menu-xdg/applications/menu-xdg/ding.desktop
editres	X-Debian-Apps-Tools	/var/lib/menu-xdg/applications/menu-xdg/editres.desktop
emelfm	X-Debian-Apps-Tools	/var/lib/menu-xdg/applications/menu-xdg/emelfm.desktop
file-roller	X-Debian-Apps-Tools	/var/lib/menu-xdg/applications/menu-xdg/file-roller.desktop
fookb-wmaker	X-Debian-Apps-Tools	/var/lib/menu-xdg/applications/menu-xdg/fookb-wmaker.desktop
gcombust	X-Debian-Apps-Tools	/var/lib/menu-xdg/applications/menu-xdg/gcombust.desktop
gcrontab	X-Debian-Apps-Tools	/var/lib/menu-xdg/applications/menu-xdg/gcrontab.desktop
gnomecard	X-Debian-Apps-Tools	/var/lib/menu-xdg/applications/menu-xdg/gnome_address_book.desktop
gnomecal	X-Debian-Apps-Tools	/var/lib/menu-xdg/applications/menu-xdg/gnome_calendar.desktop
gcm	X-Debian-Apps-Tools	/var/lib/menu-xdg/applications/menu-xdg/gnome_clipboard_manager.desktop
gnome-search-tool	X-Debian-Apps-Tools	/var/lib/menu-xdg/applications/menu-xdg/gnome_search_tool.desktop
gnucash	X-Debian-Apps-Tools	/var/lib/menu-xdg/applications/menu-xdg/gnucash.desktop
gODBCConfig	X-Debian-Apps-Tools	/var/lib/menu-xdg/applications/menu-xdg/godbcconfig.desktop
gramps	X-Debian-Apps-Tools	/var/lib/menu-xdg/applications/menu-xdg/gramps.desktop
gtktrain	X-Debian-Apps-Tools	/var/lib/menu-xdg/applications/menu-xdg/gtktrain.desktop
guitar	X-Debian-Apps-Tools	/var/lib/menu-xdg/applications/menu-xdg/guitar.desktop
iceconf	X-Debian-Apps-Tools	/var/lib/menu-xdg/applications/menu-xdg/iceconf.desktop
jscalibrator	X-Debian-Apps-Tools	/var/lib/menu-xdg/applications/menu-xdg/joystick_calibration.desktop
kaddressbook	X-Debian-Apps-Tools	/var/lib/menu-xdg/applications/menu-xdg/kaddressbook.desktop
kalarm	X-Debian-Apps-Tools	/var/lib/menu-xdg/applications/menu-xdg/kalarm.desktop
kandy	X-Debian-Apps-Tools	/var/lib/menu-xdg/applications/menu-xdg/kandy.desktop
karm	X-Debian-Apps-Tools	/var/lib/menu-xdg/applications/menu-xdg/karm.desktop
kcharselect	X-Debian-Apps-Tools	/var/lib/menu-xdg/applications/menu-xdg/kcharselect.desktop
kgpg	X-Debian-Apps-Tools	/var/lib/menu-xdg/applications/menu-xdg/kgpg.desktop
khexedit	X-Debian-Apps-Tools	/var/lib/menu-xdg/applications/menu-xdg/khexedit.desktop
kivio	X-Debian-Apps-Tools	/var/lib/menu-xdg/applications/menu-xdg/kivio.desktop
kjots	X-Debian-Apps-Tools	/var/lib/menu-xdg/applications/menu-xdg/kjots.desktop
klipper	X-Debian-Apps-Tools	/var/lib/menu-xdg/applications/menu-xdg/klipper.desktop
knotes	X-Debian-Apps-Tools	/var/lib/menu-xdg/applications/menu-xdg/knotes.desktop
koshell	X-Debian-Apps-Tools	/var/lib/menu-xdg/applications/menu-xdg/koffice_workspace.desktop
kmdr-editor	X-Debian-Apps-Tools	/var/lib/menu-xdg/applications/menu-xdg/kommander_editor.desktop
kontact	X-Debian-Apps-Tools	/var/lib/menu-xdg/applications/menu-xdg/kontact.desktop
korganizer	X-Debian-Apps-Tools	/var/lib/menu-xdg/applications/menu-xdg/korganizer.desktop
kpager	X-Debian-Apps-Tools	/var/lib/menu-xdg/applications/menu-xdg/kpager.desktop
kpalmdoc	X-Debian-Apps-Tools	/var/lib/menu-xdg/applications/menu-xdg/kpalmdoc.desktop
kpilot	X-Debian-Apps-Tools	/var/lib/menu-xdg/applications/menu-xdg/kpilot.desktop
kpresenter	X-Debian-Apps-Tools	/var/lib/menu-xdg/applications/menu-xdg/kpresenter.desktop
kregexpeditor	X-Debian-Apps-Tools	/var/lib/menu-xdg/applications/menu-xdg/kregexpeditor.desktop
ksync	X-Debian-Apps-Tools	/var/lib/menu-xdg/applications/menu-xdg/ksync.desktop
kthesaurus	X-Debian-Apps-Tools	/var/lib/menu-xdg/applications/menu-xdg/kthesaurus.desktop
ktimer	X-Debian-Apps-Tools	/var/lib/menu-xdg/applications/menu-xdg/ktimer.desktop
ktip	X-Debian-Apps-Tools	/var/lib/menu-xdg/applications/menu-xdg/ktip.desktop
ktnef	X-Debian-Apps-Tools	/var/lib/menu-xdg/applications/menu-xdg/ktnef.desktop
kugar	X-Debian-Apps-Tools	/var/lib/menu-xdg/applications/menu-xdg/kugar.desktop
kudesigner	X-Debian-Apps-Tools	/var/lib/menu-xdg/applications/menu-xdg/kugar_designer.desktop
mc	X-Debian-Apps-Tools	/var/lib/menu-xdg/applications/menu-xdg/mc.desktop
nonlock	X-Debian-Apps-Tools	/var/lib/menu-xdg/applications/menu-xdg/nonlock.desktop
oclock	X-Debian-Apps-Tools	/var/lib/menu-xdg/applications/menu-xdg/oclock.desktop
ODBCConfig	X-Debian-Apps-Tools	/var/lib/menu-xdg/applications/menu-xdg/odbcconfig.desktop
odbctest	X-Debian-Apps-Tools	/var/lib/menu-xdg/applications/menu-xdg/odbctest.desktop
qps	X-Debian-Apps-Tools	/var/lib/menu-xdg/applications/menu-xdg/qps.desktop
/usr/bin/X11/regexplorer	X-Debian-Apps-Tools	/var/lib/menu-xdg/applications/menu-xdg/regexplorer.desktop
texfind	X-Debian-Apps-Tools	/var/lib/menu-xdg/applications/menu-xdg/texfind.desktop
dotfile	X-Debian-Apps-Tools	/var/lib/menu-xdg/applications/menu-xdg/the_dotfile_generator.desktop
unclutter	X-Debian-Apps-Tools	/var/lib/menu-xdg/applications/menu-xdg/unclutter_-_start.desktop
killall	X-Debian-Apps-Tools	/var/lib/menu-xdg/applications/menu-xdg/unclutter_-_stop.desktop
wmcalc	X-Debian-Apps-Tools	/var/lib/menu-xdg/applications/menu-xdg/wmcalc.desktop
wmCalClock	X-Debian-Apps-Tools	/var/lib/menu-xdg/applications/menu-xdg/wmcalclock.desktop
wmGrabImage	X-Debian-Apps-Tools	/var/lib/menu-xdg/applications/menu-xdg/wmgrabimage.desktop
wmMoonClock	X-Debian-Apps-Tools	/var/lib/menu-xdg/applications/menu-xdg/wmmoonclock.desktop
wmpinboard	X-Debian-Apps-Tools	/var/lib/menu-xdg/applications/menu-xdg/wmpinboard.desktop
worker	X-Debian-Apps-Tools	/var/lib/menu-xdg/applications/menu-xdg/worker.desktop
xwd	X-Debian-Apps-Tools	/var/lib/menu-xdg/applications/menu-xdg/x_window_snapshot.desktop
xcalendar	X-Debian-Apps-Tools	/var/lib/menu-xdg/applications/menu-xdg/xcalendar-i18n.desktop
xclipboard	X-Debian-Apps-Tools	/var/lib/menu-xdg/applications/menu-xdg/xclipboard.desktop
xclock	X-Debian-Apps-Tools	/var/lib/menu-xdg/applications/menu-xdg/xclock_(analog).desktop
xcutsel	X-Debian-Apps-Tools	/var/lib/menu-xdg/applications/menu-xdg/xcutsel.desktop
x-terminal-emulator	X-Debian-Apps-Tools	/var/lib/menu-xdg/applications/menu-xdg/xev.desktop
xfe	X-Debian-Apps-Tools	/var/lib/menu-xdg/applications/menu-xdg/xfe_file_manager.desktop
xfontsel	X-Debian-Apps-Tools	/var/lib/menu-xdg/applications/menu-xdg/xfontsel.desktop
/usr/bin/X11/xkbsel-aw	X-Debian-Apps-Tools	/var/lib/menu-xdg/applications/menu-xdg/xkbsel.desktop
xkill	X-Debian-Apps-Tools	/var/lib/menu-xdg/applications/menu-xdg/xkill.desktop
xmag	X-Debian-Apps-Tools	/var/lib/menu-xdg/applications/menu-xdg/xmag.desktop
xrefresh	X-Debian-Apps-Tools	/var/lib/menu-xdg/applications/menu-xdg/xrefresh.desktop
zclock	X-Debian-Apps-Tools	/var/lib/menu-xdg/applications/menu-xdg/zclock.desktop
acroread	X-Debian-Apps-Viewers	/var/lib/menu-xdg/applications/menu-xdg/acrobat_reader.desktop
alevt	X-Debian-Apps-Viewers	/var/lib/menu-xdg/applications/menu-xdg/alevt.desktop
effectv	X-Debian-Apps-Viewers	/var/lib/menu-xdg/applications/menu-xdg/effectv.desktop
endeavour2	X-Debian-Apps-Viewers	/var/lib/menu-xdg/applications/menu-xdg/endeavour2_viewer.desktop
gfontview	X-Debian-Apps-Viewers	/var/lib/menu-xdg/applications/menu-xdg/gfontview.desktop
gliv	X-Debian-Apps-Viewers	/var/lib/menu-xdg/applications/menu-xdg/gliv.desktop
gnome-gv	X-Debian-Apps-Viewers	/var/lib/menu-xdg/applications/menu-xdg/gnome_ghostscript_pdf_viewer.desktop
gqview	X-Debian-Apps-Viewers	/var/lib/menu-xdg/applications/menu-xdg/gqview.desktop
gtv	X-Debian-Apps-Viewers	/var/lib/menu-xdg/applications/menu-xdg/gtv_mpeg_player.desktop
/usr/bin/X11/gv	X-Debian-Apps-Viewers	/var/lib/menu-xdg/applications/menu-xdg/gv.desktop
display	X-Debian-Apps-Viewers	/var/lib/menu-xdg/applications/menu-xdg/imagemagick.desktop
kdvi	X-Debian-Apps-Viewers	/var/lib/menu-xdg/applications/menu-xdg/kdvi.desktop
kghostview	X-Debian-Apps-Viewers	/var/lib/menu-xdg/applications/menu-xdg/kghostview.desktop
kview	X-Debian-Apps-Viewers	/var/lib/menu-xdg/applications/menu-xdg/kview.desktop
gmplayer	X-Debian-Apps-Viewers	/var/lib/menu-xdg/applications/menu-xdg/mplayer.desktop
paul	X-Debian-Apps-Viewers	/var/lib/menu-xdg/applications/menu-xdg/paul.desktop
pornview	X-Debian-Apps-Viewers	/var/lib/menu-xdg/applications/menu-xdg/pornview.desktop
realplayer	X-Debian-Apps-Viewers	/var/lib/menu-xdg/applications/menu-xdg/real_player.desktop
wordview	X-Debian-Apps-Viewers	/var/lib/menu-xdg/applications/menu-xdg/wordview.desktop
xawtv	X-Debian-Apps-Viewers	/var/lib/menu-xdg/applications/menu-xdg/xawtv.desktop
xbmbrowser	X-Debian-Apps-Viewers	/var/lib/menu-xdg/applications/menu-xdg/xbmbrowser.desktop
xditview	X-Debian-Apps-Viewers	/var/lib/menu-xdg/applications/menu-xdg/xditview.desktop
xdvi	X-Debian-Apps-Viewers	/var/lib/menu-xdg/applications/menu-xdg/xdvi.desktop
xfileview	X-Debian-Apps-Viewers	/var/lib/menu-xdg/applications/menu-xdg/xfv_file_viewer.desktop
xine	X-Debian-Apps-Viewers	/var/lib/menu-xdg/applications/menu-xdg/xine_media_player.desktop
xmovie	X-Debian-Apps-Viewers	/var/lib/menu-xdg/applications/menu-xdg/xmovie.desktop
kasteroids	X-Debian-Games-Arcade	/var/lib/menu-xdg/applications/menu-xdg/kasteroids.desktop
kbounce	X-Debian-Games-Arcade	/var/lib/menu-xdg/applications/menu-xdg/kde_bounce_ball_game.desktop
kolf	X-Debian-Games-Arcade	/var/lib/menu-xdg/applications/menu-xdg/kde_miniature_golf.desktop
ksnake	X-Debian-Games-Arcade	/var/lib/menu-xdg/applications/menu-xdg/kde_snake_race.desktop
kspaceduel	X-Debian-Games-Arcade	/var/lib/menu-xdg/applications/menu-xdg/kde_spaceduel.desktop
ktron	X-Debian-Games-Arcade	/var/lib/menu-xdg/applications/menu-xdg/kde_tron.desktop
kgoldrunner	X-Debian-Games-Arcade	/var/lib/menu-xdg/applications/menu-xdg/kgoldrunner.desktop
xasteroids	X-Debian-Games-Arcade	/var/lib/menu-xdg/applications/menu-xdg/xasteroids.desktop
atlantik	X-Debian-Games-Board	/var/lib/menu-xdg/applications/menu-xdg/atlantik.desktop
atlantikdesigner	X-Debian-Games-Board	/var/lib/menu-xdg/applications/menu-xdg/atlantik_designer.desktop
gnubg	X-Debian-Games-Board	/var/lib/menu-xdg/applications/menu-xdg/gnu_backgammon.desktop
kbattleship	X-Debian-Games-Board	/var/lib/menu-xdg/applications/menu-xdg/kbattleship.desktop
kbackgammon	X-Debian-Games-Board	/var/lib/menu-xdg/applications/menu-xdg/kde_backgammon.desktop
kreversi	X-Debian-Games-Board	/var/lib/menu-xdg/applications/menu-xdg/kde_reversi.desktop
kshisen	X-Debian-Games-Board	/var/lib/menu-xdg/applications/menu-xdg/kde_shisen-sho.desktop
kenolaba	X-Debian-Games-Board	/var/lib/menu-xdg/applications/menu-xdg/kenolaba.desktop
klines	X-Debian-Games-Board	/var/lib/menu-xdg/applications/menu-xdg/klines.desktop
kmahjongg	X-Debian-Games-Board	/var/lib/menu-xdg/applications/menu-xdg/kmahjongg.desktop
kwin4	X-Debian-Games-Board	/var/lib/menu-xdg/applications/menu-xdg/kwin4.desktop
gnome-freecell	X-Debian-Games-Card	/var/lib/menu-xdg/applications/menu-xdg/gnome_freecell.desktop
sol	X-Debian-Games-Card	/var/lib/menu-xdg/applications/menu-xdg/gnome_solitaire_games.desktop
megami	X-Debian-Games-Card	/var/lib/menu-xdg/applications/menu-xdg/kde_blackjack.desktop
lskat	X-Debian-Games-Card	/var/lib/menu-xdg/applications/menu-xdg/kde_lieutnant_skat.desktop
kpat	X-Debian-Games-Card	/var/lib/menu-xdg/applications/menu-xdg/kde_patience.desktop
kpoker	X-Debian-Games-Card	/var/lib/menu-xdg/applications/menu-xdg/kde_poker.desktop
kblackbox	X-Debian-Games-Puzzles	/var/lib/menu-xdg/applications/menu-xdg/kblackbox.desktop
katomic	X-Debian-Games-Puzzles	/var/lib/menu-xdg/applications/menu-xdg/kde_atomic_entertainment.desktop
khangman	X-Debian-Games-Puzzles	/var/lib/menu-xdg/applications/menu-xdg/khangman.desktop
ksame	X-Debian-Games-Puzzles	/var/lib/menu-xdg/applications/menu-xdg/kde_samegame.desktop
ksokoban	X-Debian-Games-Puzzles	/var/lib/menu-xdg/applications/menu-xdg/kde_sokoban.desktop
klickety	X-Debian-Games-Puzzles	/var/lib/menu-xdg/applications/menu-xdg/klickety.desktop
kmessedwords	X-Debian-Games-Puzzles	/var/lib/menu-xdg/applications/menu-xdg/kmessedwords.desktop
kmines	X-Debian-Games-Puzzles	/var/lib/menu-xdg/applications/menu-xdg/kmines.desktop
foobillard	X-Debian-Games-Sports	/var/lib/menu-xdg/applications/menu-xdg/foobillard.desktop
kjumpingcube	X-Debian-Games-Strategy	/var/lib/menu-xdg/applications/menu-xdg/kjumpingcube.desktop
konquest	X-Debian-Games-Strategy	/var/lib/menu-xdg/applications/menu-xdg/konquest.desktop
kfouleggs	X-Debian-Games-Tetris-like	/var/lib/menu-xdg/applications/menu-xdg/kde_foul_eggs.desktop
ksirtet	X-Debian-Games-Tetris-like	/var/lib/menu-xdg/applications/menu-xdg/kde_sirtet.desktop
ksmiletris	X-Debian-Games-Tetris-like	/var/lib/menu-xdg/applications/menu-xdg/kde_smiletris.desktop
amor	X-Debian-Games-Toys	/var/lib/menu-xdg/applications/menu-xdg/amor.desktop
kaphorism	X-Debian-Games-Toys	/var/lib/menu-xdg/applications/menu-xdg/k_aphorisms.desktop
ktuberling	X-Debian-Games-Toys	/var/lib/menu-xdg/applications/menu-xdg/kde_potato_guy.desktop
kmoon	X-Debian-Games-Toys	/var/lib/menu-xdg/applications/menu-xdg/kmoon.desktop
kodo	X-Debian-Games-Toys	/var/lib/menu-xdg/applications/menu-xdg/kodometer.desktop
kteatime	X-Debian-Games-Toys	/var/lib/menu-xdg/applications/menu-xdg/kteatime.desktop
kworldclock	X-Debian-Games-Toys	/var/lib/menu-xdg/applications/menu-xdg/kworldclock.desktop
lightspeed	X-Debian-Games-Toys	/var/lib/menu-xdg/applications/menu-xdg/light_speed.desktop
penguineyes	X-Debian-Games-Toys	/var/lib/menu-xdg/applications/menu-xdg/penguineyes.desktop
tdfsb	X-Debian-Games-Toys	/var/lib/menu-xdg/applications/menu-xdg/tdfsb.desktop
wmtictactoe	X-Debian-Games-Toys	/var/lib/menu-xdg/applications/menu-xdg/wmtictactoe.desktop
xcruiser	X-Debian-Games-Toys	/var/lib/menu-xdg/applications/menu-xdg/xcruiser.desktop
xeyes	X-Debian-Games-Toys	/var/lib/menu-xdg/applications/menu-xdg/xeyes.desktop
xlogo	X-Debian-Games-Toys	/var/lib/menu-xdg/applications/menu-xdg/xlogo.desktop
dwww	X-Debian-Help	/var/lib/menu-xdg/applications/menu-xdg/dwww.desktop
info	X-Debian-Help	/var/lib/menu-xdg/applications/menu-xdg/info.desktop
khelpcenter	X-Debian-Help	/var/lib/menu-xdg/applications/menu-xdg/kde_help_center.desktop
hman	X-Debian-Help	/var/lib/menu-xdg/applications/menu-xdg/man2html.desktop
texdoctk	X-Debian-Help	/var/lib/menu-xdg/applications/menu-xdg/texdoctk.desktop
texshow	X-Debian-Help	/var/lib/menu-xdg/applications/menu-xdg/texshow.desktop
xman	X-Debian-Help	/var/lib/menu-xdg/applications/menu-xdg/xman.desktop
yelp	X-Debian-Help	/var/lib/menu-xdg/applications/menu-xdg/yelp.desktop
ktux	X-Debian-Screen-Lock	/var/lib/menu-xdg/applications/menu-xdg/ktux.desktop
xscreensaver-command	X-Debian-Screen-Lock	/var/lib/menu-xdg/applications/menu-xdg/lock_screen_(xscreensaver).desktop
xplanet	X-Debian-Screen-Root-window	/var/lib/menu-xdg/applications/menu-xdg/xplanet.desktop
xsetroot	X-Debian-Screen-Root-window	/var/lib/menu-xdg/applications/menu-xdg/xsetroot.desktop
xscreensaver-command	X-Debian-Screen-Save	/var/lib/menu-xdg/applications/menu-xdg/activate_screensaver_(next).desktop
beforelight	X-Debian-Screen-Save	/var/lib/menu-xdg/applications/menu-xdg/beforelight.desktop
xscreensaver	X-Debian-Screen-Save	/var/lib/menu-xdg/applications/menu-xdg/enable_xscreensaver.desktop
aafire	X-Debian-Screen-Save-Text	/var/lib/menu-xdg/applications/menu-xdg/aa_fire.desktop
Eterm	X-Debian-XShells	/var/lib/menu-xdg/applications/menu-xdg/eterm.desktop
gnome-terminal	X-Debian-XShells	/var/lib/menu-xdg/applications/menu-xdg/gnome_terminal.desktop
konsole	X-Debian-XShells	/var/lib/menu-xdg/applications/menu-xdg/konsole.desktop
multi-gnome-terminal	X-Debian-XShells	/var/lib/menu-xdg/applications/menu-xdg/multi_gnome_terminal.desktop
oneliner	X-Debian-XShells	/var/lib/menu-xdg/applications/menu-xdg/oneliner.desktop
powershell	X-Debian-XShells	/var/lib/menu-xdg/applications/menu-xdg/powershell.desktop
xexec	X-Debian-XShells	/var/lib/menu-xdg/applications/menu-xdg/xexec.desktop
xterm	X-Debian-XShells	/var/lib/menu-xdg/applications/menu-xdg/xterm.desktop
uxterm	X-Debian-XShells	/var/lib/menu-xdg/applications/menu-xdg/xterm_(unicode).desktop
\.


--
-- Data for TOC entry 574 (OID 2063949)
-- Name: configuration; Type: TABLE DATA; Schema: public; Owner: postgres
--

COPY configuration (configuration, enabled, extends) FROM stdin;
mafix-1.0	t	\N
slix-1.0	t	\N
frix-1.0	t	\N
slix-2.0	t	\N
slix-base-2.0	\N	\N
\.


--
-- Data for TOC entry 575 (OID 2063953)
-- Name: app_configuration; Type: TABLE DATA; Schema: public; Owner: postgres
--

COPY app_configuration (app, configuration, enabled, must, want) FROM stdin;
inkscape	slix-2.0	t	\N	\N
Emacs	slix-2.0	t	\N	\N
Gimp	slix-2.0	t	\N	\N
texmacs	slix-2.0	t	\N	\N
scribus	slix-2.0	\N	\N	\N
gvim	slix-2.0	\N	\N	\N
kate	slix-2.0	\N	\N	\N
quanta	slix-2.0	\N	\N	\N
kile	slix-2.0	\N	\N	\N
audacity	slix-2.0	\N	\N	\N
blender	slix-2.0	\N	\N	\N
oowriter	frix-1.0	\N	\N	\N
oocalc	frix-1.0	\N	\N	\N
ooimpress	frix-1.0	\N	\N	\N
latex	frix-1.0	\N	t	\N
Emacs	frix-1.0	\N	t	\N
dia	slix-base-2.0	\N	t	\N
streamtuner	slix-2.0	\N	t	t
hugin	frix-1.0	\N	t	t
dotty	slix-base-2.0	\N	\N	\N
kaffeine	slix-2.0	\N	t	t
\.


--
-- Data for TOC entry 576 (OID 2064003)
-- Name: app_exec; Type: TABLE DATA; Schema: public; Owner: postgres
--

COPY app_exec (app, exec, registry) FROM stdin;
nautilus	nautilus network:	/usr/share/applications/network-scheme.desktop
xsane	xsane	/usr/share/applications/xsane.desktop
gnome-control-center	gnome-control-center	/usr/share/applications/gnomecc.desktop
gnome-system-monitor	gnome-system-monitor	/usr/share/applications/gnome-system-monitor.desktop
nautilus	nautilus --no-desktop --browser	/usr/share/applications/nautilus.desktop
gcmui	gcmui	/usr/share/applications/gcm.desktop
gdmflexiserver	gdmflexiserver --xnest	/usr/share/applications/gdmflexiserver-xnest.desktop
gnumeric	gnumeric %F	/usr/share/applications/gnumeric.desktop
dasher	dasher	/usr/share/applications/dasher.desktop
xchat	xchat	/usr/share/applications/xchat.desktop
sodipodi	sodipodi %U	/usr/share/applications/sodipodi.desktop
gucharmap	gucharmap	/usr/share/applications/gucharmap.desktop
gksu	gksu -u root /usr/sbin/synaptic	/usr/share/applications/synaptic.desktop
gnomemeeting	gnomemeeting	/usr/share/applications/gnomemeeting.desktop
yelp	yelp	/usr/share/applications/yelp.desktop
glade-2	glade-2 %F	/usr/share/applications/glade-2.desktop
gcombust	gcombust	/usr/share/applications/gcombust.desktop
gksu	gksu gdmsetup	/usr/share/applications/gdmsetup.desktop
gdmflexiserver	gdmflexiserver	/usr/share/applications/gdmflexiserver.desktop
file-roller	file-roller	/usr/share/applications/file-roller.desktop
alc	alc	/usr/share/applications/alc.desktop
xscreensaver-demo	xscreensaver-demo	/usr/share/applications/screensaver-properties.desktop
eclipse	/usr/bin/eclipse	/usr/share/applications/eclipse.desktop
inkscape	inkscape %U	/usr/share/applications/inkscape.desktop
gedit	gedit %U	/usr/share/applications/gedit.desktop
gnome-system-log	gnome-system-log	/usr/share/applications/gnome-system-log.desktop
oowriter	/usr/bin/oowriter %U	/usr/share/applications/ooo645writer.desktop
ooweb	/usr/bin/ooweb %U	/usr/share/applications/ooo645web.desktop
gnome-search-tool	gnome-search-tool	/usr/share/applications/gnome-search-tool.desktop
gnome-dictionary	gnome-dictionary -a	/usr/share/applications/gnome-dictionary.desktop
gfloppy	gfloppy	/usr/share/applications/gfloppy.desktop
bug-buddy	bug-buddy	/usr/share/applications/bug-buddy.desktop
ggv	ggv %U	/usr/share/applications/ggv.desktop
gconf-editor	gconf-editor	/usr/share/applications/gconf-editor.desktop
dia-gnome	dia-gnome	/usr/share/applications/dia.desktop
filmgimp	filmgimp	/usr/share/applications/filmgimp.desktop
wxcas	wxcas	/usr/share/applications/wxcas.desktop
gnome-terminal	gnome-terminal	/usr/share/applications/gnome-terminal.desktop
emacs21	/usr/bin/emacs21	/usr/share/applications/emacs21.desktop
vumeter	vumeter -r	/usr/share/applications/reclevel.desktop
vumeter	vumeter	/usr/share/applications/vumeter.desktop
gperiodic	gperiodic	/usr/share/applications/gperiodic.desktop
gnome-volume-control	gnome-volume-control	/usr/share/applications/gnome-volume-control.desktop
gnome-cd	gnome-cd	/usr/share/applications/gnome-cd.desktop
gnome-sound-recorder	gnome-sound-recorder	/usr/share/applications/gnome-sound-recorder.desktop
gcalctool	gcalctool	/usr/share/applications/gcalctool.desktop
ooimpress	/usr/bin/ooimpress %U	/usr/share/applications/ooo645impress.desktop
realplayer	realplayer	/usr/share/applications/realplayer.desktop
gimp-remote-2.0	gimp-remote-2.0 %U	/usr/share/applications/gimp-2.0.desktop
gksu	gksu /usr/bin/x-terminal-emulator	/usr/share/applications/gksu.desktop
kcmshell	kcmshell khtml_plugins	/usr/share/applications/kde/khtml_plugins.desktop
kcmshell	kcmshell kresources	/usr/share/applications/kde/kresources.desktop
umbrello	umbrello -caption "%c" %i %m	/usr/share/applications/kde/umbrello.desktop
amor	amor	/usr/share/applications/kde/amor.desktop
ark	ark -caption "%c" %i %m %U	/usr/share/applications/kde/ark.desktop
kcmshell	kcmshell %i kicker_config kcmtaskbar	/usr/share/applications/kde/kcmkicker.desktop
kcmshell	kcmshell kcmhistory	/usr/share/applications/kde/kcmhistory.desktop
kfmclient	kfmclient openProfile filemanagement	/usr/share/applications/kde/Home.desktop
kfmclient	kfmclient openURL %u inode/directory	/usr/share/applications/kde/kfmclient_dir.desktop
kfmclient	kfmclient openURL %u	/usr/share/applications/kde/kfmclient.desktop
appletproxy	appletproxy knewsticker.desktop	/usr/share/applications/kde/knewsticker-standalone.desktop
kfmclient	kfmclient openURL %u text/html	/usr/share/applications/kde/kfmclient_html.desktop
kfmclient	kfmclient openURL %u application/x-webarchive	/usr/share/applications/kde/kfmclient_war.desktop
kfmclient	kfmclient openProfile webbrowsing	/usr/share/applications/kde/konqbrowser.desktop
konqueror	konqueror --profile filemanagement	/usr/share/applications/kde/konquerorsu.desktop
ksysguard	ksysguard %U	/usr/share/applications/kde/ksysguard.desktop
kate	kate %u	/usr/share/applications/kde/kate.desktop
kwrite	kwrite %u	/usr/share/applications/kde/kwrite.desktop
kcalc	kcalc  -caption "%c" %i %m	/usr/share/applications/kde/kcalc.desktop
kcharselect	kcharselect -caption "%c" %i %m	/usr/share/applications/kde/KCharSelect.desktop
kcmshell	kcmshell kcmlirc	/usr/share/applications/kde/kcmlirc.desktop
kdict	kdict -caption "%c" %i %m	/usr/share/applications/kde/kdict.desktop
kget	kget -caption "%c" %i %m	/usr/share/applications/kde/kget.desktop
kppplogview	kppplogview	/usr/share/applications/kde/kppplogview.desktop
kppp	kppp %i %m	/usr/share/applications/kde/Kppp.desktop
kwifimanager	kwifimanager -caption "%c" %i %m	/usr/share/applications/kde/kwifimanager.desktop
krdc	krdc -caption "%c" %i %m	/usr/share/applications/kde/krdc.desktop
kcmshell	kcmshell kcmkrfb	/usr/share/applications/kde/kcmkrfb.desktop
krfb	krfb -caption "%c" %i %m	/usr/share/applications/kde/krfb.desktop
ksirc	ksirc %i %m	/usr/share/applications/kde/ksirc.desktop
kcmshell	kcmshell kcmwifi	/usr/share/applications/kde/kcmwifi.desktop
kregexpeditor	kregexpeditor	/usr/share/applications/kde/kregexpeditor.desktop
kdepasswd	kdepasswd	/usr/share/applications/kde/kdepasswd.desktop
kcmshell	kcmshell userinfo	/usr/share/applications/kde/userinfo.desktop
kmoon	kmoon	/usr/share/applications/kde/kmoon.desktop
kodo	kodo	/usr/share/applications/kde/kodo.desktop
kteatime	kteatime	/usr/share/applications/kde/kteatime.desktop
kworldclock	kworldclock	/usr/share/applications/kde/kworldclock.desktop
kcmshell	kcmshell kcmdf	/usr/share/applications/kde/kcmdf.desktop
kdf	kdf -caption "%c"	/usr/share/applications/kde/kdf.desktop
kwikdisk	kwikdisk -caption "%c"	/usr/share/applications/kde/kwikdisk.desktop
kedit	kedit  -caption "%c" %i %m %u	/usr/share/applications/kde/KEdit.desktop
kfloppy	kfloppy -caption "%c" %i %m	/usr/share/applications/kde/KFloppy.desktop
kgpg	kgpg %U	/usr/share/applications/kde/kgpg.desktop
khexedit	khexedit -caption "%c" %i %m %f	/usr/share/applications/kde/khexedit.desktop
kjots	kjots  -caption "%c" %i %m	/usr/share/applications/kde/Kjots.desktop
kcmshell	kcmshell laptop	/usr/share/applications/kde/laptop.desktop
kcmshell	kcmshell pcmcia	/usr/share/applications/kde/pcmcia.desktop
kcmshell	kcmshell kvaio	/usr/share/applications/kde/kvaio.desktop
kcmshell	kcmshell kwallet	/usr/share/applications/kde/kwalletconfig.desktop
ktimer	ktimer	/usr/share/applications/kde/ktimer.desktop
atlantikdesigner	atlantikdesigner -caption "%c" %i %m	/usr/share/applications/kde/atlantikdesigner.desktop
kwalletmanager	kwalletmanager %u	/usr/share/applications/kde/kwalletmanager.desktop
artsbuilder	artsbuilder -caption "%c"	/usr/share/applications/kde/artsbuilder.desktop
artscontrol	artscontrol -caption "%c"	/usr/share/applications/kde/artscontrol.desktop
juk	juk -caption "%c" %i %m	/usr/share/applications/kde/juk.desktop
kaboodle	kaboodle %i %m -caption "%c" %U	/usr/share/applications/kde/kaboodle.desktop
kcmshell	kcmshell libkcddb	/usr/share/applications/kde/libkcddb.desktop
kscd	kscd -caption "%c" %i %m	/usr/share/applications/kde/kscd.desktop
kcmshell	kcmshell audiocd	/usr/share/applications/kde/audiocd.desktop
kaudiocreator	kaudiocreator	/usr/share/applications/kde/kaudiocreator.desktop
kcmshell	kcmshell kwindecoration	/usr/share/applications/kde/kwindecoration.desktop
kcmshell	kcmshell kwinoptions	/usr/share/applications/kde/kwinoptions.desktop
kmid	kmid %u	/usr/share/applications/kde/kmid.desktop
kmix	kmix -caption "%c" %i %m	/usr/share/applications/kde/kmix.desktop
kcmshell	kcmshell kmixcfg	/usr/share/applications/kde/kmixcfg.desktop
krec	krec %i %m -caption "%c"	/usr/share/applications/kde/krec.desktop
noatun	noatun %i %m -caption "%c" %U	/usr/share/applications/kde/noatun.desktop
kig	kig %i %m -caption "%c"	/usr/share/applications/kde/kig.desktop
kpalmdoc	kpalmdoc	/usr/share/applications/kde/kpalmdoc.desktop
kpilot	kpilot	/usr/share/applications/kde/kpilot.desktop
kpilotDaemon	kpilotDaemon	/usr/share/applications/kde/kpilotdaemon.desktop
korganizer	korganizer	/usr/share/applications/kde/korganizer.desktop
kalarm	kalarm -caption "%c" %i	/usr/share/applications/kde/kalarm.desktop
kaddressbook	kaddressbook %u	/usr/share/applications/kde/kaddressbook.desktop
kandy	kandy %i %m -caption "%c"	/usr/share/applications/kde/kandy.desktop
karm	karm  -caption "%c" %i %m	/usr/share/applications/kde/karm.desktop
ktnef	ktnef %i %m -caption "%c"	/usr/share/applications/kde/ktnef.desktop
kcmshell	kcmshell kcmcgi	/usr/share/applications/kde/kcmcgi.desktop
kmail	kmail -caption "%c" %i %m	/usr/share/applications/kde/KMail.desktop
knode	knode -caption "%c" %i %m	/usr/share/applications/kde/KNode.desktop
knotes	knotes	/usr/share/applications/kde/knotes.desktop
kdialog	kdialog --sorry "konsolekalendar is a command-line only program.  Please read the handbook at help:/konsolekalendar for more info."	/usr/share/applications/kde/konsolekalendar.desktop
kontact	kontact	/usr/share/applications/kde/Kontact.desktop
korn	korn  -caption "%c" %i %m %f	/usr/share/applications/kde/KOrn.desktop
atlantik	/usr/games/atlantik -caption "%c" %i %m	/usr/share/applications/kde/atlantik.desktop
kcmshell	kcmshell keyboard_layout	/usr/share/applications/kde/keyboard_layout.desktop
cervisia	cervisia -caption "%c" %i %m %u	/usr/share/applications/kde/cervisia.desktop
flashkard	flashkard -caption "%c" %i %m	/usr/share/applications/kde/flashkard.desktop
konsole	konsole	/usr/share/applications/kde/konsole.desktop
konsole	konsole --type su	/usr/share/applications/kde/konsolesu.desktop
kalzium	kalzium -caption "%c" %i %m	/usr/share/applications/kde/kalzium.desktop
kappfinder	kappfinder	/usr/share/applications/kde/kappfinder.desktop
kasteroids	/usr/games/kasteroids %i %m -caption "%c"	/usr/share/applications/kde/kasteroids.desktop
kcmshell	kcmshell keyboard	/usr/share/applications/kde/keyboard.desktop
kcmshell	kcmshell componentchooser	/usr/share/applications/kde/componentchooser.desktop
kcmshell	kcmshell khotkeys	/usr/share/applications/kde/khotkeys.desktop
kcontrol	kcontrol -caption "%c" %i %m	/usr/share/applications/kde/KControl.desktop
kcmshell	kcmshell arts	/usr/share/applications/kde/arts.desktop
kcmshell	kcmshell background	/usr/share/applications/kde/background.desktop
kcmshell	kcmshell bell	/usr/share/applications/kde/bell.desktop
kcmshell	kcmshell cache	/usr/share/applications/kde/cache.desktop
kcmshell	kcmshell clock	/usr/share/applications/kde/clock.desktop
kcmshell	kcmshell colors	/usr/share/applications/kde/colors.desktop
kcmshell	kcmshell desktopbehavior	/usr/share/applications/kde/desktopbehavior.desktop
kcmshell	kcmshell cookies	/usr/share/applications/kde/cookies.desktop
kcmshell	kcmshell crypto	/usr/share/applications/kde/crypto.desktop
kcmshell	kcmshell desktop	/usr/share/applications/kde/desktop.desktop
kcmshell	kcmshell kcmperformance	/usr/share/applications/kde/kcmperformance.desktop
kcmshell	kcmshell desktoppath	/usr/share/applications/kde/desktoppath.desktop
kcmshell	kcmshell devices	/usr/share/applications/kde/devices.desktop
kcmshell	kcmshell display	/usr/share/applications/kde/display.desktop
kcmshell	kcmshell dma	/usr/share/applications/kde/dma.desktop
kcmshell	kcmshell ebrowsing	/usr/share/applications/kde/ebrowsing.desktop
kcmshell	kcmshell email	/usr/share/applications/kde/email.desktop
kcmshell	kcmshell energy	/usr/share/applications/kde/energy.desktop
kcmshell	kcmshell filebrowser	/usr/share/applications/kde/filebrowser.desktop
kcmshell	kcmshell fileshare	/usr/share/applications/kde/fileshare.desktop
kcmshell	kcmshell filetypes	/usr/share/applications/kde/filetypes.desktop
kcmshell	kcmshell fonts	/usr/share/applications/kde/fonts.desktop
kcmshell	kcmshell icons	/usr/share/applications/kde/icons.desktop
kcmshell	kcmshell interrupts	/usr/share/applications/kde/interrupts.desktop
kcmshell	kcmshell ioports	/usr/share/applications/kde/ioports.desktop
kcmshell	kcmshell ioslaveinfo	/usr/share/applications/kde/ioslaveinfo.desktop
kcmshell	kcmshell kcmaccess	/usr/share/applications/kde/kcmaccess.desktop
kcmshell	kcmshell kcmcss	/usr/share/applications/kde/kcmcss.desktop
kcmshell	kcmshell kcmfontinst	/usr/share/applications/kde/kcmfontinst.desktop
kcmshell	kcmshell kcmkded	/usr/share/applications/kde/kcmkded.desktop
kcmshell	kcmshell kcmlaunch	/usr/share/applications/kde/kcmlaunch.desktop
kcmshell	kcmshell kcmnotify	/usr/share/applications/kde/kcmnotify.desktop
kcmshell	kcmshell khtml_behavior	/usr/share/applications/kde/khtml_behavior.desktop
kcmshell	kcmshell kcmsmserver	/usr/share/applications/kde/kcmsmserver.desktop
kcmshell	kcmshell kcmtaskbar	/usr/share/applications/kde/kcmtaskbar.desktop
kcmshell	kcmshell kcmusb	/usr/share/applications/kde/kcmusb.desktop
kcmshell	kcmshell kcmview1394	/usr/share/applications/kde/kcmview1394.desktop
kcmshell	kcmshell kdm	/usr/share/applications/kde/kdm.desktop
kcmshell	kcmshell keys	/usr/share/applications/kde/keys.desktop
kcmshell	kcmshell khtml_java_js	/usr/share/applications/kde/khtml_java_js.desktop
kcmshell	kcmshell khtml_fonts	/usr/share/applications/kde/khtml_fonts.desktop
krandrtray	krandrtray	/usr/share/applications/kde/krandrtray.desktop
kcmshell	kcmshell lanbrowser	/usr/share/applications/kde/lanbrowser.desktop
kcmshell	kcmshell language	/usr/share/applications/kde/language.desktop
kcmshell	kcmshell memory	/usr/share/applications/kde/memory.desktop
kcmshell	kcmshell mouse	/usr/share/applications/kde/mouse.desktop
kcmshell	kcmshell netpref	/usr/share/applications/kde/netpref.desktop
kcmshell	kcmshell nic	/usr/share/applications/kde/nic.desktop
kcmshell	kcmshell panel	/usr/share/applications/kde/panel.desktop
kcmshell	kcmshell spellchecking	/usr/share/applications/kde/spellchecking.desktop
kcmshell	kcmshell partitions	/usr/share/applications/kde/partitions.desktop
kcmshell	kcmshell passwords	/usr/share/applications/kde/passwords.desktop
kcmshell	kcmshell pci	/usr/share/applications/kde/pci.desktop
kcmshell	kcmshell privacy	/usr/share/applications/kde/privacy.desktop
kcmshell	kcmshell processor	/usr/share/applications/kde/processor.desktop
kcmshell	kcmshell proxy	/usr/share/applications/kde/proxy.desktop
kcmshell	kcmshell screensaver	/usr/share/applications/kde/screensaver.desktop
kcmshell	kcmshell scsi	/usr/share/applications/kde/scsi.desktop
kcmshell	kcmshell smbstatus	/usr/share/applications/kde/smbstatus.desktop
kcmshell	kcmshell sound	/usr/share/applications/kde/sound.desktop
kcmshell	kcmshell useragent	/usr/share/applications/kde/useragent.desktop
kcmshell	kcmshell style	/usr/share/applications/kde/style.desktop
catalogmanager	catalogmanager %i %m -caption "%c" %U	/usr/share/applications/kde/catalogmanager.desktop
kcmshell	kcmshell xserver	/usr/share/applications/kde/xserver.desktop
kfind	kfind %f	/usr/share/applications/kde/Kfind.desktop
katomic	/usr/games/katomic %i %m -caption "%c"	/usr/share/applications/kde/katomic.desktop
kbabeldict	kbabeldict %i %m -caption "%c"	/usr/share/applications/kde/kbabeldict.desktop
kbabel	kbabel %i %m -caption "%c" %U	/usr/share/applications/kde/kbabel.desktop
kcolorchooser	kcolorchooser %i %m	/usr/share/applications/kde/kcolorchooser.desktop
kbackgammon	/usr/games/kbackgammon %i %m -caption "%c"	/usr/share/applications/kde/kbackgammon.desktop
kbattleship	/usr/games/kbattleship %i %m -caption "%c"	/usr/share/applications/kde/kbattleship.desktop
kblackbox	/usr/games/kblackbox %i %m -caption "%c"	/usr/share/applications/kde/kblackbox.desktop
kbounce	/usr/games/kbounce %i %m -caption "%c"	/usr/share/applications/kde/kbounce.desktop
kbruch	kbruch -caption "%c" %i %m	/usr/share/applications/kde/kbruch.desktop
kbugbuster	kbugbuster -caption "%c" %i %m	/usr/share/applications/kde/kbugbuster.desktop
kcmshell	kcmshell linuz	/usr/share/applications/kde/linuz.desktop
kpersonalizer	kpersonalizer -caption "%c" %i %m	/usr/share/applications/kde/kpersonalizer.desktop
kcoloredit	kcoloredit %i %m %U	/usr/share/applications/kde/kcoloredit.desktop
kcron	kcron %i %m -caption "%c"	/usr/share/applications/kde/kcron.desktop
kdat	kdat %i %m -caption "%c"	/usr/share/applications/kde/kdat.desktop
ksig	ksig -caption "%c" %i %m	/usr/share/applications/kde/ksig.desktop
kcmshell	kcmshell kcmvim	/usr/share/applications/kde/kcmvim.desktop
kpackage	kpackage -caption "%c" %i %m %u	/usr/share/applications/kde/kpackage.desktop
ksysv	ksysv -caption "%c" %i %m	/usr/share/applications/kde/ksysv.desktop
kuser	kuser %i %m -caption "%c"	/usr/share/applications/kde/kuser.desktop
kdeprintfax	kdeprintfax -caption "%c" %i %m %u	/usr/share/applications/kde/kdeprintfax.desktop
kjobviewer	kjobviewer --all --show %i %m	/usr/share/applications/kde/kjobviewer.desktop
kcmshell	kcmshell printmgr	/usr/share/applications/kde/printers.desktop
khelpcenter	khelpcenter	/usr/share/applications/kde/Help.desktop
klipper	klipper	/usr/share/applications/kde/klipper.desktop
kmenuedit	kmenuedit	/usr/share/applications/kde/kmenuedit.desktop
kpager	kpager	/usr/share/applications/kde/kpager.desktop
kcmshell	kcmshell ksplashthememgr	/usr/share/applications/kde/ksplashthememgr.desktop
ktip	ktip	/usr/share/applications/kde/ktip.desktop
khangman	khangman -caption "%c" %i %m	/usr/share/applications/kde/khangman.desktop
kiten	kiten -caption "%c" %i %m	/usr/share/applications/kde/kiten.desktop
klettres	klettres -caption "%c" %i %m	/usr/share/applications/kde/klettres.desktop
kmessedwords	kmessedwords -caption "%c" %i %m	/usr/share/applications/kde/kmessedwords.desktop
kmplot	kmplot	/usr/share/applications/kde/kmplot.desktop
kpercentage	kpercentage	/usr/share/applications/kde/kpercentage.desktop
kstars	kstars -caption "%c" %i %m	/usr/share/applications/kde/kstars.desktop
ktouch	ktouch -caption "%c" %i %m	/usr/share/applications/kde/ktouch.desktop
kverbos	kverbos -caption "%c" %i %m	/usr/share/applications/kde/kverbos.desktop
kvoctrain	kvoctrain	/usr/share/applications/kde/kvoctrain.desktop
kenolaba	/usr/games/kenolaba %i %m -caption "%c"	/usr/share/applications/kde/kenolaba.desktop
kfouleggs	/usr/games/kfouleggs -caption "%c" %i %m	/usr/share/applications/kde/kfouleggs.desktop
kgoldrunner	/usr/games/kgoldrunner	/usr/share/applications/kde/KGoldrunner.desktop
kjumpingcube	/usr/games/kjumpingcube -caption "%c" %i %m	/usr/share/applications/kde/kjumpingcube.desktop
klickety	/usr/games/klickety -caption "%c" %i %m	/usr/share/applications/kde/klickety.desktop
klines	/usr/games/klines -caption "%c" %i %m	/usr/share/applications/kde/klines.desktop
kmahjongg	/usr/games/kmahjongg %i %m -caption "%c"	/usr/share/applications/kde/kmahjongg.desktop
kmines	/usr/games/kmines -caption "%c" %i %m	/usr/share/applications/kde/kmines.desktop
kolf	/usr/games/kolf %U	/usr/share/applications/kde/kolf.desktop
konquest	/usr/games/konquest %i %m -caption %c	/usr/share/applications/kde/konquest.desktop
kpat	/usr/games/kpat %i %m -caption "%c"	/usr/share/applications/kde/kpat.desktop
kpoker	/usr/games/kpoker %i %m -caption "%c"	/usr/share/applications/kde/kpoker.desktop
kreversi	/usr/games/kreversi %i %m -caption "%c"	/usr/share/applications/kde/kreversi.desktop
ksame	/usr/games/ksame %i %m -caption "%c"	/usr/share/applications/kde/ksame.desktop
kshisen	/usr/games/kshisen %i %m -caption "%c"	/usr/share/applications/kde/kshisen.desktop
ksirtet	/usr/games/ksirtet -caption "%c" %i %m	/usr/share/applications/kde/ksirtet.desktop
ksmiletris	/usr/games/ksmiletris -caption "%c" %i %m	/usr/share/applications/kde/ksmiletris.desktop
ksnake	/usr/games/ksnake %i %m -caption "%c"	/usr/share/applications/kde/ksnake.desktop
ksokoban	/usr/games/ksokoban %i %m -caption "%c"	/usr/share/applications/kde/ksokoban.desktop
kspaceduel	/usr/games/kspaceduel %i %m -caption "%c"	/usr/share/applications/kde/kspaceduel.desktop
ktron	/usr/games/ktron -caption "%c" %i %m	/usr/share/applications/kde/ktron.desktop
ktuberling	/usr/games/ktuberling %i %m -caption "%c" %u	/usr/share/applications/kde/ktuberling.desktop
kwin4	/usr/games/kwin4	/usr/share/applications/kde/kwin4.desktop
lskat	/usr/games/lskat	/usr/share/applications/kde/lskat.desktop
kviewshell	kviewshell dvi %f -caption "%c" %i %m	/usr/share/applications/kde/kdvi.desktop
kfax	kfax %f   -caption "%c" %i %m	/usr/share/applications/kde/kfax.desktop
kghostview	kghostview %u -caption "%c" %i %m	/usr/share/applications/kde/kghostview.desktop
kiconedit	kiconedit -caption "%c" %i %m %u	/usr/share/applications/kde/kiconedit.desktop
kcmshell	kcmshell kcmkmrml	/usr/share/applications/kde/kcmkmrml.desktop
kooka	kooka %i %m %U	/usr/share/applications/kde/kooka.desktop
kpaint	kpaint %u -caption "%c" %i %m	/usr/share/applications/kde/kpaint.desktop
kpdf	kpdf %i %m -caption "%c"	/usr/share/applications/kde/kpdf.desktop
kpovmodeler	kpovmodeler -caption "%c" %i %m %f	/usr/share/applications/kde/kpovmodeler.desktop
kruler	kruler %i %m	/usr/share/applications/kde/kruler.desktop
ksnapshot	ksnapshot -caption "%c" %i %m	/usr/share/applications/kde/ksnapshot.desktop
kuickshow	kuickshow %i %m -caption "%c" %U	/usr/share/applications/kde/kuickshow.desktop
kview	kview -caption "%c" %i %m %U	/usr/share/applications/kde/kview.desktop
kompare	kompare -caption "%c" %i %m -o %U	/usr/share/applications/kde/kompare.desktop
kuiviewer	kuiviewer %i %m -caption "%c"	/usr/share/applications/kde/kuiviewer.desktop
kcmshell	kcmshell lilo	/usr/share/applications/kde/lilo.desktop
kcachegrind	kcachegrind -caption "%c" %i %m %u	/usr/share/applications/kde/kcachegrind.desktop
kile	kile	/usr/share/applications/kde/kile.desktop
smb4k	smb4k	/usr/share/applications/kde/smb4k.desktop
gnome-remote-shell	gnome-remote-shell	/usr/share/applications/gnome-network-utilities.desktop
gnome-netinfo	gnome-netinfo	/usr/share/applications/gnome-netinfo.desktop
grip	grip	/usr/share/applications/grip.desktop
oocalc	/usr/bin/oocalc %U	/usr/share/applications/ooo645calc.desktop
oomath	/usr/bin/oomath %U	/usr/share/applications/ooo645math.desktop
oopadmin	/usr/bin/oopadmin	/usr/share/applications/ooo645printeradmin.desktop
oodraw	/usr/bin/oodraw %U	/usr/share/applications/ooo645draw.desktop
ooffice	/usr/bin/ooffice slot:5500	/usr/share/applications/ooo645template.desktop
gmfsk	gmfsk	/usr/share/applications/gmfsk.desktop
tsclient	tsclient	/usr/share/applications/tsclient.desktop
blender	blender	/usr/share/applications/blender.desktop
mlv	mlv %F	/usr/share/applications/mlview.desktop
conglomerate	conglomerate %U	/usr/share/applications/conglomerate.desktop
nautilus	nautilus	/usr/share/applications/nautilus-home.desktop
nautilus	nautilus computer:	/usr/share/applications/nautilus-computer.desktop
mozilla-thunderbird	mozilla-thunderbird -P	/usr/share/applications/mozilla-thunderbird-pm.desktop
mozilla-thunderbird	mozilla-thunderbird	/usr/share/applications/mozilla-thunderbird.desktop
amule	amule	/usr/share/applications/amule.desktop
scribus	scribus %f	/usr/share/applications/scribus.desktop
gksuexec	gksuexec	/usr/share/applications/gksuexec.desktop
firefox	firefox	/usr/share/applications/mozilla-firefox.desktop
gmplayer	gmplayer	/usr/share/applications/mplayer.desktop
slix-central	slix-central	/usr/share/applications/slix-central.desktop
gv4l	/usr/bin/gv4l	/usr/share/applications/gnome-gv4l.desktop
cyca-central	cyca-central	/usr/share/applications/cyca-central.desktop
konqueror	konqueror %U	/usr/share/applnk/konqueror.desktop
kmdr-executor	kmdr-executor %F	/usr/share/applnk/Applications/kmdr-executor.desktop
rekall	rekall	/usr/share/applnk/Applications/rekall.desktop
kxmleditor	kxmleditor -caption "%c" %i %m	/usr/share/applnk/Applications/kxmleditor.desktop
kdesu	kdesu kxconfig	/usr/share/applnk/Settings/Peripherals/kxconfig.desktop
kcmshell	kcmshell kamera	/usr/share/applnk/Settings/Peripherals/kamera.desktop
kblankscrn.kss	kblankscrn.kss	/usr/share/applnk/System/ScreenSavers/KBlankscreen.desktop
krandom.kss	krandom.kss	/usr/share/applnk/System/ScreenSavers/KRandom.desktop
kbanner.kss	kbanner.kss	/usr/share/applnk/System/ScreenSavers/KBanner.desktop
kpolygon.kss	kpolygon.kss	/usr/share/applnk/System/ScreenSavers/KPolygon.desktop
kslideshow.kss	kslideshow.kss	/usr/share/applnk/System/ScreenSavers/KSlideshow.desktop
klines.kss	klines.kss	/usr/share/applnk/System/ScreenSavers/KLines-saver.desktop
klorenz.kss	klorenz.kss	/usr/share/applnk/System/ScreenSavers/KLorenz.desktop
kblob.kss	kblob.kss	/usr/share/applnk/System/ScreenSavers/KBlob.desktop
kvm.kss	kvm.kss	/usr/share/applnk/System/ScreenSavers/KVm.desktop
kscience.kss	kscience.kss	/usr/share/applnk/System/ScreenSavers/KScience.desktop
kgravity.kss	kgravity.kss	/usr/share/applnk/System/ScreenSavers/KGravity.desktop
kwave.kss	kwave.kss	/usr/share/applnk/System/ScreenSavers/KWave.desktop
kfountain.kss	kfountain.kss	/usr/share/applnk/System/ScreenSavers/KFountain.desktop
kflux.kss	kflux.kss	/usr/share/applnk/System/ScreenSavers/KFlux.desktop
keuphoria.kss	keuphoria.kss	/usr/share/applnk/System/ScreenSavers/KEuphoria.desktop
ksolarwinds.kss	ksolarwinds.kss	/usr/share/applnk/System/ScreenSavers/KSolarWinds.desktop
kpartsaver.kss	kpartsaver.kss	/usr/share/applnk/System/ScreenSavers/kpartsaver.desktop
anemone	anemone	/usr/share/applnk/System/ScreenSavers/anemone.desktop
ant	ant	/usr/share/applnk/System/ScreenSavers/ant.desktop
bsod	bsod	/usr/share/applnk/System/ScreenSavers/bsod.desktop
xscreensaver.kss	xscreensaver.kss	/usr/share/applnk/System/ScreenSavers/XScreenSaver.desktop
apollonian	apollonian	/usr/share/applnk/System/ScreenSavers/apollonian.desktop
atlantis	atlantis	/usr/share/applnk/System/ScreenSavers/atlantis.desktop
attraction	attraction	/usr/share/applnk/System/ScreenSavers/attraction.desktop
blaster	blaster	/usr/share/applnk/System/ScreenSavers/blaster.desktop
blitspin	blitspin	/usr/share/applnk/System/ScreenSavers/blitspin.desktop
bouboule	bouboule	/usr/share/applnk/System/ScreenSavers/bouboule.desktop
boxed	boxed	/usr/share/applnk/System/ScreenSavers/boxed.desktop
braid	braid	/usr/share/applnk/System/ScreenSavers/braid.desktop
bubble3d	bubble3d	/usr/share/applnk/System/ScreenSavers/bubble3d.desktop
bubbles	bubbles	/usr/share/applnk/System/ScreenSavers/bubbles.desktop
bumps	bumps	/usr/share/applnk/System/ScreenSavers/bumps.desktop
cage	cage	/usr/share/applnk/System/ScreenSavers/cage.desktop
ccurve	ccurve	/usr/share/applnk/System/ScreenSavers/ccurve.desktop
circuit	circuit	/usr/share/applnk/System/ScreenSavers/circuit.desktop
compass	compass	/usr/share/applnk/System/ScreenSavers/compass.desktop
coral	coral	/usr/share/applnk/System/ScreenSavers/coral.desktop
critical	critical	/usr/share/applnk/System/ScreenSavers/critical.desktop
crystal	crystal	/usr/share/applnk/System/ScreenSavers/crystal.desktop
cubenetic	cubenetic	/usr/share/applnk/System/ScreenSavers/cubenetic.desktop
cynosure	cynosure	/usr/share/applnk/System/ScreenSavers/cynosure.desktop
dangerball	dangerball	/usr/share/applnk/System/ScreenSavers/dangerball.desktop
decayscreen	decayscreen	/usr/share/applnk/System/ScreenSavers/decayscreen.desktop
deco	deco	/usr/share/applnk/System/ScreenSavers/deco.desktop
deluxe	deluxe	/usr/share/applnk/System/ScreenSavers/deluxe.desktop
demon	demon	/usr/share/applnk/System/ScreenSavers/demon.desktop
discrete	discrete	/usr/share/applnk/System/ScreenSavers/discrete.desktop
distort	distort	/usr/share/applnk/System/ScreenSavers/distort.desktop
drift	drift	/usr/share/applnk/System/ScreenSavers/drift.desktop
endgame	endgame	/usr/share/applnk/System/ScreenSavers/endgame.desktop
engine	engine	/usr/share/applnk/System/ScreenSavers/engine.desktop
epicycle	epicycle	/usr/share/applnk/System/ScreenSavers/epicycle.desktop
euler2d	euler2d	/usr/share/applnk/System/ScreenSavers/euler2d.desktop
extrusion	extrusion	/usr/share/applnk/System/ScreenSavers/extrusion.desktop
fadeplot	fadeplot	/usr/share/applnk/System/ScreenSavers/fadeplot.desktop
flag	flag	/usr/share/applnk/System/ScreenSavers/flag.desktop
flame	flame	/usr/share/applnk/System/ScreenSavers/flame.desktop
flipscreen3d	flipscreen3d	/usr/share/applnk/System/ScreenSavers/flipscreen3d.desktop
flow	flow	/usr/share/applnk/System/ScreenSavers/flow.desktop
fluidballs	fluidballs	/usr/share/applnk/System/ScreenSavers/fluidballs.desktop
forest	forest	/usr/share/applnk/System/ScreenSavers/forest.desktop
galaxy	galaxy	/usr/share/applnk/System/ScreenSavers/galaxy.desktop
gears	gears	/usr/share/applnk/System/ScreenSavers/gears.desktop
gflux	gflux	/usr/share/applnk/System/ScreenSavers/gflux.desktop
glforestfire	glforestfire	/usr/share/applnk/System/ScreenSavers/glforestfire.desktop
glplanet	glplanet	/usr/share/applnk/System/ScreenSavers/glplanet.desktop
glsnake	glsnake	/usr/share/applnk/System/ScreenSavers/glsnake.desktop
gltext	gltext	/usr/share/applnk/System/ScreenSavers/gltext.desktop
goop	goop	/usr/share/applnk/System/ScreenSavers/goop.desktop
grav	grav	/usr/share/applnk/System/ScreenSavers/grav.desktop
greynetic	greynetic	/usr/share/applnk/System/ScreenSavers/greynetic.desktop
halo	halo	/usr/share/applnk/System/ScreenSavers/halo.desktop
helix	helix	/usr/share/applnk/System/ScreenSavers/helix.desktop
hopalong	hopalong	/usr/share/applnk/System/ScreenSavers/hopalong.desktop
hyperball	hyperball	/usr/share/applnk/System/ScreenSavers/hyperball.desktop
hypercube	hypercube	/usr/share/applnk/System/ScreenSavers/hypercube.desktop
ifs	ifs	/usr/share/applnk/System/ScreenSavers/ifs.desktop
imsmap	imsmap	/usr/share/applnk/System/ScreenSavers/imsmap.desktop
interference	interference	/usr/share/applnk/System/ScreenSavers/interference.desktop
jigsaw	jigsaw	/usr/share/applnk/System/ScreenSavers/jigsaw.desktop
juggle	juggle	/usr/share/applnk/System/ScreenSavers/juggle.desktop
julia	julia	/usr/share/applnk/System/ScreenSavers/julia.desktop
kaleidescope	kaleidescope	/usr/share/applnk/System/ScreenSavers/kaleidescope.desktop
kumppa	kumppa	/usr/share/applnk/System/ScreenSavers/kumppa.desktop
lament	lament	/usr/share/applnk/System/ScreenSavers/lament.desktop
laser	laser	/usr/share/applnk/System/ScreenSavers/laser.desktop
lavalite	lavalite	/usr/share/applnk/System/ScreenSavers/lavalite.desktop
lightning	lightning	/usr/share/applnk/System/ScreenSavers/lightning.desktop
lisa	lisa	/usr/share/applnk/System/ScreenSavers/lisa.desktop
lissie	lissie	/usr/share/applnk/System/ScreenSavers/lissie.desktop
lmorph	lmorph	/usr/share/applnk/System/ScreenSavers/lmorph.desktop
loop	loop	/usr/share/applnk/System/ScreenSavers/loop.desktop
maze	maze	/usr/share/applnk/System/ScreenSavers/maze.desktop
menger	menger	/usr/share/applnk/System/ScreenSavers/menger.desktop
moebius	moebius	/usr/share/applnk/System/ScreenSavers/moebius.desktop
moire	moire	/usr/share/applnk/System/ScreenSavers/moire.desktop
moire2	moire2	/usr/share/applnk/System/ScreenSavers/moire2.desktop
molecule	molecule	/usr/share/applnk/System/ScreenSavers/molecule.desktop
morph3d	morph3d	/usr/share/applnk/System/ScreenSavers/morph3d.desktop
mountain	mountain	/usr/share/applnk/System/ScreenSavers/mountain.desktop
munch	munch	/usr/share/applnk/System/ScreenSavers/munch.desktop
nerverot	nerverot	/usr/share/applnk/System/ScreenSavers/nerverot.desktop
noseguy	noseguy	/usr/share/applnk/System/ScreenSavers/noseguy.desktop
pedal	pedal	/usr/share/applnk/System/ScreenSavers/pedal.desktop
penetrate	penetrate	/usr/share/applnk/System/ScreenSavers/penetrate.desktop
penrose	penrose	/usr/share/applnk/System/ScreenSavers/penrose.desktop
petri	petri	/usr/share/applnk/System/ScreenSavers/petri.desktop
phosphor	phosphor	/usr/share/applnk/System/ScreenSavers/phosphor.desktop
pipes	pipes	/usr/share/applnk/System/ScreenSavers/pipes.desktop
pixmaps	pixmaps	/usr/share/applnk/System/ScreenSavers/pixmaps.desktop
polyominoes	polyominoes	/usr/share/applnk/System/ScreenSavers/polyominoes.desktop
pulsar	pulsar	/usr/share/applnk/System/ScreenSavers/pulsar.desktop
pyro	pyro	/usr/share/applnk/System/ScreenSavers/pyro.desktop
qix	qix	/usr/share/applnk/System/ScreenSavers/qix.desktop
queens	queens	/usr/share/applnk/System/ScreenSavers/queens.desktop
rd-bomb	rd-bomb	/usr/share/applnk/System/ScreenSavers/rd-bomb.desktop
ripples	ripples	/usr/share/applnk/System/ScreenSavers/ripples.desktop
rocks	rocks	/usr/share/applnk/System/ScreenSavers/rocks.desktop
rorschach	rorschach	/usr/share/applnk/System/ScreenSavers/rorschach.desktop
rotor	rotor	/usr/share/applnk/System/ScreenSavers/rotor.desktop
rotzoomer	rotzoomer	/usr/share/applnk/System/ScreenSavers/rotzoomer.desktop
rubik	rubik	/usr/share/applnk/System/ScreenSavers/rubik.desktop
sballs	sballs	/usr/share/applnk/System/ScreenSavers/sballs.desktop
shadebobs	shadebobs	/usr/share/applnk/System/ScreenSavers/shadebobs.desktop
sierpinski	sierpinski	/usr/share/applnk/System/ScreenSavers/sierpinski.desktop
sierpinski3d	sierpinski3d	/usr/share/applnk/System/ScreenSavers/sierpinski3d.desktop
slidescreen	slidescreen	/usr/share/applnk/System/ScreenSavers/slidescreen.desktop
slip	slip	/usr/share/applnk/System/ScreenSavers/slip.desktop
sonar	sonar	/usr/share/applnk/System/ScreenSavers/sonar.desktop
speedmine	speedmine	/usr/share/applnk/System/ScreenSavers/speedmine.desktop
sphere	sphere	/usr/share/applnk/System/ScreenSavers/sphere.desktop
spheremonics	spheremonics	/usr/share/applnk/System/ScreenSavers/spheremonics.desktop
spiral	spiral	/usr/share/applnk/System/ScreenSavers/spiral.desktop
spotlight	spotlight	/usr/share/applnk/System/ScreenSavers/spotlight.desktop
sproingies	sproingies	/usr/share/applnk/System/ScreenSavers/sproingies.desktop
squiral	squiral	/usr/share/applnk/System/ScreenSavers/squiral.desktop
stairs	stairs	/usr/share/applnk/System/ScreenSavers/stairs.desktop
starfish	starfish	/usr/share/applnk/System/ScreenSavers/starfish.desktop
starwars	starwars	/usr/share/applnk/System/ScreenSavers/starwars.desktop
stonerview	stonerview	/usr/share/applnk/System/ScreenSavers/stonerview.desktop
strange	strange	/usr/share/applnk/System/ScreenSavers/strange.desktop
superquadrics	superquadrics	/usr/share/applnk/System/ScreenSavers/superquadrics.desktop
swirl	swirl	/usr/share/applnk/System/ScreenSavers/swirl.desktop
t3d	t3d	/usr/share/applnk/System/ScreenSavers/t3d.desktop
thornbird	thornbird	/usr/share/applnk/System/ScreenSavers/thornbird.desktop
triangle	triangle	/usr/share/applnk/System/ScreenSavers/triangle.desktop
truchet	truchet	/usr/share/applnk/System/ScreenSavers/truchet.desktop
twang	twang	/usr/share/applnk/System/ScreenSavers/twang.desktop
vermiculate	vermiculate	/usr/share/applnk/System/ScreenSavers/vermiculate.desktop
vidwhacker	vidwhacker	/usr/share/applnk/System/ScreenSavers/vidwhacker.desktop
vines	vines	/usr/share/applnk/System/ScreenSavers/vines.desktop
wander	wander	/usr/share/applnk/System/ScreenSavers/wander.desktop
webcollage	webcollage	/usr/share/applnk/System/ScreenSavers/webcollage.desktop
whirlwindwarp	whirlwindwarp	/usr/share/applnk/System/ScreenSavers/whirlwindwarp.desktop
whirlygig	whirlygig	/usr/share/applnk/System/ScreenSavers/whirlygig.desktop
worm	worm	/usr/share/applnk/System/ScreenSavers/worm.desktop
xflame	xflame	/usr/share/applnk/System/ScreenSavers/xflame.desktop
xjack	xjack	/usr/share/applnk/System/ScreenSavers/xjack.desktop
xlyap	xlyap	/usr/share/applnk/System/ScreenSavers/xlyap.desktop
xmatrix	xmatrix	/usr/share/applnk/System/ScreenSavers/xmatrix.desktop
xrayswarm	xrayswarm	/usr/share/applnk/System/ScreenSavers/xrayswarm.desktop
xspirograph	xspirograph	/usr/share/applnk/System/ScreenSavers/xspirograph.desktop
xsublim	xsublim	/usr/share/applnk/System/ScreenSavers/xsublim.desktop
xteevee	xteevee	/usr/share/applnk/System/ScreenSavers/xteevee.desktop
zoom	zoom	/usr/share/applnk/System/ScreenSavers/zoom.desktop
kspace.kss	kspace.kss	/usr/share/applnk/System/ScreenSavers/KSpace.desktop
kswarm.kss	kswarm.kss	/usr/share/applnk/System/ScreenSavers/KSwarm.desktop
ktux	ktux %i %m -caption "%c"	/usr/share/applnk/System/ScreenSavers/ktux.desktop
kclock.kss	kclock.kss	/usr/share/applnk/System/ScreenSavers/KClock.desktop
antspotlight	antspotlight	/usr/share/applnk/System/ScreenSavers/antspotlight.desktop
atunnel	atunnel	/usr/share/applnk/System/ScreenSavers/atunnel.desktop
barcode	barcode	/usr/share/applnk/System/ScreenSavers/barcode.desktop
blocktube	blocktube	/usr/share/applnk/System/ScreenSavers/blocktube.desktop
bouncingcow	bouncingcow	/usr/share/applnk/System/ScreenSavers/bouncingcow.desktop
cloudlife	cloudlife	/usr/share/applnk/System/ScreenSavers/cloudlife.desktop
cubestorm	cubestorm	/usr/share/applnk/System/ScreenSavers/cubestorm.desktop
eruption	eruption	/usr/share/applnk/System/ScreenSavers/eruption.desktop
flipflop	flipflop	/usr/share/applnk/System/ScreenSavers/flipflop.desktop
flurry	flurry	/usr/share/applnk/System/ScreenSavers/flurry.desktop
flyingtoasters	flyingtoasters	/usr/share/applnk/System/ScreenSavers/flyingtoasters.desktop
glblur	glblur	/usr/share/applnk/System/ScreenSavers/glblur.desktop
glknots	glknots	/usr/share/applnk/System/ScreenSavers/glknots.desktop
glmatrix	glmatrix	/usr/share/applnk/System/ScreenSavers/glmatrix.desktop
glslideshow	glslideshow	/usr/share/applnk/System/ScreenSavers/glslideshow.desktop
halftone	halftone	/usr/share/applnk/System/ScreenSavers/halftone.desktop
hypertorus	hypertorus	/usr/share/applnk/System/ScreenSavers/hypertorus.desktop
jigglypuff	jigglypuff	/usr/share/applnk/System/ScreenSavers/jigglypuff.desktop
klein	klein	/usr/share/applnk/System/ScreenSavers/klein.desktop
metaballs	metaballs	/usr/share/applnk/System/ScreenSavers/metaballs.desktop
piecewise	piecewise	/usr/share/applnk/System/ScreenSavers/piecewise.desktop
polytopes	polytopes	/usr/share/applnk/System/ScreenSavers/polytopes.desktop
popsquares	popsquares	/usr/share/applnk/System/ScreenSavers/popsquares.desktop
kinfocenter	kinfocenter -caption "%c" %i %m	/usr/share/applnk/System/kinfocenter.desktop
kdirstat	kdirstat -caption "%c" %i %m	/usr/share/applnk/Utilities/kdirstat.desktop
kadd_konsole	kadd_konsole	/usr/share/applnk/Utilities/add_konsole.desktop
slicker	slicker	/usr/share/applnk/Utilities/slicker.desktop
kvim	kvim -f %F	/usr/share/applnk/Editors/KVim.desktop
abiword	/usr/bin/abiword	/usr/share/applnk/Editors/AbiWord.desktop
texmacs	/usr/bin/texmacs %f	/usr/share/applnk/Editors/texmacs.desktop
kmidi	kmidi %m %i %f	/usr/share/applnk/Multimedia/More/kmidi.desktop
noteedit	noteedit %i %m -caption "%c"	/usr/share/applnk/Multimedia/noteedit.desktop
xine	xine	/usr/share/applnk/Multimedia/xine.desktop
kplayer	kplayer %U	/usr/share/applnk/Multimedia/kplayer.desktop
rosegarden4	rosegarden4 -caption "%c" %i %m	/usr/share/applnk/Multimedia/rosegarden.desktop
kthesaurus	kthesaurus	/usr/share/applnk/Office/KThesaurus.desktop
kformula	kformula	/usr/share/applnk/Office/kformula.desktop
karbon	karbon	/usr/share/applnk/Office/karbon.desktop
kchart	kchart	/usr/share/applnk/Office/kchart.desktop
kpresenter	kpresenter	/usr/share/applnk/Office/kpresenter.desktop
kivio	kivio	/usr/share/applnk/Office/kivio.desktop
koshell	koshell	/usr/share/applnk/Office/koshell.desktop
kudesigner	kudesigner	/usr/share/applnk/Office/kudesigner.desktop
kspread	kspread	/usr/share/applnk/Office/kspread.desktop
kugar	kugar	/usr/share/applnk/Office/kugar.desktop
kword	kword	/usr/share/applnk/Office/kword.desktop
krita	krita	/usr/share/applnk/Office/krita.desktop
tuxpaint	tuxpaint	/usr/share/applnk/Graphics/tuxpaint.desktop
kaphorism	kaphorism	/usr/share/applnk/Toys/kaphorism.desktop
megami	/usr/games/megami	/usr/share/applnk/Games/Card/megami.desktop
kopete	kopete %i %m -caption "%c"	/usr/share/applnk/Internet/kopete.desktop
lynx	/usr/bin/lynx %u	/usr/share/applnk/Internet/lynx.desktop
kit	kit	/usr/share/applnk/Internet/kit.desktop
kcmshell	kcmshell fileappearance	/usr/share/applnk/.hidden/fileappearance.desktop
kcmshell	kcmshell kcmkonsole	/usr/share/applnk/.hidden/kcmkonsole.desktop
kcmshell	kcmshell filebehavior	/usr/share/applnk/.hidden/filebehavior.desktop
kcmshell	kcmshell filepreviews	/usr/share/applnk/.hidden/filepreviews.desktop
kcmshell	kcmshell kwinactions	/usr/share/applnk/.hidden/kwinactions.desktop
kate	kate --initplugin katefll_initplugin %u	/usr/share/applnk/.hidden/katefll.desktop
kcmshell	kcmshell smb	/usr/share/applnk/.hidden/smb.desktop
kcmshell	kcmshell kwinadvanced	/usr/share/applnk/.hidden/kwinadvanced.desktop
kcmshell	kcmshell kwinfocus	/usr/share/applnk/.hidden/kwinfocus.desktop
kcmshell	kcmshell kwinmoving	/usr/share/applnk/.hidden/kwinmoving.desktop
kcmshell	kcmshell kcmkuick	/usr/share/applnk/.hidden/kcmkuick.desktop
kcmshell	kcmshell kcmkiolan	/usr/share/applnk/.hidden/kcmkiolan.desktop
kcmshell	kcmshell kcmlisa	/usr/share/applnk/.hidden/kcmlisa.desktop
kcmshell	kcmshell kcmreslisa	/usr/share/applnk/.hidden/kcmreslisa.desktop
kcmshell	kcmshell randr	/usr/share/applnk/.hidden/randr.desktop
knewstickerstub	knewstickerstub -a %u	/usr/share/applnk/.hidden/knewstickerstub.desktop
kalarmd	kalarmd	/usr/share/applnk/.hidden/kalarmd.desktop
kcmshell	kcmshell kgamma	/usr/share/applnk/.hidden/kgamma.desktop
kcmshell	kcmshell kcmkonqyperformance	/usr/share/applnk/.hidden/kcmkonqyperformance.desktop
kcmshell	kcmshell xinerama	/usr/share/applnk/.hidden/xinerama.desktop
cupsconfig	/usr/sbin/cupsconfig	/usr/share/applnk/Knoppix/Config/cupsconfig.desktop
oofromtemplate	/usr/bin/oofromtemplate	/usr/share/applnk/OpenOffice.org1.1/template.desktop
ooweb	/usr/bin/ooweb	/usr/share/applnk/OpenOffice.org1.1/web.desktop
oowriter	/usr/bin/oowriter	/usr/share/applnk/OpenOffice.org1.1/writer.desktop
oocalc	/usr/bin/oocalc	/usr/share/applnk/OpenOffice.org1.1/calc.desktop
oomath	/usr/bin/oomath	/usr/share/applnk/OpenOffice.org1.1/math.desktop
ooimpress	/usr/bin/ooimpress	/usr/share/applnk/OpenOffice.org1.1/impress.desktop
oodraw	/usr/bin/oodraw	/usr/share/applnk/OpenOffice.org1.1/draw.desktop
tora	tora	/usr/share/applnk/Development/tora.desktop
kmdr-editor	kmdr-editor %F	/usr/share/applnk/Development/kmdr-editor.desktop
quanta	quanta	/usr/share/applnk/Development/quanta.desktop
kdevelop3	kdevelop3 %u	/usr/share/applnk/Development/kdevelop3.desktop
designer-qt3	designer-qt3	/usr/share/applnk/Development/designer-qt3.desktop
wine	wine %f	/usr/share/applnk/wine.desktop
kgeo	kgeo -caption "%c" %i %m	/usr/share/applnk/Edutainment/Mathematics/kgeo.desktop
acroread	acroread	/home/ziga/.kde/share/applnk/.hidden/acroread.desktop
mlv	mlv	/home/ziga/.kde/share/applnk/.hidden/mlv.desktop
inkscape	inkscape	/home/ziga/.kde/share/applnk/.hidden/inkscape-2.desktop
Emacs	Emacs	/home/ziga/.kde/share/applnk/.hidden/Emacs.desktop
perl	perl	/home/ziga/.kde/share/applnk/.hidden/perl.desktop
gvim	gvim	/home/ziga/.kde/share/applnk/.hidden/gvim-2.desktop
audacity	audacity	/home/ziga/.kde/share/applnk/.hidden/audacity-2.desktop
gv	gv	/home/ziga/.kde/share/applnk/.hidden/gv-2.desktop
abiword	abiword	/home/ziga/.kde/share/applnk/.hidden/abiword-2.desktop
texmacs	/usr/bin/texmacs	/home/ziga/.kde/share/applnk/Editors/texmacs.desktop
blender	/usr/bin/blender	/home/ziga/.kde/share/applnk/Graphics/Blender.desktop
xffm	xffm	/var/lib/menu-xdg/applications/menu-xdg/xffm4.desktop
/usr/bin/gvim	/usr/bin/gvim	/usr/share/slix/apps/Aplikacije/Besedilo/gvim.desktop
kate	kate %U	/usr/share/slix/apps/Aplikacije/Besedilo/kate.desktop
kwrite	kwrite %U	/usr/share/slix/apps/Aplikacije/Besedilo/kwrite.desktop
lyx	lyx	/usr/share/slix/apps/Aplikacije/Besedilo/lyx.desktop
nedit	nedit %f	/usr/share/slix/apps/Aplikacije/Besedilo/nedit.desktop
quanta	quanta --unique %f	/usr/share/slix/apps/Aplikacije/Besedilo/quanta.desktop
Gimp	/usr/bin/Gimp %U	/usr/share/slix/apps/Aplikacije/Grafika/Gimp.desktop
/usr/bin/qcad	/usr/bin/qcad	/usr/share/slix/apps/Aplikacije/Grafika/QCad.desktop
sketch	sketch	/usr/share/slix/apps/Aplikacije/Grafika/Sketch.desktop
/usr/bin/pfaedit	/usr/bin/pfaedit	/usr/share/slix/apps/Aplikacije/Grafika/pfaedit.desktop
acroread	acroread %f	/usr/share/slix/apps/Aplikacije/Prezentacija/acroread.desktop
pspresent	pspresent %f	/usr/share/slix/apps/Aplikacije/Prezentacija/pspresent.desktop
mysqlcc	mysqlcc	/usr/share/slix/apps/Aplikacije/Tabele/MySQL_CC.desktop
tvtime	tvtime	/usr/share/slix/apps/Aplikacije/Video/net-tvtime.desktop
xawtv	xawtv	/usr/share/slix/apps/Aplikacije/Video/xawtv.desktop
/usr/bin/spiralsynthmodular	/usr/bin/spiralsynthmodular	/usr/share/slix/apps/Aplikacije/Zvok/SpiralSynthModular.desktop
sudo	sudo qsynth	/usr/share/slix/apps/Aplikacije/Zvok/qsynth.desktop
sudo	sudo qjackctl	/usr/share/slix/apps/Aplikacije/Zvok/qjackctl.desktop
sudo	sudo zynaddsubfx	/usr/share/slix/apps/Aplikacije/Zvok/zynaddsubfx.desktop
soffice	soffice private:factory/swriter	/usr/share/slix/apps/Aplikacije/openoffice.desktop
Emacs	/usr/bin/Emacs	/usr/share/slix/apps/Aplikacije/Emacs.desktop
abiword	/usr/bin/abiword %f	/usr/share/slix/apps/Aplikacije/AbiWord.desktop
/usr/bin/gq	/usr/bin/gq	/usr/share/slix/apps/Internet/Network/gq.desktop
mtr	mtr	/usr/share/slix/apps/Internet/Network/mtr.desktop
/usr/bin/gaim	/usr/bin/gaim	/usr/share/slix/apps/Internet/Gaim.desktop
mozilla	mozilla	/usr/share/slix/apps/Internet/Mozilla.desktop
/usr/bin/evolution	/usr/bin/evolution	/usr/share/slix/apps/Internet/evolution.desktop
streamtuner	streamtuner	/usr/share/slix/apps/Internet/streamtuner.desktop
akregator	akregator %i %m -caption "%c"	/usr/share/slix/apps/Internet/akregator.desktop
/usr/sbin/saveconfig	/usr/sbin/saveconfig	/usr/share/slix/apps/Nastavitve/saveconfig.desktop
k3b	k3b	/usr/share/slix/apps/Pripomo?ki/Arhiviranje/k3b.desktop
/usr/bin/gpa	/usr/bin/gpa	/usr/share/slix/apps/Pripomo?ki/The_GNU_Privacy_Assistant.desktop
gmplayer	gmplayer %u	/usr/share/slix/apps/Pripomo?ki/mplayer.desktop
xclock	xclock	/usr/share/slix/apps/Pripomo?ki/xclock.desktop
xmms	xmms -p -e %U	/usr/share/slix/apps/Pripomo?ki/xmms.desktop
kdesu	kdesu -u root /usr/sbin/synaptic	/usr/share/slix/apps/Sistem/Synaptic.desktop
/usr/bin/usbview	/usr/bin/usbview	/usr/share/slix/apps/Sistem/USB_View.desktop
sudo	sudo qps	/usr/share/slix/apps/Sistem/qps_root.desktop
sudo	sudo xlogmaster	/usr/share/slix/apps/Sistem/xlogmaster.desktop
qps	qps	/usr/share/slix/apps/Sistem/qps.desktop
/usr/games/bzflag	/usr/games/bzflag	/usr/share/slix/apps/Zabava/bzflag.desktop
Browse	Browse %U	/usr/share/slix/apps/Mozilla.desktop
dbishell	/usr/bin/dbishell	/var/lib/menu-xdg/applications/menu-xdg/dbishell.desktop
gnomedb-fe	/usr/bin/gnomedb-fe	/var/lib/menu-xdg/applications/menu-xdg/gnome-db_frontend.desktop
mysqlcc	/usr/bin/mysqlcc	/var/lib/menu-xdg/applications/menu-xdg/mysql_cc.desktop
/usr/bin/X11/pgaccess	/usr/bin/X11/pgaccess	/var/lib/menu-xdg/applications/menu-xdg/pgaccess.desktop
pgadmin3	pgadmin3	/var/lib/menu-xdg/applications/menu-xdg/pgadmin_iii.desktop
/usr/lib/postgresql/bin/psql-wm	/usr/lib/postgresql/bin/psql-wm	/var/lib/menu-xdg/applications/menu-xdg/postgresql_interactive_terminal_(psql).desktop
quicklist	/usr/bin/quicklist	/var/lib/menu-xdg/applications/menu-xdg/quicklist.desktop
sqlr-config-gtk	/usr/bin/sqlr-config-gtk	/var/lib/menu-xdg/applications/menu-xdg/sql_relay_configuration.desktop
tora	/usr/bin/tora	/var/lib/menu-xdg/applications/menu-xdg/tora.desktop
/usr/bin/X11/axe	/usr/bin/X11/axe	/var/lib/menu-xdg/applications/menu-xdg/axe.desktop
conglomerate	/usr/bin/conglomerate	/var/lib/menu-xdg/applications/menu-xdg/conglomerate_xml_editor.desktop
emacs21	/usr/bin/emacs21 -nw	/var/lib/menu-xdg/applications/menu-xdg/emacs_21_(text).desktop
fontforge	/usr/bin/fontforge	/var/lib/menu-xdg/applications/menu-xdg/fontforge.desktop
gedit	/usr/bin/gedit	/var/lib/menu-xdg/applications/menu-xdg/gedit.desktop
joe	/usr/bin/joe	/var/lib/menu-xdg/applications/menu-xdg/joe.desktop
kate	/usr/bin/kate	/var/lib/menu-xdg/applications/menu-xdg/kate.desktop
kedit	/usr/bin/kedit	/var/lib/menu-xdg/applications/menu-xdg/kedit.desktop
kile	/usr/bin/kile	/var/lib/menu-xdg/applications/menu-xdg/kile.desktop
kvim	kvim	/var/lib/menu-xdg/applications/menu-xdg/kvim.desktop
kword	/usr/bin/kword	/var/lib/menu-xdg/applications/menu-xdg/kword.desktop
kwrite	/usr/bin/kwrite	/var/lib/menu-xdg/applications/menu-xdg/kwrite.desktop
kxmleditor	/usr/bin/kxmleditor	/var/lib/menu-xdg/applications/menu-xdg/kxmleditor.desktop
lyx-qt	/usr/bin/lyx-qt	/var/lib/menu-xdg/applications/menu-xdg/lyx_(qt).desktop
mlv	/usr/bin/mlv	/var/lib/menu-xdg/applications/menu-xdg/mlview_xml_editor.desktop
nano	/bin/nano	/var/lib/menu-xdg/applications/menu-xdg/nano.desktop
nedit	nedit	/var/lib/menu-xdg/applications/menu-xdg/nedit.desktop
pw	/usr/bin/pw	/var/lib/menu-xdg/applications/menu-xdg/pathetic_writer.desktop
quanta	/usr/bin/quanta	/var/lib/menu-xdg/applications/menu-xdg/quanta_plus.desktop
vim	/usr/bin/vim	/var/lib/menu-xdg/applications/menu-xdg/vim.desktop
xedit	xedit	/var/lib/menu-xdg/applications/menu-xdg/xedit.desktop
xemacs21-mule	/usr/bin/xemacs21-mule	/var/lib/menu-xdg/applications/menu-xdg/xemacs21-mule.desktop
yudit	/usr/bin/yudit	/var/lib/menu-xdg/applications/menu-xdg/yudit.desktop
flashkard	/usr/bin/flashkard	/var/lib/menu-xdg/applications/menu-xdg/flashkard.desktop
kiten	/usr/bin/kiten	/var/lib/menu-xdg/applications/menu-xdg/kiten.desktop
klettres	/usr/bin/klettres	/var/lib/menu-xdg/applications/menu-xdg/klettres.desktop
ktouch	/usr/bin/ktouch	/var/lib/menu-xdg/applications/menu-xdg/ktouch.desktop
kverbos	/usr/bin/kverbos	/var/lib/menu-xdg/applications/menu-xdg/kverbos.desktop
kvoctrain	/usr/bin/kvoctrain	/var/lib/menu-xdg/applications/menu-xdg/kvoctrain.desktop
BasiliskII	/usr/bin/BasiliskII	/var/lib/menu-xdg/applications/menu-xdg/basiliskii.desktop
x128	/usr/bin/x128	/var/lib/menu-xdg/applications/menu-xdg/commodore_128.desktop
x64	/usr/bin/x64	/var/lib/menu-xdg/applications/menu-xdg/commodore_64.desktop
xcbm2	/usr/bin/xcbm2	/var/lib/menu-xdg/applications/menu-xdg/commodore_cbm-ii.desktop
xpet	/usr/bin/xpet	/var/lib/menu-xdg/applications/menu-xdg/commodore_pet.desktop
xvic	/usr/bin/xvic	/var/lib/menu-xdg/applications/menu-xdg/commodore_vic-20.desktop
dosemu	/usr/bin/dosemu	/var/lib/menu-xdg/applications/menu-xdg/dos_emulator_(tty).desktop
xdosemu	/usr/bin/xdosemu	/var/lib/menu-xdg/applications/menu-xdg/dos_emulator_(x11).desktop
GSnes9x	/usr/bin/GSnes9x	/var/lib/menu-xdg/applications/menu-xdg/gsnes9x.desktop
x-terminal-emulator	x-terminal-emulator -T spectemu -e /usr/bin/xspect	/var/lib/menu-xdg/applications/menu-xdg/spectemu.desktop
uae-x	/usr/bin/uae-x	/var/lib/menu-xdg/applications/menu-xdg/uae.desktop
avidemux	/usr/bin/avidemux	/var/lib/menu-xdg/applications/menu-xdg/avidemux.desktop
bitmap	bitmap	/var/lib/menu-xdg/applications/menu-xdg/bitmap.desktop
blender	/usr/bin/blender -w	/var/lib/menu-xdg/applications/menu-xdg/blender_(windowed).desktop
cenon	/usr/bin/cenon	/var/lib/menu-xdg/applications/menu-xdg/cenon.desktop
cinelerra	/usr/bin/cinelerra	/var/lib/menu-xdg/applications/menu-xdg/cinelerra.desktop
dia-normal	/usr/bin/dia-normal	/var/lib/menu-xdg/applications/menu-xdg/dia.desktop
dia-gnome	/usr/bin/dia-gnome	/var/lib/menu-xdg/applications/menu-xdg/dia_(gnome).desktop
egon	/usr/bin/egon	/var/lib/menu-xdg/applications/menu-xdg/egon.desktop
filmgimp	/usr/bin/filmgimp	/var/lib/menu-xdg/applications/menu-xdg/film_gimp.desktop
giram	/usr/bin/giram	/var/lib/menu-xdg/applications/menu-xdg/giram.desktop
ganso	/usr/bin/ganso	/var/lib/menu-xdg/applications/menu-xdg/gnome_animation_studio.desktop
gqcam	/usr/bin/gqcam	/var/lib/menu-xdg/applications/menu-xdg/gqcam.desktop
gtk-ocr	/usr/bin/gtk-ocr	/var/lib/menu-xdg/applications/menu-xdg/gtk_gocr.desktop
inkscape	/usr/bin/inkscape	/var/lib/menu-xdg/applications/menu-xdg/inkscape.desktop
innovation3d	/usr/bin/innovation3d	/var/lib/menu-xdg/applications/menu-xdg/innovation3d_modeler.desktop
x-terminal-emulator	x-terminal-emulator -e /usr/X11R6/bin/drawserv	/var/lib/menu-xdg/applications/menu-xdg/ivtools.desktop
ivview	/usr/bin/ivview	/var/lib/menu-xdg/applications/menu-xdg/ivview.desktop
karbon	/usr/bin/karbon	/var/lib/menu-xdg/applications/menu-xdg/karbon.desktop
kcolorchooser	/usr/bin/kcolorchooser	/var/lib/menu-xdg/applications/menu-xdg/kcolorchooser.desktop
kcoloredit	/usr/bin/kcoloredit	/var/lib/menu-xdg/applications/menu-xdg/kcoloredit.desktop
kfax	/usr/bin/kfax	/var/lib/menu-xdg/applications/menu-xdg/kfax.desktop
kiconedit	/usr/bin/kiconedit	/var/lib/menu-xdg/applications/menu-xdg/kiconedit.desktop
kino	/usr/bin/kino	/var/lib/menu-xdg/applications/menu-xdg/kino.desktop
kooka	/usr/bin/kooka	/var/lib/menu-xdg/applications/menu-xdg/kooka.desktop
kpaint	/usr/bin/kpaint	/var/lib/menu-xdg/applications/menu-xdg/kpaint.desktop
kpdf	/usr/bin/kpdf	/var/lib/menu-xdg/applications/menu-xdg/kpdf.desktop
kpovmodeler	/usr/bin/kpovmodeler	/var/lib/menu-xdg/applications/menu-xdg/kpovmodeler.desktop
kruler	/usr/bin/kruler	/var/lib/menu-xdg/applications/menu-xdg/kruler.desktop
ksnapshot	/usr/bin/ksnapshot	/var/lib/menu-xdg/applications/menu-xdg/ksnapshot.desktop
kuickshow	/usr/bin/kuickshow	/var/lib/menu-xdg/applications/menu-xdg/kuickshow.desktop
motion	/usr/bin/motion	/var/lib/menu-xdg/applications/menu-xdg/motion.desktop
picview	/usr/bin/picview	/var/lib/menu-xdg/applications/menu-xdg/picview.desktop
pixmap	/usr/X11R6/bin/pixmap	/var/lib/menu-xdg/applications/menu-xdg/pixmap.desktop
price	/usr/bin/price	/var/lib/menu-xdg/applications/menu-xdg/price.desktop
sced	/usr/bin/sced	/var/lib/menu-xdg/applications/menu-xdg/sced.desktop
SceneViewer	/usr/bin/SceneViewer	/var/lib/menu-xdg/applications/menu-xdg/sceneviewer.desktop
scribus	/usr/bin/scribus	/var/lib/menu-xdg/applications/menu-xdg/scribus.desktop
sketch	/usr/bin/sketch	/var/lib/menu-xdg/applications/menu-xdg/sketch.desktop
snowflake	/usr/bin/snowflake	/var/lib/menu-xdg/applications/menu-xdg/snowflake.desktop
sodipodi	sodipodi	/var/lib/menu-xdg/applications/menu-xdg/sodipodi.desktop
terraform	/usr/bin/terraform	/var/lib/menu-xdg/applications/menu-xdg/terraform.desktop
sh	sh -c 'cd /tmp && /usr/bin/xaos -driver aa'	/var/lib/menu-xdg/applications/menu-xdg/text_xaos.desktop
tgif	/usr/bin/tgif	/var/lib/menu-xdg/applications/menu-xdg/tgif.desktop
gimp-2.0	/usr/bin/gimp-2.0	/var/lib/menu-xdg/applications/menu-xdg/the_gimp_(v2.0).desktop
tulip	/usr/bin/tulip	/var/lib/menu-xdg/applications/menu-xdg/tulip.desktop
tuxpaint	/usr/bin/tuxpaint	/var/lib/menu-xdg/applications/menu-xdg/tuxpaint.desktop
vertex	/usr/bin/vertex	/var/lib/menu-xdg/applications/menu-xdg/vertex.desktop
sh	sh -c 'cd /tmp && /usr/bin/xaos -driver x11'	/var/lib/menu-xdg/applications/menu-xdg/xaos.desktop
xfig	/usr/bin/xfig	/var/lib/menu-xdg/applications/menu-xdg/xfig.desktop
xmorph	/usr/bin/xmorph	/var/lib/menu-xdg/applications/menu-xdg/xmorph.desktop
xmps	xmps	/var/lib/menu-xdg/applications/menu-xdg/xmps.desktop
/usr/bin/X11/xpaint	/usr/bin/X11/xpaint	/var/lib/menu-xdg/applications/menu-xdg/xpaint.desktop
xsane	/usr/bin/xsane	/var/lib/menu-xdg/applications/menu-xdg/xsane.desktop
gmfsk	/usr/bin/gmfsk	/var/lib/menu-xdg/applications/menu-xdg/gmfsk.desktop
gworldclock	/usr/bin/gworldclock	/var/lib/menu-xdg/applications/menu-xdg/gworldclock.desktop
hamfax	/usr/bin/hamfax	/var/lib/menu-xdg/applications/menu-xdg/hamfax.desktop
linpac	/usr/bin/linpac	/var/lib/menu-xdg/applications/menu-xdg/linpac.desktop
twclock	/usr/bin/twclock	/var/lib/menu-xdg/applications/menu-xdg/twclock.desktop
xastir	/usr/bin/xastir	/var/lib/menu-xdg/applications/menu-xdg/xastir.desktop
xcall	/usr/bin/xcall	/var/lib/menu-xdg/applications/menu-xdg/xcall.desktop
bc	/usr/bin/bc	/var/lib/menu-xdg/applications/menu-xdg/bc.desktop
burlap	/usr/bin/burlap	/var/lib/menu-xdg/applications/menu-xdg/burlap.desktop
gcalctool	/usr/bin/gcalctool	/var/lib/menu-xdg/applications/menu-xdg/calctool.desktop
dc	/usr/bin/dc	/var/lib/menu-xdg/applications/menu-xdg/dc.desktop
fudgit	/usr/bin/fudgit	/var/lib/menu-xdg/applications/menu-xdg/fudgit.desktop
geomview	/usr/bin/geomview	/var/lib/menu-xdg/applications/menu-xdg/geomview.desktop
gnumeric	/usr/bin/gnumeric	/var/lib/menu-xdg/applications/menu-xdg/gnumeric.desktop
gstar	/usr/bin/gstar	/var/lib/menu-xdg/applications/menu-xdg/gstar.desktop
kbruch	/usr/bin/kbruch	/var/lib/menu-xdg/applications/menu-xdg/kbruch.desktop
kcalc	/usr/bin/kcalc	/var/lib/menu-xdg/applications/menu-xdg/kcalc.desktop
kchart	/usr/bin/kchart	/var/lib/menu-xdg/applications/menu-xdg/kchart.desktop
kformula	/usr/bin/kformula	/var/lib/menu-xdg/applications/menu-xdg/kformula.desktop
kgeo	/usr/bin/kgeo	/var/lib/menu-xdg/applications/menu-xdg/kgeo.desktop
kig	/usr/bin/kig	/var/lib/menu-xdg/applications/menu-xdg/kig.desktop
kmplot	/usr/bin/kmplot	/var/lib/menu-xdg/applications/menu-xdg/kmplot.desktop
kpercentage	/usr/bin/kpercentage	/var/lib/menu-xdg/applications/menu-xdg/kpercentage.desktop
kspread	/usr/bin/kspread	/var/lib/menu-xdg/applications/menu-xdg/kspread.desktop
openuniverse	/usr/bin/openuniverse	/var/lib/menu-xdg/applications/menu-xdg/openuniverse.desktop
perldl	/usr/bin/perldl	/var/lib/menu-xdg/applications/menu-xdg/perldl.desktop
rcalc	/usr/bin/rcalc	/var/lib/menu-xdg/applications/menu-xdg/rcalc.desktop
rcalc	/usr/bin/rcalc -t	/var/lib/menu-xdg/applications/menu-xdg/rcalc_(text).desktop
siag	/usr/bin/siag	/var/lib/menu-xdg/applications/menu-xdg/siag.desktop
tsiag	/usr/bin/tsiag	/var/lib/menu-xdg/applications/menu-xdg/siag_(text_mode).desktop
velvet	/usr/bin/velvet	/var/lib/menu-xdg/applications/menu-xdg/velvet.desktop
xabacus	/usr/games/xabacus	/var/lib/menu-xdg/applications/menu-xdg/xabacus.desktop
xcalc	xcalc	/var/lib/menu-xdg/applications/menu-xdg/xcalc.desktop
xmaxima	/usr/bin/xmaxima	/var/lib/menu-xdg/applications/menu-xdg/xmaxima.desktop
amaya	/usr/bin/amaya	/var/lib/menu-xdg/applications/menu-xdg/amaya.desktop
amule	/usr/bin/amule	/var/lib/menu-xdg/applications/menu-xdg/amule.desktop
amulewebDLG	/usr/bin/amulewebDLG	/var/lib/menu-xdg/applications/menu-xdg/amule_webserver_control.desktop
dillo	/usr/bin/dillo	/var/lib/menu-xdg/applications/menu-xdg/dillo.desktop
driftnet	/usr/bin/driftnet	/var/lib/menu-xdg/applications/menu-xdg/driftnet.desktop
everybuddy	/usr/bin/everybuddy	/var/lib/menu-xdg/applications/menu-xdg/everybuddy.desktop
fwbuilder	/usr/bin/fwbuilder	/var/lib/menu-xdg/applications/menu-xdg/firewall_builder.desktop
gipsc	/usr/X11R6/bin/gipsc	/var/lib/menu-xdg/applications/menu-xdg/gipsc.desktop
gnapster	/usr/bin/gnapster	/var/lib/menu-xdg/applications/menu-xdg/gnapster.desktop
gnomemeeting	/usr/bin/gnomemeeting	/var/lib/menu-xdg/applications/menu-xdg/gnomemeeting.desktop
gtk-gnutella	/usr/bin/gtk-gnutella	/var/lib/menu-xdg/applications/menu-xdg/gtk-gnutella.desktop
su-to-root	/usr/sbin/su-to-root -c /usr/sbin/iptraf	/var/lib/menu-xdg/applications/menu-xdg/iptraf.desktop
kdict	/usr/bin/kdict	/var/lib/menu-xdg/applications/menu-xdg/kdict.desktop
kget	/usr/bin/kget	/var/lib/menu-xdg/applications/menu-xdg/kget.desktop
kit	/usr/bin/kit	/var/lib/menu-xdg/applications/menu-xdg/kit.desktop
kmail	/usr/bin/kmail	/var/lib/menu-xdg/applications/menu-xdg/kmail.desktop
kmailcvt	/usr/bin/kmailcvt	/var/lib/menu-xdg/applications/menu-xdg/kmail_kab_import_tool.desktop
appletproxy	/usr/bin/appletproxy knewsticker.desktop	/var/lib/menu-xdg/applications/menu-xdg/knewsticker.desktop
knode	/usr/bin/knode	/var/lib/menu-xdg/applications/menu-xdg/knode.desktop
konqueror	/usr/bin/konqueror --profile filemanagement	/var/lib/menu-xdg/applications/menu-xdg/konqueror.desktop
kopete	/usr/bin/kopete	/var/lib/menu-xdg/applications/menu-xdg/kopete.desktop
korn	/usr/bin/korn	/var/lib/menu-xdg/applications/menu-xdg/korn.desktop
kppp	/usr/bin/kppp	/var/lib/menu-xdg/applications/menu-xdg/kppp.desktop
kppplogview	/usr/bin/kppplogview	/var/lib/menu-xdg/applications/menu-xdg/kppp_-_logview.desktop
krdc	/usr/bin/krdc	/var/lib/menu-xdg/applications/menu-xdg/krdc.desktop
krfb	/usr/bin/krfb	/var/lib/menu-xdg/applications/menu-xdg/krfb.desktop
ksig	/usr/bin/ksig	/var/lib/menu-xdg/applications/menu-xdg/ksig.desktop
ksirc	/usr/bin/ksirc	/var/lib/menu-xdg/applications/menu-xdg/ksirc.desktop
kwifimanager	/usr/bin/kwifimanager	/var/lib/menu-xdg/applications/menu-xdg/kwifimanager.desktop
LinNeighborhood	/usr/bin/LinNeighborhood	/var/lib/menu-xdg/applications/menu-xdg/linneighborhood.desktop
lynx	/usr/bin/lynx	/var/lib/menu-xdg/applications/menu-xdg/lynx.desktop
minicom	/usr/bin/minicom	/var/lib/menu-xdg/applications/menu-xdg/minicom.desktop
xminicom	/usr/bin/xminicom	/var/lib/menu-xdg/applications/menu-xdg/minicom_(x11).desktop
mutt	/usr/bin/mutt	/var/lib/menu-xdg/applications/menu-xdg/mutt.desktop
ncftp3	/usr/bin/ncftp3	/var/lib/menu-xdg/applications/menu-xdg/ncftp.desktop
gnome-netinfo	/usr/bin/gnome-netinfo	/var/lib/menu-xdg/applications/menu-xdg/network_information.desktop
pan	/usr/bin/pan	/var/lib/menu-xdg/applications/menu-xdg/pan.desktop
gnome-remote-desktop	/usr/bin/gnome-remote-desktop	/var/lib/menu-xdg/applications/menu-xdg/remote_desktop.desktop
gnome-remote-shell	/usr/bin/gnome-remote-shell	/var/lib/menu-xdg/applications/menu-xdg/remote_shell.desktop
smb4k	/usr/bin/smb4k	/var/lib/menu-xdg/applications/menu-xdg/samba_for_kde.desktop
sdr	sdr	/var/lib/menu-xdg/applications/menu-xdg/sdr.desktop
telnet	telnet	/var/lib/menu-xdg/applications/menu-xdg/telnet.desktop
tsclient	/usr/bin/tsclient -f	/var/lib/menu-xdg/applications/menu-xdg/terminal_server_client.desktop
tkchooser	/usr/bin/tkchooser	/var/lib/menu-xdg/applications/menu-xdg/tkchooser.desktop
vrwave	/usr/bin/vrwave	/var/lib/menu-xdg/applications/menu-xdg/vrwave_vrml_browser.desktop
w3m	/usr/bin/w3m /usr/share/doc/w3m/MANUAL.html	/var/lib/menu-xdg/applications/menu-xdg/w3m.desktop
xchat	/usr/bin/xchat	/var/lib/menu-xdg/applications/menu-xdg/x_chat.desktop
xbiff	xbiff	/var/lib/menu-xdg/applications/menu-xdg/xbiff.desktop
xrealvncviewer	/usr/bin/xrealvncviewer	/var/lib/menu-xdg/applications/menu-xdg/xvncviewer.desktop
argouml	/usr/bin/argouml	/var/lib/menu-xdg/applications/menu-xdg/argouml.desktop
autoproject	/usr/bin/autoproject	/var/lib/menu-xdg/applications/menu-xdg/autoproject.desktop
cervisia	/usr/bin/cervisia	/var/lib/menu-xdg/applications/menu-xdg/cervisia.desktop
lisp	/usr/bin/lisp -core /usr/lib/cmucl/lisp.core	/var/lib/menu-xdg/applications/menu-xdg/cmucl_normal_image.desktop
ddd	/usr/bin/ddd	/var/lib/menu-xdg/applications/menu-xdg/data_display_debugger.desktop
elk	/usr/bin/elk	/var/lib/menu-xdg/applications/menu-xdg/elk.desktop
fluid	/usr/bin/fluid	/var/lib/menu-xdg/applications/menu-xdg/fluid.desktop
gide	/usr/bin/gide	/var/lib/menu-xdg/applications/menu-xdg/gide.desktop
glade-2	/usr/bin/glade-2	/var/lib/menu-xdg/applications/menu-xdg/glade_2.desktop
sh	/bin/sh -c "source /usr/lib/GNUstep/System/Library/Makefiles/GNUstep.sh >/dev/null 2>&1 && exec openapp Gorm.app"	/var/lib/menu-xdg/applications/menu-xdg/gorm.desktop
guile-1.6	/usr/bin/guile-1.6	/var/lib/menu-xdg/applications/menu-xdg/guile_1.6.desktop
guile1.4	guile1.4	/var/lib/menu-xdg/applications/menu-xdg/guile_scheme_1.4.desktop
insight	/usr/bin/insight	/var/lib/menu-xdg/applications/menu-xdg/insight.desktop
jython	/usr/bin/jython	/var/lib/menu-xdg/applications/menu-xdg/jython.desktop
kbabel	/usr/bin/kbabel	/var/lib/menu-xdg/applications/menu-xdg/kbabel.desktop
catalogmanager	/usr/bin/catalogmanager	/var/lib/menu-xdg/applications/menu-xdg/kbabel_catalog_manager.desktop
kbabeldict	/usr/bin/kbabeldict	/var/lib/menu-xdg/applications/menu-xdg/kbabel_dictionary.desktop
kbugbuster	/usr/bin/kbugbuster	/var/lib/menu-xdg/applications/menu-xdg/kbugbuster.desktop
kcachegrind	/usr/bin/kcachegrind	/var/lib/menu-xdg/applications/menu-xdg/kcachegrind.desktop
kdevelop3	kdevelop3	/var/lib/menu-xdg/applications/menu-xdg/kdevelop_3.0.desktop
kodos	/usr/bin/kodos	/var/lib/menu-xdg/applications/menu-xdg/kodos.desktop
kompare	/usr/bin/kompare	/var/lib/menu-xdg/applications/menu-xdg/kompare.desktop
kuiviewer	/usr/bin/kuiviewer	/var/lib/menu-xdg/applications/menu-xdg/kuiviewer.desktop
pike7.2	/usr/bin/pike7.2	/var/lib/menu-xdg/applications/menu-xdg/pike_7.2_hilfe.desktop
pycrust	/usr/bin/pycrust	/var/lib/menu-xdg/applications/menu-xdg/pycrust.desktop
pyshell	/usr/bin/pyshell	/var/lib/menu-xdg/applications/menu-xdg/pyshell.desktop
python2.1	/usr/bin/python2.1	/var/lib/menu-xdg/applications/menu-xdg/python_(v2.1).desktop
python2.2	/usr/bin/python2.2	/var/lib/menu-xdg/applications/menu-xdg/python_(v2.2).desktop
python2.3	/usr/bin/python2.3	/var/lib/menu-xdg/applications/menu-xdg/python_(v2.3).desktop
designer-qt3	/usr/bin/designer-qt3	/var/lib/menu-xdg/applications/menu-xdg/qt_designer.desktop
irb1.8	/usr/bin/irb1.8	/var/lib/menu-xdg/applications/menu-xdg/ruby_(irb1.8).desktop
tclsh8.0	/usr/bin/tclsh8.0	/var/lib/menu-xdg/applications/menu-xdg/tclsh8.0.desktop
tclsh8.2	/usr/bin/tclsh8.2	/var/lib/menu-xdg/applications/menu-xdg/tclsh8.2.desktop
tclsh8.3	/usr/bin/tclsh8.3	/var/lib/menu-xdg/applications/menu-xdg/tclsh8.3.desktop
tclsh8.4	/usr/bin/tclsh8.4	/var/lib/menu-xdg/applications/menu-xdg/tclsh8.4.desktop
tkcvs	/usr/bin/tkcvs	/var/lib/menu-xdg/applications/menu-xdg/tkcvs.desktop
tkdiff	/usr/bin/tkdiff	/var/lib/menu-xdg/applications/menu-xdg/tkdiff.desktop
wish8.0	/usr/bin/wish8.0	/var/lib/menu-xdg/applications/menu-xdg/tkwish8.0.desktop
wish8.2	/usr/bin/wish8.2	/var/lib/menu-xdg/applications/menu-xdg/tkwish8.2.desktop
x-terminal-emulator	x-terminal-emulator -e /usr/bin/wish8.3	/var/lib/menu-xdg/applications/menu-xdg/tkwish8.3.desktop
x-terminal-emulator	x-terminal-emulator -e /usr/bin/wish8.4	/var/lib/menu-xdg/applications/menu-xdg/tkwish8.4.desktop
umbrello	/usr/bin/umbrello	/var/lib/menu-xdg/applications/menu-xdg/umbrello.desktop
xrced	/usr/bin/xrced	/var/lib/menu-xdg/applications/menu-xdg/xrced.desktop
vibrate	/usr/bin/vibrate /usr/bin/asn2asn	/var/lib/menu-xdg/applications/menu-xdg/asn2asn.desktop
vibrate	/usr/bin/vibrate /usr/bin/asn2ff	/var/lib/menu-xdg/applications/menu-xdg/asn2ff.desktop
vibrate	/usr/bin/vibrate /usr/bin/asn2gb	/var/lib/menu-xdg/applications/menu-xdg/asn2gb.desktop
vibrate	/usr/bin/vibrate /usr/bin/asn2xml	/var/lib/menu-xdg/applications/menu-xdg/asn2xml.desktop
vibrate	/usr/bin/vibrate /usr/bin/asndhuff	/var/lib/menu-xdg/applications/menu-xdg/asndhuff.desktop
vibrate	/usr/bin/vibrate /usr/bin/bl2seq	/var/lib/menu-xdg/applications/menu-xdg/bl2seq.desktop
vibrate	/usr/bin/vibrate /usr/bin/blast2	/var/lib/menu-xdg/applications/menu-xdg/blast2.desktop
vibrate	/usr/bin/vibrate /usr/bin/blastall	/var/lib/menu-xdg/applications/menu-xdg/blastall.desktop
vibrate	/usr/bin/vibrate /usr/bin/blastcl3	/var/lib/menu-xdg/applications/menu-xdg/blastcl3.desktop
vibrate	/usr/bin/vibrate /usr/bin/blastclust	/var/lib/menu-xdg/applications/menu-xdg/blastclust.desktop
vibrate	/usr/bin/vibrate /usr/bin/blastpgp	/var/lib/menu-xdg/applications/menu-xdg/blastpgp.desktop
vibrate	/usr/bin/vibrate /usr/bin/checksub	/var/lib/menu-xdg/applications/menu-xdg/checksub.desktop
Cn3D-3.0	/usr/bin/Cn3D-3.0	/var/lib/menu-xdg/applications/menu-xdg/cn3d-3.0.desktop
vibrate	/usr/bin/vibrate /usr/bin/copymat	/var/lib/menu-xdg/applications/menu-xdg/copymat.desktop
ddv	/usr/bin/ddv	/var/lib/menu-xdg/applications/menu-xdg/ddv.desktop
vibrate	/usr/bin/vibrate /usr/bin/debruijn	/var/lib/menu-xdg/applications/menu-xdg/debruijn.desktop
vibrate	/usr/bin/vibrate /usr/bin/entrcmd	/var/lib/menu-xdg/applications/menu-xdg/entrcmd.desktop
Nentrez	/usr/bin/Nentrez	/var/lib/menu-xdg/applications/menu-xdg/entrez.desktop
netentcf	/usr/bin/netentcf	/var/lib/menu-xdg/applications/menu-xdg/entrez_net_config.desktop
entrez2	/usr/bin/entrez2	/var/lib/menu-xdg/applications/menu-xdg/entrez2.desktop
vibrate	/usr/bin/vibrate /usr/bin/fa2htgs	/var/lib/menu-xdg/applications/menu-xdg/fa2htgs.desktop
vibrate	/usr/bin/vibrate /usr/bin/fastacmd	/var/lib/menu-xdg/applications/menu-xdg/fastacmd.desktop
vibrate	/usr/bin/vibrate /usr/bin/findspl	/var/lib/menu-xdg/applications/menu-xdg/findspl.desktop
vibrate	/usr/bin/vibrate /usr/bin/formatdb	/var/lib/menu-xdg/applications/menu-xdg/formatdb.desktop
garlic	/usr/bin/garlic	/var/lib/menu-xdg/applications/menu-xdg/garlic.desktop
vibrate	/usr/bin/vibrate /usr/bin/gbseqget	/var/lib/menu-xdg/applications/menu-xdg/gbseqget.desktop
vibrate	/usr/bin/vibrate /usr/bin/getfeat	/var/lib/menu-xdg/applications/menu-xdg/getfeat.desktop
vibrate	/usr/bin/vibrate /usr/bin/getmesh	/var/lib/menu-xdg/applications/menu-xdg/getmesh.desktop
vibrate	/usr/bin/vibrate /usr/bin/getpub	/var/lib/menu-xdg/applications/menu-xdg/getpub.desktop
vibrate	/usr/bin/vibrate /usr/bin/gil2bin	/var/lib/menu-xdg/applications/menu-xdg/gil2bin.desktop
vibrate	/usr/bin/vibrate /usr/bin/idfetch	/var/lib/menu-xdg/applications/menu-xdg/idfetch.desktop
vibrate	/usr/bin/vibrate /usr/bin/impala	/var/lib/menu-xdg/applications/menu-xdg/impala.desktop
vibrate	/usr/bin/vibrate /usr/bin/indexpub	/var/lib/menu-xdg/applications/menu-xdg/indexpub.desktop
kalzium	/usr/bin/kalzium	/var/lib/menu-xdg/applications/menu-xdg/kalzium.desktop
kstars	/usr/bin/kstars	/var/lib/menu-xdg/applications/menu-xdg/kstars.desktop
kxterm	kxterm	/var/lib/menu-xdg/applications/menu-xdg/kxterm.desktop
vibrate	/usr/bin/vibrate /usr/bin/makemat	/var/lib/menu-xdg/applications/menu-xdg/makemat.desktop
vibrate	/usr/bin/vibrate /usr/bin/makeset	/var/lib/menu-xdg/applications/menu-xdg/makeset.desktop
vibrate	/usr/bin/vibrate /usr/bin/megablast	/var/lib/menu-xdg/applications/menu-xdg/megablast.desktop
njplot	/usr/bin/njplot	/var/lib/menu-xdg/applications/menu-xdg/njplot.desktop
unrooted	/usr/bin/unrooted	/var/lib/menu-xdg/applications/menu-xdg/njplot_unrooted.desktop
rasmol	/usr/bin/rasmol	/var/lib/menu-xdg/applications/menu-xdg/rasmol.desktop
vibrate	/usr/bin/vibrate /usr/bin/rpsblast	/var/lib/menu-xdg/applications/menu-xdg/rpsblast.desktop
vibrate	/usr/bin/vibrate /usr/bin/seedtop	/var/lib/menu-xdg/applications/menu-xdg/seedtop.desktop
Psequin	/usr/bin/Psequin	/var/lib/menu-xdg/applications/menu-xdg/sequin.desktop
starplot	/usr/bin/starplot	/var/lib/menu-xdg/applications/menu-xdg/starplot.desktop
vibrate	/usr/bin/vibrate /usr/bin/tbl2asn	/var/lib/menu-xdg/applications/menu-xdg/tbl2asn.desktop
udv	/usr/bin/udv	/var/lib/menu-xdg/applications/menu-xdg/udv.desktop
vibrate	/usr/bin/vibrate /usr/bin/vecscreen	/var/lib/menu-xdg/applications/menu-xdg/vecscreen.desktop
bash	/bin/bash --login	/var/lib/menu-xdg/applications/menu-xdg/bash.desktop
ksh	/bin/ksh -l	/var/lib/menu-xdg/applications/menu-xdg/ksh.desktop
sh	/bin/sh --login	/var/lib/menu-xdg/applications/menu-xdg/sh.desktop
tcsh	/bin/tcsh	/var/lib/menu-xdg/applications/menu-xdg/tcsh.desktop
aconnectgui	/usr/bin/aconnectgui	/var/lib/menu-xdg/applications/menu-xdg/aconnectgui.desktop
/usr/bin/X11/xterm	/usr/bin/X11/xterm -hold -e /usr/bin/ardour	/var/lib/menu-xdg/applications/menu-xdg/ardour_gtk.desktop
artsbuilder	/usr/bin/artsbuilder	/var/lib/menu-xdg/applications/menu-xdg/arts_builder.desktop
artscontrol	/usr/bin/artscontrol	/var/lib/menu-xdg/applications/menu-xdg/arts_control.desktop
audacity	/usr/bin/audacity	/var/lib/menu-xdg/applications/menu-xdg/audacity.desktop
vkeybd	/usr/bin/vkeybd	/var/lib/menu-xdg/applications/menu-xdg/awe_virtual_keyboard.desktop
bcast2000	/usr/bin/bcast2000	/var/lib/menu-xdg/applications/menu-xdg/broadcast2000.desktop
/usr/bin/X11/xterm	/usr/bin/X11/xterm -font vga -geometry 80x25 -bg black -fg gray -e /usr/bin/cam	/var/lib/menu-xdg/applications/menu-xdg/cam.desktop
cecilia	/usr/bin/cecilia	/var/lib/menu-xdg/applications/menu-xdg/cecilia.desktop
ceres3	/usr/bin/ceres3	/var/lib/menu-xdg/applications/menu-xdg/ceres3.desktop
cglame	/usr/bin/cglame	/var/lib/menu-xdg/applications/menu-xdg/cglame.desktop
ecasound	/usr/bin/ecasound	/var/lib/menu-xdg/applications/menu-xdg/ecasound.desktop
extace	/usr/bin/extace	/var/lib/menu-xdg/applications/menu-xdg/extace.desktop
freebirth	/usr/bin/freebirth	/var/lib/menu-xdg/applications/menu-xdg/freebirth.desktop
gamix	gamix	/var/lib/menu-xdg/applications/menu-xdg/gamix.desktop
gcd	/usr/bin/gcd	/var/lib/menu-xdg/applications/menu-xdg/gcd.desktop
glcthugha	glcthugha	/var/lib/menu-xdg/applications/menu-xdg/gl_cthugha.desktop
glame	/usr/bin/glame	/var/lib/menu-xdg/applications/menu-xdg/glame.desktop
gnome-volume-control	/usr/bin/gnome-volume-control	/var/lib/menu-xdg/applications/menu-xdg/gmix_(gnome_2.0_mixer).desktop
gnome-cd	/usr/bin/gnome-cd	/var/lib/menu-xdg/applications/menu-xdg/gnome-cd_(gnome_2.0_cd_player).desktop
gnomp3	/usr/bin/gnomp3	/var/lib/menu-xdg/applications/menu-xdg/gnomp3.desktop
gom-ct	/usr/bin/gom-ct --interface=t	/var/lib/menu-xdg/applications/menu-xdg/gom_(terminal).desktop
gnome-sound-recorder	/usr/bin/gnome-sound-recorder	/var/lib/menu-xdg/applications/menu-xdg/grecord_(gnome_2.0_recorder).desktop
grip	/usr/bin/grip	/var/lib/menu-xdg/applications/menu-xdg/grip.desktop
gsox	/usr/bin/gsox	/var/lib/menu-xdg/applications/menu-xdg/gsox.desktop
gtick	/usr/bin/gtick	/var/lib/menu-xdg/applications/menu-xdg/gtick.desktop
horgand	/usr/bin/horgand -b /usr/share/horgand/Default.horeb	/var/lib/menu-xdg/applications/menu-xdg/horgand.desktop
id3ren	/usr/bin/id3ren	/var/lib/menu-xdg/applications/menu-xdg/id3ren.desktop
juk	/usr/bin/juk	/var/lib/menu-xdg/applications/menu-xdg/juk_music_player.desktop
kaboodle	/usr/bin/kaboodle	/var/lib/menu-xdg/applications/menu-xdg/kaboodle.desktop
kaudiocreator	/usr/bin/kaudiocreator	/var/lib/menu-xdg/applications/menu-xdg/kaudiocreator.desktop
kmid	/usr/bin/kmid	/var/lib/menu-xdg/applications/menu-xdg/kmid.desktop
kmidi	/usr/bin/kmidi	/var/lib/menu-xdg/applications/menu-xdg/kmidi.desktop
kmix	/usr/bin/kmix	/var/lib/menu-xdg/applications/menu-xdg/kmix.desktop
krec	/usr/bin/krec	/var/lib/menu-xdg/applications/menu-xdg/krec.desktop
kscd	/usr/bin/kscd	/var/lib/menu-xdg/applications/menu-xdg/kscd.desktop
mammut	/usr/bin/mammut	/var/lib/menu-xdg/applications/menu-xdg/mammut.desktop
/usr/bin/X11/mix	/usr/bin/X11/mix	/var/lib/menu-xdg/applications/menu-xdg/mix.desktop
/usr/X11R6/bin/Mixer.app	/usr/X11R6/bin/Mixer.app	/var/lib/menu-xdg/applications/menu-xdg/mixer.app.desktop
mixmagic	/usr/bin/mixmagic	/var/lib/menu-xdg/applications/menu-xdg/mixmagic.desktop
mxv	/usr/X11R6/bin/mxv	/var/lib/menu-xdg/applications/menu-xdg/mixviews.desktop
muse	/usr/bin/muse	/var/lib/menu-xdg/applications/menu-xdg/muse.desktop
music-librarian	/usr/bin/music-librarian	/var/lib/menu-xdg/applications/menu-xdg/music_librarian.desktop
noatun	/usr/bin/noatun	/var/lib/menu-xdg/applications/menu-xdg/noatun.desktop
noteedit	/usr/bin/noteedit	/var/lib/menu-xdg/applications/menu-xdg/noteedit.desktop
qrt	/usr/bin/qrt	/var/lib/menu-xdg/applications/menu-xdg/qrt.desktop
qsynth	/usr/bin/qsynth	/var/lib/menu-xdg/applications/menu-xdg/qsynth.desktop
rezound	/usr/bin/rezound	/var/lib/menu-xdg/applications/menu-xdg/rezound.desktop
rosegarden4	/usr/bin/rosegarden4	/var/lib/menu-xdg/applications/menu-xdg/rosegarden4.desktop
shaketracker	shaketracker	/var/lib/menu-xdg/applications/menu-xdg/shacketracker.desktop
smurf	/usr/bin/smurf	/var/lib/menu-xdg/applications/menu-xdg/smurf.desktop
snd	/usr/bin/snd	/var/lib/menu-xdg/applications/menu-xdg/snd.desktop
soundtracker	/usr/bin/soundtracker	/var/lib/menu-xdg/applications/menu-xdg/soundtracker.desktop
GUIBowedBar	/usr/bin/GUIBowedBar	/var/lib/menu-xdg/applications/menu-xdg/bowedbar.desktop
GUIDrums	/usr/bin/GUIDrums	/var/lib/menu-xdg/applications/menu-xdg/drums.desktop
GUIeffects	/usr/bin/GUIeffects	/var/lib/menu-xdg/applications/menu-xdg/effects.desktop
GUIModal	/usr/bin/GUIModal	/var/lib/menu-xdg/applications/menu-xdg/modal.desktop
GUIPhysical	/usr/bin/GUIPhysical	/var/lib/menu-xdg/applications/menu-xdg/physical.desktop
GUIRaga	/usr/bin/GUIRaga	/var/lib/menu-xdg/applications/menu-xdg/ragamatic.desktop
GUIShakers	/usr/bin/GUIShakers	/var/lib/menu-xdg/applications/menu-xdg/shakers.desktop
GUIVoice	/usr/bin/GUIVoice	/var/lib/menu-xdg/applications/menu-xdg/voice.desktop
sweep	/usr/bin/sweep	/var/lib/menu-xdg/applications/menu-xdg/sweep.desktop
synaesthesia	synaesthesia cd	/var/lib/menu-xdg/applications/menu-xdg/synaesthesia_(cd_input).desktop
synaesthesia	synaesthesia esd	/var/lib/menu-xdg/applications/menu-xdg/synaesthesia_(esd_input).desktop
synaesthesia	synaesthesia line	/var/lib/menu-xdg/applications/menu-xdg/synaesthesia_(line_input).desktop
terminatorX	/usr/bin/terminatorX	/var/lib/menu-xdg/applications/menu-xdg/terminatorx.desktop
timidity	timidity -ia	/var/lib/menu-xdg/applications/menu-xdg/timidity++.desktop
tk707	/usr/bin/tk707	/var/lib/menu-xdg/applications/menu-xdg/tk-707.desktop
tkmixer	/usr/bin/tkmixer	/var/lib/menu-xdg/applications/menu-xdg/tkmixer.desktop
vumeter	/usr/bin/vumeter	/var/lib/menu-xdg/applications/menu-xdg/vumeter_(gnome_2.0_volume_meter).desktop
wavesurfer	/usr/bin/wavesurfer	/var/lib/menu-xdg/applications/menu-xdg/wavesurfer.desktop
wmmixer	/usr/bin/wmmixer	/var/lib/menu-xdg/applications/menu-xdg/wmmixer.desktop
wmmixer	/usr/bin/wmmixer -w	/var/lib/menu-xdg/applications/menu-xdg/wmmixer_(docked).desktop
wmxmms	wmxmms	/var/lib/menu-xdg/applications/menu-xdg/wmxmms.desktop
workman	/usr/bin/workman	/var/lib/menu-xdg/applications/menu-xdg/workman.desktop
xcthugha	xcthugha	/var/lib/menu-xdg/applications/menu-xdg/x_cthugha.desktop
xfreecd	/usr/bin/xfreecd	/var/lib/menu-xdg/applications/menu-xdg/xfreecd.desktop
xmcd	/usr/bin/xmcd	/var/lib/menu-xdg/applications/menu-xdg/xmcd.desktop
/usr/bin/X11/xmix	/usr/bin/X11/xmix	/var/lib/menu-xdg/applications/menu-xdg/xmix.desktop
xmixer	xmixer	/var/lib/menu-xdg/applications/menu-xdg/xmixer.desktop
xmms	xmms	/var/lib/menu-xdg/applications/menu-xdg/xmms.desktop
xplaycd	xplaycd	/var/lib/menu-xdg/applications/menu-xdg/xplaycd.desktop
xwave	/usr/bin/xwave	/var/lib/menu-xdg/applications/menu-xdg/xwave.desktop
su-to-root	/usr/sbin/su-to-root -p root -c /usr/sbin/alsaconf	/var/lib/menu-xdg/applications/menu-xdg/alsaconf.desktop
su-to-root	/usr/sbin/su-to-root -p root -c /usr/sbin/gpmconfig	/var/lib/menu-xdg/applications/menu-xdg/gpm-config.desktop
kdesu	/usr/bin/kdesu kcmshell lilo	/var/lib/menu-xdg/applications/menu-xdg/lilo-config.desktop
su-to-root	/usr/sbin/su-to-root -c '/usr/sbin/orphaner -a'	/var/lib/menu-xdg/applications/menu-xdg/orphaner_(all).desktop
su-to-root	/usr/sbin/su-to-root -c /usr/sbin/orphaner	/var/lib/menu-xdg/applications/menu-xdg/orphaner_(libs).desktop
su-to-root	/usr/sbin/su-to-root -c '/usr/sbin/editkeep '	/var/lib/menu-xdg/applications/menu-xdg/orphaner_-_editkeep.desktop
su-to-root	/usr/sbin/su-to-root -p root -c /usr/sbin/pppconfig	/var/lib/menu-xdg/applications/menu-xdg/pppconfig.desktop
aptitude	/usr/bin/aptitude	/var/lib/menu-xdg/applications/menu-xdg/aptitude.desktop
gvidm	/usr/bin/gvidm	/var/lib/menu-xdg/applications/menu-xdg/change_x11_resolution_(gvidm).desktop
fsview	/usr/bin/fsview	/var/lib/menu-xdg/applications/menu-xdg/fsview.desktop
gdmflexiserver	gdmflexiserver -n	/var/lib/menu-xdg/applications/menu-xdg/gdm_flexiserver_in_xnest.desktop
gdmphotosetup	gdmphotosetup	/var/lib/menu-xdg/applications/menu-xdg/gdm_photo_setup.desktop
gnome-control-center	/usr/bin/gnome-control-center	/var/lib/menu-xdg/applications/menu-xdg/gnome_control_center.desktop
bug-buddy	/usr/bin/bug-buddy	/var/lib/menu-xdg/applications/menu-xdg/gnome_bug_report_tool.desktop
gfloppy	/usr/bin/gfloppy	/var/lib/menu-xdg/applications/menu-xdg/gnome_floppy_formatter.desktop
gnome-system-log	/usr/bin/gnome-system-log	/var/lib/menu-xdg/applications/menu-xdg/gnome_log_viewer.desktop
gnome-system-monitor	/usr/bin/gnome-system-monitor	/var/lib/menu-xdg/applications/menu-xdg/gnome_system_monitor.desktop
gps	/usr/bin/gps	/var/lib/menu-xdg/applications/menu-xdg/gps.desktop
gxset	/usr/bin/gxset	/var/lib/menu-xdg/applications/menu-xdg/gtk_xset.desktop
gtkrecover	/usr/sbin/gtkrecover	/var/lib/menu-xdg/applications/menu-xdg/gtkrecover.desktop
openapp	openapp GWorkspace	/var/lib/menu-xdg/applications/menu-xdg/gworkspace.app.desktop
gxproc	/usr/bin/gxproc	/var/lib/menu-xdg/applications/menu-xdg/gxproc.desktop
kappfinder	/usr/bin/kappfinder	/var/lib/menu-xdg/applications/menu-xdg/kappfinder.desktop
kcmshell	/usr/bin/kcmshell linuz	/var/lib/menu-xdg/applications/menu-xdg/kcmlinuz.desktop
kcontrol	/usr/bin/kcontrol	/var/lib/menu-xdg/applications/menu-xdg/kcontrol.desktop
kdat	/usr/bin/kdat	/var/lib/menu-xdg/applications/menu-xdg/kdat.desktop
kdcop	/usr/bin/kdcop	/var/lib/menu-xdg/applications/menu-xdg/kdcop.desktop
kpackage	/usr/bin/kpackage	/var/lib/menu-xdg/applications/menu-xdg/kde_package_manager.desktop
secpolicy	/usr/bin/secpolicy	/var/lib/menu-xdg/applications/menu-xdg/kde_pam_security_policy_editor.desktop
ksysguard	/usr/bin/ksysguard	/var/lib/menu-xdg/applications/menu-xdg/kde_system_guard.desktop
kpm	/usr/bin/kpm	/var/lib/menu-xdg/applications/menu-xdg/kde_system_guard_-_process_table.desktop
ksysv	/usr/bin/ksysv	/var/lib/menu-xdg/applications/menu-xdg/kde_sysv-init_editor.desktop
kcron	/usr/bin/kcron	/var/lib/menu-xdg/applications/menu-xdg/kde_task_scheduler.desktop
kuser	/usr/bin/kuser	/var/lib/menu-xdg/applications/menu-xdg/kde_user_manager.desktop
kdebugdialog	/usr/bin/kdebugdialog	/var/lib/menu-xdg/applications/menu-xdg/kdebugdialog.desktop
kdepasswd	/usr/bin/kdepasswd	/var/lib/menu-xdg/applications/menu-xdg/kdepasswd.desktop
kdeprintfax	/usr/bin/kdeprintfax	/var/lib/menu-xdg/applications/menu-xdg/kdeprintfax.desktop
kdf	/usr/bin/kdf	/var/lib/menu-xdg/applications/menu-xdg/kdiskfree.desktop
keditbookmarks	/usr/bin/keditbookmarks	/var/lib/menu-xdg/applications/menu-xdg/keditbookmarks.desktop
kfind	/usr/bin/kfind	/var/lib/menu-xdg/applications/menu-xdg/kfind.desktop
kfloppy	/usr/bin/kfloppy	/var/lib/menu-xdg/applications/menu-xdg/kfloppy.desktop
kicker	/usr/bin/kicker	/var/lib/menu-xdg/applications/menu-xdg/kicker.desktop
kjobviewer	/usr/bin/kjobviewer --show --all	/var/lib/menu-xdg/applications/menu-xdg/kjobviewer.desktop
kmenuedit	/usr/bin/kmenuedit	/var/lib/menu-xdg/applications/menu-xdg/kmenuedit.desktop
kpersonalizer	/usr/bin/kpersonalizer	/var/lib/menu-xdg/applications/menu-xdg/kpersonalizer.desktop
kprinter	/usr/bin/kprinter	/var/lib/menu-xdg/applications/menu-xdg/kprinter.desktop
kwikdisk	/usr/bin/kwikdisk	/var/lib/menu-xdg/applications/menu-xdg/kwikdisk.desktop
loadmeter	/usr/bin/loadmeter	/var/lib/menu-xdg/applications/menu-xdg/loadmeter.desktop
moodss	/usr/bin/moodss	/var/lib/menu-xdg/applications/menu-xdg/moodss.desktop
mount.app	/usr/bin/mount.app	/var/lib/menu-xdg/applications/menu-xdg/mountapp.desktop
nautilus	/usr/bin/nautilus	/var/lib/menu-xdg/applications/menu-xdg/nautilus.desktop
netwatch	/usr/sbin/netwatch	/var/lib/menu-xdg/applications/menu-xdg/netwatch.desktop
netload	/usr/bin/netload ppp0	/var/lib/menu-xdg/applications/menu-xdg/network_load_on_ppp0.desktop
/usr/lib/openoffice/program/setup	/usr/lib/openoffice/program/setup	/var/lib/menu-xdg/applications/menu-xdg/openoffice.org_setup.desktop
x-terminal-emulator	x-terminal-emulator -e /usr/bin/pstree.x11	/var/lib/menu-xdg/applications/menu-xdg/pstree.desktop
su-to-root	/usr/sbin/su-to-root -p root -c /usr/sbin/recover	/var/lib/menu-xdg/applications/menu-xdg/recover.desktop
reportbug	/usr/bin/reportbug --exit-prompt	/var/lib/menu-xdg/applications/menu-xdg/reportbug.desktop
gksuexec	/usr/bin/gksuexec	/var/lib/menu-xdg/applications/menu-xdg/run_as_different_user_(gksu).desktop
si	/usr/bin/si	/var/lib/menu-xdg/applications/menu-xdg/si.desktop
statnet	/usr/sbin/statnet	/var/lib/menu-xdg/applications/menu-xdg/statnet.desktop
su-to-root	/usr/sbin/su-to-root -X -c /usr/sbin/synaptic	/var/lib/menu-xdg/applications/menu-xdg/synaptic_package_manager.desktop
su-to-root	/usr/sbin/su-to-root -c /usr/bin/tasksel	/var/lib/menu-xdg/applications/menu-xdg/task_selector.desktop
/usr/bin/texconfig	/usr/bin/texconfig	/var/lib/menu-xdg/applications/menu-xdg/texconfig.desktop
top	/usr/bin/top	/var/lib/menu-xdg/applications/menu-xdg/top.desktop
trafshow	/usr/sbin/trafshow	/var/lib/menu-xdg/applications/menu-xdg/trafshow.desktop
wmbubble	wmbubble	/var/lib/menu-xdg/applications/menu-xdg/wmbubble.desktop
wmsensors	/usr/X11R6/bin/wmsensors	/var/lib/menu-xdg/applications/menu-xdg/wmsensors.desktop
wmsmpmon	/usr/bin/wmsmpmon	/var/lib/menu-xdg/applications/menu-xdg/wmsmpmon.desktop
wmtop	/usr/bin/wmtop	/var/lib/menu-xdg/applications/menu-xdg/wmtop.desktop
gksu	/usr/bin/gksu -u root /usr/bin/x-terminal-emulator	/var/lib/menu-xdg/applications/menu-xdg/x-terminal_as_root_(gksu).desktop
xconsole	xconsole	/var/lib/menu-xdg/applications/menu-xdg/xconsole.desktop
sh	/bin/sh -c 'exec /usr/bin/xdiskusage <&-'	/var/lib/menu-xdg/applications/menu-xdg/xdiskusage.desktop
xfilequery	/usr/bin/xfilequery	/var/lib/menu-xdg/applications/menu-xdg/xfq_rpm_manager.desktop
xload	xload	/var/lib/menu-xdg/applications/menu-xdg/xload.desktop
xlogmaster	/usr/X11R6/bin/xlogmaster -terse	/var/lib/menu-xdg/applications/menu-xdg/xlogmaster.desktop
xlogmaster	/usr/X11R6/bin/xlogmaster -terse -config /etc/xlogmaster/config	/var/lib/menu-xdg/applications/menu-xdg/xlogmaster_(system).desktop
xtraceroute	/usr/bin/xtraceroute	/var/lib/menu-xdg/applications/menu-xdg/xt.desktop
xvidtune	xvidtune	/var/lib/menu-xdg/applications/menu-xdg/xvidtune.desktop
gpsman	/usr/bin/gpsman	/var/lib/menu-xdg/applications/menu-xdg/gpsman.desktop
tkgate	/usr/X11R6/bin/tkgate	/var/lib/menu-xdg/applications/menu-xdg/tkgate.desktop
wordinspect	/usr/bin/wordinspect	/var/lib/menu-xdg/applications/menu-xdg/dict_client.desktop
sh	sh -c 'while /usr/games/fortune | col -x | xmessage -center -buttons OK:1,Another:0 -default OK -file - ; do :; done'	/var/lib/menu-xdg/applications/menu-xdg/fortune.desktop
gnome-dictionary	/usr/bin/gnome-dictionary	/var/lib/menu-xdg/applications/menu-xdg/gnome_dictionary.desktop
htmldoc	/usr/bin/htmldoc	/var/lib/menu-xdg/applications/menu-xdg/htmldoc.desktop
gucharmap	/usr/bin/gucharmap	/var/lib/menu-xdg/applications/menu-xdg/unicode_character_map.desktop
ark	/usr/bin/ark	/var/lib/menu-xdg/applications/menu-xdg/ark.desktop
dasher	/usr/bin/dasher	/var/lib/menu-xdg/applications/menu-xdg/dasher_text_entry.desktop
DataManager	DataManager	/var/lib/menu-xdg/applications/menu-xdg/datamanager.desktop
dclock	/usr/bin/dclock	/var/lib/menu-xdg/applications/menu-xdg/dclock.desktop
dfm	/usr/bin/dfm	/var/lib/menu-xdg/applications/menu-xdg/desktop_file_manager.desktop
ding	/usr/bin/ding	/var/lib/menu-xdg/applications/menu-xdg/ding.desktop
editres	editres	/var/lib/menu-xdg/applications/menu-xdg/editres.desktop
emelfm	/usr/X11R6/bin/emelfm	/var/lib/menu-xdg/applications/menu-xdg/emelfm.desktop
file-roller	/usr/bin/file-roller	/var/lib/menu-xdg/applications/menu-xdg/file-roller.desktop
fookb-wmaker	/usr/bin/fookb-wmaker	/var/lib/menu-xdg/applications/menu-xdg/fookb-wmaker.desktop
gcombust	/usr/bin/gcombust	/var/lib/menu-xdg/applications/menu-xdg/gcombust.desktop
gcrontab	/usr/bin/gcrontab	/var/lib/menu-xdg/applications/menu-xdg/gcrontab.desktop
gnomecard	/usr/bin/gnomecard	/var/lib/menu-xdg/applications/menu-xdg/gnome_address_book.desktop
gnomecal	/usr/bin/gnomecal	/var/lib/menu-xdg/applications/menu-xdg/gnome_calendar.desktop
gcm	/usr/bin/gcm	/var/lib/menu-xdg/applications/menu-xdg/gnome_clipboard_manager.desktop
gnome-search-tool	/usr/bin/gnome-search-tool	/var/lib/menu-xdg/applications/menu-xdg/gnome_search_tool.desktop
gnucash	gnucash	/var/lib/menu-xdg/applications/menu-xdg/gnucash.desktop
gODBCConfig	gODBCConfig	/var/lib/menu-xdg/applications/menu-xdg/godbcconfig.desktop
gramps	/usr/bin/gramps	/var/lib/menu-xdg/applications/menu-xdg/gramps.desktop
gtktrain	/usr/bin/gtktrain	/var/lib/menu-xdg/applications/menu-xdg/gtktrain.desktop
guitar	/usr/bin/guitar	/var/lib/menu-xdg/applications/menu-xdg/guitar.desktop
iceconf	/usr/bin/iceconf	/var/lib/menu-xdg/applications/menu-xdg/iceconf.desktop
jscalibrator	/usr/bin/jscalibrator	/var/lib/menu-xdg/applications/menu-xdg/joystick_calibration.desktop
kaddressbook	/usr/bin/kaddressbook	/var/lib/menu-xdg/applications/menu-xdg/kaddressbook.desktop
kalarm	/usr/bin/kalarm	/var/lib/menu-xdg/applications/menu-xdg/kalarm.desktop
kandy	/usr/bin/kandy	/var/lib/menu-xdg/applications/menu-xdg/kandy.desktop
karm	/usr/bin/karm	/var/lib/menu-xdg/applications/menu-xdg/karm.desktop
kcharselect	/usr/bin/kcharselect	/var/lib/menu-xdg/applications/menu-xdg/kcharselect.desktop
kgpg	/usr/bin/kgpg	/var/lib/menu-xdg/applications/menu-xdg/kgpg.desktop
khexedit	/usr/bin/khexedit	/var/lib/menu-xdg/applications/menu-xdg/khexedit.desktop
kivio	/usr/bin/kivio	/var/lib/menu-xdg/applications/menu-xdg/kivio.desktop
kjots	/usr/bin/kjots	/var/lib/menu-xdg/applications/menu-xdg/kjots.desktop
klipper	/usr/bin/klipper	/var/lib/menu-xdg/applications/menu-xdg/klipper.desktop
knotes	/usr/bin/knotes	/var/lib/menu-xdg/applications/menu-xdg/knotes.desktop
koshell	/usr/bin/koshell	/var/lib/menu-xdg/applications/menu-xdg/koffice_workspace.desktop
kmdr-editor	/usr/bin/kmdr-editor	/var/lib/menu-xdg/applications/menu-xdg/kommander_editor.desktop
kontact	/usr/bin/kontact	/var/lib/menu-xdg/applications/menu-xdg/kontact.desktop
korganizer	/usr/bin/korganizer	/var/lib/menu-xdg/applications/menu-xdg/korganizer.desktop
kpager	/usr/bin/kpager	/var/lib/menu-xdg/applications/menu-xdg/kpager.desktop
kpalmdoc	/usr/bin/kpalmdoc	/var/lib/menu-xdg/applications/menu-xdg/kpalmdoc.desktop
kpilot	/usr/bin/kpilot	/var/lib/menu-xdg/applications/menu-xdg/kpilot.desktop
kpresenter	/usr/bin/kpresenter	/var/lib/menu-xdg/applications/menu-xdg/kpresenter.desktop
kregexpeditor	/usr/bin/kregexpeditor	/var/lib/menu-xdg/applications/menu-xdg/kregexpeditor.desktop
ksync	/usr/bin/ksync	/var/lib/menu-xdg/applications/menu-xdg/ksync.desktop
kthesaurus	/usr/bin/kthesaurus	/var/lib/menu-xdg/applications/menu-xdg/kthesaurus.desktop
ktimer	/usr/bin/ktimer	/var/lib/menu-xdg/applications/menu-xdg/ktimer.desktop
ktip	/usr/bin/ktip	/var/lib/menu-xdg/applications/menu-xdg/ktip.desktop
ktnef	/usr/bin/ktnef	/var/lib/menu-xdg/applications/menu-xdg/ktnef.desktop
kugar	/usr/bin/kugar	/var/lib/menu-xdg/applications/menu-xdg/kugar.desktop
kudesigner	/usr/bin/kudesigner	/var/lib/menu-xdg/applications/menu-xdg/kugar_designer.desktop
mc	/usr/bin/mc	/var/lib/menu-xdg/applications/menu-xdg/mc.desktop
nonlock	nonlock	/var/lib/menu-xdg/applications/menu-xdg/nonlock.desktop
oclock	oclock	/var/lib/menu-xdg/applications/menu-xdg/oclock.desktop
ODBCConfig	ODBCConfig	/var/lib/menu-xdg/applications/menu-xdg/odbcconfig.desktop
odbctest	odbctest	/var/lib/menu-xdg/applications/menu-xdg/odbctest.desktop
qps	/usr/bin/qps	/var/lib/menu-xdg/applications/menu-xdg/qps.desktop
/usr/bin/X11/regexplorer	/usr/bin/X11/regexplorer	/var/lib/menu-xdg/applications/menu-xdg/regexplorer.desktop
texfind	/usr/bin/texfind	/var/lib/menu-xdg/applications/menu-xdg/texfind.desktop
dotfile	/usr/bin/dotfile	/var/lib/menu-xdg/applications/menu-xdg/the_dotfile_generator.desktop
unclutter	unclutter	/var/lib/menu-xdg/applications/menu-xdg/unclutter_-_start.desktop
killall	killall -TERM unclutter	/var/lib/menu-xdg/applications/menu-xdg/unclutter_-_stop.desktop
wmcalc	/usr/bin/wmcalc	/var/lib/menu-xdg/applications/menu-xdg/wmcalc.desktop
wmCalClock	/usr/bin/wmCalClock	/var/lib/menu-xdg/applications/menu-xdg/wmcalclock.desktop
wmGrabImage	wmGrabImage	/var/lib/menu-xdg/applications/menu-xdg/wmgrabimage.desktop
wmMoonClock	/usr/bin/wmMoonClock	/var/lib/menu-xdg/applications/menu-xdg/wmmoonclock.desktop
wmpinboard	/usr/bin/wmpinboard	/var/lib/menu-xdg/applications/menu-xdg/wmpinboard.desktop
worker	/usr/bin/worker	/var/lib/menu-xdg/applications/menu-xdg/worker.desktop
xwd	xwd | xwud	/var/lib/menu-xdg/applications/menu-xdg/x_window_snapshot.desktop
xcalendar	/usr/X11R6/bin/xcalendar	/var/lib/menu-xdg/applications/menu-xdg/xcalendar-i18n.desktop
xclipboard	xclipboard	/var/lib/menu-xdg/applications/menu-xdg/xclipboard.desktop
xclock	xclock -analog	/var/lib/menu-xdg/applications/menu-xdg/xclock_(analog).desktop
xclock	xclock -digital -update 1	/var/lib/menu-xdg/applications/menu-xdg/xclock_(digital).desktop
xcutsel	xcutsel	/var/lib/menu-xdg/applications/menu-xdg/xcutsel.desktop
x-terminal-emulator	x-terminal-emulator -e xev	/var/lib/menu-xdg/applications/menu-xdg/xev.desktop
xfe	/usr/bin/xfe	/var/lib/menu-xdg/applications/menu-xdg/xfe_file_manager.desktop
xfontsel	xfontsel	/var/lib/menu-xdg/applications/menu-xdg/xfontsel.desktop
/usr/bin/X11/xkbsel-aw	/usr/bin/X11/xkbsel-aw	/var/lib/menu-xdg/applications/menu-xdg/xkbsel.desktop
xkill	xkill	/var/lib/menu-xdg/applications/menu-xdg/xkill.desktop
xmag	xmag	/var/lib/menu-xdg/applications/menu-xdg/xmag.desktop
xrefresh	xrefresh	/var/lib/menu-xdg/applications/menu-xdg/xrefresh.desktop
zclock	/usr/bin/zclock	/var/lib/menu-xdg/applications/menu-xdg/zclock.desktop
acroread	/usr/bin/acroread	/var/lib/menu-xdg/applications/menu-xdg/acrobat_reader.desktop
alevt	/usr/bin/alevt	/var/lib/menu-xdg/applications/menu-xdg/alevt.desktop
effectv	/usr/bin/effectv	/var/lib/menu-xdg/applications/menu-xdg/effectv.desktop
endeavour2	/usr/bin/endeavour2	/var/lib/menu-xdg/applications/menu-xdg/endeavour2_viewer.desktop
gfontview	gfontview	/var/lib/menu-xdg/applications/menu-xdg/gfontview.desktop
gliv	/usr/bin/gliv	/var/lib/menu-xdg/applications/menu-xdg/gliv.desktop
gnome-gv	/usr/bin/gnome-gv	/var/lib/menu-xdg/applications/menu-xdg/gnome_ghostscript_pdf_viewer.desktop
gqview	/usr/bin/gqview	/var/lib/menu-xdg/applications/menu-xdg/gqview.desktop
gtv	/usr/bin/gtv	/var/lib/menu-xdg/applications/menu-xdg/gtv_mpeg_player.desktop
/usr/bin/X11/gv	/usr/bin/X11/gv	/var/lib/menu-xdg/applications/menu-xdg/gv.desktop
display	/usr/bin/display	/var/lib/menu-xdg/applications/menu-xdg/imagemagick.desktop
kdvi	/usr/bin/kdvi	/var/lib/menu-xdg/applications/menu-xdg/kdvi.desktop
kghostview	/usr/bin/kghostview	/var/lib/menu-xdg/applications/menu-xdg/kghostview.desktop
kview	/usr/bin/kview	/var/lib/menu-xdg/applications/menu-xdg/kview.desktop
gmplayer	/usr/bin/gmplayer < /dev/null	/var/lib/menu-xdg/applications/menu-xdg/mplayer.desktop
paul	/usr/bin/paul	/var/lib/menu-xdg/applications/menu-xdg/paul.desktop
pornview	/usr/bin/pornview	/var/lib/menu-xdg/applications/menu-xdg/pornview.desktop
realplayer	/usr/bin/realplayer	/var/lib/menu-xdg/applications/menu-xdg/real_player.desktop
wordview	/usr/X11R6/bin/wordview	/var/lib/menu-xdg/applications/menu-xdg/wordview.desktop
xawtv	/usr/bin/xawtv	/var/lib/menu-xdg/applications/menu-xdg/xawtv.desktop
xbmbrowser	/usr/bin/xbmbrowser	/var/lib/menu-xdg/applications/menu-xdg/xbmbrowser.desktop
xditview	xditview	/var/lib/menu-xdg/applications/menu-xdg/xditview.desktop
xdvi	/usr/bin/xdvi	/var/lib/menu-xdg/applications/menu-xdg/xdvi.desktop
xfileview	/usr/bin/xfileview	/var/lib/menu-xdg/applications/menu-xdg/xfv_file_viewer.desktop
xine	/usr/bin/xine	/var/lib/menu-xdg/applications/menu-xdg/xine_media_player.desktop
xmovie	/usr/bin/xmovie	/var/lib/menu-xdg/applications/menu-xdg/xmovie.desktop
kasteroids	/usr/games/kasteroids	/var/lib/menu-xdg/applications/menu-xdg/kasteroids.desktop
kbounce	/usr/games/kbounce	/var/lib/menu-xdg/applications/menu-xdg/kde_bounce_ball_game.desktop
kolf	/usr/games/kolf	/var/lib/menu-xdg/applications/menu-xdg/kde_miniature_golf.desktop
ksnake	/usr/games/ksnake	/var/lib/menu-xdg/applications/menu-xdg/kde_snake_race.desktop
kspaceduel	/usr/games/kspaceduel	/var/lib/menu-xdg/applications/menu-xdg/kde_spaceduel.desktop
ktron	/usr/games/ktron	/var/lib/menu-xdg/applications/menu-xdg/kde_tron.desktop
xasteroids	/usr/games/xasteroids	/var/lib/menu-xdg/applications/menu-xdg/xasteroids.desktop
atlantik	/usr/games/atlantik	/var/lib/menu-xdg/applications/menu-xdg/atlantik.desktop
atlantikdesigner	/usr/bin/atlantikdesigner	/var/lib/menu-xdg/applications/menu-xdg/atlantik_designer.desktop
gnubg	/usr/bin/gnubg	/var/lib/menu-xdg/applications/menu-xdg/gnu_backgammon.desktop
kbattleship	/usr/games/kbattleship	/var/lib/menu-xdg/applications/menu-xdg/kbattleship.desktop
kbackgammon	/usr/games/kbackgammon	/var/lib/menu-xdg/applications/menu-xdg/kde_backgammon.desktop
kreversi	/usr/games/kreversi	/var/lib/menu-xdg/applications/menu-xdg/kde_reversi.desktop
kshisen	/usr/games/kshisen	/var/lib/menu-xdg/applications/menu-xdg/kde_shisen-sho.desktop
kenolaba	/usr/games/kenolaba	/var/lib/menu-xdg/applications/menu-xdg/kenolaba.desktop
klines	/usr/games/klines	/var/lib/menu-xdg/applications/menu-xdg/klines.desktop
kmahjongg	/usr/games/kmahjongg	/var/lib/menu-xdg/applications/menu-xdg/kmahjongg.desktop
gnome-freecell	/usr/games/gnome-freecell	/var/lib/menu-xdg/applications/menu-xdg/gnome_freecell.desktop
sol	/usr/games/sol	/var/lib/menu-xdg/applications/menu-xdg/gnome_solitaire_games.desktop
kpat	/usr/games/kpat	/var/lib/menu-xdg/applications/menu-xdg/kde_patience.desktop
kpoker	/usr/games/kpoker	/var/lib/menu-xdg/applications/menu-xdg/kde_poker.desktop
kblackbox	/usr/games/kblackbox	/var/lib/menu-xdg/applications/menu-xdg/kblackbox.desktop
katomic	/usr/games/katomic	/var/lib/menu-xdg/applications/menu-xdg/kde_atomic_entertainment.desktop
khangman	/usr/bin/khangman	/var/lib/menu-xdg/applications/menu-xdg/khangman.desktop
ksame	/usr/games/ksame	/var/lib/menu-xdg/applications/menu-xdg/kde_samegame.desktop
ksokoban	/usr/games/ksokoban	/var/lib/menu-xdg/applications/menu-xdg/kde_sokoban.desktop
klickety	/usr/games/klickety	/var/lib/menu-xdg/applications/menu-xdg/klickety.desktop
kmessedwords	/usr/bin/kmessedwords	/var/lib/menu-xdg/applications/menu-xdg/kmessedwords.desktop
kmines	/usr/games/kmines	/var/lib/menu-xdg/applications/menu-xdg/kmines.desktop
foobillard	/usr/games/foobillard	/var/lib/menu-xdg/applications/menu-xdg/foobillard.desktop
kjumpingcube	/usr/games/kjumpingcube	/var/lib/menu-xdg/applications/menu-xdg/kjumpingcube.desktop
konquest	/usr/games/konquest	/var/lib/menu-xdg/applications/menu-xdg/konquest.desktop
kfouleggs	/usr/games/kfouleggs	/var/lib/menu-xdg/applications/menu-xdg/kde_foul_eggs.desktop
ksirtet	/usr/games/ksirtet	/var/lib/menu-xdg/applications/menu-xdg/kde_sirtet.desktop
ksmiletris	/usr/games/ksmiletris	/var/lib/menu-xdg/applications/menu-xdg/kde_smiletris.desktop
amor	/usr/bin/amor	/var/lib/menu-xdg/applications/menu-xdg/amor.desktop
kaphorism	/usr/bin/kaphorism	/var/lib/menu-xdg/applications/menu-xdg/k_aphorisms.desktop
ktuberling	/usr/games/ktuberling	/var/lib/menu-xdg/applications/menu-xdg/kde_potato_guy.desktop
kmoon	/usr/bin/kmoon	/var/lib/menu-xdg/applications/menu-xdg/kmoon.desktop
kodo	/usr/bin/kodo	/var/lib/menu-xdg/applications/menu-xdg/kodometer.desktop
kteatime	/usr/bin/kteatime	/var/lib/menu-xdg/applications/menu-xdg/kteatime.desktop
kworldclock	/usr/bin/kworldclock	/var/lib/menu-xdg/applications/menu-xdg/kworldclock.desktop
lightspeed	/usr/bin/lightspeed	/var/lib/menu-xdg/applications/menu-xdg/light_speed.desktop
penguineyes	/usr/games/penguineyes	/var/lib/menu-xdg/applications/menu-xdg/penguineyes.desktop
tdfsb	/usr/games/tdfsb	/var/lib/menu-xdg/applications/menu-xdg/tdfsb.desktop
wmtictactoe	/usr/games/wmtictactoe -q	/var/lib/menu-xdg/applications/menu-xdg/wmtictactoe.desktop
xcruiser	/usr/games/xcruiser	/var/lib/menu-xdg/applications/menu-xdg/xcruiser.desktop
xeyes	xeyes	/var/lib/menu-xdg/applications/menu-xdg/xeyes.desktop
xlogo	xlogo	/var/lib/menu-xdg/applications/menu-xdg/xlogo.desktop
dwww	/usr/bin/dwww	/var/lib/menu-xdg/applications/menu-xdg/dwww.desktop
info	info	/var/lib/menu-xdg/applications/menu-xdg/info.desktop
khelpcenter	/usr/bin/khelpcenter	/var/lib/menu-xdg/applications/menu-xdg/kde_help_center.desktop
hman	hman -P sensible-browser	/var/lib/menu-xdg/applications/menu-xdg/man2html.desktop
texdoctk	/usr/bin/texdoctk	/var/lib/menu-xdg/applications/menu-xdg/texdoctk.desktop
texshow	/usr/bin/texshow	/var/lib/menu-xdg/applications/menu-xdg/texshow.desktop
xman	xman	/var/lib/menu-xdg/applications/menu-xdg/xman.desktop
yelp	/usr/bin/yelp	/var/lib/menu-xdg/applications/menu-xdg/yelp.desktop
ktux	/usr/bin/ktux -root	/var/lib/menu-xdg/applications/menu-xdg/ktux.desktop
xscreensaver-command	/usr/bin/xscreensaver-command -lock	/var/lib/menu-xdg/applications/menu-xdg/lock_screen_(xscreensaver).desktop
xplanet	/usr/bin/xplanet	/var/lib/menu-xdg/applications/menu-xdg/xplanet.desktop
xsetroot	xsetroot	/var/lib/menu-xdg/applications/menu-xdg/xsetroot.desktop
xscreensaver-command	/usr/bin/xscreensaver-command -next	/var/lib/menu-xdg/applications/menu-xdg/activate_screensaver_(next).desktop
xscreensaver-command	/usr/bin/xscreensaver-command -prev	/var/lib/menu-xdg/applications/menu-xdg/activate_screensaver_(previous).desktop
xscreensaver-command	/usr/bin/xscreensaver-command -activate	/var/lib/menu-xdg/applications/menu-xdg/activate_screensaver_(random).desktop
beforelight	beforelight	/var/lib/menu-xdg/applications/menu-xdg/beforelight.desktop
xscreensaver-command	/usr/bin/xscreensaver-command -demo	/var/lib/menu-xdg/applications/menu-xdg/demo_screen_hacks.desktop
xscreensaver-command	/usr/bin/xscreensaver-command -exit	/var/lib/menu-xdg/applications/menu-xdg/disable_xscreensaver.desktop
xscreensaver	/usr/bin/xscreensaver	/var/lib/menu-xdg/applications/menu-xdg/enable_xscreensaver.desktop
xscreensaver-command	/usr/bin/xscreensaver-command -restart	/var/lib/menu-xdg/applications/menu-xdg/reinitialize_xscreensaver.desktop
xscreensaver-command	/usr/bin/xscreensaver-command -prefs	/var/lib/menu-xdg/applications/menu-xdg/screensaver_preferences.desktop
aafire	aafire -driver slang	/var/lib/menu-xdg/applications/menu-xdg/aa_fire.desktop
Eterm	/usr/bin/Eterm	/var/lib/menu-xdg/applications/menu-xdg/eterm.desktop
gnome-terminal	/usr/bin/gnome-terminal	/var/lib/menu-xdg/applications/menu-xdg/gnome_terminal.desktop
konsole	/usr/bin/konsole	/var/lib/menu-xdg/applications/menu-xdg/konsole.desktop
multi-gnome-terminal	/usr/bin/multi-gnome-terminal	/var/lib/menu-xdg/applications/menu-xdg/multi_gnome_terminal.desktop
oneliner	/usr/X11R6/bin/oneliner	/var/lib/menu-xdg/applications/menu-xdg/oneliner.desktop
powershell	/usr/bin/powershell	/var/lib/menu-xdg/applications/menu-xdg/powershell.desktop
xexec	/usr/bin/xexec	/var/lib/menu-xdg/applications/menu-xdg/xexec.desktop
xterm	xterm	/var/lib/menu-xdg/applications/menu-xdg/xterm.desktop
uxterm	uxterm	/var/lib/menu-xdg/applications/menu-xdg/xterm_(unicode).desktop
konqueror	/usr/bin/konqueror --profile webbrowsing	/var/lib/gnome/Debian/Apps/Net/Konqueror.desktop
su-to-root	/usr/sbin/su-to-root -p root -c /usr/sbin/liloconfig	/var/lib/gnome/Debian/Apps/System/Admin/Lilo-config.desktop
\.


--
-- Data for TOC entry 577 (OID 2067672)
-- Name: xmls; Type: TABLE DATA; Schema: public; Owner: postgres
--

COPY xmls (xml) FROM stdin;
<timestamp>L'attimo fugge.\n\nChe altro puo' fare un attimo?\n</timestamp>
<timestamp>The whole of life is futile unless you consider it as a sporting proposition.\n</timestamp>
<fortune>Live long and prosper.\n\t\t-- Spock, "Amok Time", stardate 3372.7\n</fortune>
<fortune>En la mesa y en el juego, se conoce al caballero. \n</fortune>
<fortune>El que por su gusto es buey, hasta la coyunta lame. \n</fortune>
<fortune>\tMuita luz e como muita sombra: nao deixa ver.\n\t\t-- Carlos Casteneda \n</fortune>
<fortune>"For that matter, compare your pocket computer with the massive jobs of\na thousand years ago.  Why not, then, the last step of doing away with\ncomputers altogether?"\n\t\t-- Jehan Shuman\n</fortune>
<fortune>If you mess with a thing long enough, it'll break.\n\t\t-- Schmidt\n</fortune>
<fortune>Denver, n.:\n\tA smallish city located just below the `O' in Colorado.\n</fortune>
<fortune>Hija enlodada, ni viuda, ni casada. \n</fortune>
<fortune>Appunto di Grelb:\n\tL'ottanta percento delle persone si considera essere un guidatore\n\tsopra la media.\n</fortune>
<fortune>Cos'e' la bile?  Non posso dirlo: e' un secreto.\n\t\t-- Da it.hobby.umorismo\n</fortune>
<fortune>"Cable is not a luxury, since many areas have poor TV reception."\n-- The mayor of Tucson, Arizona, 1989\n[apparently, good TV reception is a basic necessity -- at least in Tucson  -kl]\n</fortune>
<fortune>To err is human; to forgive is simply not our policy.\n\t\t-- MIT Assasination Club\n</fortune>
<fortune>Easy come and easy go,\n\tsome call me easy money,\nSometimes life is full of laughs,\n\tand sometimes it ain't funny\nYou may think that I'm a fool\n\tand sometimes that is true,\nBut I'm goin' to heaven in a flash of fire,\n\twith or without you.\n\t\t-- Hoyt Axton\n</fortune>
<fortune>The smallest worm will turn being trodden on.\n\t\t-- William Shakespeare, "Henry VI"\n</fortune>
<fortune>CAVALLO DA TIRO - Equino di precisione.\n</fortune>
<fortune>La nuez llena, menos que la vana suena. \n</fortune>
<fortune>Ser feliz significa poder percibirse a si mismo sin temor.\n\t\t-- Paul Klee. \n</fortune>
<fortune>hard, adj.:\n\tThe quality of your own data; also how it is to believe those\n\tof other people.\n</fortune>
<fortune>Referendum, s.:\n\t``Va dove ti porta il quorum''.\n</fortune>
<fortune>Quod licet Iovi non licet bovi.\n(What Jove may do, is not permitted to a cow.)\n</fortune>
<fortune>Picard: Il Consigliere Troi e' incinta.\nRiker: Un bambino?  Questa e' una sorpresa.\nTroi: Specialmente per me.\n\t\t-- "The Child", data astrale 42073.1\n</fortune>
<fortune>Bodas buenas y magistrado, del cielo es dado. \n</fortune>
<fortune>\tTodos nos nascemos originais e morremos copias.\n\t\t-- Carl J. Jung \n</fortune>
<fortune>Quien a otra ha de decir puta, ha de ser ella muy buena mujer. \n</fortune>
<fortune>Marriage is based on the theory that when a man discovers a brand of beer\nexactly to his taste he should at once throw up his job and go to work\nin the brewery.\n\t\t-- George Jean Nathan\n</fortune>
<fortune>4.  Per andare all'estero dovrete attraversare una dogana, e i vostri\nbagagli verranno accuratamente ispezionati.  Se volete evitare figure\nimbarazzanti, non mettete in valigia foto nude di Rosanna Cancellieri.\n\t\t-- Daniele Luttazzi, 13 consigli per chi va in vacanza,\n\t\t   postata su it.hobby.umorismo [4/13]\n</fortune>
<fortune>Se il vostro idolo e' Dali', non fate gli architetti comunali.\n\t\t-- Daniele Luttazzi, "C.R.A.M.P.O."\n</fortune>
<fortune>Nada dura mas que el cambio.\n\t\t-- Bourne. \n</fortune>
<fortune>A group of politicians deciding to dump a President because his morals\nare bad is like the Mafia getting together to bump off the Godfather for\nnot going to church on Sunday.\n\t\t-- Russell Baker\n</fortune>
<fortune>Thus spake the master programmer:\n\t"Let the programmers be many and the managers few -- then all will\n\tbe productive."\n\t\t-- Geoffrey James, "The Tao of Programming"\n</fortune>
<fortune>QOTD:\n\t "It's not the despair... I can stand the despair.  It's the hope."\n</fortune>
<fortune>When nothing can possibly go wrong, it will.\n</fortune>
<fortune>"I'm growing older, but not up."\n-- Jimmy Buffett\n</fortune>
<fortune>- Perche' i carabinieri girano con la giacca tagliata a meta'?\n- Perche' e' la divisa.\n\t\t-- Da it.hobby.umorismo\n</fortune>
<fortune>\t"Seven years and six months!"  Humpty Dumpty repeated thoughtfully.\n"An uncomfortable sort of age.  Now if you'd asked MY advice, I'd have\nsaid 'Leave off at seven' -- but it's too late now."\n\t"I never ask advice about growing,"  Alice said indignantly.\n\t"Too proud?"  the other enquired.\n\tAlice felt even more indignant at this suggestion.  "I mean,"\nshe said, "that one can't help growing older."\n\t"ONE can't, perhaps," said Humpty Dumpty; "but TWO can.  With\nproper assistance, you might have left off at seven."\n\t\t-- Lewis Carroll, "Through the Looking-Glass"\n</fortune>
<fortune>Los mundos nuevos deben ser vividos antes de ser explicados.\n\t\t-- Alejo Carpentier. \n</fortune>
<fortune>I'm having a BIG BANG THEORY!!\n</fortune>
<fortune>\t\t\t-- Gifts for Men --\n\nMen are amused by almost any idiot thing -- that is why professional ice\nhockey is so popular -- so buying gifts for them is easy.  But you should\nnever buy them clothes.  Men believe they already have all the clothes they\nwill ever need, and new ones make them nervous.  For example, your average\nman has 84 ties, but he wears, at most, only three of them.  He has learned,\nthrough humiliating trial and error, that if he wears any of the other 81\nties, his wife will probably laugh at him ("You're not going to wear THAT\ntie with that suit, are you?"). So he has narrowed it down to three safe\nties, and has gone several years without being laughed at.  If you give him\na new tie, he will pretend to like it, but deep inside he will hate you.\n\nIf you want to give a man something practical, consider tires.  More than\nonce, I would have gladly traded all the gifts I got for a new set of tires.\n\t\t-- Dave Barry, "Christmas Shopping: A Survivor's Guide"\n</fortune>
<fortune>I just ate a whole package of Sweet Tarts and a can of Coke. I think I saw God.\n\t\t-- B. Hathrume Duk\n</fortune>
<fortune>Non si puo' concludere assolutamente niente da queste immagini, eccetto\nil fatto che non si possono fare conclusioni da esse.\n\t\t-- Joseph L. Brothers, Linux/PowerPC Project\n</fortune>
<fortune>Siete mai entrati in una stanza dimenticandovi perche' siete entrati?\nIo penso che sia cosi' che i cani passano la loro vita.\n\t\t-- Sue Murphy\n</fortune>
<fortune>BOFH excuse #399:\n\nWe are a 100% Microsoft Shop.\n</fortune>
<fortune>Tutto e' stato ormai gia' scritto, basta solo andarlo a cercare e rileggere.\n\t\t-- Viazzi\n</fortune>
<fortune>Optimism, n.:\n\tThe belief that everything is beautiful, including what is ugly, good,\n\tbad, and everything right that is wrong.  It is held with greatest\n\ttenacity by those accustomed to falling into adversity, and most\n\tacceptably expounded with the grin that apes a smile.  Being a blind\n\tfaith, it is inaccessible to the light of disproof -- an intellectual\n\tdisorder, yielding to no treatment but death.  It is hereditary, but\n\tnot contagious.\n</fortune>
<fortune>No se puede estar en misa y repicando. \n</fortune>
<fortune>A drama critic is a person who surprises a playwright by informing him\nwhat he meant.\n\t\t-- Wilson Mizner\n</fortune>
<fortune>"The student in question is performing minimally for his peer group and\nis an emerging underachiever."\n</fortune>
<fortune>The full impact of parenthood doesn't hit you until you multiply the\nnumber of your kids by thirty-two teeth.\n</fortune>
<fortune>"Well hello there Charlie Brown, you blockhead."\n-- Lucy Van Pelt\n</fortune>
<fortune>..you could spend *all day* customizing the title bar.  Believe me.  I\nspeak from experience.\n\t-- Matt Welsh\n</fortune>
<fortune>Let's go to dream.\n</fortune>
<fortune>A la suegra hay que sufrirla, como a la muela picada. \n</fortune>
<fortune>  Some bachelors want a meaningful overnight relationship.\n</fortune>
<fortune>Confirmed bachelor:\n\tA man who goes through life without a hitch.\n</fortune>
<fortune>The more we disagree, the more chance there is that at least one of us is right.\n</fortune>
<fortune>BOFH excuse #416:\n\nWe're out of slots on the server\n</fortune>
<fortune>Jarabe de pico a muchos hizo rico. \n</fortune>
<fortune>Hailing frequencies open, Captain.\n</fortune>
<fortune>Patriotism is the last refuge of a scoundrel.\n\t\t-- S. Johnson, "The Life of Samuel Johnson" by J. Boswell\n\nIn Dr. Johnson's famous dictionary patriotism is defined as the last\nresort of the scoundrel.  With all due respect to an enlightened but\ninferior lexicographer I beg to submit that it is the first.\n\t\t-- Ambrose Bierce\n\nWhen Dr. Johnson defined patriotism as the last refuge of a scoundrel,\nhe ignored the enormous possibilities of the word reform.\n\t\t-- Sen. Roscoe Conkling\n\nPublic office is the last refuge of a scoundrel.\n\t\t-- Boies Penrose\n</fortune>
<fortune>There is not a man in the country that can't make a living for himself and\nfamily.  But he can't make a living for them *and* his government, too,\nthe way his government is living.  What the government has got to do is\nlive as cheap as the people.\n\t\t-- The Best of Will Rogers\n</fortune>
<fortune>"Logica e informazioni pratiche non sembrano applicabili qui."\n"Lo ammette?"\n"Negare i fatti sarebbe illogico, Dottore."\n\t\t-- Spock e McCoy, "A Piece of the Action", data astrale ignota\n</fortune>
<fortune>I hope the ``Eurythmics'' practice birth control ...\n</fortune>
<fortune>Old timer, n.:\n\tOne who remembers when charity was a virtue and not an organization.\n</fortune>
<fortune>Se avete paura della solitudine, non sposatevi.\n\t\t-- Anton Cechov\n</fortune>
<fortune>Last night I met upon the stair\nA little man who wasn't there.\nHe wasn't there again today.\nGee how I wish he'd go away!\n</fortune>
<fortune>I was the best I ever had.\n\t\t-- Woody Allen\n</fortune>
<fortune>Cuando te vayas a casar, manda a los amigos a otro lugar. \n</fortune>
<fortune>There is a great discovery still to be made in Literature: that of\npaying literary men by the quantity they do NOT write.\n</fortune>
<fortune>The church is near but the road is icy; the bar is far away but I will\nwalk carefully.\n\t\t-- Russian Proverb\n</fortune>
<fortune>Never go to a doctor whose office plants have died.\n\t\t-- Erma Bombeck\n</fortune>
<fortune>Pssss!  Hai una scarpa slacciata!\n</fortune>
<fortune>Le strade sono sicure a Philadelphia, e' solo la gente che le rende insicure.\n\t\t-- Il Sindaco Frank Rizzo\n</fortune>
<fortune>Tiger got to hunt,\nBird got to fly;\nMan got to sit and wonder, "Why, why, why?"\n\nTiger got to sleep,\nBird got to land;\nMan got to tell himself he understand.\n\t\t-- The Books of Bokonon\n</fortune>
<fortune>I just heard the SEVENTIES were over!!  And I was just getting in touch\nwith my LEISURE SUIT!!\n</fortune>
<fortune>L'amore e' come un paio di scarpe: ne occorrono due e debbono combaciare.\n\t\t-- Da it.hobby.umorismo\n</fortune>
<fortune>Legge di Wiker:\n\tIl governo si espande fino ad assorbire tutti i redditi e poi\n\tancora un po'.\n</fortune>
<fortune>There has been a little distress selling on the stock exchange.\n\t\t-- Thomas W. Lamont, October 29, 1929 (Black Tuesday)\n</fortune>
<fortune>I do not find in orthodox Christianity one redeeming feature.\n- Thomas Jefferson\n</fortune>
<fortune>One man tells a falsehood, a hundred repeat it as true.\n</fortune>
<fortune>My haircut is totally traditional!\n</fortune>
<fortune>Gli esseri umani sono stati creati dall'acqua per trasportarla in salita.\n</fortune>
<fortune>Luci Antinebbia:\n\tFari eccessivamente (spesso odiosamente) luminosi montati\n\tanteriormente alle automobili; usati nelle notti asciutte e\n\tlimpide per indicare che la mente del conducente e' annebbiata.\n</fortune>
<fortune>Universita', s.f.:\n\tCome una software house, eccetto che il software e' gratuito, ed\n\te' utilizzabile, e funziona, e se si pianta ti dicono subito\n\tcome correggerlo, e ...\n</fortune>
<fortune>I've always made it a solemn practice to never drink anything stronger\nthan tequila before breakfast.\n\t\t-- R. Nesson\n</fortune>
<fortune>The only problem with seeing too much is that it makes you insane.\n\t\t-- Phaedrus\n</fortune>
<fortune>May a Misguided Platypus lay its Eggs in your Jockey Shorts.\n</fortune>
<fortune>El matrimonio es el sepulcro del amor; pero del amor loco, del amor sensual.\n\t\t-- Francesco Guerrazzi. \n</fortune>
<fortune>Indifference will certainly be the downfall of mankind, but who cares?\n</fortune>
\.


--
-- Data for TOC entry 578 (OID 2068206)
-- Name: action_verb; Type: TABLE DATA; Schema: public; Owner: postgres
--

COPY action_verb (name, "class") FROM stdin;
open	input
import	input
view	input
see	input
play	input
save	output
export	output
input	input
output	output
edit	input
\.


--
-- Data for TOC entry 579 (OID 2068322)
-- Name: icon; Type: TABLE DATA; Schema: public; Owner: postgres
--

COPY icon (icon) FROM stdin;
\.


--
-- Data for TOC entry 580 (OID 2068326)
-- Name: app_icon; Type: TABLE DATA; Schema: public; Owner: postgres
--

COPY app_icon (app, icon, registry) FROM stdin;
texmacs	/usr/share/pixmaps/texmacs/TeXmacs.xpm	/home/ziga/.kde/share/applnk/Editors/texmacs.desktop
blender	/usr/share/blender/icons/Blender.xpm	/home/ziga/.kde/share/applnk/Graphics/Blender.desktop
/usr/bin/gvim	/usr/X11R6/include/X11/pixmaps/vim.xpm	/usr/share/slix/apps/Aplikacije/Besedilo/gvim.desktop
kate	kate	/usr/share/slix/apps/Aplikacije/Besedilo/kate.desktop
kile	kile	/usr/share/slix/apps/Aplikacije/Besedilo/kile.desktop
kwrite	kwrite	/usr/share/slix/apps/Aplikacije/Besedilo/kwrite.desktop
lyx	lyx.xpm	/usr/share/slix/apps/Aplikacije/Besedilo/lyx.desktop
nedit	kedit	/usr/share/slix/apps/Aplikacije/Besedilo/nedit.desktop
quanta	quanta	/usr/share/slix/apps/Aplikacije/Besedilo/quanta.desktop
blender	/usr/share/icons/slix/48x48/apps/blender.png	/usr/share/slix/apps/Aplikacije/Grafika/Blender.desktop
dia-normal	/usr/share/pixmaps/dia.xpm	/usr/share/slix/apps/Aplikacije/Grafika/Dia.desktop
Gimp	/usr/share/gimp/1.3/images/wilber-icon.png	/usr/share/slix/apps/Aplikacije/Grafika/Gimp.desktop
/usr/bin/qcad	/usr/share/qcad/pixmaps/qcad.xpm	/usr/share/slix/apps/Aplikacije/Grafika/QCad.desktop
scribus	/usr/share/scribus/icons/scribusicon.png	/usr/share/slix/apps/Aplikacije/Grafika/Scribus.desktop
sketch	designer	/usr/share/slix/apps/Aplikacije/Grafika/Sketch.desktop
tgif	kontour	/usr/share/slix/apps/Aplikacije/Grafika/Tgif.desktop
oodraw	ooo_draw.xpm	/usr/share/slix/apps/Aplikacije/Grafika/drawing.desktop
kgeo	kgeo	/usr/share/slix/apps/Aplikacije/Grafika/kgeo.desktop
kooka	scanner	/usr/share/slix/apps/Aplikacije/Grafika/kooka.desktop
kpovmodeler	kpovmodeler	/usr/share/slix/apps/Aplikacije/Grafika/kpovmodeler.desktop
/usr/bin/pfaedit	/usr/share/pixmaps/font-capplet.png	/usr/share/slix/apps/Aplikacije/Grafika/pfaedit.desktop
sodipodi	sodipodi.png	/usr/share/slix/apps/Aplikacije/Grafika/sodipodi.desktop
/usr/bin/X11/gv	/usr/share/icons/slix/48x48/mimetypes/application/AdobePostscri	/usr/share/slix/apps/Aplikacije/Prezentacija/GV.desktop
acroread	acroread	/usr/share/slix/apps/Aplikacije/Prezentacija/acroread.desktop
pspresent	/usr/share/icons/slix/48x48/mimetypes/application/AdobePostscri	/usr/share/slix/apps/Aplikacije/Prezentacija/pspresent.desktop
gnumeric	/usr/share/pixmaps/gnome-gnumeric.png	/usr/share/slix/apps/Aplikacije/Tabele/gnumeric.desktop
kino	/usr/share/pixmaps/kino/film.png	/usr/share/slix/apps/Aplikacije/Video/Kino.desktop
effectv	tv	/usr/share/slix/apps/Aplikacije/Video/effectv.desktop
tvtime	Television	/usr/share/slix/apps/Aplikacije/Video/net-tvtime.desktop
audacity	audacity	/usr/share/slix/apps/Aplikacije/Zvok/Audacity.desktop
muse	muse	/usr/share/slix/apps/Aplikacije/Zvok/MusE.desktop
rezound	mime_empty	/usr/share/slix/apps/Aplikacije/Zvok/ReZound.desktop
soundtracker	kcmmidi	/usr/share/slix/apps/Aplikacije/Zvok/SoundTracker.desktop
/usr/bin/spiralsynthmodular	multimedia	/usr/share/slix/apps/Aplikacije/Zvok/SpiralSynthModular.desktop
grip	gripicon	/usr/share/slix/apps/Aplikacije/Zvok/grip.desktop
noteedit	knotify	/usr/share/slix/apps/Aplikacije/Zvok/noteedit.desktop
sudo	exec	/usr/share/slix/apps/Aplikacije/Zvok/qsynth.desktop
oowriter	openoffice	/usr/share/slix/apps/Aplikacije/OOo.desktop
soffice	gnome-applications	/usr/share/slix/apps/Aplikacije/openoffice.desktop
Emacs	xemacs	/usr/share/slix/apps/Aplikacije/Emacs.desktop
abiword	package_wordprocessing	/usr/share/slix/apps/Aplikacije/AbiWord.desktop
kalzium	kalzium	/usr/share/slix/apps/Internet/Biblioteke/kalzium.desktop
kdict	kdict	/usr/share/slix/apps/Internet/Biblioteke/kdict.desktop
kstars	kstars	/usr/share/slix/apps/Internet/Biblioteke/kstars.desktop
/usr/bin/gq	mime_empty	/usr/share/slix/apps/Internet/Network/gq.desktop
mtr	mtr_icon	/usr/share/slix/apps/Internet/Network/mtr.desktop
/usr/bin/gaim	gaim	/usr/share/slix/apps/Internet/Gaim.desktop
kfmclient	konqueror	/usr/share/slix/apps/Internet/Konqueror.desktop
mozilla	mozilla	/usr/share/slix/apps/Internet/Mozilla.desktop
/usr/bin/evolution	/usr/share/pixmaps/evolution.png	/usr/share/slix/apps/Internet/evolution.desktop
gnomemeeting	kdmconfig	/usr/share/slix/apps/Internet/gnomemeeting.desktop
xchat	xchat	/usr/share/slix/apps/Internet/xchat.desktop
xrealvncviewer	vnc	/usr/share/slix/apps/Internet/xvncviewer.desktop
LinNeighborhood	linneighbourhood	/usr/share/slix/apps/Internet/linneighborhood.desktop
streamtuner	streamtuner.png	/usr/share/slix/apps/Internet/streamtuner.desktop
akregator	akregator	/usr/share/slix/apps/Internet/akregator.desktop
kcontrol	kcontrol	/usr/share/slix/apps/Nastavitve/KControl.desktop
kcron	kcron	/usr/share/slix/apps/Nastavitve/kcron.desktop
/usr/sbin/saveconfig	filesave.png	/usr/share/slix/apps/Nastavitve/saveconfig.desktop
ark	ark	/usr/share/slix/apps/Pripomo?ki/Arhiviranje/ark.desktop
gcombust	cdwriter_unmount	/usr/share/slix/apps/Pripomo?ki/Arhiviranje/gcombust.desktop
k3b	k3b	/usr/share/slix/apps/Pripomo?ki/Arhiviranje/k3b.desktop
kdat	kdat	/usr/share/slix/apps/Pripomo?ki/Arhiviranje/kdat.desktop
kcharselect	kcharselect	/usr/share/slix/apps/Pripomo?ki/KCharSelect.desktop
/usr/bin/gpa	password	/usr/share/slix/apps/Pripomo?ki/The_GNU_Privacy_Assistant.desktop
xkill	error	/usr/share/slix/apps/Pripomo?ki/Xkill.desktop
gfontview	kcmfontinst	/usr/share/slix/apps/Pripomo?ki/gfontview.desktop
gucharmap	gucharmap.png	/usr/share/slix/apps/Pripomo?ki/gucharmap.desktop
kcalc	kcalc	/usr/share/slix/apps/Pripomo?ki/kcalc.desktop
kcoloredit	kcoloredit	/usr/share/slix/apps/Pripomo?ki/kcoloredit.desktop
kdf	kdf	/usr/share/slix/apps/Pripomo?ki/kdf.desktop
knotes	knotes	/usr/share/slix/apps/Pripomo?ki/knotes.desktop
kpilot	kpilot	/usr/share/slix/apps/Pripomo?ki/kpilot.desktop
krfb	krfb	/usr/share/slix/apps/Pripomo?ki/krfb.desktop
kruler	kruler	/usr/share/slix/apps/Pripomo?ki/kruler.desktop
ksnapshot	ksnapshot	/usr/share/slix/apps/Pripomo?ki/ksnapshot.desktop
ktimer	date	/usr/share/slix/apps/Pripomo?ki/ktimer.desktop
gmplayer	mplayer	/usr/share/slix/apps/Pripomo?ki/mplayer.desktop
xclock	xclock	/usr/share/slix/apps/Pripomo?ki/xclock.desktop
xmms	xmms	/usr/share/slix/apps/Pripomo?ki/xmms.desktop
kdesu	/usr/share/synaptic/pixmaps/synaptic_48x48.png	/usr/share/slix/apps/Sistem/Synaptic.desktop
/usr/bin/usbview	usb	/usr/share/slix/apps/Sistem/USB_View.desktop
kinfocenter	hwinfo	/usr/share/slix/apps/Sistem/kinfocenter.desktop
sudo	qps	/usr/share/slix/apps/Sistem/qps_root.desktop
sudo	ksim	/usr/share/slix/apps/Sistem/xlogmaster.desktop
qps	qps	/usr/share/slix/apps/Sistem/qps.desktop
cupsconfig	print_printer	/usr/share/slix/apps/Sistem/cupsconfig.desktop
konsole	konsole	/usr/share/slix/apps/Sistem/shell.desktop
sh	xapp	/usr/share/slix/apps/Zabava/Xaos.desktop
/usr/games/bzflag	kbattleship	/usr/share/slix/apps/Zabava/bzflag.desktop
xeyes	xeyes	/usr/share/slix/apps/Zabava/xeyes.desktop
Browse	mozilla2	/usr/share/slix/apps/Mozilla.desktop
xchat	/usr/share/icons/xchat_mini.xpm	/usr/share/icons/slix/48x48/mimetypes/application/AdobePostscri
nautilus	gnome-fs-network	/usr/share/applications/network-scheme.desktop
xsane	xsane	/usr/share/applications/xsane.desktop
gnome-control-center	control-center2	/usr/share/applications/gnomecc.desktop
gnome-system-monitor	procman.png	/usr/share/applications/gnome-system-monitor.desktop
nautilus	file-manager	/usr/share/applications/nautilus.desktop
gcmui	/usr/share/pixmaps/gcm//gcm-app-icon.png	/usr/share/applications/gcm.desktop
gdmflexiserver	gdm-xnest	/usr/share/applications/gdmflexiserver-xnest.desktop
gnumeric	gnome-gnumeric.png	/usr/share/applications/gnumeric.desktop
dasher	dasher.png	/usr/share/applications/dasher.desktop
xchat	xchat.png	/usr/share/applications/xchat.desktop
gksu	synaptic.png	/usr/share/applications/synaptic.desktop
gnomemeeting	gnomemeeting-logo-icon.png	/usr/share/applications/gnomemeeting.desktop
yelp	gnome-help.png	/usr/share/applications/yelp.desktop
glade-2	glade-2.png	/usr/share/applications/glade-2.desktop
gcombust	gcombust.xpm	/usr/share/applications/gcombust.desktop
gksu	gdm-setup	/usr/share/applications/gdmsetup.desktop
gdmflexiserver	gdm	/usr/share/applications/gdmflexiserver.desktop
file-roller	file-roller.png	/usr/share/applications/file-roller.desktop
alc	alc.xpm	/usr/share/applications/alc.desktop
xscreensaver-demo	xscreensaver.xpm	/usr/share/applications/screensaver-properties.desktop
eclipse	/usr/share/eclipse/icon.xpm	/usr/share/applications/eclipse.desktop
inkscape	inkscape.png	/usr/share/applications/inkscape.desktop
gedit	gedit-icon.png	/usr/share/applications/gedit.desktop
gnome-system-log	logviewer	/usr/share/applications/gnome-system-log.desktop
oowriter	ooo_writer	/usr/share/applications/ooo645writer.desktop
ooweb	ooo_web	/usr/share/applications/ooo645web.desktop
gnome-search-tool	gnome-searchtool	/usr/share/applications/gnome-search-tool.desktop
gnome-dictionary	gdict	/usr/share/applications/gnome-dictionary.desktop
gfloppy	gnome-dev-floppy	/usr/share/applications/gfloppy.desktop
bug-buddy	bug-buddy.png	/usr/share/applications/bug-buddy.desktop
ggv	gnome-ghostview.png	/usr/share/applications/ggv.desktop
gconf-editor	gconf-editor.png	/usr/share/applications/gconf-editor.desktop
dia-gnome	dia_gnome_icon.png	/usr/share/applications/dia.desktop
filmgimp	/usr/share/pixmaps/wilber.png	/usr/share/applications/filmgimp.desktop
wxcas	wxcas.xpm	/usr/share/applications/wxcas.desktop
gnome-terminal	gnome-terminal.png	/usr/share/applications/gnome-terminal.desktop
emacs21	/usr/share/emacs/21.3/etc/gnu-32x32.xpm	/usr/share/applications/emacs21.desktop
vumeter	gnome-reclevel.png	/usr/share/applications/reclevel.desktop
vumeter	gnome-vumeter.png	/usr/share/applications/vumeter.desktop
gperiodic	gperiodic.png	/usr/share/applications/gperiodic.desktop
gnome-volume-control	gnome-mixer.png	/usr/share/applications/gnome-volume-control.desktop
gnome-cd	gnome-cd.png	/usr/share/applications/gnome-cd.desktop
gnome-sound-recorder	gnome-grecord.png	/usr/share/applications/gnome-sound-recorder.desktop
gcalctool	gcalctool.png	/usr/share/applications/gcalctool.desktop
ooimpress	ooo_impress	/usr/share/applications/ooo645impress.desktop
realplayer	realplayer-icon.xpm	/usr/share/applications/realplayer.desktop
gimp-remote-2.0	gimp.png	/usr/share/applications/gimp-2.0.desktop
gksu	/usr/share/pixmaps/gksu-root-terminal.png	/usr/share/applications/gksu.desktop
kcmshell	konqueror	/usr/share/applications/kde/khtml_plugins.desktop
kcmshell	calendars	/usr/share/applications/kde/kresources.desktop
umbrello	umbrello	/usr/share/applications/kde/umbrello.desktop
amor	amor	/usr/share/applications/kde/amor.desktop
kcmshell	kcmkicker	/usr/share/applications/kde/kcmkicker.desktop
kcmshell	history	/usr/share/applications/kde/kcmhistory.desktop
kfmclient	folder_home	/usr/share/applications/kde/Home.desktop
appletproxy	knewsticker	/usr/share/applications/kde/knewsticker-standalone.desktop
konqueror	kfm	/usr/share/applications/kde/konquerorsu.desktop
ksysguard	ksysguard	/usr/share/applications/kde/ksysguard.desktop
kcmshell	irkick	/usr/share/applications/kde/kcmlirc.desktop
kget	kget	/usr/share/applications/kde/kget.desktop
kppplogview	kppp	/usr/share/applications/kde/kppplogview.desktop
kppp	kppp	/usr/share/applications/kde/Kppp.desktop
kwifimanager	kwifimanager.png	/usr/share/applications/kde/kwifimanager.desktop
krdc	krdc	/usr/share/applications/kde/krdc.desktop
kcmshell	krfb	/usr/share/applications/kde/kcmkrfb.desktop
ksirc	ksirc	/usr/share/applications/kde/ksirc.desktop
kcmshell	kwifimanager_kcmodule	/usr/share/applications/kde/kcmwifi.desktop
kdepasswd	password	/usr/share/applications/kde/kdepasswd.desktop
kcmshell	kdmconfig	/usr/share/applications/kde/userinfo.desktop
kmoon	kmoon	/usr/share/applications/kde/kmoon.desktop
kodo	kodo	/usr/share/applications/kde/kodo.desktop
kteatime	kteatime	/usr/share/applications/kde/kteatime.desktop
kworldclock	kworldclock	/usr/share/applications/kde/kworldclock.desktop
kcmshell	kcmdf	/usr/share/applications/kde/kcmdf.desktop
kwikdisk	kwikdisk	/usr/share/applications/kde/kwikdisk.desktop
kedit	kedit	/usr/share/applications/kde/KEdit.desktop
kfloppy	kfloppy	/usr/share/applications/kde/KFloppy.desktop
kgpg	kgpg	/usr/share/applications/kde/kgpg.desktop
khexedit	khexedit	/usr/share/applications/kde/khexedit.desktop
kjots	kjots	/usr/share/applications/kde/Kjots.desktop
kcmshell	laptop_battery	/usr/share/applications/kde/laptop.desktop
kcmshell	laptop_pcmcia	/usr/share/applications/kde/pcmcia.desktop
kcmshell	pda_black	/usr/share/applications/kde/kvaio.desktop
kcmshell	kwalletmanager	/usr/share/applications/kde/kwalletconfig.desktop
ktimer	ktimer	/usr/share/applications/kde/ktimer.desktop
atlantikdesigner	atlantikdesigner	/usr/share/applications/kde/atlantikdesigner.desktop
kwalletmanager	kwalletmanager	/usr/share/applications/kde/kwalletmanager.desktop
artsbuilder	artsbuilder	/usr/share/applications/kde/artsbuilder.desktop
artscontrol	artscontrol	/usr/share/applications/kde/artscontrol.desktop
juk	juk	/usr/share/applications/kde/juk.desktop
kaboodle	kaboodle	/usr/share/applications/kde/kaboodle.desktop
kcmshell	cdaudio_unmount	/usr/share/applications/kde/libkcddb.desktop
kscd	kscd	/usr/share/applications/kde/kscd.desktop
kaudiocreator	kaudiocreator	/usr/share/applications/kde/kaudiocreator.desktop
kcmshell	kcmkwm	/usr/share/applications/kde/kwindecoration.desktop
kmid	kmid	/usr/share/applications/kde/kmid.desktop
kmix	kmix	/usr/share/applications/kde/kmix.desktop
kcmshell	kmix	/usr/share/applications/kde/kmixcfg.desktop
krec	krec	/usr/share/applications/kde/krec.desktop
noatun	noatun	/usr/share/applications/kde/noatun.desktop
kig	kig	/usr/share/applications/kde/kig.desktop
kpalmdoc	kpalmdoc	/usr/share/applications/kde/kpalmdoc.desktop
kpilotDaemon	kpilot.xpm	/usr/share/applications/kde/kpilotdaemon.desktop
korganizer	korganizer	/usr/share/applications/kde/korganizer.desktop
kalarm	kalarm	/usr/share/applications/kde/kalarm.desktop
kaddressbook	kaddressbook	/usr/share/applications/kde/kaddressbook.desktop
kandy	kandy	/usr/share/applications/kde/kandy.desktop
karm	karm	/usr/share/applications/kde/karm.desktop
ktnef	ktnef	/usr/share/applications/kde/ktnef.desktop
kcmshell	run	/usr/share/applications/kde/kcmcgi.desktop
kmail	kmail	/usr/share/applications/kde/KMail.desktop
knode	knode	/usr/share/applications/kde/KNode.desktop
kdialog	konsolekalendar	/usr/share/applications/kde/konsolekalendar.desktop
kontact	kontact	/usr/share/applications/kde/Kontact.desktop
korn	korn	/usr/share/applications/kde/KOrn.desktop
atlantik	atlantik	/usr/share/applications/kde/atlantik.desktop
kcmshell	keyboard	/usr/share/applications/kde/keyboard_layout.desktop
cervisia	cervisia	/usr/share/applications/kde/cervisia.desktop
flashkard	flashkard	/usr/share/applications/kde/flashkard.desktop
kappfinder	kappfinder	/usr/share/applications/kde/kappfinder.desktop
kasteroids	kasteroids	/usr/share/applications/kde/kasteroids.desktop
kcmshell	misc	/usr/share/applications/kde/componentchooser.desktop
kcmshell	khotkeys	/usr/share/applications/kde/khotkeys.desktop
kcmshell	arts	/usr/share/applications/kde/arts.desktop
kcmshell	background	/usr/share/applications/kde/background.desktop
kcmshell	bell	/usr/share/applications/kde/bell.desktop
kcmshell	cache	/usr/share/applications/kde/cache.desktop
kcmshell	date	/usr/share/applications/kde/clock.desktop
kcmshell	colorscm	/usr/share/applications/kde/colors.desktop
kcmshell	desktop	/usr/share/applications/kde/desktopbehavior.desktop
kcmshell	cookie	/usr/share/applications/kde/cookies.desktop
kcmshell	encrypted	/usr/share/applications/kde/crypto.desktop
kcmshell	launch	/usr/share/applications/kde/kcmperformance.desktop
kcmshell	kfm	/usr/share/applications/kde/desktoppath.desktop
kcmshell	kcmdevices	/usr/share/applications/kde/devices.desktop
kcmshell	kscreensaver	/usr/share/applications/kde/display.desktop
kcmshell	kcmmemory	/usr/share/applications/kde/dma.desktop
kcmshell	enhanced_browsing	/usr/share/applications/kde/ebrowsing.desktop
kcmshell	email	/usr/share/applications/kde/email.desktop
kcmshell	energy_star	/usr/share/applications/kde/energy.desktop
kcmshell	fileshare	/usr/share/applications/kde/fileshare.desktop
kcmshell	filetypes	/usr/share/applications/kde/filetypes.desktop
kcmshell	font	/usr/share/applications/kde/fonts.desktop
kcmshell	icons	/usr/share/applications/kde/icons.desktop
kcmshell	access	/usr/share/applications/kde/kcmaccess.desktop
kcmshell	stylesheet	/usr/share/applications/kde/kcmcss.desktop
kcmshell	kcmfontinst	/usr/share/applications/kde/kcmfontinst.desktop
kcmshell	kded	/usr/share/applications/kde/kcmkded.desktop
kcmshell	knotify	/usr/share/applications/kde/kcmnotify.desktop
kcmshell	smserver	/usr/share/applications/kde/kcmsmserver.desktop
kcmshell	go	/usr/share/applications/kde/kcmtaskbar.desktop
kcmshell	usb	/usr/share/applications/kde/kcmusb.desktop
kcmshell	ieee1394	/usr/share/applications/kde/kcmview1394.desktop
kcmshell	key_bindings	/usr/share/applications/kde/keys.desktop
kcmshell	fonts	/usr/share/applications/kde/khtml_fonts.desktop
krandrtray	randr	/usr/share/applications/kde/krandrtray.desktop
kcmshell	samba	/usr/share/applications/kde/lanbrowser.desktop
kcmshell	locale	/usr/share/applications/kde/language.desktop
kcmshell	mouse	/usr/share/applications/kde/mouse.desktop
kcmshell	socket	/usr/share/applications/kde/netpref.desktop
kcmshell	network	/usr/share/applications/kde/nic.desktop
kcmshell	spellcheck	/usr/share/applications/kde/spellchecking.desktop
kcmshell	kcmpartitions	/usr/share/applications/kde/partitions.desktop
kcmshell	password	/usr/share/applications/kde/passwords.desktop
kcmshell	kcmpci	/usr/share/applications/kde/pci.desktop
kcmshell	trashcan_empty	/usr/share/applications/kde/privacy.desktop
kcmshell	kcmprocessor	/usr/share/applications/kde/processor.desktop
kcmshell	proxy	/usr/share/applications/kde/proxy.desktop
kcmshell	kcmscsi	/usr/share/applications/kde/scsi.desktop
kcmshell	kcmsound	/usr/share/applications/kde/sound.desktop
kcmshell	agent	/usr/share/applications/kde/useragent.desktop
kcmshell	style	/usr/share/applications/kde/style.desktop
catalogmanager	catalogmanager	/usr/share/applications/kde/catalogmanager.desktop
kcmshell	kcmx	/usr/share/applications/kde/xserver.desktop
kfind	kfind	/usr/share/applications/kde/Kfind.desktop
katomic	katomic	/usr/share/applications/kde/katomic.desktop
kbabeldict	kbabeldict	/usr/share/applications/kde/kbabeldict.desktop
kbabel	kbabel	/usr/share/applications/kde/kbabel.desktop
kcolorchooser	kcolorchooser	/usr/share/applications/kde/kcolorchooser.desktop
kbackgammon	kbackgammon	/usr/share/applications/kde/kbackgammon.desktop
kbattleship	kbattleship	/usr/share/applications/kde/kbattleship.desktop
kblackbox	kblackbox	/usr/share/applications/kde/kblackbox.desktop
kbounce	kbounce	/usr/share/applications/kde/kbounce.desktop
kbruch	kbruch	/usr/share/applications/kde/kbruch.desktop
kbugbuster	kbugbuster	/usr/share/applications/kde/kbugbuster.desktop
kcmshell	penguin	/usr/share/applications/kde/linuz.desktop
kpersonalizer	kpersonalizer	/usr/share/applications/kde/kpersonalizer.desktop
ksig	ksig	/usr/share/applications/kde/ksig.desktop
kcmshell	kvim	/usr/share/applications/kde/kcmvim.desktop
kpackage	kpackage	/usr/share/applications/kde/kpackage.desktop
ksysv	ksysv	/usr/share/applications/kde/ksysv.desktop
kuser	kuser	/usr/share/applications/kde/kuser.desktop
kdeprintfax	kdeprintfax	/usr/share/applications/kde/kdeprintfax.desktop
kjobviewer	kjobviewer	/usr/share/applications/kde/kjobviewer.desktop
kcmshell	printmgr	/usr/share/applications/kde/printers.desktop
khelpcenter	khelpcenter	/usr/share/applications/kde/Help.desktop
klipper	klipper	/usr/share/applications/kde/klipper.desktop
kmenuedit	kmenuedit	/usr/share/applications/kde/kmenuedit.desktop
kpager	kpager	/usr/share/applications/kde/kpager.desktop
kcmshell	ksplash	/usr/share/applications/kde/ksplashthememgr.desktop
ktip	ktip	/usr/share/applications/kde/ktip.desktop
khangman	khangman	/usr/share/applications/kde/khangman.desktop
kiten	kiten	/usr/share/applications/kde/kiten.desktop
klettres	klettres	/usr/share/applications/kde/klettres.desktop
kmessedwords	kmessedwords	/usr/share/applications/kde/kmessedwords.desktop
kmplot	kmplot	/usr/share/applications/kde/kmplot.desktop
kpercentage	kpercentage	/usr/share/applications/kde/kpercentage.desktop
ktouch	ktouch	/usr/share/applications/kde/ktouch.desktop
kverbos	kverbos	/usr/share/applications/kde/kverbos.desktop
kvoctrain	kvoctrain	/usr/share/applications/kde/kvoctrain.desktop
kenolaba	kenolaba	/usr/share/applications/kde/kenolaba.desktop
kfouleggs	kfouleggs	/usr/share/applications/kde/kfouleggs.desktop
kgoldrunner	kgoldrunner	/usr/share/applications/kde/KGoldrunner.desktop
kjumpingcube	kjumpingcube	/usr/share/applications/kde/kjumpingcube.desktop
klickety	klickety	/usr/share/applications/kde/klickety.desktop
klines	klines	/usr/share/applications/kde/klines.desktop
kmahjongg	kmahjongg	/usr/share/applications/kde/kmahjongg.desktop
kmines	kmines	/usr/share/applications/kde/kmines.desktop
kolf	kolf	/usr/share/applications/kde/kolf.desktop
konquest	konquest	/usr/share/applications/kde/konquest.desktop
kpat	kpat	/usr/share/applications/kde/kpat.desktop
kpoker	kpoker	/usr/share/applications/kde/kpoker.desktop
kreversi	kreversi	/usr/share/applications/kde/kreversi.desktop
ksame	ksame	/usr/share/applications/kde/ksame.desktop
kshisen	kshisen	/usr/share/applications/kde/kshisen.desktop
ksirtet	ksirtet	/usr/share/applications/kde/ksirtet.desktop
ksmiletris	ksmiletris	/usr/share/applications/kde/ksmiletris.desktop
ksnake	ksnake	/usr/share/applications/kde/ksnake.desktop
ksokoban	ksokoban	/usr/share/applications/kde/ksokoban.desktop
kspaceduel	kspaceduel	/usr/share/applications/kde/kspaceduel.desktop
ktron	ktron	/usr/share/applications/kde/ktron.desktop
ktuberling	ktuberling	/usr/share/applications/kde/ktuberling.desktop
kwin4	kwin4	/usr/share/applications/kde/kwin4.desktop
lskat	lskat	/usr/share/applications/kde/lskat.desktop
kviewshell	kdvi	/usr/share/applications/kde/kdvi.desktop
kfax	kfax	/usr/share/applications/kde/kfax.desktop
kghostview	kghostview	/usr/share/applications/kde/kghostview.desktop
kiconedit	kiconedit	/usr/share/applications/kde/kiconedit.desktop
kcmshell	kmrml	/usr/share/applications/kde/kcmkmrml.desktop
kpaint	kpaint	/usr/share/applications/kde/kpaint.desktop
kpdf	kpdf	/usr/share/applications/kde/kpdf.desktop
kuickshow	kuickshow	/usr/share/applications/kde/kuickshow.desktop
kview	kview	/usr/share/applications/kde/kview.desktop
kompare	kompare	/usr/share/applications/kde/kompare.desktop
kuiviewer	kuiviewer	/usr/share/applications/kde/kuiviewer.desktop
kcmshell	lilo	/usr/share/applications/kde/lilo.desktop
kcachegrind	kcachegrind	/usr/share/applications/kde/kcachegrind.desktop
smb4k	smb4k	/usr/share/applications/kde/smb4k.desktop
gnome-remote-shell	gnome-remote-shell.png	/usr/share/applications/gnome-network-utilities.desktop
gnome-netinfo	gnome-netinfo.png	/usr/share/applications/gnome-netinfo.desktop
grip	gripicon.png	/usr/share/applications/grip.desktop
oocalc	ooo_calc	/usr/share/applications/ooo645calc.desktop
oomath	ooo_math	/usr/share/applications/ooo645math.desktop
oopadmin	ooo_printeradmin	/usr/share/applications/ooo645printeradmin.desktop
oodraw	ooo_draw	/usr/share/applications/ooo645draw.desktop
ooffice	ooo_template	/usr/share/applications/ooo645template.desktop
tsclient	tsclient.png	/usr/share/applications/tsclient.desktop
blender	blender	/usr/share/applications/blender.desktop
mlv	mlview-app-icon.xpm	/usr/share/applications/mlview.desktop
conglomerate	conglomerate-icon-16.png	/usr/share/applications/conglomerate.desktop
nautilus	gnome-home	/usr/share/applications/nautilus-home.desktop
nautilus	gnome-fs-client	/usr/share/applications/nautilus-computer.desktop
mozilla-thunderbird	mozilla-thunderbird-pm-menu.xpm	/usr/share/applications/mozilla-thunderbird-pm.desktop
mozilla-thunderbird	mozilla-thunderbird.xpm	/usr/share/applications/mozilla-thunderbird.desktop
amule	amule.xpm	/usr/share/applications/amule.desktop
scribus	/usr/share/pixmaps/scribus-3d.xpm	/usr/share/applications/scribus.desktop
gksuexec	/usr/share/pixmaps/gksu-icon.png	/usr/share/applications/gksuexec.desktop
firefox	mozilla-firefox.png	/usr/share/applications/mozilla-firefox.desktop
gmplayer	mplayer.png	/usr/share/applications/mplayer.desktop
slix-central	exec.png	/usr/share/applications/slix-central.desktop
gv4l	/usr/share/pixmaps/gv4l/gv4l.png	/usr/share/applications/gnome-gv4l.desktop
cyca-central	exec.png	/usr/share/applications/cyca-central.desktop
gnomedb-fe	/usr/share/pixmaps/gnome-db.xpm	/var/lib/menu-xdg/applications/menu-xdg/gnome-db_frontend.desktop
mysqlcc	/usr/share/pixmaps/mysqlcc.xpm	/var/lib/menu-xdg/applications/menu-xdg/mysql_cc.desktop
/usr/bin/X11/pgaccess	/usr/share/pixmaps/pgaccess.xpm	/var/lib/menu-xdg/applications/menu-xdg/pgaccess.desktop
pgadmin3	/usr/share/pixmaps/pgadmin3.xpm	/var/lib/menu-xdg/applications/menu-xdg/pgadmin_iii.desktop
/usr/lib/postgresql/bin/psql-wm	/usr/share/pixmaps/postgresql.xpm	/var/lib/menu-xdg/applications/menu-xdg/postgresql_interactive_terminal_(psql).desktop
tora	/usr/share/icons/hicolor/32x32/apps/tora.xpm	/var/lib/menu-xdg/applications/menu-xdg/tora.desktop
abiword	/usr/share/AbiSuite-2.0/icons/menu.xpm	/var/lib/menu-xdg/applications/menu-xdg/abiword_word_processor.desktop
conglomerate	/usr/share/pixmaps/conglomerate_icon.xpm	/var/lib/menu-xdg/applications/menu-xdg/conglomerate_xml_editor.desktop
gedit	/usr/share/pixmaps/gedit-icon.xpm	/var/lib/menu-xdg/applications/menu-xdg/gedit.desktop
texmacs	/usr/share/pixmaps/texmacs/TeXmacs-icon.xpm	/var/lib/menu-xdg/applications/menu-xdg/gnu_texmacs.desktop
kile	/usr/share/pixmaps/kile.xpm	/var/lib/menu-xdg/applications/menu-xdg/kile.desktop
kword	/usr/share/pixmaps/kword.xpm	/var/lib/menu-xdg/applications/menu-xdg/kword.desktop
lyx-qt	/usr/share/pixmaps/lyx-qt.xpm	/var/lib/menu-xdg/applications/menu-xdg/lyx_(qt).desktop
mlv	/usr/share/pixmaps/mlview-app-icon.xpm	/var/lib/menu-xdg/applications/menu-xdg/mlview_xml_editor.desktop
nano	/usr/share/nano/nano-menu.xpm	/var/lib/menu-xdg/applications/menu-xdg/nano.desktop
oofromtemplate	/usr/share/icons/hicolor/32x32/apps/ooo_template.xpm	/var/lib/menu-xdg/applications/menu-xdg/openoffice.org_from_template.desktop
ooweb	/usr/share/icons/hicolor/32x32/apps/ooo_web.xpm	/var/lib/menu-xdg/applications/menu-xdg/openoffice.org_html_document.desktop
oowriter	/usr/share/icons/hicolor/32x32/apps/ooo_writer.xpm	/var/lib/menu-xdg/applications/menu-xdg/openoffice.org_writer.desktop
pw	/usr/share/siag/common/bitmaps/pw.xpm	/var/lib/menu-xdg/applications/menu-xdg/pathetic_writer.desktop
quanta	/usr/share/pixmaps/quanta.xpm	/var/lib/menu-xdg/applications/menu-xdg/quanta_plus.desktop
vim	/usr/X11R6/include/X11/pixmaps/vim.xpm	/var/lib/menu-xdg/applications/menu-xdg/vim.desktop
flashkard	/usr/share/pixmaps/flashkard.xpm	/var/lib/menu-xdg/applications/menu-xdg/flashkard.desktop
kiten	/usr/share/pixmaps/kiten.xpm	/var/lib/menu-xdg/applications/menu-xdg/kiten.desktop
klettres	/usr/share/pixmaps/klettres.xpm	/var/lib/menu-xdg/applications/menu-xdg/klettres.desktop
ktouch	/usr/share/pixmaps/ktouch.xpm	/var/lib/menu-xdg/applications/menu-xdg/ktouch.desktop
kverbos	/usr/share/pixmaps/kverbos.xpm	/var/lib/menu-xdg/applications/menu-xdg/kverbos.desktop
kvoctrain	/usr/share/pixmaps/kvoctrain.xpm	/var/lib/menu-xdg/applications/menu-xdg/kvoctrain.desktop
x128	/usr/share/pixmaps/c128icon-32x28.xpm	/var/lib/menu-xdg/applications/menu-xdg/commodore_128.desktop
x64	/usr/share/pixmaps/c64icon-32x28.xpm	/var/lib/menu-xdg/applications/menu-xdg/commodore_64.desktop
xcbm2	/usr/share/pixmaps/cbm2icon-32x28.xpm	/var/lib/menu-xdg/applications/menu-xdg/commodore_cbm-ii.desktop
xpet	/usr/share/pixmaps/peticon-32x28.xpm	/var/lib/menu-xdg/applications/menu-xdg/commodore_pet.desktop
xvic	/usr/share/pixmaps/vic20icon-32x28.xpm	/var/lib/menu-xdg/applications/menu-xdg/commodore_vic-20.desktop
GSnes9x	/usr/share/pixmaps/gsnes9x-icon.xpm	/var/lib/menu-xdg/applications/menu-xdg/gsnes9x.desktop
uae-x	/usr/X11R6/include/X11/pixmaps/uae-menu.xpm	/var/lib/menu-xdg/applications/menu-xdg/uae.desktop
blender	/usr/share/pixmaps/blender.xpm	/var/lib/menu-xdg/applications/menu-xdg/blender_(full_screen).desktop
cinelerra	/usr/share/pixmaps/cinelerra.xpm	/var/lib/menu-xdg/applications/menu-xdg/cinelerra.desktop
dia-normal	/usr/share/pixmaps/dia_menu.xpm	/var/lib/menu-xdg/applications/menu-xdg/dia.desktop
dia-gnome	/usr/share/pixmaps/dia_menu.xpm	/var/lib/menu-xdg/applications/menu-xdg/dia_(gnome).desktop
egon	/usr/share/siag/common/bitmaps/egon.xpm	/var/lib/menu-xdg/applications/menu-xdg/egon.desktop
filmgimp	/usr/share/pixmaps/wilber.xpm	/var/lib/menu-xdg/applications/menu-xdg/film_gimp.desktop
inkscape	/usr/share/pixmaps/inkscape.xpm	/var/lib/menu-xdg/applications/menu-xdg/inkscape.desktop
karbon	/usr/share/pixmaps/karbon.xpm	/var/lib/menu-xdg/applications/menu-xdg/karbon.desktop
oodraw	/usr/share/icons/hicolor/32x32/apps/ooo_draw.xpm	/var/lib/menu-xdg/applications/menu-xdg/openoffice.org_draw.desktop
ooimpress	/usr/share/icons/hicolor/32x32/apps/ooo_impress.xpm	/var/lib/menu-xdg/applications/menu-xdg/openoffice.org_impress.desktop
scribus	/usr/share/pixmaps/scribus.xpm	/var/lib/menu-xdg/applications/menu-xdg/scribus.desktop
snowflake	/usr/share/pixmaps/Snowflake32x32.xpm	/var/lib/menu-xdg/applications/menu-xdg/snowflake.desktop
sodipodi	/usr/share/pixmaps/sodipodi.xpm	/var/lib/menu-xdg/applications/menu-xdg/sodipodi.desktop
terraform	/usr/share/pixmaps/terraform.xpm	/var/lib/menu-xdg/applications/menu-xdg/terraform.desktop
gimp-2.0	/usr/share/gimp/2.0/images/wilber-icon.png	/var/lib/menu-xdg/applications/menu-xdg/the_gimp_(v2.0).desktop
tuxpaint	/usr/X11R6/include/X11/pixmaps/tuxpaint.xpm	/var/lib/menu-xdg/applications/menu-xdg/tuxpaint.desktop
xfig	/usr/share/pixmaps/xfig32x32.xpm	/var/lib/menu-xdg/applications/menu-xdg/xfig.desktop
xsane	/usr/share/pixmaps/xsane.xpm	/var/lib/menu-xdg/applications/menu-xdg/xsane.desktop
twclock	mini.twclock.xpm	/var/lib/menu-xdg/applications/menu-xdg/twclock.desktop
xcall	/usr/share/xcall/pixmaps/mini-xcall.xpm	/var/lib/menu-xdg/applications/menu-xdg/xcall.desktop
gcalctool	/usr/share/pixmaps/gcalctool.png	/var/lib/menu-xdg/applications/menu-xdg/calctool.desktop
gnumeric	/usr/share/pixmaps/gnome-gnumeric.xpm	/var/lib/menu-xdg/applications/menu-xdg/gnumeric.desktop
kbruch	/usr/share/pixmaps/kbruch.xpm	/var/lib/menu-xdg/applications/menu-xdg/kbruch.desktop
kchart	/usr/share/pixmaps/kchart.xpm	/var/lib/menu-xdg/applications/menu-xdg/kchart.desktop
kformula	/usr/share/pixmaps/kformula.xpm	/var/lib/menu-xdg/applications/menu-xdg/kformula.desktop
kgeo	/usr/share/pixmaps/kgeo.xpm	/var/lib/menu-xdg/applications/menu-xdg/kgeo.desktop
kig	/usr/share/pixmaps/kig.xpm	/var/lib/menu-xdg/applications/menu-xdg/kig.desktop
kmplot	/usr/share/pixmaps/kmplot.xpm	/var/lib/menu-xdg/applications/menu-xdg/kmplot.desktop
kpercentage	/usr/share/pixmaps/kpercentage.xpm	/var/lib/menu-xdg/applications/menu-xdg/kpercentage.desktop
kspread	/usr/share/pixmaps/kspread.xpm	/var/lib/menu-xdg/applications/menu-xdg/kspread.desktop
oocalc	/usr/share/icons/hicolor/32x32/apps/ooo_calc.xpm	/var/lib/menu-xdg/applications/menu-xdg/openoffice.org_calc.desktop
oomath	/usr/share/icons/hicolor/32x32/apps/ooo_math.xpm	/var/lib/menu-xdg/applications/menu-xdg/openoffice.org_math.desktop
siag	/usr/share/siag/common/bitmaps/siag.xpm	/var/lib/menu-xdg/applications/menu-xdg/siag.desktop
tsiag	/usr/share/siag/common/bitmaps/siag.xpm	/var/lib/menu-xdg/applications/menu-xdg/siag_(text_mode).desktop
xabacus	/usr/share/pixmaps/xabacus.m.xpm	/var/lib/menu-xdg/applications/menu-xdg/xabacus.desktop
amule	/usr/share/pixmaps/amule.xpm	/var/lib/menu-xdg/applications/menu-xdg/amule.desktop
amulewebDLG	/usr/share/pixmaps/amule.xpm	/var/lib/menu-xdg/applications/menu-xdg/amule_webserver_control.desktop
everybuddy	/usr/share/pixmaps/ebicon.png	/var/lib/menu-xdg/applications/menu-xdg/everybuddy.desktop
fwbuilder	/usr/share/pixmaps/fwbuilder/firewall.xpm	/var/lib/menu-xdg/applications/menu-xdg/firewall_builder.desktop
gnomemeeting	/usr/share/pixmaps/gnomemeeting-logo-icon.png	/var/lib/menu-xdg/applications/menu-xdg/gnomemeeting.desktop
gtk-gnutella	/usr/share/gtk-gnutella/pixmaps/icon.xpm	/var/lib/menu-xdg/applications/menu-xdg/gtk-gnutella.desktop
ksig	/usr/share/pixmaps/ksig.xpm	/var/lib/menu-xdg/applications/menu-xdg/ksig.desktop
firefox	/usr/share/pixmaps/mozilla-firefox.xpm	/var/lib/menu-xdg/applications/menu-xdg/mozilla_firefox.desktop
mozilla-thunderbird	/usr/share/pixmaps/mozilla-thunderbird-menu.xpm	/var/lib/menu-xdg/applications/menu-xdg/mozilla_thunderbird.desktop
mutt	/usr/share/pixmaps/mutt.xpm	/var/lib/menu-xdg/applications/menu-xdg/mutt.desktop
gnome-netinfo	/usr/share/pixmaps/gnome-netinfo.png	/var/lib/menu-xdg/applications/menu-xdg/network_information.desktop
pan	/usr/X11R6/include/X11/pixmaps/pan.xpm	/var/lib/menu-xdg/applications/menu-xdg/pan.desktop
gnome-remote-desktop	/usr/share/pixmaps/gnome-remote-desktop.png	/var/lib/menu-xdg/applications/menu-xdg/remote_desktop.desktop
gnome-remote-shell	/usr/share/pixmaps/gnome-remote-shell.png	/var/lib/menu-xdg/applications/menu-xdg/remote_shell.desktop
tsclient	/usr/share/pixmaps/tsclient.xpm	/var/lib/menu-xdg/applications/menu-xdg/terminal_server_client.desktop
argouml	/usr/share/pixmaps/argouml_icon.xpm	/var/lib/menu-xdg/applications/menu-xdg/argouml.desktop
cervisia	/usr/share/pixmaps/cervisia.xpm	/var/lib/menu-xdg/applications/menu-xdg/cervisia.desktop
eclipse	/usr/share/eclipse/icon32x32.xpm	/var/lib/menu-xdg/applications/menu-xdg/eclipse.desktop
glade-2	/usr/share/pixmaps/glade-2.xpm	/var/lib/menu-xdg/applications/menu-xdg/glade_2.desktop
guile1.4	mini.lambda.xpm	/var/lib/menu-xdg/applications/menu-xdg/guile_scheme_1.4.desktop
insight	/usr/share/pixmaps/gdbtk_icon.xpm	/var/lib/menu-xdg/applications/menu-xdg/insight.desktop
jython	/usr/share/pixmaps/python2.1-32.xpm	/var/lib/menu-xdg/applications/menu-xdg/jython.desktop
kbabel	/usr/share/pixmaps/kbabel.xpm	/var/lib/menu-xdg/applications/menu-xdg/kbabel.desktop
catalogmanager	/usr/share/pixmaps/catalogmanager.xpm	/var/lib/menu-xdg/applications/menu-xdg/kbabel_catalog_manager.desktop
kbabeldict	/usr/share/pixmaps/kbabeldict.xpm	/var/lib/menu-xdg/applications/menu-xdg/kbabel_dictionary.desktop
kbugbuster	/usr/share/pixmaps/kbugbuster.xpm	/var/lib/menu-xdg/applications/menu-xdg/kbugbuster.desktop
kcachegrind	/usr/share/pixmaps/kcachegrind.xpm	/var/lib/menu-xdg/applications/menu-xdg/kcachegrind.desktop
kdevelop3	/usr/share/icons/hicolor/16x16/apps/kdevelop3.png	/var/lib/menu-xdg/applications/menu-xdg/kdevelop_3.0.desktop
kodos	/usr/share/pixmaps/kodos.xpm	/var/lib/menu-xdg/applications/menu-xdg/kodos.desktop
kompare	/usr/share/pixmaps/kompare.xpm	/var/lib/menu-xdg/applications/menu-xdg/kompare.desktop
kuiviewer	/usr/share/pixmaps/kuiviewer.xpm	/var/lib/menu-xdg/applications/menu-xdg/kuiviewer.desktop
pike7.2	/usr/share/pixmaps/pike/pike7.2.xpm	/var/lib/menu-xdg/applications/menu-xdg/pike_7.2_hilfe.desktop
python2.1	/usr/share/pixmaps/python2.1-32.xpm	/var/lib/menu-xdg/applications/menu-xdg/python_(v2.1).desktop
python2.2	/usr/share/pixmaps/python2.2-32.xpm	/var/lib/menu-xdg/applications/menu-xdg/python_(v2.2).desktop
python2.3	/usr/share/pixmaps/python2.3-32.xpm	/var/lib/menu-xdg/applications/menu-xdg/python_(v2.3).desktop
vibrate	/usr/share/pixmaps/ncbilogo.xpm	/var/lib/menu-xdg/applications/menu-xdg/asn2asn.desktop
Cn3D-3.0	/usr/share/pixmaps/ncbilogo.xpm	/var/lib/menu-xdg/applications/menu-xdg/cn3d-3.0.desktop
ddv	/usr/share/pixmaps/ncbilogo.xpm	/var/lib/menu-xdg/applications/menu-xdg/ddv.desktop
Nentrez	/usr/share/pixmaps/ncbilogo.xpm	/var/lib/menu-xdg/applications/menu-xdg/entrez.desktop
netentcf	/usr/share/pixmaps/ncbilogo.xpm	/var/lib/menu-xdg/applications/menu-xdg/entrez_net_config.desktop
entrez2	/usr/share/pixmaps/ncbilogo.xpm	/var/lib/menu-xdg/applications/menu-xdg/entrez2.desktop
kalzium	/usr/share/pixmaps/kalzium.xpm	/var/lib/menu-xdg/applications/menu-xdg/kalzium.desktop
kstars	/usr/share/pixmaps/kstars.xpm	/var/lib/menu-xdg/applications/menu-xdg/kstars.desktop
kxterm	/usr/share/pixmaps/kxterm.xpm	/var/lib/menu-xdg/applications/menu-xdg/kxterm.desktop
Psequin	/usr/share/pixmaps/ncbilogo.xpm	/var/lib/menu-xdg/applications/menu-xdg/sequin.desktop
udv	/usr/share/pixmaps/ncbilogo.xpm	/var/lib/menu-xdg/applications/menu-xdg/udv.desktop
audacity	/usr/share/audacity/audacity.xpm	/var/lib/menu-xdg/applications/menu-xdg/audacity.desktop
gnome-volume-control	/usr/share/pixmaps/gnome-mixer.xpm	/var/lib/menu-xdg/applications/menu-xdg/gmix_(gnome_2.0_mixer).desktop
gnome-cd	/usr/share/pixmaps/gnome-cd.xpm	/var/lib/menu-xdg/applications/menu-xdg/gnome-cd_(gnome_2.0_cd_player).desktop
gnome-sound-recorder	/usr/share/pixmaps/gnome-grecord.xpm	/var/lib/menu-xdg/applications/menu-xdg/grecord_(gnome_2.0_recorder).desktop
gtick	/usr/share/pixmaps/gtick_32x32.xpm	/var/lib/menu-xdg/applications/menu-xdg/gtick.desktop
sweep	/usr/share/pixmaps/sweep.xpm	/var/lib/menu-xdg/applications/menu-xdg/sweep.desktop
terminatorX	/usr/share/pixmaps/terminatorX-app.png	/var/lib/menu-xdg/applications/menu-xdg/terminatorx.desktop
vumeter	/usr/share/pixmaps/gnome-vumeter.xpm	/var/lib/menu-xdg/applications/menu-xdg/vumeter_(gnome_2.0_volume_meter).desktop
workman	/usr/X11R6/include/X11/pixmaps/workman.xpm	/var/lib/menu-xdg/applications/menu-xdg/workman.desktop
xmcd	/usr/share/xmcd/pixmaps/xmcd_small.xpm	/var/lib/menu-xdg/applications/menu-xdg/xmcd.desktop
fsview	/usr/share/pixmaps/fsview.xpm	/var/lib/menu-xdg/applications/menu-xdg/fsview.desktop
gdmflexiserver	/usr/share/pixmaps/gdm.xpm	/var/lib/menu-xdg/applications/menu-xdg/gdm_flexiserver.desktop
gdmphotosetup	/usr/share/pixmaps/gdm.xpm	/var/lib/menu-xdg/applications/menu-xdg/gdm_photo_setup.desktop
gksu	/usr/share/pixmaps/gdm.xpm	/var/lib/menu-xdg/applications/menu-xdg/gdm_setup.desktop
gnome-control-center	/usr/share/pixmaps/control-center2.xpm	/var/lib/menu-xdg/applications/menu-xdg/gnome_control_center.desktop
bug-buddy	/usr/share/pixmaps/bug-buddy.xpm	/var/lib/menu-xdg/applications/menu-xdg/gnome_bug_report_tool.desktop
gfloppy	/usr/share/pixmaps/gfloppy.xpm	/var/lib/menu-xdg/applications/menu-xdg/gnome_floppy_formatter.desktop
gnome-system-log	/usr/share/pixmaps/gnome-system-log.xpm	/var/lib/menu-xdg/applications/menu-xdg/gnome_log_viewer.desktop
openapp	/usr/share/pixmaps/gworkspace.xpm	/var/lib/menu-xdg/applications/menu-xdg/gworkspace.app.desktop
nautilus	/usr/share/pixmaps/nautilus.xpm	/var/lib/menu-xdg/applications/menu-xdg/nautilus.desktop
oopadmin	/usr/share/icons/hicolor/32x32/apps/ooo_setup.xpm	/var/lib/menu-xdg/applications/menu-xdg/openoffice.org_printer_administration.desktop
/usr/lib/openoffice/program/setup	/usr/share/icons/hicolor/32x32/apps/ooo_setup.xpm	/var/lib/menu-xdg/applications/menu-xdg/openoffice.org_setup.desktop
x-terminal-emulator	/usr/share/pixmaps/pstree16.xpm	/var/lib/menu-xdg/applications/menu-xdg/pstree.desktop
gksuexec	/usr/share/pixmaps/gksuexec-debian.xpm	/var/lib/menu-xdg/applications/menu-xdg/run_as_different_user_(gksu).desktop
si	/usr/share/pixmaps/si.xpm	/var/lib/menu-xdg/applications/menu-xdg/si.desktop
su-to-root	/usr/share/synaptic/pixmaps/synaptic_32x32.xpm	/var/lib/menu-xdg/applications/menu-xdg/synaptic_package_manager.desktop
gksu	/usr/share/pixmaps/gksu-debian.xpm	/var/lib/menu-xdg/applications/menu-xdg/x-terminal_as_root_(gksu).desktop
gnome-dictionary	/usr/share/pixmaps/gdict.xpm	/var/lib/menu-xdg/applications/menu-xdg/gnome_dictionary.desktop
ding	/usr/share/pixmaps/dbook.xpm	/var/lib/menu-xdg/applications/menu-xdg/ding.desktop
emelfm	/usr/share/pixmaps/icon_dirparent.xpm	/var/lib/menu-xdg/applications/menu-xdg/emelfm.desktop
file-roller	/usr/share/pixmaps/file-roller.png	/var/lib/menu-xdg/applications/menu-xdg/file-roller.desktop
gcm	/usr/share/pixmaps/gcm.xpm	/var/lib/menu-xdg/applications/menu-xdg/gnome_clipboard_manager.desktop
gnome-search-tool	/usr/share/pixmaps/gsearchtool.xpm	/var/lib/menu-xdg/applications/menu-xdg/gnome_search_tool.desktop
gnucash	/usr/share/pixmaps/gnucash/gnucash-icon.png	/var/lib/menu-xdg/applications/menu-xdg/gnucash.desktop
gramps	/usr/share/pixmaps/gramps.xpm	/var/lib/menu-xdg/applications/menu-xdg/gramps.desktop
kivio	/usr/share/pixmaps/kivio.xpm	/var/lib/menu-xdg/applications/menu-xdg/kivio.desktop
kpresenter	/usr/share/pixmaps/kpresenter.xpm	/var/lib/menu-xdg/applications/menu-xdg/kpresenter.desktop
kugar	/usr/share/pixmaps/kugar.xpm	/var/lib/menu-xdg/applications/menu-xdg/kugar.desktop
mc	/usr/share/pixmaps/mc.xpm	/var/lib/menu-xdg/applications/menu-xdg/mc.desktop
worker	/usr/share/pixmaps/worker_32x32.xpm	/var/lib/menu-xdg/applications/menu-xdg/worker.desktop
alevt	/usr/X11R6/include/X11/pixmaps/mini-alevt.xpm	/var/lib/menu-xdg/applications/menu-xdg/alevt.desktop
gnome-gv	/usr/share/pixmaps/gnome-ghostview.png	/var/lib/menu-xdg/applications/menu-xdg/gnome_ghostscript_pdf_viewer.desktop
gqview	/usr/share/pixmaps/gqview.xpm	/var/lib/menu-xdg/applications/menu-xdg/gqview.desktop
/usr/bin/X11/gv	/usr/X11R6/include/X11/pixmaps/mini-gv.xpm	/var/lib/menu-xdg/applications/menu-xdg/gv.desktop
gmplayer	/usr/share/pixmaps/mplayer.xpm	/var/lib/menu-xdg/applications/menu-xdg/mplayer.desktop
paul	paul.xpm	/var/lib/menu-xdg/applications/menu-xdg/paul.desktop
realplayer	/usr/share/pixmaps/realplayer-icon.xpm	/var/lib/menu-xdg/applications/menu-xdg/real_player.desktop
xawtv	xawtv	/var/lib/menu-xdg/applications/menu-xdg/xawtv.desktop
xine	/usr/share/xine/desktop/xine.xpm	/var/lib/menu-xdg/applications/menu-xdg/xine_media_player.desktop
kasteroids	/usr/share/pixmaps/kasteroids.xpm	/var/lib/menu-xdg/applications/menu-xdg/kasteroids.desktop
kbounce	/usr/share/pixmaps/kbounce.xpm	/var/lib/menu-xdg/applications/menu-xdg/kde_bounce_ball_game.desktop
kolf	/usr/share/pixmaps/kolf.xpm	/var/lib/menu-xdg/applications/menu-xdg/kde_miniature_golf.desktop
ksnake	/usr/share/pixmaps/ksnake.xpm	/var/lib/menu-xdg/applications/menu-xdg/kde_snake_race.desktop
kspaceduel	/usr/share/pixmaps/kspaceduel.xpm	/var/lib/menu-xdg/applications/menu-xdg/kde_spaceduel.desktop
ktron	/usr/share/pixmaps/ktron.xpm	/var/lib/menu-xdg/applications/menu-xdg/kde_tron.desktop
kgoldrunner	/usr/share/pixmaps/kgoldrunner.xpm	/var/lib/menu-xdg/applications/menu-xdg/kgoldrunner.desktop
atlantik	/usr/share/pixmaps/atlantik.xpm	/var/lib/menu-xdg/applications/menu-xdg/atlantik.desktop
atlantikdesigner	/usr/share/pixmaps/atlantikdesigner.xpm	/var/lib/menu-xdg/applications/menu-xdg/atlantik_designer.desktop
kbattleship	/usr/share/pixmaps/kbattleship.xpm	/var/lib/menu-xdg/applications/menu-xdg/kbattleship.desktop
kbackgammon	/usr/share/pixmaps/kbackgammon.xpm	/var/lib/menu-xdg/applications/menu-xdg/kde_backgammon.desktop
kreversi	/usr/share/pixmaps/kreversi.xpm	/var/lib/menu-xdg/applications/menu-xdg/kde_reversi.desktop
kshisen	/usr/share/pixmaps/kshisen.xpm	/var/lib/menu-xdg/applications/menu-xdg/kde_shisen-sho.desktop
kenolaba	/usr/share/pixmaps/kenolaba.xpm	/var/lib/menu-xdg/applications/menu-xdg/kenolaba.desktop
klines	/usr/share/pixmaps/klines.xpm	/var/lib/menu-xdg/applications/menu-xdg/klines.desktop
kmahjongg	/usr/share/pixmaps/kmahjongg.xpm	/var/lib/menu-xdg/applications/menu-xdg/kmahjongg.desktop
kwin4	/usr/share/pixmaps/kwin4.xpm	/var/lib/menu-xdg/applications/menu-xdg/kwin4.desktop
gnome-freecell	/usr/share/pixmaps/gnome-aisleriot.xpm	/var/lib/menu-xdg/applications/menu-xdg/gnome_freecell.desktop
sol	/usr/share/pixmaps/gnome-aisleriot.xpm	/var/lib/menu-xdg/applications/menu-xdg/gnome_solitaire_games.desktop
megami	/usr/share/pixmaps/megami.xpm	/var/lib/menu-xdg/applications/menu-xdg/kde_blackjack.desktop
lskat	/usr/share/pixmaps/lskat.xpm	/var/lib/menu-xdg/applications/menu-xdg/kde_lieutnant_skat.desktop
kpat	/usr/share/pixmaps/kpat.xpm	/var/lib/menu-xdg/applications/menu-xdg/kde_patience.desktop
kpoker	/usr/share/pixmaps/kpoker.xpm	/var/lib/menu-xdg/applications/menu-xdg/kde_poker.desktop
kblackbox	/usr/share/pixmaps/kblackbox.xpm	/var/lib/menu-xdg/applications/menu-xdg/kblackbox.desktop
katomic	/usr/share/pixmaps/katomic.xpm	/var/lib/menu-xdg/applications/menu-xdg/kde_atomic_entertainment.desktop
ksame	/usr/share/pixmaps/ksame.xpm	/var/lib/menu-xdg/applications/menu-xdg/kde_samegame.desktop
ksokoban	/usr/share/pixmaps/ksokoban.xpm	/var/lib/menu-xdg/applications/menu-xdg/kde_sokoban.desktop
khangman	/usr/share/pixmaps/khangman.xpm	/var/lib/menu-xdg/applications/menu-xdg/khangman.desktop
kmessedwords	/usr/share/pixmaps/kmessedwords.xpm	/var/lib/menu-xdg/applications/menu-xdg/kmessedwords.desktop
kmines	/usr/share/pixmaps/kmines.xpm	/var/lib/menu-xdg/applications/menu-xdg/kmines.desktop
kjumpingcube	/usr/share/pixmaps/kjumpingcube.xpm	/var/lib/menu-xdg/applications/menu-xdg/kjumpingcube.desktop
konquest	/usr/share/pixmaps/konquest.xpm	/var/lib/menu-xdg/applications/menu-xdg/konquest.desktop
kfouleggs	/usr/share/pixmaps/kfouleggs.xpm	/var/lib/menu-xdg/applications/menu-xdg/kde_foul_eggs.desktop
ksirtet	/usr/share/pixmaps/ksirtet.xpm	/var/lib/menu-xdg/applications/menu-xdg/kde_sirtet.desktop
ksmiletris	/usr/share/pixmaps/ksmiletris.xpm	/var/lib/menu-xdg/applications/menu-xdg/kde_smiletris.desktop
amor	/usr/share/pixmaps/amor.xpm	/var/lib/menu-xdg/applications/menu-xdg/amor.desktop
kaphorism	/usr/share/pixmaps/kaphorism.xpm	/var/lib/menu-xdg/applications/menu-xdg/k_aphorisms.desktop
ktuberling	/usr/share/pixmaps/ktuberling.xpm	/var/lib/menu-xdg/applications/menu-xdg/kde_potato_guy.desktop
kmoon	/usr/share/pixmaps/kmoon.xpm	/var/lib/menu-xdg/applications/menu-xdg/kmoon.desktop
kodo	/usr/share/pixmaps/kodo.xpm	/var/lib/menu-xdg/applications/menu-xdg/kodometer.desktop
kteatime	/usr/share/pixmaps/kteatime.xpm	/var/lib/menu-xdg/applications/menu-xdg/kteatime.desktop
kworldclock	/usr/share/pixmaps/kworldclock.xpm	/var/lib/menu-xdg/applications/menu-xdg/kworldclock.desktop
penguineyes	/usr/share/penguineyes/deb-icon.xpm	/var/lib/menu-xdg/applications/menu-xdg/penguineyes.desktop
gnome-terminal	/usr/share/pixmaps/gnome-terminal.xpm	/var/lib/menu-xdg/applications/menu-xdg/gnome_terminal.desktop
multi-gnome-terminal	/usr/share/pixmaps/mgt/multignometerm.xpm	/var/lib/menu-xdg/applications/menu-xdg/multi_gnome_terminal.desktop
powershell	/usr/share/pixmaps/gnome-powershell.xpm	/var/lib/menu-xdg/applications/menu-xdg/powershell.desktop
xfig	/usr/share/pixmaps/xfig32x32cmap.xpm	/var/lib/gnome/Debian/Apps/Graphics/xfig.desktop
guile1.4	/usr/X11R6/include/X11/pixmaps/mini.lambda.xpm	/var/lib/gnome/Debian/Apps/Programming/Guile Scheme 1.4.desktop
su-to-root	/usr/share/pixmaps/lilo-term.xpm	/var/lib/gnome/Debian/Apps/System/Admin/Lilo-config.desktop
paul	/usr/X11R6/include/X11/pixmaps/paul.xpm	/var/lib/gnome/Debian/Apps/Viewers/Paul.desktop
\.


--
-- Data for TOC entry 581 (OID 2068332)
-- Name: app_registry; Type: TABLE DATA; Schema: public; Owner: postgres
--

COPY app_registry (app, registry) FROM stdin;
dbishell	/var/lib/menu-xdg/applications/menu-xdg/dbishell.desktop
gnomedb-fe	/var/lib/menu-xdg/applications/menu-xdg/gnome-db_frontend.desktop
mysqlcc	/var/lib/menu-xdg/applications/menu-xdg/mysql_cc.desktop
/usr/bin/X11/pgaccess	/var/lib/menu-xdg/applications/menu-xdg/pgaccess.desktop
pgadmin3	/var/lib/menu-xdg/applications/menu-xdg/pgadmin_iii.desktop
/usr/lib/postgresql/bin/psql-wm	/var/lib/menu-xdg/applications/menu-xdg/postgresql_interactive_terminal_(psql).desktop
quicklist	/var/lib/menu-xdg/applications/menu-xdg/quicklist.desktop
sqlr-config-gtk	/var/lib/menu-xdg/applications/menu-xdg/sql_relay_configuration.desktop
tora	/var/lib/menu-xdg/applications/menu-xdg/tora.desktop
abiword	/var/lib/menu-xdg/applications/menu-xdg/abiword_word_processor.desktop
/usr/bin/X11/axe	/var/lib/menu-xdg/applications/menu-xdg/axe.desktop
conglomerate	/var/lib/menu-xdg/applications/menu-xdg/conglomerate_xml_editor.desktop
emacs21	/var/lib/menu-xdg/applications/menu-xdg/emacs_21_(text).desktop
emacs21	/var/lib/menu-xdg/applications/menu-xdg/emacs_21_(x11).desktop
fontforge	/var/lib/menu-xdg/applications/menu-xdg/fontforge.desktop
gedit	/var/lib/menu-xdg/applications/menu-xdg/gedit.desktop
texmacs	/var/lib/menu-xdg/applications/menu-xdg/gnu_texmacs.desktop
joe	/var/lib/menu-xdg/applications/menu-xdg/joe.desktop
kate	/var/lib/menu-xdg/applications/menu-xdg/kate.desktop
kedit	/var/lib/menu-xdg/applications/menu-xdg/kedit.desktop
kile	/var/lib/menu-xdg/applications/menu-xdg/kile.desktop
kvim	/var/lib/menu-xdg/applications/menu-xdg/kvim.desktop
kword	/var/lib/menu-xdg/applications/menu-xdg/kword.desktop
kwrite	/var/lib/menu-xdg/applications/menu-xdg/kwrite.desktop
kxmleditor	/var/lib/menu-xdg/applications/menu-xdg/kxmleditor.desktop
lyx-qt	/var/lib/menu-xdg/applications/menu-xdg/lyx_(qt).desktop
mlv	/var/lib/menu-xdg/applications/menu-xdg/mlview_xml_editor.desktop
nano	/var/lib/menu-xdg/applications/menu-xdg/nano.desktop
nedit	/var/lib/menu-xdg/applications/menu-xdg/nedit.desktop
oofromtemplate	/var/lib/menu-xdg/applications/menu-xdg/openoffice.org_from_template.desktop
ooweb	/var/lib/menu-xdg/applications/menu-xdg/openoffice.org_html_document.desktop
oowriter	/var/lib/menu-xdg/applications/menu-xdg/openoffice.org_writer.desktop
pw	/var/lib/menu-xdg/applications/menu-xdg/pathetic_writer.desktop
quanta	/var/lib/menu-xdg/applications/menu-xdg/quanta_plus.desktop
vim	/var/lib/menu-xdg/applications/menu-xdg/vim.desktop
xedit	/var/lib/menu-xdg/applications/menu-xdg/xedit.desktop
xemacs21-mule	/var/lib/menu-xdg/applications/menu-xdg/xemacs21-mule.desktop
yudit	/var/lib/menu-xdg/applications/menu-xdg/yudit.desktop
flashkard	/var/lib/menu-xdg/applications/menu-xdg/flashkard.desktop
kiten	/var/lib/menu-xdg/applications/menu-xdg/kiten.desktop
klettres	/var/lib/menu-xdg/applications/menu-xdg/klettres.desktop
ktouch	/var/lib/menu-xdg/applications/menu-xdg/ktouch.desktop
kverbos	/var/lib/menu-xdg/applications/menu-xdg/kverbos.desktop
kvoctrain	/var/lib/menu-xdg/applications/menu-xdg/kvoctrain.desktop
BasiliskII	/var/lib/menu-xdg/applications/menu-xdg/basiliskii.desktop
x128	/var/lib/menu-xdg/applications/menu-xdg/commodore_128.desktop
x64	/var/lib/menu-xdg/applications/menu-xdg/commodore_64.desktop
xcbm2	/var/lib/menu-xdg/applications/menu-xdg/commodore_cbm-ii.desktop
xpet	/var/lib/menu-xdg/applications/menu-xdg/commodore_pet.desktop
xvic	/var/lib/menu-xdg/applications/menu-xdg/commodore_vic-20.desktop
dosemu	/var/lib/menu-xdg/applications/menu-xdg/dos_emulator_(tty).desktop
xdosemu	/var/lib/menu-xdg/applications/menu-xdg/dos_emulator_(x11).desktop
GSnes9x	/var/lib/menu-xdg/applications/menu-xdg/gsnes9x.desktop
x-terminal-emulator	/var/lib/menu-xdg/applications/menu-xdg/spectemu.desktop
uae-x	/var/lib/menu-xdg/applications/menu-xdg/uae.desktop
avidemux	/var/lib/menu-xdg/applications/menu-xdg/avidemux.desktop
bitmap	/var/lib/menu-xdg/applications/menu-xdg/bitmap.desktop
blender	/var/lib/menu-xdg/applications/menu-xdg/blender_(full_screen).desktop
blender	/var/lib/menu-xdg/applications/menu-xdg/blender_(windowed).desktop
cenon	/var/lib/menu-xdg/applications/menu-xdg/cenon.desktop
cinelerra	/var/lib/menu-xdg/applications/menu-xdg/cinelerra.desktop
dia-normal	/var/lib/menu-xdg/applications/menu-xdg/dia.desktop
dia-gnome	/var/lib/menu-xdg/applications/menu-xdg/dia_(gnome).desktop
egon	/var/lib/menu-xdg/applications/menu-xdg/egon.desktop
filmgimp	/var/lib/menu-xdg/applications/menu-xdg/film_gimp.desktop
giram	/var/lib/menu-xdg/applications/menu-xdg/giram.desktop
ganso	/var/lib/menu-xdg/applications/menu-xdg/gnome_animation_studio.desktop
gqcam	/var/lib/menu-xdg/applications/menu-xdg/gqcam.desktop
gtk-ocr	/var/lib/menu-xdg/applications/menu-xdg/gtk_gocr.desktop
inkscape	/var/lib/menu-xdg/applications/menu-xdg/inkscape.desktop
innovation3d	/var/lib/menu-xdg/applications/menu-xdg/innovation3d_modeler.desktop
x-terminal-emulator	/var/lib/menu-xdg/applications/menu-xdg/ivtools.desktop
ivview	/var/lib/menu-xdg/applications/menu-xdg/ivview.desktop
karbon	/var/lib/menu-xdg/applications/menu-xdg/karbon.desktop
kcolorchooser	/var/lib/menu-xdg/applications/menu-xdg/kcolorchooser.desktop
kcoloredit	/var/lib/menu-xdg/applications/menu-xdg/kcoloredit.desktop
kfax	/var/lib/menu-xdg/applications/menu-xdg/kfax.desktop
kiconedit	/var/lib/menu-xdg/applications/menu-xdg/kiconedit.desktop
kino	/var/lib/menu-xdg/applications/menu-xdg/kino.desktop
kooka	/var/lib/menu-xdg/applications/menu-xdg/kooka.desktop
kpaint	/var/lib/menu-xdg/applications/menu-xdg/kpaint.desktop
kpdf	/var/lib/menu-xdg/applications/menu-xdg/kpdf.desktop
kpovmodeler	/var/lib/menu-xdg/applications/menu-xdg/kpovmodeler.desktop
krita	/var/lib/menu-xdg/applications/menu-xdg/krita.desktop
kruler	/var/lib/menu-xdg/applications/menu-xdg/kruler.desktop
ksnapshot	/var/lib/menu-xdg/applications/menu-xdg/ksnapshot.desktop
kuickshow	/var/lib/menu-xdg/applications/menu-xdg/kuickshow.desktop
motion	/var/lib/menu-xdg/applications/menu-xdg/motion.desktop
oodraw	/var/lib/menu-xdg/applications/menu-xdg/openoffice.org_draw.desktop
ooimpress	/var/lib/menu-xdg/applications/menu-xdg/openoffice.org_impress.desktop
picview	/var/lib/menu-xdg/applications/menu-xdg/picview.desktop
pixmap	/var/lib/menu-xdg/applications/menu-xdg/pixmap.desktop
price	/var/lib/menu-xdg/applications/menu-xdg/price.desktop
sced	/var/lib/menu-xdg/applications/menu-xdg/sced.desktop
SceneViewer	/var/lib/menu-xdg/applications/menu-xdg/sceneviewer.desktop
scribus	/var/lib/menu-xdg/applications/menu-xdg/scribus.desktop
sketch	/var/lib/menu-xdg/applications/menu-xdg/sketch.desktop
snowflake	/var/lib/menu-xdg/applications/menu-xdg/snowflake.desktop
sodipodi	/var/lib/menu-xdg/applications/menu-xdg/sodipodi.desktop
terraform	/var/lib/menu-xdg/applications/menu-xdg/terraform.desktop
sh	/var/lib/menu-xdg/applications/menu-xdg/text_xaos.desktop
tgif	/var/lib/menu-xdg/applications/menu-xdg/tgif.desktop
gimp-2.0	/var/lib/menu-xdg/applications/menu-xdg/the_gimp_(v2.0).desktop
tulip	/var/lib/menu-xdg/applications/menu-xdg/tulip.desktop
tuxpaint	/var/lib/menu-xdg/applications/menu-xdg/tuxpaint.desktop
vertex	/var/lib/menu-xdg/applications/menu-xdg/vertex.desktop
sh	/var/lib/menu-xdg/applications/menu-xdg/xaos.desktop
xfig	/var/lib/menu-xdg/applications/menu-xdg/xfig.desktop
xmorph	/var/lib/menu-xdg/applications/menu-xdg/xmorph.desktop
xmps	/var/lib/menu-xdg/applications/menu-xdg/xmps.desktop
xmps	/var/lib/menu-xdg/applications/menu-xdg/xmps_(gnome).desktop
/usr/bin/X11/xpaint	/var/lib/menu-xdg/applications/menu-xdg/xpaint.desktop
xsane	/var/lib/menu-xdg/applications/menu-xdg/xsane.desktop
gmfsk	/var/lib/menu-xdg/applications/menu-xdg/gmfsk.desktop
gworldclock	/var/lib/menu-xdg/applications/menu-xdg/gworldclock.desktop
hamfax	/var/lib/menu-xdg/applications/menu-xdg/hamfax.desktop
linpac	/var/lib/menu-xdg/applications/menu-xdg/linpac.desktop
twclock	/var/lib/menu-xdg/applications/menu-xdg/twclock.desktop
xastir	/var/lib/menu-xdg/applications/menu-xdg/xastir.desktop
xcall	/var/lib/menu-xdg/applications/menu-xdg/xcall.desktop
bc	/var/lib/menu-xdg/applications/menu-xdg/bc.desktop
burlap	/var/lib/menu-xdg/applications/menu-xdg/burlap.desktop
gcalctool	/var/lib/menu-xdg/applications/menu-xdg/calctool.desktop
dc	/var/lib/menu-xdg/applications/menu-xdg/dc.desktop
fudgit	/var/lib/menu-xdg/applications/menu-xdg/fudgit.desktop
geomview	/var/lib/menu-xdg/applications/menu-xdg/geomview.desktop
gnumeric	/var/lib/menu-xdg/applications/menu-xdg/gnumeric.desktop
gstar	/var/lib/menu-xdg/applications/menu-xdg/gstar.desktop
kbruch	/var/lib/menu-xdg/applications/menu-xdg/kbruch.desktop
kcalc	/var/lib/menu-xdg/applications/menu-xdg/kcalc.desktop
kchart	/var/lib/menu-xdg/applications/menu-xdg/kchart.desktop
kformula	/var/lib/menu-xdg/applications/menu-xdg/kformula.desktop
kgeo	/var/lib/menu-xdg/applications/menu-xdg/kgeo.desktop
kig	/var/lib/menu-xdg/applications/menu-xdg/kig.desktop
kmplot	/var/lib/menu-xdg/applications/menu-xdg/kmplot.desktop
kpercentage	/var/lib/menu-xdg/applications/menu-xdg/kpercentage.desktop
kspread	/var/lib/menu-xdg/applications/menu-xdg/kspread.desktop
oocalc	/var/lib/menu-xdg/applications/menu-xdg/openoffice.org_calc.desktop
oomath	/var/lib/menu-xdg/applications/menu-xdg/openoffice.org_math.desktop
openuniverse	/var/lib/menu-xdg/applications/menu-xdg/openuniverse.desktop
perldl	/var/lib/menu-xdg/applications/menu-xdg/perldl.desktop
rcalc	/var/lib/menu-xdg/applications/menu-xdg/rcalc.desktop
rcalc	/var/lib/menu-xdg/applications/menu-xdg/rcalc_(text).desktop
siag	/var/lib/menu-xdg/applications/menu-xdg/siag.desktop
tsiag	/var/lib/menu-xdg/applications/menu-xdg/siag_(text_mode).desktop
velvet	/var/lib/menu-xdg/applications/menu-xdg/velvet.desktop
xabacus	/var/lib/menu-xdg/applications/menu-xdg/xabacus.desktop
xcalc	/var/lib/menu-xdg/applications/menu-xdg/xcalc.desktop
xmaxima	/var/lib/menu-xdg/applications/menu-xdg/xmaxima.desktop
amaya	/var/lib/menu-xdg/applications/menu-xdg/amaya.desktop
amule	/var/lib/menu-xdg/applications/menu-xdg/amule.desktop
amulewebDLG	/var/lib/menu-xdg/applications/menu-xdg/amule_webserver_control.desktop
dillo	/var/lib/menu-xdg/applications/menu-xdg/dillo.desktop
driftnet	/var/lib/menu-xdg/applications/menu-xdg/driftnet.desktop
everybuddy	/var/lib/menu-xdg/applications/menu-xdg/everybuddy.desktop
fwbuilder	/var/lib/menu-xdg/applications/menu-xdg/firewall_builder.desktop
gipsc	/var/lib/menu-xdg/applications/menu-xdg/gipsc.desktop
gnapster	/var/lib/menu-xdg/applications/menu-xdg/gnapster.desktop
gnomemeeting	/var/lib/menu-xdg/applications/menu-xdg/gnomemeeting.desktop
gtk-gnutella	/var/lib/menu-xdg/applications/menu-xdg/gtk-gnutella.desktop
su-to-root	/var/lib/menu-xdg/applications/menu-xdg/iptraf.desktop
kdict	/var/lib/menu-xdg/applications/menu-xdg/kdict.desktop
kget	/var/lib/menu-xdg/applications/menu-xdg/kget.desktop
kit	/var/lib/menu-xdg/applications/menu-xdg/kit.desktop
kmail	/var/lib/menu-xdg/applications/menu-xdg/kmail.desktop
kmailcvt	/var/lib/menu-xdg/applications/menu-xdg/kmail_kab_import_tool.desktop
appletproxy	/var/lib/menu-xdg/applications/menu-xdg/knewsticker.desktop
knode	/var/lib/menu-xdg/applications/menu-xdg/knode.desktop
konqueror	/var/lib/menu-xdg/applications/menu-xdg/konqueror.desktop
kopete	/var/lib/menu-xdg/applications/menu-xdg/kopete.desktop
korn	/var/lib/menu-xdg/applications/menu-xdg/korn.desktop
kppp	/var/lib/menu-xdg/applications/menu-xdg/kppp.desktop
kppplogview	/var/lib/menu-xdg/applications/menu-xdg/kppp_-_logview.desktop
krdc	/var/lib/menu-xdg/applications/menu-xdg/krdc.desktop
krfb	/var/lib/menu-xdg/applications/menu-xdg/krfb.desktop
ksig	/var/lib/menu-xdg/applications/menu-xdg/ksig.desktop
ksirc	/var/lib/menu-xdg/applications/menu-xdg/ksirc.desktop
kwifimanager	/var/lib/menu-xdg/applications/menu-xdg/kwifimanager.desktop
LinNeighborhood	/var/lib/menu-xdg/applications/menu-xdg/linneighborhood.desktop
lynx	/var/lib/menu-xdg/applications/menu-xdg/lynx.desktop
minicom	/var/lib/menu-xdg/applications/menu-xdg/minicom.desktop
xminicom	/var/lib/menu-xdg/applications/menu-xdg/minicom_(x11).desktop
firefox	/var/lib/menu-xdg/applications/menu-xdg/mozilla_firefox.desktop
mozilla-thunderbird	/var/lib/menu-xdg/applications/menu-xdg/mozilla_thunderbird.desktop
mutt	/var/lib/menu-xdg/applications/menu-xdg/mutt.desktop
ncftp3	/var/lib/menu-xdg/applications/menu-xdg/ncftp.desktop
gnome-netinfo	/var/lib/menu-xdg/applications/menu-xdg/network_information.desktop
pan	/var/lib/menu-xdg/applications/menu-xdg/pan.desktop
gnome-remote-desktop	/var/lib/menu-xdg/applications/menu-xdg/remote_desktop.desktop
gnome-remote-shell	/var/lib/menu-xdg/applications/menu-xdg/remote_shell.desktop
smb4k	/var/lib/menu-xdg/applications/menu-xdg/samba_for_kde.desktop
sdr	/var/lib/menu-xdg/applications/menu-xdg/sdr.desktop
telnet	/var/lib/menu-xdg/applications/menu-xdg/telnet.desktop
tsclient	/var/lib/menu-xdg/applications/menu-xdg/terminal_server_client.desktop
tkchooser	/var/lib/menu-xdg/applications/menu-xdg/tkchooser.desktop
vrwave	/var/lib/menu-xdg/applications/menu-xdg/vrwave_vrml_browser.desktop
w3m	/var/lib/menu-xdg/applications/menu-xdg/w3m.desktop
xchat	/var/lib/menu-xdg/applications/menu-xdg/x_chat.desktop
xbiff	/var/lib/menu-xdg/applications/menu-xdg/xbiff.desktop
xrealvncviewer	/var/lib/menu-xdg/applications/menu-xdg/xvncviewer.desktop
argouml	/var/lib/menu-xdg/applications/menu-xdg/argouml.desktop
autoproject	/var/lib/menu-xdg/applications/menu-xdg/autoproject.desktop
cervisia	/var/lib/menu-xdg/applications/menu-xdg/cervisia.desktop
lisp	/var/lib/menu-xdg/applications/menu-xdg/cmucl_normal_image.desktop
ddd	/var/lib/menu-xdg/applications/menu-xdg/data_display_debugger.desktop
eclipse	/var/lib/menu-xdg/applications/menu-xdg/eclipse.desktop
elk	/var/lib/menu-xdg/applications/menu-xdg/elk.desktop
fluid	/var/lib/menu-xdg/applications/menu-xdg/fluid.desktop
gide	/var/lib/menu-xdg/applications/menu-xdg/gide.desktop
glade-2	/var/lib/menu-xdg/applications/menu-xdg/glade_2.desktop
sh	/var/lib/menu-xdg/applications/menu-xdg/gorm.desktop
guile-1.6	/var/lib/menu-xdg/applications/menu-xdg/guile_1.6.desktop
guile1.4	/var/lib/menu-xdg/applications/menu-xdg/guile_scheme_1.4.desktop
insight	/var/lib/menu-xdg/applications/menu-xdg/insight.desktop
jython	/var/lib/menu-xdg/applications/menu-xdg/jython.desktop
kbabel	/var/lib/menu-xdg/applications/menu-xdg/kbabel.desktop
catalogmanager	/var/lib/menu-xdg/applications/menu-xdg/kbabel_catalog_manager.desktop
kbabeldict	/var/lib/menu-xdg/applications/menu-xdg/kbabel_dictionary.desktop
kbugbuster	/var/lib/menu-xdg/applications/menu-xdg/kbugbuster.desktop
kcachegrind	/var/lib/menu-xdg/applications/menu-xdg/kcachegrind.desktop
kdevelop3	/var/lib/menu-xdg/applications/menu-xdg/kdevelop_3.0.desktop
kodos	/var/lib/menu-xdg/applications/menu-xdg/kodos.desktop
kompare	/var/lib/menu-xdg/applications/menu-xdg/kompare.desktop
kuiviewer	/var/lib/menu-xdg/applications/menu-xdg/kuiviewer.desktop
pike7.2	/var/lib/menu-xdg/applications/menu-xdg/pike_7.2_hilfe.desktop
pycrust	/var/lib/menu-xdg/applications/menu-xdg/pycrust.desktop
pyshell	/var/lib/menu-xdg/applications/menu-xdg/pyshell.desktop
python2.1	/var/lib/menu-xdg/applications/menu-xdg/python_(v2.1).desktop
python2.2	/var/lib/menu-xdg/applications/menu-xdg/python_(v2.2).desktop
python2.3	/var/lib/menu-xdg/applications/menu-xdg/python_(v2.3).desktop
designer-qt3	/var/lib/menu-xdg/applications/menu-xdg/qt_designer.desktop
irb1.8	/var/lib/menu-xdg/applications/menu-xdg/ruby_(irb1.8).desktop
tclsh8.0	/var/lib/menu-xdg/applications/menu-xdg/tclsh8.0.desktop
tclsh8.2	/var/lib/menu-xdg/applications/menu-xdg/tclsh8.2.desktop
tclsh8.3	/var/lib/menu-xdg/applications/menu-xdg/tclsh8.3.desktop
tclsh8.4	/var/lib/menu-xdg/applications/menu-xdg/tclsh8.4.desktop
tkcvs	/var/lib/menu-xdg/applications/menu-xdg/tkcvs.desktop
tkdiff	/var/lib/menu-xdg/applications/menu-xdg/tkdiff.desktop
wish8.0	/var/lib/menu-xdg/applications/menu-xdg/tkwish8.0.desktop
wish8.2	/var/lib/menu-xdg/applications/menu-xdg/tkwish8.2.desktop
x-terminal-emulator	/var/lib/menu-xdg/applications/menu-xdg/tkwish8.3.desktop
x-terminal-emulator	/var/lib/menu-xdg/applications/menu-xdg/tkwish8.4.desktop
xrced	/var/lib/menu-xdg/applications/menu-xdg/xrced.desktop
vibrate	/var/lib/menu-xdg/applications/menu-xdg/asn2asn.desktop
vibrate	/var/lib/menu-xdg/applications/menu-xdg/asn2ff.desktop
vibrate	/var/lib/menu-xdg/applications/menu-xdg/asn2gb.desktop
vibrate	/var/lib/menu-xdg/applications/menu-xdg/asn2xml.desktop
vibrate	/var/lib/menu-xdg/applications/menu-xdg/asndhuff.desktop
vibrate	/var/lib/menu-xdg/applications/menu-xdg/bl2seq.desktop
vibrate	/var/lib/menu-xdg/applications/menu-xdg/blast2.desktop
vibrate	/var/lib/menu-xdg/applications/menu-xdg/blastall.desktop
vibrate	/var/lib/menu-xdg/applications/menu-xdg/blastcl3.desktop
vibrate	/var/lib/menu-xdg/applications/menu-xdg/blastclust.desktop
vibrate	/var/lib/menu-xdg/applications/menu-xdg/blastpgp.desktop
vibrate	/var/lib/menu-xdg/applications/menu-xdg/checksub.desktop
Cn3D-3.0	/var/lib/menu-xdg/applications/menu-xdg/cn3d-3.0.desktop
vibrate	/var/lib/menu-xdg/applications/menu-xdg/copymat.desktop
ddv	/var/lib/menu-xdg/applications/menu-xdg/ddv.desktop
vibrate	/var/lib/menu-xdg/applications/menu-xdg/debruijn.desktop
vibrate	/var/lib/menu-xdg/applications/menu-xdg/entrcmd.desktop
Nentrez	/var/lib/menu-xdg/applications/menu-xdg/entrez.desktop
netentcf	/var/lib/menu-xdg/applications/menu-xdg/entrez_net_config.desktop
entrez2	/var/lib/menu-xdg/applications/menu-xdg/entrez2.desktop
vibrate	/var/lib/menu-xdg/applications/menu-xdg/fa2htgs.desktop
vibrate	/var/lib/menu-xdg/applications/menu-xdg/fastacmd.desktop
vibrate	/var/lib/menu-xdg/applications/menu-xdg/findspl.desktop
vibrate	/var/lib/menu-xdg/applications/menu-xdg/formatdb.desktop
garlic	/var/lib/menu-xdg/applications/menu-xdg/garlic.desktop
vibrate	/var/lib/menu-xdg/applications/menu-xdg/gbseqget.desktop
vibrate	/var/lib/menu-xdg/applications/menu-xdg/getfeat.desktop
vibrate	/var/lib/menu-xdg/applications/menu-xdg/getmesh.desktop
vibrate	/var/lib/menu-xdg/applications/menu-xdg/getpub.desktop
vibrate	/var/lib/menu-xdg/applications/menu-xdg/gil2bin.desktop
gperiodic	/var/lib/menu-xdg/applications/menu-xdg/gperiodic.desktop
vibrate	/var/lib/menu-xdg/applications/menu-xdg/idfetch.desktop
vibrate	/var/lib/menu-xdg/applications/menu-xdg/impala.desktop
vibrate	/var/lib/menu-xdg/applications/menu-xdg/indexpub.desktop
kalzium	/var/lib/menu-xdg/applications/menu-xdg/kalzium.desktop
kstars	/var/lib/menu-xdg/applications/menu-xdg/kstars.desktop
kxterm	/var/lib/menu-xdg/applications/menu-xdg/kxterm.desktop
vibrate	/var/lib/menu-xdg/applications/menu-xdg/makemat.desktop
vibrate	/var/lib/menu-xdg/applications/menu-xdg/makeset.desktop
vibrate	/var/lib/menu-xdg/applications/menu-xdg/megablast.desktop
njplot	/var/lib/menu-xdg/applications/menu-xdg/njplot.desktop
unrooted	/var/lib/menu-xdg/applications/menu-xdg/njplot_unrooted.desktop
rasmol	/var/lib/menu-xdg/applications/menu-xdg/rasmol.desktop
vibrate	/var/lib/menu-xdg/applications/menu-xdg/rpsblast.desktop
vibrate	/var/lib/menu-xdg/applications/menu-xdg/seedtop.desktop
Psequin	/var/lib/menu-xdg/applications/menu-xdg/sequin.desktop
starplot	/var/lib/menu-xdg/applications/menu-xdg/starplot.desktop
vibrate	/var/lib/menu-xdg/applications/menu-xdg/tbl2asn.desktop
udv	/var/lib/menu-xdg/applications/menu-xdg/udv.desktop
vibrate	/var/lib/menu-xdg/applications/menu-xdg/vecscreen.desktop
bash	/var/lib/menu-xdg/applications/menu-xdg/bash.desktop
ksh	/var/lib/menu-xdg/applications/menu-xdg/ksh.desktop
sh	/var/lib/menu-xdg/applications/menu-xdg/sh.desktop
tcsh	/var/lib/menu-xdg/applications/menu-xdg/tcsh.desktop
aconnectgui	/var/lib/menu-xdg/applications/menu-xdg/aconnectgui.desktop
/usr/bin/X11/xterm	/var/lib/menu-xdg/applications/menu-xdg/ardour_gtk.desktop
artsbuilder	/var/lib/menu-xdg/applications/menu-xdg/arts_builder.desktop
artscontrol	/var/lib/menu-xdg/applications/menu-xdg/arts_control.desktop
audacity	/var/lib/menu-xdg/applications/menu-xdg/audacity.desktop
vkeybd	/var/lib/menu-xdg/applications/menu-xdg/awe_virtual_keyboard.desktop
bcast2000	/var/lib/menu-xdg/applications/menu-xdg/broadcast2000.desktop
/usr/bin/X11/xterm	/var/lib/menu-xdg/applications/menu-xdg/cam.desktop
cecilia	/var/lib/menu-xdg/applications/menu-xdg/cecilia.desktop
ceres3	/var/lib/menu-xdg/applications/menu-xdg/ceres3.desktop
cglame	/var/lib/menu-xdg/applications/menu-xdg/cglame.desktop
ecasound	/var/lib/menu-xdg/applications/menu-xdg/ecasound.desktop
extace	/var/lib/menu-xdg/applications/menu-xdg/extace.desktop
freebirth	/var/lib/menu-xdg/applications/menu-xdg/freebirth.desktop
gamix	/var/lib/menu-xdg/applications/menu-xdg/gamix.desktop
gcd	/var/lib/menu-xdg/applications/menu-xdg/gcd.desktop
glcthugha	/var/lib/menu-xdg/applications/menu-xdg/gl_cthugha.desktop
glame	/var/lib/menu-xdg/applications/menu-xdg/glame.desktop
gnome-volume-control	/var/lib/menu-xdg/applications/menu-xdg/gmix_(gnome_2.0_mixer).desktop
gnome-cd	/var/lib/menu-xdg/applications/menu-xdg/gnome-cd_(gnome_2.0_cd_player).desktop
gnomp3	/var/lib/menu-xdg/applications/menu-xdg/gnomp3.desktop
gom-ct	/var/lib/menu-xdg/applications/menu-xdg/gom_(terminal).desktop
gnome-sound-recorder	/var/lib/menu-xdg/applications/menu-xdg/grecord_(gnome_2.0_recorder).desktop
grip	/var/lib/menu-xdg/applications/menu-xdg/grip.desktop
gsox	/var/lib/menu-xdg/applications/menu-xdg/gsox.desktop
gtick	/var/lib/menu-xdg/applications/menu-xdg/gtick.desktop
horgand	/var/lib/menu-xdg/applications/menu-xdg/horgand.desktop
id3ren	/var/lib/menu-xdg/applications/menu-xdg/id3ren.desktop
juk	/var/lib/menu-xdg/applications/menu-xdg/juk_music_player.desktop
kaboodle	/var/lib/menu-xdg/applications/menu-xdg/kaboodle.desktop
kaudiocreator	/var/lib/menu-xdg/applications/menu-xdg/kaudiocreator.desktop
kmid	/var/lib/menu-xdg/applications/menu-xdg/kmid.desktop
kmidi	/var/lib/menu-xdg/applications/menu-xdg/kmidi.desktop
kmix	/var/lib/menu-xdg/applications/menu-xdg/kmix.desktop
krec	/var/lib/menu-xdg/applications/menu-xdg/krec.desktop
kscd	/var/lib/menu-xdg/applications/menu-xdg/kscd.desktop
mammut	/var/lib/menu-xdg/applications/menu-xdg/mammut.desktop
/usr/bin/X11/mix	/var/lib/menu-xdg/applications/menu-xdg/mix.desktop
/usr/X11R6/bin/Mixer.app	/var/lib/menu-xdg/applications/menu-xdg/mixer.app.desktop
mixmagic	/var/lib/menu-xdg/applications/menu-xdg/mixmagic.desktop
mxv	/var/lib/menu-xdg/applications/menu-xdg/mixviews.desktop
muse	/var/lib/menu-xdg/applications/menu-xdg/muse.desktop
music-librarian	/var/lib/menu-xdg/applications/menu-xdg/music_librarian.desktop
noatun	/var/lib/menu-xdg/applications/menu-xdg/noatun.desktop
noteedit	/var/lib/menu-xdg/applications/menu-xdg/noteedit.desktop
qrt	/var/lib/menu-xdg/applications/menu-xdg/qrt.desktop
qsynth	/var/lib/menu-xdg/applications/menu-xdg/qsynth.desktop
rezound	/var/lib/menu-xdg/applications/menu-xdg/rezound.desktop
rosegarden4	/var/lib/menu-xdg/applications/menu-xdg/rosegarden4.desktop
shaketracker	/var/lib/menu-xdg/applications/menu-xdg/shacketracker.desktop
smurf	/var/lib/menu-xdg/applications/menu-xdg/smurf.desktop
snd	/var/lib/menu-xdg/applications/menu-xdg/snd.desktop
soundtracker	/var/lib/menu-xdg/applications/menu-xdg/soundtracker.desktop
GUIBowedBar	/var/lib/menu-xdg/applications/menu-xdg/bowedbar.desktop
GUIDrums	/var/lib/menu-xdg/applications/menu-xdg/drums.desktop
GUIeffects	/var/lib/menu-xdg/applications/menu-xdg/effects.desktop
GUIModal	/var/lib/menu-xdg/applications/menu-xdg/modal.desktop
GUIPhysical	/var/lib/menu-xdg/applications/menu-xdg/physical.desktop
GUIRaga	/var/lib/menu-xdg/applications/menu-xdg/ragamatic.desktop
GUIShakers	/var/lib/menu-xdg/applications/menu-xdg/shakers.desktop
GUIVoice	/var/lib/menu-xdg/applications/menu-xdg/voice.desktop
sweep	/var/lib/menu-xdg/applications/menu-xdg/sweep.desktop
synaesthesia	/var/lib/menu-xdg/applications/menu-xdg/synaesthesia_(cd_input).desktop
synaesthesia	/var/lib/menu-xdg/applications/menu-xdg/synaesthesia_(esd_input).desktop
synaesthesia	/var/lib/menu-xdg/applications/menu-xdg/synaesthesia_(line_input).desktop
terminatorX	/var/lib/menu-xdg/applications/menu-xdg/terminatorx.desktop
timidity	/var/lib/menu-xdg/applications/menu-xdg/timidity++.desktop
tk707	/var/lib/menu-xdg/applications/menu-xdg/tk-707.desktop
tkmixer	/var/lib/menu-xdg/applications/menu-xdg/tkmixer.desktop
vumeter	/var/lib/menu-xdg/applications/menu-xdg/vumeter_(gnome_2.0_volume_meter).desktop
wavesurfer	/var/lib/menu-xdg/applications/menu-xdg/wavesurfer.desktop
wmmixer	/var/lib/menu-xdg/applications/menu-xdg/wmmixer.desktop
wmmixer	/var/lib/menu-xdg/applications/menu-xdg/wmmixer_(docked).desktop
wmxmms	/var/lib/menu-xdg/applications/menu-xdg/wmxmms.desktop
workman	/var/lib/menu-xdg/applications/menu-xdg/workman.desktop
xcthugha	/var/lib/menu-xdg/applications/menu-xdg/x_cthugha.desktop
xfreecd	/var/lib/menu-xdg/applications/menu-xdg/xfreecd.desktop
xmcd	/var/lib/menu-xdg/applications/menu-xdg/xmcd.desktop
/usr/bin/X11/xmix	/var/lib/menu-xdg/applications/menu-xdg/xmix.desktop
xmixer	/var/lib/menu-xdg/applications/menu-xdg/xmixer.desktop
xmms	/var/lib/menu-xdg/applications/menu-xdg/xmms.desktop
xplaycd	/var/lib/menu-xdg/applications/menu-xdg/xplaycd.desktop
xwave	/var/lib/menu-xdg/applications/menu-xdg/xwave.desktop
su-to-root	/var/lib/menu-xdg/applications/menu-xdg/alsaconf.desktop
su-to-root	/var/lib/menu-xdg/applications/menu-xdg/gpm-config.desktop
kdesu	/var/lib/menu-xdg/applications/menu-xdg/lilo-config.desktop
su-to-root	/var/lib/menu-xdg/applications/menu-xdg/orphaner_(all).desktop
su-to-root	/var/lib/menu-xdg/applications/menu-xdg/orphaner_(libs).desktop
su-to-root	/var/lib/menu-xdg/applications/menu-xdg/orphaner_-_editkeep.desktop
su-to-root	/var/lib/menu-xdg/applications/menu-xdg/pppconfig.desktop
aptitude	/var/lib/menu-xdg/applications/menu-xdg/aptitude.desktop
gvidm	/var/lib/menu-xdg/applications/menu-xdg/change_x11_resolution_(gvidm).desktop
fsview	/var/lib/menu-xdg/applications/menu-xdg/fsview.desktop
gdmflexiserver	/var/lib/menu-xdg/applications/menu-xdg/gdm_flexiserver.desktop
gdmflexiserver	/var/lib/menu-xdg/applications/menu-xdg/gdm_flexiserver_in_xnest.desktop
gdmphotosetup	/var/lib/menu-xdg/applications/menu-xdg/gdm_photo_setup.desktop
gksu	/var/lib/menu-xdg/applications/menu-xdg/gdm_setup.desktop
gnome-control-center	/var/lib/menu-xdg/applications/menu-xdg/gnome_control_center.desktop
bug-buddy	/var/lib/menu-xdg/applications/menu-xdg/gnome_bug_report_tool.desktop
gfloppy	/var/lib/menu-xdg/applications/menu-xdg/gnome_floppy_formatter.desktop
gnome-system-log	/var/lib/menu-xdg/applications/menu-xdg/gnome_log_viewer.desktop
gnome-system-monitor	/var/lib/menu-xdg/applications/menu-xdg/gnome_system_monitor.desktop
gps	/var/lib/menu-xdg/applications/menu-xdg/gps.desktop
gxset	/var/lib/menu-xdg/applications/menu-xdg/gtk_xset.desktop
gtkrecover	/var/lib/menu-xdg/applications/menu-xdg/gtkrecover.desktop
openapp	/var/lib/menu-xdg/applications/menu-xdg/gworkspace.app.desktop
gxproc	/var/lib/menu-xdg/applications/menu-xdg/gxproc.desktop
kappfinder	/var/lib/menu-xdg/applications/menu-xdg/kappfinder.desktop
kcmshell	/var/lib/menu-xdg/applications/menu-xdg/kcmlinuz.desktop
kcontrol	/var/lib/menu-xdg/applications/menu-xdg/kcontrol.desktop
kdat	/var/lib/menu-xdg/applications/menu-xdg/kdat.desktop
kdcop	/var/lib/menu-xdg/applications/menu-xdg/kdcop.desktop
kpackage	/var/lib/menu-xdg/applications/menu-xdg/kde_package_manager.desktop
secpolicy	/var/lib/menu-xdg/applications/menu-xdg/kde_pam_security_policy_editor.desktop
ksysguard	/var/lib/menu-xdg/applications/menu-xdg/kde_system_guard.desktop
kpm	/var/lib/menu-xdg/applications/menu-xdg/kde_system_guard_-_process_table.desktop
ksysv	/var/lib/menu-xdg/applications/menu-xdg/kde_sysv-init_editor.desktop
kcron	/var/lib/menu-xdg/applications/menu-xdg/kde_task_scheduler.desktop
kuser	/var/lib/menu-xdg/applications/menu-xdg/kde_user_manager.desktop
kdebugdialog	/var/lib/menu-xdg/applications/menu-xdg/kdebugdialog.desktop
kdepasswd	/var/lib/menu-xdg/applications/menu-xdg/kdepasswd.desktop
kdeprintfax	/var/lib/menu-xdg/applications/menu-xdg/kdeprintfax.desktop
kdf	/var/lib/menu-xdg/applications/menu-xdg/kdiskfree.desktop
keditbookmarks	/var/lib/menu-xdg/applications/menu-xdg/keditbookmarks.desktop
kfind	/var/lib/menu-xdg/applications/menu-xdg/kfind.desktop
kfloppy	/var/lib/menu-xdg/applications/menu-xdg/kfloppy.desktop
kicker	/var/lib/menu-xdg/applications/menu-xdg/kicker.desktop
kjobviewer	/var/lib/menu-xdg/applications/menu-xdg/kjobviewer.desktop
kmenuedit	/var/lib/menu-xdg/applications/menu-xdg/kmenuedit.desktop
kpersonalizer	/var/lib/menu-xdg/applications/menu-xdg/kpersonalizer.desktop
kprinter	/var/lib/menu-xdg/applications/menu-xdg/kprinter.desktop
kwikdisk	/var/lib/menu-xdg/applications/menu-xdg/kwikdisk.desktop
loadmeter	/var/lib/menu-xdg/applications/menu-xdg/loadmeter.desktop
moodss	/var/lib/menu-xdg/applications/menu-xdg/moodss.desktop
mount.app	/var/lib/menu-xdg/applications/menu-xdg/mountapp.desktop
nautilus	/var/lib/menu-xdg/applications/menu-xdg/nautilus.desktop
netwatch	/var/lib/menu-xdg/applications/menu-xdg/netwatch.desktop
netload	/var/lib/menu-xdg/applications/menu-xdg/network_load_on_ppp0.desktop
oopadmin	/var/lib/menu-xdg/applications/menu-xdg/openoffice.org_printer_administration.desktop
/usr/lib/openoffice/program/setup	/var/lib/menu-xdg/applications/menu-xdg/openoffice.org_setup.desktop
x-terminal-emulator	/var/lib/menu-xdg/applications/menu-xdg/pstree.desktop
su-to-root	/var/lib/menu-xdg/applications/menu-xdg/recover.desktop
reportbug	/var/lib/menu-xdg/applications/menu-xdg/reportbug.desktop
gksuexec	/var/lib/menu-xdg/applications/menu-xdg/run_as_different_user_(gksu).desktop
si	/var/lib/menu-xdg/applications/menu-xdg/si.desktop
statnet	/var/lib/menu-xdg/applications/menu-xdg/statnet.desktop
su-to-root	/var/lib/menu-xdg/applications/menu-xdg/synaptic_package_manager.desktop
su-to-root	/var/lib/menu-xdg/applications/menu-xdg/task_selector.desktop
/usr/bin/texconfig	/var/lib/menu-xdg/applications/menu-xdg/texconfig.desktop
top	/var/lib/menu-xdg/applications/menu-xdg/top.desktop
trafshow	/var/lib/menu-xdg/applications/menu-xdg/trafshow.desktop
wmbubble	/var/lib/menu-xdg/applications/menu-xdg/wmbubble.desktop
wmsensors	/var/lib/menu-xdg/applications/menu-xdg/wmsensors.desktop
wmsmpmon	/var/lib/menu-xdg/applications/menu-xdg/wmsmpmon.desktop
wmtop	/var/lib/menu-xdg/applications/menu-xdg/wmtop.desktop
gksu	/var/lib/menu-xdg/applications/menu-xdg/x-terminal_as_root_(gksu).desktop
xconsole	/var/lib/menu-xdg/applications/menu-xdg/xconsole.desktop
sh	/var/lib/menu-xdg/applications/menu-xdg/xdiskusage.desktop
xfilequery	/var/lib/menu-xdg/applications/menu-xdg/xfq_rpm_manager.desktop
xload	/var/lib/menu-xdg/applications/menu-xdg/xload.desktop
xlogmaster	/var/lib/menu-xdg/applications/menu-xdg/xlogmaster.desktop
xlogmaster	/var/lib/menu-xdg/applications/menu-xdg/xlogmaster_(system).desktop
xtraceroute	/var/lib/menu-xdg/applications/menu-xdg/xt.desktop
xvidtune	/var/lib/menu-xdg/applications/menu-xdg/xvidtune.desktop
gpsman	/var/lib/menu-xdg/applications/menu-xdg/gpsman.desktop
tkgate	/var/lib/menu-xdg/applications/menu-xdg/tkgate.desktop
wordinspect	/var/lib/menu-xdg/applications/menu-xdg/dict_client.desktop
sh	/var/lib/menu-xdg/applications/menu-xdg/fortune.desktop
gnome-dictionary	/var/lib/menu-xdg/applications/menu-xdg/gnome_dictionary.desktop
htmldoc	/var/lib/menu-xdg/applications/menu-xdg/htmldoc.desktop
gucharmap	/var/lib/menu-xdg/applications/menu-xdg/unicode_character_map.desktop
ark	/var/lib/menu-xdg/applications/menu-xdg/ark.desktop
dasher	/var/lib/menu-xdg/applications/menu-xdg/dasher_text_entry.desktop
DataManager	/var/lib/menu-xdg/applications/menu-xdg/datamanager.desktop
dclock	/var/lib/menu-xdg/applications/menu-xdg/dclock.desktop
dfm	/var/lib/menu-xdg/applications/menu-xdg/desktop_file_manager.desktop
ding	/var/lib/menu-xdg/applications/menu-xdg/ding.desktop
editres	/var/lib/menu-xdg/applications/menu-xdg/editres.desktop
emelfm	/var/lib/menu-xdg/applications/menu-xdg/emelfm.desktop
file-roller	/var/lib/menu-xdg/applications/menu-xdg/file-roller.desktop
fookb-wmaker	/var/lib/menu-xdg/applications/menu-xdg/fookb-wmaker.desktop
gcombust	/var/lib/menu-xdg/applications/menu-xdg/gcombust.desktop
gcrontab	/var/lib/menu-xdg/applications/menu-xdg/gcrontab.desktop
gnomecard	/var/lib/menu-xdg/applications/menu-xdg/gnome_address_book.desktop
gnomecal	/var/lib/menu-xdg/applications/menu-xdg/gnome_calendar.desktop
gcm	/var/lib/menu-xdg/applications/menu-xdg/gnome_clipboard_manager.desktop
gnome-search-tool	/var/lib/menu-xdg/applications/menu-xdg/gnome_search_tool.desktop
gnucash	/var/lib/menu-xdg/applications/menu-xdg/gnucash.desktop
gODBCConfig	/var/lib/menu-xdg/applications/menu-xdg/godbcconfig.desktop
gramps	/var/lib/menu-xdg/applications/menu-xdg/gramps.desktop
gtktrain	/var/lib/menu-xdg/applications/menu-xdg/gtktrain.desktop
guitar	/var/lib/menu-xdg/applications/menu-xdg/guitar.desktop
iceconf	/var/lib/menu-xdg/applications/menu-xdg/iceconf.desktop
jscalibrator	/var/lib/menu-xdg/applications/menu-xdg/joystick_calibration.desktop
kaddressbook	/var/lib/menu-xdg/applications/menu-xdg/kaddressbook.desktop
kalarm	/var/lib/menu-xdg/applications/menu-xdg/kalarm.desktop
kandy	/var/lib/menu-xdg/applications/menu-xdg/kandy.desktop
karm	/var/lib/menu-xdg/applications/menu-xdg/karm.desktop
kcharselect	/var/lib/menu-xdg/applications/menu-xdg/kcharselect.desktop
kgpg	/var/lib/menu-xdg/applications/menu-xdg/kgpg.desktop
khexedit	/var/lib/menu-xdg/applications/menu-xdg/khexedit.desktop
kivio	/var/lib/menu-xdg/applications/menu-xdg/kivio.desktop
kjots	/var/lib/menu-xdg/applications/menu-xdg/kjots.desktop
klipper	/var/lib/menu-xdg/applications/menu-xdg/klipper.desktop
knotes	/var/lib/menu-xdg/applications/menu-xdg/knotes.desktop
koshell	/var/lib/menu-xdg/applications/menu-xdg/koffice_workspace.desktop
kmdr-editor	/var/lib/menu-xdg/applications/menu-xdg/kommander_editor.desktop
kontact	/var/lib/menu-xdg/applications/menu-xdg/kontact.desktop
korganizer	/var/lib/menu-xdg/applications/menu-xdg/korganizer.desktop
kpager	/var/lib/menu-xdg/applications/menu-xdg/kpager.desktop
kpalmdoc	/var/lib/menu-xdg/applications/menu-xdg/kpalmdoc.desktop
kpilot	/var/lib/menu-xdg/applications/menu-xdg/kpilot.desktop
kpresenter	/var/lib/menu-xdg/applications/menu-xdg/kpresenter.desktop
kregexpeditor	/var/lib/menu-xdg/applications/menu-xdg/kregexpeditor.desktop
ksync	/var/lib/menu-xdg/applications/menu-xdg/ksync.desktop
kthesaurus	/var/lib/menu-xdg/applications/menu-xdg/kthesaurus.desktop
ktimer	/var/lib/menu-xdg/applications/menu-xdg/ktimer.desktop
ktip	/var/lib/menu-xdg/applications/menu-xdg/ktip.desktop
ktnef	/var/lib/menu-xdg/applications/menu-xdg/ktnef.desktop
kugar	/var/lib/menu-xdg/applications/menu-xdg/kugar.desktop
kudesigner	/var/lib/menu-xdg/applications/menu-xdg/kugar_designer.desktop
mc	/var/lib/menu-xdg/applications/menu-xdg/mc.desktop
nonlock	/var/lib/menu-xdg/applications/menu-xdg/nonlock.desktop
oclock	/var/lib/menu-xdg/applications/menu-xdg/oclock.desktop
ODBCConfig	/var/lib/menu-xdg/applications/menu-xdg/odbcconfig.desktop
odbctest	/var/lib/menu-xdg/applications/menu-xdg/odbctest.desktop
qps	/var/lib/menu-xdg/applications/menu-xdg/qps.desktop
/usr/bin/X11/regexplorer	/var/lib/menu-xdg/applications/menu-xdg/regexplorer.desktop
texfind	/var/lib/menu-xdg/applications/menu-xdg/texfind.desktop
dotfile	/var/lib/menu-xdg/applications/menu-xdg/the_dotfile_generator.desktop
unclutter	/var/lib/menu-xdg/applications/menu-xdg/unclutter_-_start.desktop
killall	/var/lib/menu-xdg/applications/menu-xdg/unclutter_-_stop.desktop
wmcalc	/var/lib/menu-xdg/applications/menu-xdg/wmcalc.desktop
wmCalClock	/var/lib/menu-xdg/applications/menu-xdg/wmcalclock.desktop
wmGrabImage	/var/lib/menu-xdg/applications/menu-xdg/wmgrabimage.desktop
wmMoonClock	/var/lib/menu-xdg/applications/menu-xdg/wmmoonclock.desktop
wmpinboard	/var/lib/menu-xdg/applications/menu-xdg/wmpinboard.desktop
worker	/var/lib/menu-xdg/applications/menu-xdg/worker.desktop
xwd	/var/lib/menu-xdg/applications/menu-xdg/x_window_snapshot.desktop
xcalendar	/var/lib/menu-xdg/applications/menu-xdg/xcalendar-i18n.desktop
xclipboard	/var/lib/menu-xdg/applications/menu-xdg/xclipboard.desktop
xclock	/var/lib/menu-xdg/applications/menu-xdg/xclock_(analog).desktop
xclock	/var/lib/menu-xdg/applications/menu-xdg/xclock_(digital).desktop
xcutsel	/var/lib/menu-xdg/applications/menu-xdg/xcutsel.desktop
x-terminal-emulator	/var/lib/menu-xdg/applications/menu-xdg/xev.desktop
xfe	/var/lib/menu-xdg/applications/menu-xdg/xfe_file_manager.desktop
xffm	/var/lib/menu-xdg/applications/menu-xdg/xffm4.desktop
xfontsel	/var/lib/menu-xdg/applications/menu-xdg/xfontsel.desktop
/usr/bin/X11/xkbsel-aw	/var/lib/menu-xdg/applications/menu-xdg/xkbsel.desktop
xkill	/var/lib/menu-xdg/applications/menu-xdg/xkill.desktop
xmag	/var/lib/menu-xdg/applications/menu-xdg/xmag.desktop
xrefresh	/var/lib/menu-xdg/applications/menu-xdg/xrefresh.desktop
zclock	/var/lib/menu-xdg/applications/menu-xdg/zclock.desktop
acroread	/var/lib/menu-xdg/applications/menu-xdg/acrobat_reader.desktop
alevt	/var/lib/menu-xdg/applications/menu-xdg/alevt.desktop
effectv	/var/lib/menu-xdg/applications/menu-xdg/effectv.desktop
endeavour2	/var/lib/menu-xdg/applications/menu-xdg/endeavour2_viewer.desktop
gfontview	/var/lib/menu-xdg/applications/menu-xdg/gfontview.desktop
gliv	/var/lib/menu-xdg/applications/menu-xdg/gliv.desktop
gnome-gv	/var/lib/menu-xdg/applications/menu-xdg/gnome_ghostscript_pdf_viewer.desktop
gqview	/var/lib/menu-xdg/applications/menu-xdg/gqview.desktop
gtv	/var/lib/menu-xdg/applications/menu-xdg/gtv_mpeg_player.desktop
/usr/bin/X11/gv	/var/lib/menu-xdg/applications/menu-xdg/gv.desktop
display	/var/lib/menu-xdg/applications/menu-xdg/imagemagick.desktop
kdvi	/var/lib/menu-xdg/applications/menu-xdg/kdvi.desktop
kghostview	/var/lib/menu-xdg/applications/menu-xdg/kghostview.desktop
kview	/var/lib/menu-xdg/applications/menu-xdg/kview.desktop
gmplayer	/var/lib/menu-xdg/applications/menu-xdg/mplayer.desktop
paul	/var/lib/menu-xdg/applications/menu-xdg/paul.desktop
pornview	/var/lib/menu-xdg/applications/menu-xdg/pornview.desktop
realplayer	/var/lib/menu-xdg/applications/menu-xdg/real_player.desktop
wordview	/var/lib/menu-xdg/applications/menu-xdg/wordview.desktop
xawtv	/var/lib/menu-xdg/applications/menu-xdg/xawtv.desktop
xbmbrowser	/var/lib/menu-xdg/applications/menu-xdg/xbmbrowser.desktop
xditview	/var/lib/menu-xdg/applications/menu-xdg/xditview.desktop
xdvi	/var/lib/menu-xdg/applications/menu-xdg/xdvi.desktop
xfileview	/var/lib/menu-xdg/applications/menu-xdg/xfv_file_viewer.desktop
xine	/var/lib/menu-xdg/applications/menu-xdg/xine_media_player.desktop
xmovie	/var/lib/menu-xdg/applications/menu-xdg/xmovie.desktop
kasteroids	/var/lib/menu-xdg/applications/menu-xdg/kasteroids.desktop
kbounce	/var/lib/menu-xdg/applications/menu-xdg/kde_bounce_ball_game.desktop
kolf	/var/lib/menu-xdg/applications/menu-xdg/kde_miniature_golf.desktop
ksnake	/var/lib/menu-xdg/applications/menu-xdg/kde_snake_race.desktop
kspaceduel	/var/lib/menu-xdg/applications/menu-xdg/kde_spaceduel.desktop
ktron	/var/lib/menu-xdg/applications/menu-xdg/kde_tron.desktop
kgoldrunner	/var/lib/menu-xdg/applications/menu-xdg/kgoldrunner.desktop
xasteroids	/var/lib/menu-xdg/applications/menu-xdg/xasteroids.desktop
atlantik	/var/lib/menu-xdg/applications/menu-xdg/atlantik.desktop
atlantikdesigner	/var/lib/menu-xdg/applications/menu-xdg/atlantik_designer.desktop
gnubg	/var/lib/menu-xdg/applications/menu-xdg/gnu_backgammon.desktop
kbattleship	/var/lib/menu-xdg/applications/menu-xdg/kbattleship.desktop
kbackgammon	/var/lib/menu-xdg/applications/menu-xdg/kde_backgammon.desktop
kreversi	/var/lib/menu-xdg/applications/menu-xdg/kde_reversi.desktop
kshisen	/var/lib/menu-xdg/applications/menu-xdg/kde_shisen-sho.desktop
kenolaba	/var/lib/menu-xdg/applications/menu-xdg/kenolaba.desktop
klines	/var/lib/menu-xdg/applications/menu-xdg/klines.desktop
kmahjongg	/var/lib/menu-xdg/applications/menu-xdg/kmahjongg.desktop
kwin4	/var/lib/menu-xdg/applications/menu-xdg/kwin4.desktop
gnome-freecell	/var/lib/menu-xdg/applications/menu-xdg/gnome_freecell.desktop
sol	/var/lib/menu-xdg/applications/menu-xdg/gnome_solitaire_games.desktop
megami	/var/lib/menu-xdg/applications/menu-xdg/kde_blackjack.desktop
lskat	/var/lib/menu-xdg/applications/menu-xdg/kde_lieutnant_skat.desktop
kpat	/var/lib/menu-xdg/applications/menu-xdg/kde_patience.desktop
kpoker	/var/lib/menu-xdg/applications/menu-xdg/kde_poker.desktop
kblackbox	/var/lib/menu-xdg/applications/menu-xdg/kblackbox.desktop
katomic	/var/lib/menu-xdg/applications/menu-xdg/kde_atomic_entertainment.desktop
ksame	/var/lib/menu-xdg/applications/menu-xdg/kde_samegame.desktop
ksokoban	/var/lib/menu-xdg/applications/menu-xdg/kde_sokoban.desktop
khangman	/var/lib/menu-xdg/applications/menu-xdg/khangman.desktop
klickety	/var/lib/menu-xdg/applications/menu-xdg/klickety.desktop
kmessedwords	/var/lib/menu-xdg/applications/menu-xdg/kmessedwords.desktop
kmines	/var/lib/menu-xdg/applications/menu-xdg/kmines.desktop
foobillard	/var/lib/menu-xdg/applications/menu-xdg/foobillard.desktop
kjumpingcube	/var/lib/menu-xdg/applications/menu-xdg/kjumpingcube.desktop
konquest	/var/lib/menu-xdg/applications/menu-xdg/konquest.desktop
kfouleggs	/var/lib/menu-xdg/applications/menu-xdg/kde_foul_eggs.desktop
ksirtet	/var/lib/menu-xdg/applications/menu-xdg/kde_sirtet.desktop
ksmiletris	/var/lib/menu-xdg/applications/menu-xdg/kde_smiletris.desktop
amor	/var/lib/menu-xdg/applications/menu-xdg/amor.desktop
kaphorism	/var/lib/menu-xdg/applications/menu-xdg/k_aphorisms.desktop
ktuberling	/var/lib/menu-xdg/applications/menu-xdg/kde_potato_guy.desktop
kmoon	/var/lib/menu-xdg/applications/menu-xdg/kmoon.desktop
kodo	/var/lib/menu-xdg/applications/menu-xdg/kodometer.desktop
kteatime	/var/lib/menu-xdg/applications/menu-xdg/kteatime.desktop
kworldclock	/var/lib/menu-xdg/applications/menu-xdg/kworldclock.desktop
lightspeed	/var/lib/menu-xdg/applications/menu-xdg/light_speed.desktop
penguineyes	/var/lib/menu-xdg/applications/menu-xdg/penguineyes.desktop
tdfsb	/var/lib/menu-xdg/applications/menu-xdg/tdfsb.desktop
wmtictactoe	/var/lib/menu-xdg/applications/menu-xdg/wmtictactoe.desktop
xcruiser	/var/lib/menu-xdg/applications/menu-xdg/xcruiser.desktop
xeyes	/var/lib/menu-xdg/applications/menu-xdg/xeyes.desktop
xlogo	/var/lib/menu-xdg/applications/menu-xdg/xlogo.desktop
dwww	/var/lib/menu-xdg/applications/menu-xdg/dwww.desktop
info	/var/lib/menu-xdg/applications/menu-xdg/info.desktop
khelpcenter	/var/lib/menu-xdg/applications/menu-xdg/kde_help_center.desktop
hman	/var/lib/menu-xdg/applications/menu-xdg/man2html.desktop
texdoctk	/var/lib/menu-xdg/applications/menu-xdg/texdoctk.desktop
texshow	/var/lib/menu-xdg/applications/menu-xdg/texshow.desktop
xman	/var/lib/menu-xdg/applications/menu-xdg/xman.desktop
yelp	/var/lib/menu-xdg/applications/menu-xdg/yelp.desktop
ktux	/var/lib/menu-xdg/applications/menu-xdg/ktux.desktop
xscreensaver-command	/var/lib/menu-xdg/applications/menu-xdg/lock_screen_(xscreensaver).desktop
xplanet	/var/lib/menu-xdg/applications/menu-xdg/xplanet.desktop
xsetroot	/var/lib/menu-xdg/applications/menu-xdg/xsetroot.desktop
xscreensaver-command	/var/lib/menu-xdg/applications/menu-xdg/activate_screensaver_(next).desktop
xscreensaver-command	/var/lib/menu-xdg/applications/menu-xdg/activate_screensaver_(previous).desktop
xscreensaver-command	/var/lib/menu-xdg/applications/menu-xdg/activate_screensaver_(random).desktop
beforelight	/var/lib/menu-xdg/applications/menu-xdg/beforelight.desktop
xscreensaver-command	/var/lib/menu-xdg/applications/menu-xdg/demo_screen_hacks.desktop
xscreensaver-command	/var/lib/menu-xdg/applications/menu-xdg/disable_xscreensaver.desktop
xscreensaver	/var/lib/menu-xdg/applications/menu-xdg/enable_xscreensaver.desktop
xscreensaver-command	/var/lib/menu-xdg/applications/menu-xdg/reinitialize_xscreensaver.desktop
xscreensaver-command	/var/lib/menu-xdg/applications/menu-xdg/screensaver_preferences.desktop
aafire	/var/lib/menu-xdg/applications/menu-xdg/aa_fire.desktop
Eterm	/var/lib/menu-xdg/applications/menu-xdg/eterm.desktop
gnome-terminal	/var/lib/menu-xdg/applications/menu-xdg/gnome_terminal.desktop
konsole	/var/lib/menu-xdg/applications/menu-xdg/konsole.desktop
multi-gnome-terminal	/var/lib/menu-xdg/applications/menu-xdg/multi_gnome_terminal.desktop
oneliner	/var/lib/menu-xdg/applications/menu-xdg/oneliner.desktop
powershell	/var/lib/menu-xdg/applications/menu-xdg/powershell.desktop
xexec	/var/lib/menu-xdg/applications/menu-xdg/xexec.desktop
xterm	/var/lib/menu-xdg/applications/menu-xdg/xterm.desktop
uxterm	/var/lib/menu-xdg/applications/menu-xdg/xterm_(unicode).desktop
dbishell	/var/lib/gnome/Debian/Apps/Databases/dbishell.desktop
gnomedb-fe	/var/lib/gnome/Debian/Apps/Databases/GNOME-DB frontend.desktop
mysqlcc	/var/lib/gnome/Debian/Apps/Databases/MySQL CC.desktop
/usr/bin/X11/pgaccess	/var/lib/gnome/Debian/Apps/Databases/PgAccess.desktop
pgadmin3	/var/lib/gnome/Debian/Apps/Databases/pgAdmin III.desktop
/usr/lib/postgresql/bin/psql-wm	/var/lib/gnome/Debian/Apps/Databases/PostgreSQL interactive terminal (psql).desktop
quicklist	/var/lib/gnome/Debian/Apps/Databases/quicklist.desktop
sqlr-config-gtk	/var/lib/gnome/Debian/Apps/Databases/SQL Relay Configuration.desktop
tora	/var/lib/gnome/Debian/Apps/Databases/TOra.desktop
abiword	/var/lib/gnome/Debian/Apps/Editors/AbiWord Word Processor.desktop
/usr/bin/X11/axe	/var/lib/gnome/Debian/Apps/Editors/aXe.desktop
conglomerate	/var/lib/gnome/Debian/Apps/Editors/Conglomerate XML editor.desktop
emacs21	/var/lib/gnome/Debian/Apps/Editors/Emacs 21 (text).desktop
emacs21	/var/lib/gnome/Debian/Apps/Editors/Emacs 21 (X11).desktop
fontforge	/var/lib/gnome/Debian/Apps/Editors/fontforge.desktop
gedit	/var/lib/gnome/Debian/Apps/Editors/Gedit.desktop
texmacs	/var/lib/gnome/Debian/Apps/Editors/GNU TeXmacs.desktop
joe	/var/lib/gnome/Debian/Apps/Editors/Joe.desktop
kate	/var/lib/gnome/Debian/Apps/Editors/Kate.desktop
kedit	/var/lib/gnome/Debian/Apps/Editors/KEdit.desktop
kile	/var/lib/gnome/Debian/Apps/Editors/Kile.desktop
kvim	/var/lib/gnome/Debian/Apps/Editors/KVim.desktop
kword	/var/lib/gnome/Debian/Apps/Editors/KWord.desktop
kwrite	/var/lib/gnome/Debian/Apps/Editors/KWrite.desktop
kxmleditor	/var/lib/gnome/Debian/Apps/Editors/kxmleditor.desktop
lyx-qt	/var/lib/gnome/Debian/Apps/Editors/LyX (Qt).desktop
mlv	/var/lib/gnome/Debian/Apps/Editors/MlView XML editor.desktop
nano	/var/lib/gnome/Debian/Apps/Editors/Nano.desktop
nedit	/var/lib/gnome/Debian/Apps/Editors/NEdit.desktop
oofromtemplate	/var/lib/gnome/Debian/Apps/Editors/Openoffice.org From Template.desktop
ooweb	/var/lib/gnome/Debian/Apps/Editors/Openoffice.org HTML Document.desktop
oowriter	/var/lib/gnome/Debian/Apps/Editors/Openoffice.org Writer.desktop
pw	/var/lib/gnome/Debian/Apps/Editors/Pathetic Writer.desktop
quanta	/var/lib/gnome/Debian/Apps/Editors/Quanta Plus.desktop
vim	/var/lib/gnome/Debian/Apps/Editors/Vim.desktop
xedit	/var/lib/gnome/Debian/Apps/Editors/Xedit.desktop
xemacs21-mule	/var/lib/gnome/Debian/Apps/Editors/XEmacs21-mule.desktop
yudit	/var/lib/gnome/Debian/Apps/Editors/yudit.desktop
flashkard	/var/lib/gnome/Debian/Apps/Education/FlashKard.desktop
kiten	/var/lib/gnome/Debian/Apps/Education/Kiten.desktop
klettres	/var/lib/gnome/Debian/Apps/Education/KLettres.desktop
ktouch	/var/lib/gnome/Debian/Apps/Education/KTouch.desktop
kverbos	/var/lib/gnome/Debian/Apps/Education/Kverbos.desktop
kvoctrain	/var/lib/gnome/Debian/Apps/Education/KVocTrain.desktop
BasiliskII	/var/lib/gnome/Debian/Apps/Emulators/BasiliskII.desktop
x128	/var/lib/gnome/Debian/Apps/Emulators/Commodore 128.desktop
x64	/var/lib/gnome/Debian/Apps/Emulators/Commodore 64.desktop
xcbm2	/var/lib/gnome/Debian/Apps/Emulators/Commodore CBM-II.desktop
xpet	/var/lib/gnome/Debian/Apps/Emulators/Commodore PET.desktop
xvic	/var/lib/gnome/Debian/Apps/Emulators/Commodore VIC-20.desktop
dosemu	/var/lib/gnome/Debian/Apps/Emulators/Dos Emulator (tty).desktop
xdosemu	/var/lib/gnome/Debian/Apps/Emulators/Dos Emulator (X11).desktop
GSnes9x	/var/lib/gnome/Debian/Apps/Emulators/gsnes9x.desktop
x-terminal-emulator	/var/lib/gnome/Debian/Apps/Emulators/spectemu.desktop
uae-x	/var/lib/gnome/Debian/Apps/Emulators/UAE.desktop
avidemux	/var/lib/gnome/Debian/Apps/Graphics/avidemux.desktop
bitmap	/var/lib/gnome/Debian/Apps/Graphics/Bitmap.desktop
blender	/var/lib/gnome/Debian/Apps/Graphics/Blender (full screen).desktop
blender	/var/lib/gnome/Debian/Apps/Graphics/Blender (windowed).desktop
cenon	/var/lib/gnome/Debian/Apps/Graphics/Cenon.desktop
cinelerra	/var/lib/gnome/Debian/Apps/Graphics/cinelerra.desktop
dia-normal	/var/lib/gnome/Debian/Apps/Graphics/Dia.desktop
dia-gnome	/var/lib/gnome/Debian/Apps/Graphics/Dia (GNOME).desktop
egon	/var/lib/gnome/Debian/Apps/Graphics/Egon.desktop
filmgimp	/var/lib/gnome/Debian/Apps/Graphics/Film Gimp.desktop
giram	/var/lib/gnome/Debian/Apps/Graphics/giram.desktop
ganso	/var/lib/gnome/Debian/Apps/Graphics/Gnome Animation Studio.desktop
gqcam	/var/lib/gnome/Debian/Apps/Graphics/gqcam.desktop
gtk-ocr	/var/lib/gnome/Debian/Apps/Graphics/GTK Gocr.desktop
inkscape	/var/lib/gnome/Debian/Apps/Graphics/Inkscape.desktop
innovation3d	/var/lib/gnome/Debian/Apps/Graphics/Innovation3D modeler.desktop
x-terminal-emulator	/var/lib/gnome/Debian/Apps/Graphics/Ivtools.desktop
ivview	/var/lib/gnome/Debian/Apps/Graphics/ivview.desktop
karbon	/var/lib/gnome/Debian/Apps/Graphics/Karbon.desktop
kcolorchooser	/var/lib/gnome/Debian/Apps/Graphics/kcolorchooser.desktop
kcoloredit	/var/lib/gnome/Debian/Apps/Graphics/kcoloredit.desktop
kfax	/var/lib/gnome/Debian/Apps/Graphics/kfax.desktop
kiconedit	/var/lib/gnome/Debian/Apps/Graphics/kiconedit.desktop
kino	/var/lib/gnome/Debian/Apps/Graphics/Kino.desktop
kooka	/var/lib/gnome/Debian/Apps/Graphics/kooka.desktop
kpaint	/var/lib/gnome/Debian/Apps/Graphics/kpaint.desktop
kpdf	/var/lib/gnome/Debian/Apps/Graphics/kpdf.desktop
kpovmodeler	/var/lib/gnome/Debian/Apps/Graphics/KPovModeler.desktop
krita	/var/lib/gnome/Debian/Apps/Graphics/Krita.desktop
kruler	/var/lib/gnome/Debian/Apps/Graphics/kruler.desktop
ksnapshot	/var/lib/gnome/Debian/Apps/Graphics/ksnapshot.desktop
kuickshow	/var/lib/gnome/Debian/Apps/Graphics/kuickshow.desktop
motion	/var/lib/gnome/Debian/Apps/Graphics/motion.desktop
oodraw	/var/lib/gnome/Debian/Apps/Graphics/Openoffice.org Draw.desktop
ooimpress	/var/lib/gnome/Debian/Apps/Graphics/Openoffice.org Impress.desktop
picview	/var/lib/gnome/Debian/Apps/Graphics/Picview.desktop
pixmap	/var/lib/gnome/Debian/Apps/Graphics/Pixmap.desktop
price	/var/lib/gnome/Debian/Apps/Graphics/PRICE.desktop
sced	/var/lib/gnome/Debian/Apps/Graphics/ScEd.desktop
SceneViewer	/var/lib/gnome/Debian/Apps/Graphics/SceneViewer.desktop
scribus	/var/lib/gnome/Debian/Apps/Graphics/Scribus.desktop
sketch	/var/lib/gnome/Debian/Apps/Graphics/Sketch.desktop
snowflake	/var/lib/gnome/Debian/Apps/Graphics/snowflake.desktop
sodipodi	/var/lib/gnome/Debian/Apps/Graphics/Sodipodi.desktop
terraform	/var/lib/gnome/Debian/Apps/Graphics/Terraform.desktop
sh	/var/lib/gnome/Debian/Apps/Graphics/Text Xaos.desktop
tgif	/var/lib/gnome/Debian/Apps/Graphics/Tgif.desktop
gimp-2.0	/var/lib/gnome/Debian/Apps/Graphics/The GIMP (v2.0).desktop
tulip	/var/lib/gnome/Debian/Apps/Graphics/tulip.desktop
tuxpaint	/var/lib/gnome/Debian/Apps/Graphics/tuxpaint.desktop
vertex	/var/lib/gnome/Debian/Apps/Graphics/vertex.desktop
sh	/var/lib/gnome/Debian/Apps/Graphics/Xaos.desktop
xfig	/var/lib/gnome/Debian/Apps/Graphics/xfig.desktop
xmorph	/var/lib/gnome/Debian/Apps/Graphics/xmorph.desktop
xmps	/var/lib/gnome/Debian/Apps/Graphics/XMPS.desktop
xmps	/var/lib/gnome/Debian/Apps/Graphics/XMPS (GNOME).desktop
/usr/bin/X11/xpaint	/var/lib/gnome/Debian/Apps/Graphics/Xpaint.desktop
xsane	/var/lib/gnome/Debian/Apps/Graphics/xsane.desktop
gmfsk	/var/lib/gnome/Debian/Apps/Hamradio/gmfsk.desktop
gworldclock	/var/lib/gnome/Debian/Apps/Hamradio/gworldclock.desktop
hamfax	/var/lib/gnome/Debian/Apps/Hamradio/hamfax.desktop
linpac	/var/lib/gnome/Debian/Apps/Hamradio/linpac.desktop
twclock	/var/lib/gnome/Debian/Apps/Hamradio/Twclock.desktop
xastir	/var/lib/gnome/Debian/Apps/Hamradio/xastir.desktop
xcall	/var/lib/gnome/Debian/Apps/Hamradio/Xcall.desktop
bc	/var/lib/gnome/Debian/Apps/Math/bc.desktop
burlap	/var/lib/gnome/Debian/Apps/Math/Burlap.desktop
gcalctool	/var/lib/gnome/Debian/Apps/Math/CalcTool.desktop
dc	/var/lib/gnome/Debian/Apps/Math/dc.desktop
fudgit	/var/lib/gnome/Debian/Apps/Math/Fudgit.desktop
geomview	/var/lib/gnome/Debian/Apps/Math/geomview.desktop
gnumeric	/var/lib/gnome/Debian/Apps/Math/gnumeric.desktop
gstar	/var/lib/gnome/Debian/Apps/Math/gstar.desktop
kbruch	/var/lib/gnome/Debian/Apps/Math/KBruch.desktop
kcalc	/var/lib/gnome/Debian/Apps/Math/KCalc.desktop
kchart	/var/lib/gnome/Debian/Apps/Math/KChart.desktop
kformula	/var/lib/gnome/Debian/Apps/Math/KFormula.desktop
kgeo	/var/lib/gnome/Debian/Apps/Math/KGeo.desktop
kig	/var/lib/gnome/Debian/Apps/Math/Kig.desktop
kmplot	/var/lib/gnome/Debian/Apps/Math/KmPlot.desktop
kpercentage	/var/lib/gnome/Debian/Apps/Math/KPercentage.desktop
kspread	/var/lib/gnome/Debian/Apps/Math/KSpread.desktop
oocalc	/var/lib/gnome/Debian/Apps/Math/Openoffice.org Calc.desktop
oomath	/var/lib/gnome/Debian/Apps/Math/Openoffice.org Math.desktop
openuniverse	/var/lib/gnome/Debian/Apps/Math/openuniverse.desktop
perldl	/var/lib/gnome/Debian/Apps/Math/PerlDl.desktop
rcalc	/var/lib/gnome/Debian/Apps/Math/rCalc.desktop
rcalc	/var/lib/gnome/Debian/Apps/Math/rCalc (text).desktop
siag	/var/lib/gnome/Debian/Apps/Math/Siag.desktop
tsiag	/var/lib/gnome/Debian/Apps/Math/Siag (text mode).desktop
velvet	/var/lib/gnome/Debian/Apps/Math/Velvet.desktop
xabacus	/var/lib/gnome/Debian/Apps/Math/xabacus.desktop
xcalc	/var/lib/gnome/Debian/Apps/Math/Xcalc.desktop
xmaxima	/var/lib/gnome/Debian/Apps/Math/xmaxima.desktop
amaya	/var/lib/gnome/Debian/Apps/Net/Amaya.desktop
amule	/var/lib/gnome/Debian/Apps/Net/amule.desktop
amulewebDLG	/var/lib/gnome/Debian/Apps/Net/aMule webserver control.desktop
dillo	/var/lib/gnome/Debian/Apps/Net/Dillo.desktop
driftnet	/var/lib/gnome/Debian/Apps/Net/Driftnet.desktop
everybuddy	/var/lib/gnome/Debian/Apps/Net/EveryBuddy.desktop
fwbuilder	/var/lib/gnome/Debian/Apps/Net/Firewall Builder.desktop
gipsc	/var/lib/gnome/Debian/Apps/Net/Gipsc.desktop
gnapster	/var/lib/gnome/Debian/Apps/Net/Gnapster.desktop
gnomemeeting	/var/lib/gnome/Debian/Apps/Net/GnomeMeeting.desktop
gtk-gnutella	/var/lib/gnome/Debian/Apps/Net/gtk-gnutella.desktop
su-to-root	/var/lib/gnome/Debian/Apps/Net/IPTraf.desktop
kdict	/var/lib/gnome/Debian/Apps/Net/KDict.desktop
kget	/var/lib/gnome/Debian/Apps/Net/KGet.desktop
kit	/var/lib/gnome/Debian/Apps/Net/Kit.desktop
kmail	/var/lib/gnome/Debian/Apps/Net/KMail.desktop
kmailcvt	/var/lib/gnome/Debian/Apps/Net/KMail_KAB Import Tool.desktop
appletproxy	/var/lib/gnome/Debian/Apps/Net/KNewsTicker.desktop
knode	/var/lib/gnome/Debian/Apps/Net/KNode.desktop
konqueror	/var/lib/gnome/Debian/Apps/Net/Konqueror.desktop
kopete	/var/lib/gnome/Debian/Apps/Net/Kopete.desktop
korn	/var/lib/gnome/Debian/Apps/Net/KOrn.desktop
kppp	/var/lib/gnome/Debian/Apps/Net/KPPP.desktop
kppplogview	/var/lib/gnome/Debian/Apps/Net/KPPP - Logview.desktop
krdc	/var/lib/gnome/Debian/Apps/Net/Krdc.desktop
krfb	/var/lib/gnome/Debian/Apps/Net/Krfb.desktop
ksig	/var/lib/gnome/Debian/Apps/Net/KSig.desktop
ksirc	/var/lib/gnome/Debian/Apps/Net/KSirc.desktop
kwifimanager	/var/lib/gnome/Debian/Apps/Net/KWifiManager.desktop
LinNeighborhood	/var/lib/gnome/Debian/Apps/Net/LinNeighborhood.desktop
lynx	/var/lib/gnome/Debian/Apps/Net/Lynx.desktop
minicom	/var/lib/gnome/Debian/Apps/Net/Minicom.desktop
xminicom	/var/lib/gnome/Debian/Apps/Net/Minicom (X11).desktop
firefox	/var/lib/gnome/Debian/Apps/Net/Mozilla Firefox.desktop
mozilla-thunderbird	/var/lib/gnome/Debian/Apps/Net/Mozilla Thunderbird.desktop
mutt	/var/lib/gnome/Debian/Apps/Net/Mutt.desktop
ncftp3	/var/lib/gnome/Debian/Apps/Net/ncftp.desktop
gnome-netinfo	/var/lib/gnome/Debian/Apps/Net/Network Information.desktop
pan	/var/lib/gnome/Debian/Apps/Net/Pan.desktop
gnome-remote-desktop	/var/lib/gnome/Debian/Apps/Net/Remote Desktop.desktop
gnome-remote-shell	/var/lib/gnome/Debian/Apps/Net/Remote Shell.desktop
smb4k	/var/lib/gnome/Debian/Apps/Net/SAMBA for KDE.desktop
sdr	/var/lib/gnome/Debian/Apps/Net/Sdr.desktop
telnet	/var/lib/gnome/Debian/Apps/Net/Telnet.desktop
tsclient	/var/lib/gnome/Debian/Apps/Net/Terminal Server Client.desktop
tkchooser	/var/lib/gnome/Debian/Apps/Net/TkChooser.desktop
vrwave	/var/lib/gnome/Debian/Apps/Net/VRwave VRML browser.desktop
w3m	/var/lib/gnome/Debian/Apps/Net/w3m.desktop
xchat	/var/lib/gnome/Debian/Apps/Net/X Chat.desktop
xbiff	/var/lib/gnome/Debian/Apps/Net/Xbiff.desktop
xrealvncviewer	/var/lib/gnome/Debian/Apps/Net/xvncviewer.desktop
argouml	/var/lib/gnome/Debian/Apps/Programming/ArgoUML.desktop
autoproject	/var/lib/gnome/Debian/Apps/Programming/autoproject.desktop
cervisia	/var/lib/gnome/Debian/Apps/Programming/Cervisia.desktop
lisp	/var/lib/gnome/Debian/Apps/Programming/CMUCL Normal Image.desktop
ddd	/var/lib/gnome/Debian/Apps/Programming/Data Display Debugger.desktop
eclipse	/var/lib/gnome/Debian/Apps/Programming/Eclipse.desktop
elk	/var/lib/gnome/Debian/Apps/Programming/elk.desktop
fluid	/var/lib/gnome/Debian/Apps/Programming/Fluid.desktop
gide	/var/lib/gnome/Debian/Apps/Programming/gIDE.desktop
glade-2	/var/lib/gnome/Debian/Apps/Programming/Glade 2.desktop
sh	/var/lib/gnome/Debian/Apps/Programming/Gorm.desktop
guile-1.6	/var/lib/gnome/Debian/Apps/Programming/Guile 1.6.desktop
guile1.4	/var/lib/gnome/Debian/Apps/Programming/Guile Scheme 1.4.desktop
insight	/var/lib/gnome/Debian/Apps/Programming/Insight.desktop
jython	/var/lib/gnome/Debian/Apps/Programming/Jython.desktop
kbabel	/var/lib/gnome/Debian/Apps/Programming/KBabel.desktop
catalogmanager	/var/lib/gnome/Debian/Apps/Programming/KBabel Catalog Manager.desktop
kbabeldict	/var/lib/gnome/Debian/Apps/Programming/KBabel Dictionary.desktop
kbugbuster	/var/lib/gnome/Debian/Apps/Programming/KBugBuster.desktop
kcachegrind	/var/lib/gnome/Debian/Apps/Programming/KCachegrind.desktop
kdevelop3	/var/lib/gnome/Debian/Apps/Programming/KDevelop 3.0.desktop
kodos	/var/lib/gnome/Debian/Apps/Programming/Kodos.desktop
kompare	/var/lib/gnome/Debian/Apps/Programming/Kompare.desktop
kuiviewer	/var/lib/gnome/Debian/Apps/Programming/KUIViewer.desktop
pike7.2	/var/lib/gnome/Debian/Apps/Programming/Pike 7.2 HILFE.desktop
pycrust	/var/lib/gnome/Debian/Apps/Programming/pycrust.desktop
pyshell	/var/lib/gnome/Debian/Apps/Programming/pyshell.desktop
python2.1	/var/lib/gnome/Debian/Apps/Programming/Python (v2.1).desktop
python2.2	/var/lib/gnome/Debian/Apps/Programming/Python (v2.2).desktop
python2.3	/var/lib/gnome/Debian/Apps/Programming/Python (v2.3).desktop
designer-qt3	/var/lib/gnome/Debian/Apps/Programming/Qt Designer.desktop
irb1.8	/var/lib/gnome/Debian/Apps/Programming/Ruby (irb1.8).desktop
tclsh8.0	/var/lib/gnome/Debian/Apps/Programming/Tclsh8.0.desktop
tclsh8.2	/var/lib/gnome/Debian/Apps/Programming/Tclsh8.2.desktop
tclsh8.3	/var/lib/gnome/Debian/Apps/Programming/Tclsh8.3.desktop
tclsh8.4	/var/lib/gnome/Debian/Apps/Programming/Tclsh8.4.desktop
tkcvs	/var/lib/gnome/Debian/Apps/Programming/TkCVS.desktop
tkdiff	/var/lib/gnome/Debian/Apps/Programming/Tkdiff.desktop
wish8.0	/var/lib/gnome/Debian/Apps/Programming/TkWish8.0.desktop
wish8.2	/var/lib/gnome/Debian/Apps/Programming/TkWish8.2.desktop
x-terminal-emulator	/var/lib/gnome/Debian/Apps/Programming/TkWish8.3.desktop
x-terminal-emulator	/var/lib/gnome/Debian/Apps/Programming/TkWish8.4.desktop
xrced	/var/lib/gnome/Debian/Apps/Programming/xrced.desktop
vibrate	/var/lib/gnome/Debian/Apps/Science/asn2asn.desktop
vibrate	/var/lib/gnome/Debian/Apps/Science/asn2ff.desktop
vibrate	/var/lib/gnome/Debian/Apps/Science/asn2gb.desktop
vibrate	/var/lib/gnome/Debian/Apps/Science/asn2xml.desktop
vibrate	/var/lib/gnome/Debian/Apps/Science/asndhuff.desktop
vibrate	/var/lib/gnome/Debian/Apps/Science/bl2seq.desktop
vibrate	/var/lib/gnome/Debian/Apps/Science/blast2.desktop
vibrate	/var/lib/gnome/Debian/Apps/Science/blastall.desktop
vibrate	/var/lib/gnome/Debian/Apps/Science/blastcl3.desktop
vibrate	/var/lib/gnome/Debian/Apps/Science/blastclust.desktop
vibrate	/var/lib/gnome/Debian/Apps/Science/blastpgp.desktop
vibrate	/var/lib/gnome/Debian/Apps/Science/checksub.desktop
Cn3D-3.0	/var/lib/gnome/Debian/Apps/Science/Cn3D-3.0.desktop
vibrate	/var/lib/gnome/Debian/Apps/Science/copymat.desktop
ddv	/var/lib/gnome/Debian/Apps/Science/ddv.desktop
vibrate	/var/lib/gnome/Debian/Apps/Science/debruijn.desktop
vibrate	/var/lib/gnome/Debian/Apps/Science/entrcmd.desktop
Nentrez	/var/lib/gnome/Debian/Apps/Science/Entrez.desktop
netentcf	/var/lib/gnome/Debian/Apps/Science/Entrez net config.desktop
entrez2	/var/lib/gnome/Debian/Apps/Science/entrez2.desktop
vibrate	/var/lib/gnome/Debian/Apps/Science/fa2htgs.desktop
vibrate	/var/lib/gnome/Debian/Apps/Science/fastacmd.desktop
vibrate	/var/lib/gnome/Debian/Apps/Science/findspl.desktop
vibrate	/var/lib/gnome/Debian/Apps/Science/formatdb.desktop
garlic	/var/lib/gnome/Debian/Apps/Science/garlic.desktop
vibrate	/var/lib/gnome/Debian/Apps/Science/gbseqget.desktop
vibrate	/var/lib/gnome/Debian/Apps/Science/getfeat.desktop
vibrate	/var/lib/gnome/Debian/Apps/Science/getmesh.desktop
vibrate	/var/lib/gnome/Debian/Apps/Science/getpub.desktop
vibrate	/var/lib/gnome/Debian/Apps/Science/gil2bin.desktop
gperiodic	/var/lib/gnome/Debian/Apps/Science/gperiodic.desktop
vibrate	/var/lib/gnome/Debian/Apps/Science/idfetch.desktop
vibrate	/var/lib/gnome/Debian/Apps/Science/impala.desktop
vibrate	/var/lib/gnome/Debian/Apps/Science/indexpub.desktop
kalzium	/var/lib/gnome/Debian/Apps/Science/Kalzium.desktop
kstars	/var/lib/gnome/Debian/Apps/Science/KStars.desktop
kxterm	/var/lib/gnome/Debian/Apps/Science/KXterm.desktop
vibrate	/var/lib/gnome/Debian/Apps/Science/makemat.desktop
vibrate	/var/lib/gnome/Debian/Apps/Science/makeset.desktop
vibrate	/var/lib/gnome/Debian/Apps/Science/megablast.desktop
njplot	/var/lib/gnome/Debian/Apps/Science/NJPlot.desktop
unrooted	/var/lib/gnome/Debian/Apps/Science/NJPlot unrooted.desktop
rasmol	/var/lib/gnome/Debian/Apps/Science/Rasmol.desktop
vibrate	/var/lib/gnome/Debian/Apps/Science/rpsblast.desktop
vibrate	/var/lib/gnome/Debian/Apps/Science/seedtop.desktop
Psequin	/var/lib/gnome/Debian/Apps/Science/Sequin.desktop
starplot	/var/lib/gnome/Debian/Apps/Science/StarPlot.desktop
vibrate	/var/lib/gnome/Debian/Apps/Science/tbl2asn.desktop
udv	/var/lib/gnome/Debian/Apps/Science/udv.desktop
vibrate	/var/lib/gnome/Debian/Apps/Science/vecscreen.desktop
bash	/var/lib/gnome/Debian/Apps/Shells/Bash.desktop
ksh	/var/lib/gnome/Debian/Apps/Shells/Ksh.desktop
sh	/var/lib/gnome/Debian/Apps/Shells/Sh.desktop
tcsh	/var/lib/gnome/Debian/Apps/Shells/tcsh.desktop
aconnectgui	/var/lib/gnome/Debian/Apps/Sound/aconnectgui.desktop
/usr/bin/X11/xterm	/var/lib/gnome/Debian/Apps/Sound/Ardour GTK.desktop
artsbuilder	/var/lib/gnome/Debian/Apps/Sound/aRts Builder.desktop
artscontrol	/var/lib/gnome/Debian/Apps/Sound/aRts Control.desktop
audacity	/var/lib/gnome/Debian/Apps/Sound/Audacity.desktop
vkeybd	/var/lib/gnome/Debian/Apps/Sound/AWE Virtual Keyboard.desktop
bcast2000	/var/lib/gnome/Debian/Apps/Sound/Broadcast2000.desktop
/usr/bin/X11/xterm	/var/lib/gnome/Debian/Apps/Sound/cam.desktop
cecilia	/var/lib/gnome/Debian/Apps/Sound/Cecilia.desktop
ceres3	/var/lib/gnome/Debian/Apps/Sound/ceres3.desktop
cglame	/var/lib/gnome/Debian/Apps/Sound/cglame.desktop
ecasound	/var/lib/gnome/Debian/Apps/Sound/ecasound.desktop
extace	/var/lib/gnome/Debian/Apps/Sound/extace.desktop
freebirth	/var/lib/gnome/Debian/Apps/Sound/freebirth.desktop
gamix	/var/lib/gnome/Debian/Apps/Sound/gamix.desktop
gcd	/var/lib/gnome/Debian/Apps/Sound/gcd.desktop
glcthugha	/var/lib/gnome/Debian/Apps/Sound/GL Cthugha.desktop
glame	/var/lib/gnome/Debian/Apps/Sound/glame.desktop
gnome-volume-control	/var/lib/gnome/Debian/Apps/Sound/gmix (Gnome 2.0 Mixer).desktop
gnome-cd	/var/lib/gnome/Debian/Apps/Sound/gnome-cd (Gnome 2.0 CD Player).desktop
gnomp3	/var/lib/gnome/Debian/Apps/Sound/gnomp3.desktop
gom-ct	/var/lib/gnome/Debian/Apps/Sound/Gom (terminal).desktop
gnome-sound-recorder	/var/lib/gnome/Debian/Apps/Sound/grecord (GNOME 2.0 Recorder).desktop
grip	/var/lib/gnome/Debian/Apps/Sound/grip.desktop
gsox	/var/lib/gnome/Debian/Apps/Sound/gsox.desktop
gtick	/var/lib/gnome/Debian/Apps/Sound/gtick.desktop
horgand	/var/lib/gnome/Debian/Apps/Sound/Horgand.desktop
id3ren	/var/lib/gnome/Debian/Apps/Sound/id3ren.desktop
juk	/var/lib/gnome/Debian/Apps/Sound/JuK Music Player.desktop
kaboodle	/var/lib/gnome/Debian/Apps/Sound/Kaboodle.desktop
kaudiocreator	/var/lib/gnome/Debian/Apps/Sound/KAudioCreator.desktop
kmid	/var/lib/gnome/Debian/Apps/Sound/KMid.desktop
kmidi	/var/lib/gnome/Debian/Apps/Sound/KMidi.desktop
kmix	/var/lib/gnome/Debian/Apps/Sound/KMix.desktop
krec	/var/lib/gnome/Debian/Apps/Sound/KRec.desktop
kscd	/var/lib/gnome/Debian/Apps/Sound/Kscd.desktop
mammut	/var/lib/gnome/Debian/Apps/Sound/mammut.desktop
/usr/bin/X11/mix	/var/lib/gnome/Debian/Apps/Sound/Mix.desktop
/usr/X11R6/bin/Mixer.app	/var/lib/gnome/Debian/Apps/Sound/Mixer.app.desktop
mixmagic	/var/lib/gnome/Debian/Apps/Sound/MixMagic.desktop
mxv	/var/lib/gnome/Debian/Apps/Sound/MixViews.desktop
muse	/var/lib/gnome/Debian/Apps/Sound/MusE.desktop
music-librarian	/var/lib/gnome/Debian/Apps/Sound/Music Librarian.desktop
noatun	/var/lib/gnome/Debian/Apps/Sound/Noatun.desktop
noteedit	/var/lib/gnome/Debian/Apps/Sound/noteedit.desktop
qrt	/var/lib/gnome/Debian/Apps/Sound/qrt.desktop
qsynth	/var/lib/gnome/Debian/Apps/Sound/qsynth.desktop
rezound	/var/lib/gnome/Debian/Apps/Sound/ReZound.desktop
rosegarden4	/var/lib/gnome/Debian/Apps/Sound/Rosegarden4.desktop
shaketracker	/var/lib/gnome/Debian/Apps/Sound/ShackeTracker.desktop
smurf	/var/lib/gnome/Debian/Apps/Sound/smurf.desktop
snd	/var/lib/gnome/Debian/Apps/Sound/Snd.desktop
soundtracker	/var/lib/gnome/Debian/Apps/Sound/SoundTracker.desktop
GUIBowedBar	/var/lib/gnome/Debian/Apps/Sound/STK/BowedBar.desktop
GUIDrums	/var/lib/gnome/Debian/Apps/Sound/STK/Drums.desktop
GUIeffects	/var/lib/gnome/Debian/Apps/Sound/STK/Effects.desktop
GUIModal	/var/lib/gnome/Debian/Apps/Sound/STK/Modal.desktop
GUIPhysical	/var/lib/gnome/Debian/Apps/Sound/STK/Physical.desktop
GUIRaga	/var/lib/gnome/Debian/Apps/Sound/STK/Ragamatic.desktop
GUIShakers	/var/lib/gnome/Debian/Apps/Sound/STK/Shakers.desktop
GUIVoice	/var/lib/gnome/Debian/Apps/Sound/STK/Voice.desktop
sweep	/var/lib/gnome/Debian/Apps/Sound/sweep.desktop
synaesthesia	/var/lib/gnome/Debian/Apps/Sound/Synaesthesia (CD input).desktop
synaesthesia	/var/lib/gnome/Debian/Apps/Sound/Synaesthesia (ESD input).desktop
synaesthesia	/var/lib/gnome/Debian/Apps/Sound/Synaesthesia (line input).desktop
terminatorX	/var/lib/gnome/Debian/Apps/Sound/terminatorX.desktop
timidity	/var/lib/gnome/Debian/Apps/Sound/TiMidity++.desktop
tk707	/var/lib/gnome/Debian/Apps/Sound/TK-707.desktop
tkmixer	/var/lib/gnome/Debian/Apps/Sound/TkMixer.desktop
vumeter	/var/lib/gnome/Debian/Apps/Sound/vumeter (Gnome 2.0 Volume Meter).desktop
wavesurfer	/var/lib/gnome/Debian/Apps/Sound/wavesurfer.desktop
wmmixer	/var/lib/gnome/Debian/Apps/Sound/WMMixer.desktop
wmmixer	/var/lib/gnome/Debian/Apps/Sound/WMMixer (Docked).desktop
wmxmms	/var/lib/gnome/Debian/Apps/Sound/wmXMMS.desktop
workman	/var/lib/gnome/Debian/Apps/Sound/Workman.desktop
xcthugha	/var/lib/gnome/Debian/Apps/Sound/X Cthugha.desktop
xfreecd	/var/lib/gnome/Debian/Apps/Sound/XfreeCD.desktop
xmcd	/var/lib/gnome/Debian/Apps/Sound/Xmcd.desktop
/usr/bin/X11/xmix	/var/lib/gnome/Debian/Apps/Sound/xmix.desktop
xmixer	/var/lib/gnome/Debian/Apps/Sound/Xmixer.desktop
xmms	/var/lib/gnome/Debian/Apps/Sound/XMMS.desktop
xplaycd	/var/lib/gnome/Debian/Apps/Sound/Xplaycd.desktop
xwave	/var/lib/gnome/Debian/Apps/Sound/XWave.desktop
su-to-root	/var/lib/gnome/Debian/Apps/System/Admin/alsaconf.desktop
su-to-root	/var/lib/gnome/Debian/Apps/System/Admin/gpm-config.desktop
su-to-root	/var/lib/gnome/Debian/Apps/System/Admin/Lilo-config.desktop
su-to-root	/var/lib/gnome/Debian/Apps/System/Admin/Orphaner (all).desktop
su-to-root	/var/lib/gnome/Debian/Apps/System/Admin/Orphaner (libs).desktop
su-to-root	/var/lib/gnome/Debian/Apps/System/Admin/Orphaner - editkeep.desktop
su-to-root	/var/lib/gnome/Debian/Apps/System/Admin/pppconfig.desktop
aptitude	/var/lib/gnome/Debian/Apps/System/aptitude.desktop
gvidm	/var/lib/gnome/Debian/Apps/System/Change X11 resolution (gvidm).desktop
fsview	/var/lib/gnome/Debian/Apps/System/FSView.desktop
gdmflexiserver	/var/lib/gnome/Debian/Apps/System/GDM flexiserver.desktop
gdmflexiserver	/var/lib/gnome/Debian/Apps/System/GDM flexiserver in Xnest.desktop
gdmphotosetup	/var/lib/gnome/Debian/Apps/System/GDM Photo Setup.desktop
gksu	/var/lib/gnome/Debian/Apps/System/GDM Setup.desktop
gnome-control-center	/var/lib/gnome/Debian/Apps/System/Gnome/Gnome Control Center.desktop
bug-buddy	/var/lib/gnome/Debian/Apps/System/GNOME Bug Report Tool.desktop
gfloppy	/var/lib/gnome/Debian/Apps/System/GNOME Floppy Formatter.desktop
gnome-system-log	/var/lib/gnome/Debian/Apps/System/GNOME Log Viewer.desktop
gnome-system-monitor	/var/lib/gnome/Debian/Apps/System/GNOME system monitor.desktop
gps	/var/lib/gnome/Debian/Apps/System/Gps.desktop
gxset	/var/lib/gnome/Debian/Apps/System/GTK xset.desktop
gtkrecover	/var/lib/gnome/Debian/Apps/System/gtkrecover.desktop
openapp	/var/lib/gnome/Debian/Apps/System/GWorkspace.app.desktop
gxproc	/var/lib/gnome/Debian/Apps/System/GXproc.desktop
kappfinder	/var/lib/gnome/Debian/Apps/System/kAppfinder.desktop
kcmshell	/var/lib/gnome/Debian/Apps/System/kcmlinuz.desktop
kcontrol	/var/lib/gnome/Debian/Apps/System/KControl.desktop
kdat	/var/lib/gnome/Debian/Apps/System/KDat.desktop
kdcop	/var/lib/gnome/Debian/Apps/System/KDCOP.desktop
kpackage	/var/lib/gnome/Debian/Apps/System/KDE Package Manager.desktop
secpolicy	/var/lib/gnome/Debian/Apps/System/KDE PAM Security Policy Editor.desktop
ksysguard	/var/lib/gnome/Debian/Apps/System/KDE System Guard.desktop
kpm	/var/lib/gnome/Debian/Apps/System/KDE System Guard - Process Table.desktop
ksysv	/var/lib/gnome/Debian/Apps/System/KDE SysV-Init Editor.desktop
kcron	/var/lib/gnome/Debian/Apps/System/KDE Task Scheduler.desktop
kuser	/var/lib/gnome/Debian/Apps/System/KDE User Manager.desktop
kdebugdialog	/var/lib/gnome/Debian/Apps/System/KDebugDialog.desktop
kdepasswd	/var/lib/gnome/Debian/Apps/System/kdepasswd.desktop
kdeprintfax	/var/lib/gnome/Debian/Apps/System/KDEPrintFax.desktop
kdf	/var/lib/gnome/Debian/Apps/System/KDiskFree.desktop
keditbookmarks	/var/lib/gnome/Debian/Apps/System/KEditBookmarks.desktop
kfind	/var/lib/gnome/Debian/Apps/System/KFind.desktop
kfloppy	/var/lib/gnome/Debian/Apps/System/KFloppy.desktop
kicker	/var/lib/gnome/Debian/Apps/System/Kicker.desktop
kjobviewer	/var/lib/gnome/Debian/Apps/System/KJobViewer.desktop
kmenuedit	/var/lib/gnome/Debian/Apps/System/KMenuEdit.desktop
konqueror	/var/lib/gnome/Debian/Apps/System/Konqueror.desktop
kpersonalizer	/var/lib/gnome/Debian/Apps/System/KPersonalizer.desktop
kprinter	/var/lib/gnome/Debian/Apps/System/KPrinter.desktop
kwikdisk	/var/lib/gnome/Debian/Apps/System/kwikdisk.desktop
kdesu	/var/lib/gnome/Debian/Apps/System/lilo-config.desktop
loadmeter	/var/lib/gnome/Debian/Apps/System/Loadmeter.desktop
moodss	/var/lib/gnome/Debian/Apps/System/moodss.desktop
mount.app	/var/lib/gnome/Debian/Apps/System/mountapp.desktop
nautilus	/var/lib/gnome/Debian/Apps/System/Nautilus.desktop
netwatch	/var/lib/gnome/Debian/Apps/System/netwatch.desktop
netload	/var/lib/gnome/Debian/Apps/System/Network load on ppp0.desktop
oopadmin	/var/lib/gnome/Debian/Apps/System/Openoffice.org Printer Administration.desktop
/usr/lib/openoffice/program/setup	/var/lib/gnome/Debian/Apps/System/Openoffice.org Setup.desktop
x-terminal-emulator	/var/lib/gnome/Debian/Apps/System/pstree.desktop
su-to-root	/var/lib/gnome/Debian/Apps/System/recover.desktop
reportbug	/var/lib/gnome/Debian/Apps/System/reportbug.desktop
gksuexec	/var/lib/gnome/Debian/Apps/System/Run as different user (GKsu).desktop
si	/var/lib/gnome/Debian/Apps/System/si.desktop
statnet	/var/lib/gnome/Debian/Apps/System/statnet.desktop
su-to-root	/var/lib/gnome/Debian/Apps/System/Synaptic Package Manager.desktop
su-to-root	/var/lib/gnome/Debian/Apps/System/Task selector.desktop
/usr/bin/texconfig	/var/lib/gnome/Debian/Apps/System/TeXconfig.desktop
top	/var/lib/gnome/Debian/Apps/System/Top.desktop
trafshow	/var/lib/gnome/Debian/Apps/System/trafshow.desktop
wmbubble	/var/lib/gnome/Debian/Apps/System/wmbubble.desktop
wmsensors	/var/lib/gnome/Debian/Apps/System/wmsensors.desktop
wmsmpmon	/var/lib/gnome/Debian/Apps/System/wmsmpmon.desktop
wmtop	/var/lib/gnome/Debian/Apps/System/wmtop.desktop
gksu	/var/lib/gnome/Debian/Apps/System/X-Terminal as root (GKsu).desktop
xconsole	/var/lib/gnome/Debian/Apps/System/Xconsole.desktop
sh	/var/lib/gnome/Debian/Apps/System/xdiskusage.desktop
xfilequery	/var/lib/gnome/Debian/Apps/System/Xfq RPM Manager.desktop
xload	/var/lib/gnome/Debian/Apps/System/Xload.desktop
xlogmaster	/var/lib/gnome/Debian/Apps/System/xlogmaster.desktop
xlogmaster	/var/lib/gnome/Debian/Apps/System/xlogmaster (system).desktop
xtraceroute	/var/lib/gnome/Debian/Apps/System/xt.desktop
xvidtune	/var/lib/gnome/Debian/Apps/System/Xvidtune.desktop
gpsman	/var/lib/gnome/Debian/Apps/Technical/GPSMan.desktop
tkgate	/var/lib/gnome/Debian/Apps/Technical/TkGate.desktop
wordinspect	/var/lib/gnome/Debian/Apps/Text/Dict Client.desktop
sh	/var/lib/gnome/Debian/Apps/Text/Fortune.desktop
gnome-dictionary	/var/lib/gnome/Debian/Apps/Text/GNOME Dictionary.desktop
htmldoc	/var/lib/gnome/Debian/Apps/Text/HTMLDoc.desktop
gucharmap	/var/lib/gnome/Debian/Apps/Text/Unicode character map.desktop
ark	/var/lib/gnome/Debian/Apps/Tools/Ark.desktop
dasher	/var/lib/gnome/Debian/Apps/Tools/Dasher text entry.desktop
DataManager	/var/lib/gnome/Debian/Apps/Tools/DataManager.desktop
dclock	/var/lib/gnome/Debian/Apps/Tools/dclock.desktop
dfm	/var/lib/gnome/Debian/Apps/Tools/Desktop File Manager.desktop
ding	/var/lib/gnome/Debian/Apps/Tools/ding.desktop
editres	/var/lib/gnome/Debian/Apps/Tools/Editres.desktop
emelfm	/var/lib/gnome/Debian/Apps/Tools/emelFM.desktop
file-roller	/var/lib/gnome/Debian/Apps/Tools/File-Roller.desktop
fookb-wmaker	/var/lib/gnome/Debian/Apps/Tools/fookb-wmaker.desktop
gcombust	/var/lib/gnome/Debian/Apps/Tools/gcombust.desktop
gcrontab	/var/lib/gnome/Debian/Apps/Tools/gcrontab.desktop
gnomecard	/var/lib/gnome/Debian/Apps/Tools/GNOME Address Book.desktop
gnomecal	/var/lib/gnome/Debian/Apps/Tools/GNOME Calendar.desktop
gcm	/var/lib/gnome/Debian/Apps/Tools/GNOME Clipboard Manager.desktop
gnome-search-tool	/var/lib/gnome/Debian/Apps/Tools/GNOME Search Tool.desktop
gnucash	/var/lib/gnome/Debian/Apps/Tools/GnuCash.desktop
gODBCConfig	/var/lib/gnome/Debian/Apps/Tools/gODBCConfig.desktop
gramps	/var/lib/gnome/Debian/Apps/Tools/gramps.desktop
gtktrain	/var/lib/gnome/Debian/Apps/Tools/gtktrain.desktop
guitar	/var/lib/gnome/Debian/Apps/Tools/guitar.desktop
iceconf	/var/lib/gnome/Debian/Apps/Tools/iceconf.desktop
jscalibrator	/var/lib/gnome/Debian/Apps/Tools/Joystick Calibration.desktop
kaddressbook	/var/lib/gnome/Debian/Apps/Tools/KAddressbook.desktop
kalarm	/var/lib/gnome/Debian/Apps/Tools/KAlarm.desktop
kandy	/var/lib/gnome/Debian/Apps/Tools/Kandy.desktop
karm	/var/lib/gnome/Debian/Apps/Tools/KArm.desktop
kcharselect	/var/lib/gnome/Debian/Apps/Tools/KCharSelect.desktop
kgpg	/var/lib/gnome/Debian/Apps/Tools/Kgpg.desktop
khexedit	/var/lib/gnome/Debian/Apps/Tools/KHexEdit.desktop
kivio	/var/lib/gnome/Debian/Apps/Tools/Kivio.desktop
kjots	/var/lib/gnome/Debian/Apps/Tools/KJots.desktop
klipper	/var/lib/gnome/Debian/Apps/Tools/Klipper.desktop
knotes	/var/lib/gnome/Debian/Apps/Tools/KNotes.desktop
koshell	/var/lib/gnome/Debian/Apps/Tools/KOffice Workspace.desktop
kmdr-editor	/var/lib/gnome/Debian/Apps/Tools/Kommander Editor.desktop
kontact	/var/lib/gnome/Debian/Apps/Tools/Kontact.desktop
korganizer	/var/lib/gnome/Debian/Apps/Tools/KOrganizer.desktop
kpager	/var/lib/gnome/Debian/Apps/Tools/KPager.desktop
kpalmdoc	/var/lib/gnome/Debian/Apps/Tools/KPalmDOC.desktop
kpilot	/var/lib/gnome/Debian/Apps/Tools/KPilot.desktop
kpresenter	/var/lib/gnome/Debian/Apps/Tools/KPresenter.desktop
kregexpeditor	/var/lib/gnome/Debian/Apps/Tools/Kregexpeditor.desktop
ksync	/var/lib/gnome/Debian/Apps/Tools/KSync.desktop
kthesaurus	/var/lib/gnome/Debian/Apps/Tools/KThesaurus.desktop
ktimer	/var/lib/gnome/Debian/Apps/Tools/KTimer.desktop
ktip	/var/lib/gnome/Debian/Apps/Tools/KTip.desktop
ktnef	/var/lib/gnome/Debian/Apps/Tools/KTnef.desktop
kugar	/var/lib/gnome/Debian/Apps/Tools/Kugar.desktop
kudesigner	/var/lib/gnome/Debian/Apps/Tools/Kugar Designer.desktop
mc	/var/lib/gnome/Debian/Apps/Tools/mc.desktop
nonlock	/var/lib/gnome/Debian/Apps/Tools/nonlock.desktop
oclock	/var/lib/gnome/Debian/Apps/Tools/Oclock.desktop
ODBCConfig	/var/lib/gnome/Debian/Apps/Tools/ODBCConfig.desktop
odbctest	/var/lib/gnome/Debian/Apps/Tools/odbctest.desktop
qps	/var/lib/gnome/Debian/Apps/Tools/qps.desktop
/usr/bin/X11/regexplorer	/var/lib/gnome/Debian/Apps/Tools/RegExplorer.desktop
texfind	/var/lib/gnome/Debian/Apps/Tools/TeXfind.desktop
dotfile	/var/lib/gnome/Debian/Apps/Tools/The Dotfile Generator.desktop
unclutter	/var/lib/gnome/Debian/Apps/Tools/unclutter - start.desktop
killall	/var/lib/gnome/Debian/Apps/Tools/unclutter - stop.desktop
wmcalc	/var/lib/gnome/Debian/Apps/Tools/wmcalc.desktop
wmCalClock	/var/lib/gnome/Debian/Apps/Tools/wmcalclock.desktop
wmGrabImage	/var/lib/gnome/Debian/Apps/Tools/wmGrabImage.desktop
wmMoonClock	/var/lib/gnome/Debian/Apps/Tools/wmMoonClock.desktop
wmpinboard	/var/lib/gnome/Debian/Apps/Tools/wmPinboard.desktop
worker	/var/lib/gnome/Debian/Apps/Tools/Worker.desktop
xwd	/var/lib/gnome/Debian/Apps/Tools/X Window Snapshot.desktop
xcalendar	/var/lib/gnome/Debian/Apps/Tools/xcalendar-i18n.desktop
xclipboard	/var/lib/gnome/Debian/Apps/Tools/Xclipboard.desktop
xclock	/var/lib/gnome/Debian/Apps/Tools/Xclock (analog).desktop
xclock	/var/lib/gnome/Debian/Apps/Tools/Xclock (digital).desktop
xcutsel	/var/lib/gnome/Debian/Apps/Tools/Xcutsel.desktop
x-terminal-emulator	/var/lib/gnome/Debian/Apps/Tools/Xev.desktop
xfe	/var/lib/gnome/Debian/Apps/Tools/Xfe File Manager.desktop
xffm	/var/lib/gnome/Debian/Apps/Tools/XFfm4.desktop
xfontsel	/var/lib/gnome/Debian/Apps/Tools/Xfontsel.desktop
/usr/bin/X11/xkbsel-aw	/var/lib/gnome/Debian/Apps/Tools/xkbsel.desktop
xkill	/var/lib/gnome/Debian/Apps/Tools/Xkill.desktop
xmag	/var/lib/gnome/Debian/Apps/Tools/Xmag.desktop
xrefresh	/var/lib/gnome/Debian/Apps/Tools/Xrefresh.desktop
zclock	/var/lib/gnome/Debian/Apps/Tools/ZClock.desktop
acroread	/var/lib/gnome/Debian/Apps/Viewers/Acrobat Reader.desktop
alevt	/var/lib/gnome/Debian/Apps/Viewers/AleVT.desktop
effectv	/var/lib/gnome/Debian/Apps/Viewers/effectv.desktop
endeavour2	/var/lib/gnome/Debian/Apps/Viewers/Endeavour2 Viewer.desktop
gfontview	/var/lib/gnome/Debian/Apps/Viewers/gfontview.desktop
gliv	/var/lib/gnome/Debian/Apps/Viewers/gliv.desktop
gnome-gv	/var/lib/gnome/Debian/Apps/Viewers/GNOME Ghostscript_PDF Viewer.desktop
gqview	/var/lib/gnome/Debian/Apps/Viewers/GQview.desktop
gtv	/var/lib/gnome/Debian/Apps/Viewers/gtv MPEG player.desktop
/usr/bin/X11/gv	/var/lib/gnome/Debian/Apps/Viewers/GV.desktop
display	/var/lib/gnome/Debian/Apps/Viewers/ImageMagick.desktop
kdvi	/var/lib/gnome/Debian/Apps/Viewers/kdvi.desktop
kghostview	/var/lib/gnome/Debian/Apps/Viewers/kghostview.desktop
kview	/var/lib/gnome/Debian/Apps/Viewers/kview.desktop
gmplayer	/var/lib/gnome/Debian/Apps/Viewers/Mplayer.desktop
paul	/var/lib/gnome/Debian/Apps/Viewers/Paul.desktop
pornview	/var/lib/gnome/Debian/Apps/Viewers/PornView.desktop
realplayer	/var/lib/gnome/Debian/Apps/Viewers/Real Player.desktop
wordview	/var/lib/gnome/Debian/Apps/Viewers/Wordview.desktop
xawtv	/var/lib/gnome/Debian/Apps/Viewers/xawtv.desktop
xbmbrowser	/var/lib/gnome/Debian/Apps/Viewers/xbmbrowser.desktop
xditview	/var/lib/gnome/Debian/Apps/Viewers/Xditview.desktop
xdvi	/var/lib/gnome/Debian/Apps/Viewers/XDvi.desktop
xfileview	/var/lib/gnome/Debian/Apps/Viewers/Xfv File Viewer.desktop
xine	/var/lib/gnome/Debian/Apps/Viewers/xine media player.desktop
xmovie	/var/lib/gnome/Debian/Apps/Viewers/XMovie.desktop
kasteroids	/var/lib/gnome/Debian/Games/Arcade/KAsteroids.desktop
kbounce	/var/lib/gnome/Debian/Games/Arcade/KDE Bounce Ball Game.desktop
kolf	/var/lib/gnome/Debian/Games/Arcade/KDE Miniature Golf.desktop
ksnake	/var/lib/gnome/Debian/Games/Arcade/KDE Snake Race.desktop
kspaceduel	/var/lib/gnome/Debian/Games/Arcade/KDE SpaceDuel.desktop
ktron	/var/lib/gnome/Debian/Games/Arcade/KDE Tron.desktop
kgoldrunner	/var/lib/gnome/Debian/Games/Arcade/KGoldrunner.desktop
xasteroids	/var/lib/gnome/Debian/Games/Arcade/Xasteroids.desktop
atlantik	/var/lib/gnome/Debian/Games/Board/Atlantik.desktop
atlantikdesigner	/var/lib/gnome/Debian/Games/Board/Atlantik Designer.desktop
gnubg	/var/lib/gnome/Debian/Games/Board/GNU backgammon.desktop
kbattleship	/var/lib/gnome/Debian/Games/Board/KBattleship.desktop
kbackgammon	/var/lib/gnome/Debian/Games/Board/KDE Backgammon.desktop
kreversi	/var/lib/gnome/Debian/Games/Board/KDE Reversi.desktop
kshisen	/var/lib/gnome/Debian/Games/Board/KDE Shisen-Sho.desktop
kenolaba	/var/lib/gnome/Debian/Games/Board/KEnolaba.desktop
klines	/var/lib/gnome/Debian/Games/Board/KLines.desktop
kmahjongg	/var/lib/gnome/Debian/Games/Board/KMahjongg.desktop
kwin4	/var/lib/gnome/Debian/Games/Board/KWin4.desktop
gnome-freecell	/var/lib/gnome/Debian/Games/Card/Gnome FreeCell.desktop
sol	/var/lib/gnome/Debian/Games/Card/Gnome Solitaire Games.desktop
megami	/var/lib/gnome/Debian/Games/Card/KDE Blackjack.desktop
lskat	/var/lib/gnome/Debian/Games/Card/KDE Lieutnant Skat.desktop
kpat	/var/lib/gnome/Debian/Games/Card/KDE Patience.desktop
kpoker	/var/lib/gnome/Debian/Games/Card/KDE Poker.desktop
kblackbox	/var/lib/gnome/Debian/Games/Puzzles/KBlackBox.desktop
katomic	/var/lib/gnome/Debian/Games/Puzzles/KDE Atomic Entertainment.desktop
ksame	/var/lib/gnome/Debian/Games/Puzzles/KDE SameGame.desktop
ksokoban	/var/lib/gnome/Debian/Games/Puzzles/KDE Sokoban.desktop
khangman	/var/lib/gnome/Debian/Games/Puzzles/KHangMan.desktop
klickety	/var/lib/gnome/Debian/Games/Puzzles/Klickety.desktop
kmessedwords	/var/lib/gnome/Debian/Games/Puzzles/KMessedWords.desktop
kmines	/var/lib/gnome/Debian/Games/Puzzles/Kmines.desktop
foobillard	/var/lib/gnome/Debian/Games/Sports/Foobillard.desktop
kjumpingcube	/var/lib/gnome/Debian/Games/Strategy/KJumpingCube.desktop
konquest	/var/lib/gnome/Debian/Games/Strategy/Konquest.desktop
kfouleggs	/var/lib/gnome/Debian/Games/Tetris-like/KDE Foul Eggs.desktop
ksirtet	/var/lib/gnome/Debian/Games/Tetris-like/KDE Sirtet.desktop
ksmiletris	/var/lib/gnome/Debian/Games/Tetris-like/KDE Smiletris.desktop
amor	/var/lib/gnome/Debian/Games/Toys/AMOR.desktop
kaphorism	/var/lib/gnome/Debian/Games/Toys/K Aphorisms.desktop
ktuberling	/var/lib/gnome/Debian/Games/Toys/KDE Potato Guy.desktop
kmoon	/var/lib/gnome/Debian/Games/Toys/KMoon.desktop
kodo	/var/lib/gnome/Debian/Games/Toys/KOdometer.desktop
kteatime	/var/lib/gnome/Debian/Games/Toys/KTeaTime.desktop
kworldclock	/var/lib/gnome/Debian/Games/Toys/KWorldClock.desktop
lightspeed	/var/lib/gnome/Debian/Games/Toys/Light Speed.desktop
penguineyes	/var/lib/gnome/Debian/Games/Toys/Penguineyes.desktop
tdfsb	/var/lib/gnome/Debian/Games/Toys/tdfsb.desktop
wmtictactoe	/var/lib/gnome/Debian/Games/Toys/wmtictactoe.desktop
xcruiser	/var/lib/gnome/Debian/Games/Toys/xcruiser.desktop
xeyes	/var/lib/gnome/Debian/Games/Toys/Xeyes.desktop
xlogo	/var/lib/gnome/Debian/Games/Toys/Xlogo.desktop
dwww	/var/lib/gnome/Debian/Help/Dwww.desktop
info	/var/lib/gnome/Debian/Help/Info.desktop
khelpcenter	/var/lib/gnome/Debian/Help/KDE Help Center.desktop
hman	/var/lib/gnome/Debian/Help/Man2html.desktop
texdoctk	/var/lib/gnome/Debian/Help/Texdoctk.desktop
texshow	/var/lib/gnome/Debian/Help/TeXshow.desktop
xman	/var/lib/gnome/Debian/Help/Xman.desktop
yelp	/var/lib/gnome/Debian/Help/yelp.desktop
ktux	/var/lib/gnome/Debian/Screen/Lock/KTux.desktop
xscreensaver-command	/var/lib/gnome/Debian/Screen/Lock/Lock Screen (XScreenSaver).desktop
xplanet	/var/lib/gnome/Debian/Screen/Root-window/xplanet.desktop
xsetroot	/var/lib/gnome/Debian/Screen/Root-window/Xsetroot.desktop
xscreensaver-command	/var/lib/gnome/Debian/Screen/Save/Activate ScreenSaver (Next).desktop
xscreensaver-command	/var/lib/gnome/Debian/Screen/Save/Activate ScreenSaver (Previous).desktop
xscreensaver-command	/var/lib/gnome/Debian/Screen/Save/Activate ScreenSaver (Random).desktop
beforelight	/var/lib/gnome/Debian/Screen/Save/Beforelight.desktop
xscreensaver-command	/var/lib/gnome/Debian/Screen/Save/Demo Screen Hacks.desktop
xscreensaver-command	/var/lib/gnome/Debian/Screen/Save/Disable XScreenSaver.desktop
xscreensaver	/var/lib/gnome/Debian/Screen/Save/Enable XScreenSaver.desktop
xscreensaver-command	/var/lib/gnome/Debian/Screen/Save/Reinitialize XScreenSaver.desktop
xscreensaver-command	/var/lib/gnome/Debian/Screen/Save/ScreenSaver Preferences.desktop
aafire	/var/lib/gnome/Debian/Screen/Save/Text/AA Fire.desktop
Eterm	/var/lib/gnome/Debian/XShells/Eterm.desktop
gnome-terminal	/var/lib/gnome/Debian/XShells/Gnome Terminal.desktop
konsole	/var/lib/gnome/Debian/XShells/Konsole.desktop
multi-gnome-terminal	/var/lib/gnome/Debian/XShells/Multi GNOME Terminal.desktop
oneliner	/var/lib/gnome/Debian/XShells/OneLiner.desktop
powershell	/var/lib/gnome/Debian/XShells/PowerShell.desktop
xexec	/var/lib/gnome/Debian/XShells/xexec.desktop
xterm	/var/lib/gnome/Debian/XShells/XTerm.desktop
uxterm	/var/lib/gnome/Debian/XShells/XTerm (Unicode).desktop
acroread	/home/ziga/.kde/share/applnk/.hidden/acroread.desktop
mlv	/home/ziga/.kde/share/applnk/.hidden/mlv.desktop
inkscape	/home/ziga/.kde/share/applnk/.hidden/inkscape-2.desktop
Emacs	/home/ziga/.kde/share/applnk/.hidden/Emacs.desktop
perl	/home/ziga/.kde/share/applnk/.hidden/perl.desktop
gvim	/home/ziga/.kde/share/applnk/.hidden/gvim-2.desktop
audacity	/home/ziga/.kde/share/applnk/.hidden/audacity-2.desktop
gv	/home/ziga/.kde/share/applnk/.hidden/gv-2.desktop
abiword	/home/ziga/.kde/share/applnk/.hidden/abiword-2.desktop
texmacs	/home/ziga/.kde/share/applnk/Editors/texmacs.desktop
blender	/home/ziga/.kde/share/applnk/Graphics/Blender.desktop
kxmleditor	/usr/share/applnk/Applications/kxmleditor.desktop
designer-qt3	/usr/share/applnk/Development/designer-qt3.desktop
kdevelop3	/usr/share/applnk/Development/kdevelop3.desktop
kmdr-editor	/usr/share/applnk/Development/kmdr-editor.desktop
quanta	/usr/share/applnk/Development/quanta.desktop
tora	/usr/share/applnk/Development/tora.desktop
conglomerate	/usr/share/applications/conglomerate.desktop
/usr/bin/gvim	/usr/share/slix/apps/Aplikacije/Besedilo/gvim.desktop
kate	/usr/share/slix/apps/Aplikacije/Besedilo/kate.desktop
kile	/usr/share/slix/apps/Aplikacije/Besedilo/kile.desktop
kwrite	/usr/share/slix/apps/Aplikacije/Besedilo/kwrite.desktop
lyx	/usr/share/slix/apps/Aplikacije/Besedilo/lyx.desktop
nedit	/usr/share/slix/apps/Aplikacije/Besedilo/nedit.desktop
quanta	/usr/share/slix/apps/Aplikacije/Besedilo/quanta.desktop
texmacs	/usr/share/slix/apps/Aplikacije/Besedilo/texmacs.desktop
blender	/usr/share/slix/apps/Aplikacije/Grafika/Blender.desktop
dia-normal	/usr/share/slix/apps/Aplikacije/Grafika/Dia.desktop
Gimp	/usr/share/slix/apps/Aplikacije/Grafika/Gimp.desktop
/usr/bin/qcad	/usr/share/slix/apps/Aplikacije/Grafika/QCad.desktop
scribus	/usr/share/slix/apps/Aplikacije/Grafika/Scribus.desktop
sketch	/usr/share/slix/apps/Aplikacije/Grafika/Sketch.desktop
tgif	/usr/share/slix/apps/Aplikacije/Grafika/Tgif.desktop
oodraw	/usr/share/slix/apps/Aplikacije/Grafika/drawing.desktop
kgeo	/usr/share/slix/apps/Aplikacije/Grafika/kgeo.desktop
kooka	/usr/share/slix/apps/Aplikacije/Grafika/kooka.desktop
kpovmodeler	/usr/share/slix/apps/Aplikacije/Grafika/kpovmodeler.desktop
/usr/bin/pfaedit	/usr/share/slix/apps/Aplikacije/Grafika/pfaedit.desktop
sodipodi	/usr/share/slix/apps/Aplikacije/Grafika/sodipodi.desktop
xfig	/usr/share/slix/apps/Aplikacije/Grafika/xfig.desktop
/usr/bin/X11/gv	/usr/share/slix/apps/Aplikacije/Prezentacija/GV.desktop
acroread	/usr/share/slix/apps/Aplikacije/Prezentacija/acroread.desktop
pspresent	/usr/share/slix/apps/Aplikacije/Prezentacija/pspresent.desktop
mysqlcc	/usr/share/slix/apps/Aplikacije/Tabele/MySQL_CC.desktop
gnumeric	/usr/share/slix/apps/Aplikacije/Tabele/gnumeric.desktop
pgadmin3	/usr/share/slix/apps/Aplikacije/Tabele/pgAdmin3.desktop
kino	/usr/share/slix/apps/Aplikacije/Video/Kino.desktop
effectv	/usr/share/slix/apps/Aplikacije/Video/effectv.desktop
tvtime	/usr/share/slix/apps/Aplikacije/Video/net-tvtime.desktop
xawtv	/usr/share/slix/apps/Aplikacije/Video/xawtv.desktop
audacity	/usr/share/slix/apps/Aplikacije/Zvok/Audacity.desktop
muse	/usr/share/slix/apps/Aplikacije/Zvok/MusE.desktop
rezound	/usr/share/slix/apps/Aplikacije/Zvok/ReZound.desktop
soundtracker	/usr/share/slix/apps/Aplikacije/Zvok/SoundTracker.desktop
/usr/bin/spiralsynthmodular	/usr/share/slix/apps/Aplikacije/Zvok/SpiralSynthModular.desktop
grip	/usr/share/slix/apps/Aplikacije/Zvok/grip.desktop
noteedit	/usr/share/slix/apps/Aplikacije/Zvok/noteedit.desktop
sweep	/usr/share/slix/apps/Aplikacije/Zvok/sweep.desktop
terminatorX	/usr/share/slix/apps/Aplikacije/Zvok/terminatorX.desktop
sudo	/usr/share/slix/apps/Aplikacije/Zvok/qsynth.desktop
sudo	/usr/share/slix/apps/Aplikacije/Zvok/qjackctl.desktop
sudo	/usr/share/slix/apps/Aplikacije/Zvok/zynaddsubfx.desktop
oowriter	/usr/share/slix/apps/Aplikacije/OOo.desktop
soffice	/usr/share/slix/apps/Aplikacije/openoffice.desktop
Emacs	/usr/share/slix/apps/Aplikacije/Emacs.desktop
abiword	/usr/share/slix/apps/Aplikacije/AbiWord.desktop
gnome-dictionary	/usr/share/slix/apps/Internet/Biblioteke/GNOME_Dictionary.desktop
kalzium	/usr/share/slix/apps/Internet/Biblioteke/kalzium.desktop
kdict	/usr/share/slix/apps/Internet/Biblioteke/kdict.desktop
kstars	/usr/share/slix/apps/Internet/Biblioteke/kstars.desktop
/usr/bin/gq	/usr/share/slix/apps/Internet/Network/gq.desktop
mtr	/usr/share/slix/apps/Internet/Network/mtr.desktop
/usr/bin/gaim	/usr/share/slix/apps/Internet/Gaim.desktop
kfmclient	/usr/share/slix/apps/Internet/Konqueror.desktop
mozilla	/usr/share/slix/apps/Internet/Mozilla.desktop
/usr/bin/evolution	/usr/share/slix/apps/Internet/evolution.desktop
gnomemeeting	/usr/share/slix/apps/Internet/gnomemeeting.desktop
gtk-gnutella	/usr/share/slix/apps/Internet/gtk-gnutella.desktop
xchat	/usr/share/slix/apps/Internet/xchat.desktop
xrealvncviewer	/usr/share/slix/apps/Internet/xvncviewer.desktop
LinNeighborhood	/usr/share/slix/apps/Internet/linneighborhood.desktop
streamtuner	/usr/share/slix/apps/Internet/streamtuner.desktop
akregator	/usr/share/slix/apps/Internet/akregator.desktop
kcontrol	/usr/share/slix/apps/Nastavitve/KControl.desktop
kcron	/usr/share/slix/apps/Nastavitve/kcron.desktop
/usr/sbin/saveconfig	/usr/share/slix/apps/Nastavitve/saveconfig.desktop
ark	/usr/share/slix/apps/Pripomo?ki/Arhiviranje/ark.desktop
gcombust	/usr/share/slix/apps/Pripomo?ki/Arhiviranje/gcombust.desktop
k3b	/usr/share/slix/apps/Pripomo?ki/Arhiviranje/k3b.desktop
kdat	/usr/share/slix/apps/Pripomo?ki/Arhiviranje/kdat.desktop
kcharselect	/usr/share/slix/apps/Pripomo?ki/KCharSelect.desktop
/usr/bin/gpa	/usr/share/slix/apps/Pripomo?ki/The_GNU_Privacy_Assistant.desktop
xkill	/usr/share/slix/apps/Pripomo?ki/Xkill.desktop
gfontview	/usr/share/slix/apps/Pripomo?ki/gfontview.desktop
grip	/usr/share/slix/apps/Pripomo?ki/grip.desktop
gucharmap	/usr/share/slix/apps/Pripomo?ki/gucharmap.desktop
kcalc	/usr/share/slix/apps/Pripomo?ki/kcalc.desktop
kcoloredit	/usr/share/slix/apps/Pripomo?ki/kcoloredit.desktop
kdf	/usr/share/slix/apps/Pripomo?ki/kdf.desktop
knotes	/usr/share/slix/apps/Pripomo?ki/knotes.desktop
kpilot	/usr/share/slix/apps/Pripomo?ki/kpilot.desktop
krfb	/usr/share/slix/apps/Pripomo?ki/krfb.desktop
kruler	/usr/share/slix/apps/Pripomo?ki/kruler.desktop
ksnapshot	/usr/share/slix/apps/Pripomo?ki/ksnapshot.desktop
ktimer	/usr/share/slix/apps/Pripomo?ki/ktimer.desktop
mc	/usr/share/slix/apps/Pripomo?ki/mc.desktop
gmplayer	/usr/share/slix/apps/Pripomo?ki/mplayer.desktop
xclock	/usr/share/slix/apps/Pripomo?ki/xclock.desktop
xmms	/usr/share/slix/apps/Pripomo?ki/xmms.desktop
kdesu	/usr/share/slix/apps/Sistem/Synaptic.desktop
/usr/bin/usbview	/usr/share/slix/apps/Sistem/USB_View.desktop
kinfocenter	/usr/share/slix/apps/Sistem/kinfocenter.desktop
sudo	/usr/share/slix/apps/Sistem/qps_root.desktop
sudo	/usr/share/slix/apps/Sistem/xlogmaster.desktop
qps	/usr/share/slix/apps/Sistem/qps.desktop
cupsconfig	/usr/share/slix/apps/Sistem/cupsconfig.desktop
konsole	/usr/share/slix/apps/Sistem/shell.desktop
sh	/usr/share/slix/apps/Zabava/Xaos.desktop
/usr/games/bzflag	/usr/share/slix/apps/Zabava/bzflag.desktop
xeyes	/usr/share/slix/apps/Zabava/xeyes.desktop
abiword	/usr/share/slix/apps/AbiWord.desktop
Emacs	/usr/share/slix/apps/Emacs.desktop
Browse	/usr/share/slix/apps/Mozilla.desktop
oowriter	/usr/share/slix/apps/OOo.desktop
cupsconfig	/usr/share/slix/apps/cupsconfig.desktop
qps	/usr/share/slix/apps/qps.desktop
konsole	/usr/share/slix/apps/shell.desktop
nautilus	/usr/share/applications/network-scheme.desktop
xsane	/usr/share/applications/xsane.desktop
gnome-control-center	/usr/share/applications/gnomecc.desktop
gnome-system-monitor	/usr/share/applications/gnome-system-monitor.desktop
nautilus	/usr/share/applications/nautilus.desktop
gcmui	/usr/share/applications/gcm.desktop
gdmflexiserver	/usr/share/applications/gdmflexiserver-xnest.desktop
gnumeric	/usr/share/applications/gnumeric.desktop
dasher	/usr/share/applications/dasher.desktop
xchat	/usr/share/applications/xchat.desktop
sodipodi	/usr/share/applications/sodipodi.desktop
gucharmap	/usr/share/applications/gucharmap.desktop
gksu	/usr/share/applications/synaptic.desktop
gnomemeeting	/usr/share/applications/gnomemeeting.desktop
yelp	/usr/share/applications/yelp.desktop
glade-2	/usr/share/applications/glade-2.desktop
gcombust	/usr/share/applications/gcombust.desktop
gksu	/usr/share/applications/gdmsetup.desktop
gdmflexiserver	/usr/share/applications/gdmflexiserver.desktop
file-roller	/usr/share/applications/file-roller.desktop
alc	/usr/share/applications/alc.desktop
xscreensaver-demo	/usr/share/applications/screensaver-properties.desktop
eclipse	/usr/share/applications/eclipse.desktop
inkscape	/usr/share/applications/inkscape.desktop
gedit	/usr/share/applications/gedit.desktop
gnome-system-log	/usr/share/applications/gnome-system-log.desktop
oowriter	/usr/share/applications/ooo645writer.desktop
ooweb	/usr/share/applications/ooo645web.desktop
gnome-search-tool	/usr/share/applications/gnome-search-tool.desktop
gnome-dictionary	/usr/share/applications/gnome-dictionary.desktop
gfloppy	/usr/share/applications/gfloppy.desktop
bug-buddy	/usr/share/applications/bug-buddy.desktop
ggv	/usr/share/applications/ggv.desktop
gconf-editor	/usr/share/applications/gconf-editor.desktop
dia-gnome	/usr/share/applications/dia.desktop
filmgimp	/usr/share/applications/filmgimp.desktop
wxcas	/usr/share/applications/wxcas.desktop
gnome-terminal	/usr/share/applications/gnome-terminal.desktop
emacs21	/usr/share/applications/emacs21.desktop
vumeter	/usr/share/applications/reclevel.desktop
vumeter	/usr/share/applications/vumeter.desktop
gperiodic	/usr/share/applications/gperiodic.desktop
gnome-volume-control	/usr/share/applications/gnome-volume-control.desktop
gnome-cd	/usr/share/applications/gnome-cd.desktop
gnome-sound-recorder	/usr/share/applications/gnome-sound-recorder.desktop
gcalctool	/usr/share/applications/gcalctool.desktop
ooimpress	/usr/share/applications/ooo645impress.desktop
realplayer	/usr/share/applications/realplayer.desktop
gimp-remote-2.0	/usr/share/applications/gimp-2.0.desktop
gksu	/usr/share/applications/gksu.desktop
kcmshell	/usr/share/applications/kde/khtml_plugins.desktop
kcmshell	/usr/share/applications/kde/kresources.desktop
umbrello	/usr/share/applications/kde/umbrello.desktop
amor	/usr/share/applications/kde/amor.desktop
ark	/usr/share/applications/kde/ark.desktop
kcmshell	/usr/share/applications/kde/kcmkicker.desktop
kcmshell	/usr/share/applications/kde/kcmhistory.desktop
kfmclient	/usr/share/applications/kde/Home.desktop
kfmclient	/usr/share/applications/kde/kfmclient_dir.desktop
kfmclient	/usr/share/applications/kde/kfmclient.desktop
appletproxy	/usr/share/applications/kde/knewsticker-standalone.desktop
kfmclient	/usr/share/applications/kde/kfmclient_html.desktop
kfmclient	/usr/share/applications/kde/kfmclient_war.desktop
kfmclient	/usr/share/applications/kde/konqbrowser.desktop
konqueror	/usr/share/applications/kde/konquerorsu.desktop
ksysguard	/usr/share/applications/kde/ksysguard.desktop
kate	/usr/share/applications/kde/kate.desktop
kwrite	/usr/share/applications/kde/kwrite.desktop
kcalc	/usr/share/applications/kde/kcalc.desktop
kcharselect	/usr/share/applications/kde/KCharSelect.desktop
kcmshell	/usr/share/applications/kde/kcmlirc.desktop
kdict	/usr/share/applications/kde/kdict.desktop
kget	/usr/share/applications/kde/kget.desktop
kppplogview	/usr/share/applications/kde/kppplogview.desktop
kppp	/usr/share/applications/kde/Kppp.desktop
kwifimanager	/usr/share/applications/kde/kwifimanager.desktop
krdc	/usr/share/applications/kde/krdc.desktop
kcmshell	/usr/share/applications/kde/kcmkrfb.desktop
krfb	/usr/share/applications/kde/krfb.desktop
ksirc	/usr/share/applications/kde/ksirc.desktop
kcmshell	/usr/share/applications/kde/kcmwifi.desktop
kregexpeditor	/usr/share/applications/kde/kregexpeditor.desktop
kdepasswd	/usr/share/applications/kde/kdepasswd.desktop
kcmshell	/usr/share/applications/kde/userinfo.desktop
kmoon	/usr/share/applications/kde/kmoon.desktop
kodo	/usr/share/applications/kde/kodo.desktop
kteatime	/usr/share/applications/kde/kteatime.desktop
kworldclock	/usr/share/applications/kde/kworldclock.desktop
kcmshell	/usr/share/applications/kde/kcmdf.desktop
kdf	/usr/share/applications/kde/kdf.desktop
kwikdisk	/usr/share/applications/kde/kwikdisk.desktop
kedit	/usr/share/applications/kde/KEdit.desktop
kfloppy	/usr/share/applications/kde/KFloppy.desktop
kgpg	/usr/share/applications/kde/kgpg.desktop
khexedit	/usr/share/applications/kde/khexedit.desktop
kjots	/usr/share/applications/kde/Kjots.desktop
kcmshell	/usr/share/applications/kde/laptop.desktop
kcmshell	/usr/share/applications/kde/pcmcia.desktop
kcmshell	/usr/share/applications/kde/kvaio.desktop
kcmshell	/usr/share/applications/kde/kwalletconfig.desktop
ktimer	/usr/share/applications/kde/ktimer.desktop
atlantikdesigner	/usr/share/applications/kde/atlantikdesigner.desktop
kwalletmanager	/usr/share/applications/kde/kwalletmanager.desktop
artsbuilder	/usr/share/applications/kde/artsbuilder.desktop
artscontrol	/usr/share/applications/kde/artscontrol.desktop
juk	/usr/share/applications/kde/juk.desktop
kaboodle	/usr/share/applications/kde/kaboodle.desktop
kcmshell	/usr/share/applications/kde/libkcddb.desktop
kscd	/usr/share/applications/kde/kscd.desktop
kcmshell	/usr/share/applications/kde/audiocd.desktop
kaudiocreator	/usr/share/applications/kde/kaudiocreator.desktop
kcmshell	/usr/share/applications/kde/kwindecoration.desktop
kcmshell	/usr/share/applications/kde/kwinoptions.desktop
kmid	/usr/share/applications/kde/kmid.desktop
kmix	/usr/share/applications/kde/kmix.desktop
kcmshell	/usr/share/applications/kde/kmixcfg.desktop
krec	/usr/share/applications/kde/krec.desktop
noatun	/usr/share/applications/kde/noatun.desktop
kig	/usr/share/applications/kde/kig.desktop
kpalmdoc	/usr/share/applications/kde/kpalmdoc.desktop
kpilot	/usr/share/applications/kde/kpilot.desktop
kpilotDaemon	/usr/share/applications/kde/kpilotdaemon.desktop
korganizer	/usr/share/applications/kde/korganizer.desktop
kalarm	/usr/share/applications/kde/kalarm.desktop
kaddressbook	/usr/share/applications/kde/kaddressbook.desktop
kandy	/usr/share/applications/kde/kandy.desktop
karm	/usr/share/applications/kde/karm.desktop
ktnef	/usr/share/applications/kde/ktnef.desktop
kcmshell	/usr/share/applications/kde/kcmcgi.desktop
kmail	/usr/share/applications/kde/KMail.desktop
knode	/usr/share/applications/kde/KNode.desktop
knotes	/usr/share/applications/kde/knotes.desktop
kdialog	/usr/share/applications/kde/konsolekalendar.desktop
kontact	/usr/share/applications/kde/Kontact.desktop
korn	/usr/share/applications/kde/KOrn.desktop
atlantik	/usr/share/applications/kde/atlantik.desktop
kcmshell	/usr/share/applications/kde/keyboard_layout.desktop
cervisia	/usr/share/applications/kde/cervisia.desktop
flashkard	/usr/share/applications/kde/flashkard.desktop
konsole	/usr/share/applications/kde/konsole.desktop
konsole	/usr/share/applications/kde/konsolesu.desktop
kalzium	/usr/share/applications/kde/kalzium.desktop
kappfinder	/usr/share/applications/kde/kappfinder.desktop
kasteroids	/usr/share/applications/kde/kasteroids.desktop
kcmshell	/usr/share/applications/kde/keyboard.desktop
kcmshell	/usr/share/applications/kde/componentchooser.desktop
kcmshell	/usr/share/applications/kde/khotkeys.desktop
kcontrol	/usr/share/applications/kde/KControl.desktop
kcmshell	/usr/share/applications/kde/arts.desktop
kcmshell	/usr/share/applications/kde/background.desktop
kcmshell	/usr/share/applications/kde/bell.desktop
kcmshell	/usr/share/applications/kde/cache.desktop
kcmshell	/usr/share/applications/kde/clock.desktop
kcmshell	/usr/share/applications/kde/colors.desktop
kcmshell	/usr/share/applications/kde/desktopbehavior.desktop
kcmshell	/usr/share/applications/kde/cookies.desktop
kcmshell	/usr/share/applications/kde/crypto.desktop
kcmshell	/usr/share/applications/kde/desktop.desktop
kcmshell	/usr/share/applications/kde/kcmperformance.desktop
kcmshell	/usr/share/applications/kde/desktoppath.desktop
kcmshell	/usr/share/applications/kde/devices.desktop
kcmshell	/usr/share/applications/kde/display.desktop
kcmshell	/usr/share/applications/kde/dma.desktop
kcmshell	/usr/share/applications/kde/ebrowsing.desktop
kcmshell	/usr/share/applications/kde/email.desktop
kcmshell	/usr/share/applications/kde/energy.desktop
kcmshell	/usr/share/applications/kde/filebrowser.desktop
kcmshell	/usr/share/applications/kde/fileshare.desktop
kcmshell	/usr/share/applications/kde/filetypes.desktop
kcmshell	/usr/share/applications/kde/fonts.desktop
kcmshell	/usr/share/applications/kde/icons.desktop
kcmshell	/usr/share/applications/kde/interrupts.desktop
kcmshell	/usr/share/applications/kde/ioports.desktop
kcmshell	/usr/share/applications/kde/ioslaveinfo.desktop
kcmshell	/usr/share/applications/kde/kcmaccess.desktop
kcmshell	/usr/share/applications/kde/kcmcss.desktop
kcmshell	/usr/share/applications/kde/kcmfontinst.desktop
kcmshell	/usr/share/applications/kde/kcmkded.desktop
kcmshell	/usr/share/applications/kde/kcmlaunch.desktop
kcmshell	/usr/share/applications/kde/kcmnotify.desktop
kcmshell	/usr/share/applications/kde/khtml_behavior.desktop
kcmshell	/usr/share/applications/kde/kcmsmserver.desktop
kcmshell	/usr/share/applications/kde/kcmtaskbar.desktop
kcmshell	/usr/share/applications/kde/kcmusb.desktop
kcmshell	/usr/share/applications/kde/kcmview1394.desktop
kcmshell	/usr/share/applications/kde/kdm.desktop
kcmshell	/usr/share/applications/kde/keys.desktop
kcmshell	/usr/share/applications/kde/khtml_java_js.desktop
kcmshell	/usr/share/applications/kde/khtml_fonts.desktop
krandrtray	/usr/share/applications/kde/krandrtray.desktop
kcmshell	/usr/share/applications/kde/lanbrowser.desktop
kcmshell	/usr/share/applications/kde/language.desktop
kcmshell	/usr/share/applications/kde/memory.desktop
kcmshell	/usr/share/applications/kde/mouse.desktop
kcmshell	/usr/share/applications/kde/netpref.desktop
kcmshell	/usr/share/applications/kde/nic.desktop
kcmshell	/usr/share/applications/kde/panel.desktop
kcmshell	/usr/share/applications/kde/spellchecking.desktop
kcmshell	/usr/share/applications/kde/partitions.desktop
kcmshell	/usr/share/applications/kde/passwords.desktop
kcmshell	/usr/share/applications/kde/pci.desktop
kcmshell	/usr/share/applications/kde/privacy.desktop
kcmshell	/usr/share/applications/kde/processor.desktop
kcmshell	/usr/share/applications/kde/proxy.desktop
kcmshell	/usr/share/applications/kde/screensaver.desktop
kcmshell	/usr/share/applications/kde/scsi.desktop
kcmshell	/usr/share/applications/kde/smbstatus.desktop
kcmshell	/usr/share/applications/kde/sound.desktop
kcmshell	/usr/share/applications/kde/useragent.desktop
kcmshell	/usr/share/applications/kde/style.desktop
catalogmanager	/usr/share/applications/kde/catalogmanager.desktop
kcmshell	/usr/share/applications/kde/xserver.desktop
kfind	/usr/share/applications/kde/Kfind.desktop
katomic	/usr/share/applications/kde/katomic.desktop
kbabeldict	/usr/share/applications/kde/kbabeldict.desktop
kbabel	/usr/share/applications/kde/kbabel.desktop
kcolorchooser	/usr/share/applications/kde/kcolorchooser.desktop
kbackgammon	/usr/share/applications/kde/kbackgammon.desktop
kbattleship	/usr/share/applications/kde/kbattleship.desktop
kblackbox	/usr/share/applications/kde/kblackbox.desktop
kbounce	/usr/share/applications/kde/kbounce.desktop
kbruch	/usr/share/applications/kde/kbruch.desktop
kbugbuster	/usr/share/applications/kde/kbugbuster.desktop
kcmshell	/usr/share/applications/kde/linuz.desktop
kpersonalizer	/usr/share/applications/kde/kpersonalizer.desktop
kcoloredit	/usr/share/applications/kde/kcoloredit.desktop
kcron	/usr/share/applications/kde/kcron.desktop
kdat	/usr/share/applications/kde/kdat.desktop
ksig	/usr/share/applications/kde/ksig.desktop
kcmshell	/usr/share/applications/kde/kcmvim.desktop
kpackage	/usr/share/applications/kde/kpackage.desktop
ksysv	/usr/share/applications/kde/ksysv.desktop
kuser	/usr/share/applications/kde/kuser.desktop
kdeprintfax	/usr/share/applications/kde/kdeprintfax.desktop
kjobviewer	/usr/share/applications/kde/kjobviewer.desktop
kcmshell	/usr/share/applications/kde/printers.desktop
khelpcenter	/usr/share/applications/kde/Help.desktop
klipper	/usr/share/applications/kde/klipper.desktop
kmenuedit	/usr/share/applications/kde/kmenuedit.desktop
kpager	/usr/share/applications/kde/kpager.desktop
kcmshell	/usr/share/applications/kde/ksplashthememgr.desktop
ktip	/usr/share/applications/kde/ktip.desktop
khangman	/usr/share/applications/kde/khangman.desktop
kiten	/usr/share/applications/kde/kiten.desktop
klettres	/usr/share/applications/kde/klettres.desktop
kmessedwords	/usr/share/applications/kde/kmessedwords.desktop
kmplot	/usr/share/applications/kde/kmplot.desktop
kpercentage	/usr/share/applications/kde/kpercentage.desktop
kstars	/usr/share/applications/kde/kstars.desktop
ktouch	/usr/share/applications/kde/ktouch.desktop
kverbos	/usr/share/applications/kde/kverbos.desktop
kvoctrain	/usr/share/applications/kde/kvoctrain.desktop
kenolaba	/usr/share/applications/kde/kenolaba.desktop
kfouleggs	/usr/share/applications/kde/kfouleggs.desktop
kgoldrunner	/usr/share/applications/kde/KGoldrunner.desktop
kjumpingcube	/usr/share/applications/kde/kjumpingcube.desktop
klickety	/usr/share/applications/kde/klickety.desktop
klines	/usr/share/applications/kde/klines.desktop
kmahjongg	/usr/share/applications/kde/kmahjongg.desktop
kmines	/usr/share/applications/kde/kmines.desktop
kolf	/usr/share/applications/kde/kolf.desktop
konquest	/usr/share/applications/kde/konquest.desktop
kpat	/usr/share/applications/kde/kpat.desktop
kpoker	/usr/share/applications/kde/kpoker.desktop
kreversi	/usr/share/applications/kde/kreversi.desktop
ksame	/usr/share/applications/kde/ksame.desktop
kshisen	/usr/share/applications/kde/kshisen.desktop
ksirtet	/usr/share/applications/kde/ksirtet.desktop
ksmiletris	/usr/share/applications/kde/ksmiletris.desktop
ksnake	/usr/share/applications/kde/ksnake.desktop
ksokoban	/usr/share/applications/kde/ksokoban.desktop
kspaceduel	/usr/share/applications/kde/kspaceduel.desktop
ktron	/usr/share/applications/kde/ktron.desktop
ktuberling	/usr/share/applications/kde/ktuberling.desktop
kwin4	/usr/share/applications/kde/kwin4.desktop
lskat	/usr/share/applications/kde/lskat.desktop
kviewshell	/usr/share/applications/kde/kdvi.desktop
kfax	/usr/share/applications/kde/kfax.desktop
kghostview	/usr/share/applications/kde/kghostview.desktop
kiconedit	/usr/share/applications/kde/kiconedit.desktop
kcmshell	/usr/share/applications/kde/kcmkmrml.desktop
kooka	/usr/share/applications/kde/kooka.desktop
kpaint	/usr/share/applications/kde/kpaint.desktop
kpdf	/usr/share/applications/kde/kpdf.desktop
kpovmodeler	/usr/share/applications/kde/kpovmodeler.desktop
kruler	/usr/share/applications/kde/kruler.desktop
ksnapshot	/usr/share/applications/kde/ksnapshot.desktop
kuickshow	/usr/share/applications/kde/kuickshow.desktop
kview	/usr/share/applications/kde/kview.desktop
kompare	/usr/share/applications/kde/kompare.desktop
kuiviewer	/usr/share/applications/kde/kuiviewer.desktop
kcmshell	/usr/share/applications/kde/lilo.desktop
kcachegrind	/usr/share/applications/kde/kcachegrind.desktop
kile	/usr/share/applications/kde/kile.desktop
smb4k	/usr/share/applications/kde/smb4k.desktop
gnome-remote-shell	/usr/share/applications/gnome-network-utilities.desktop
gnome-netinfo	/usr/share/applications/gnome-netinfo.desktop
grip	/usr/share/applications/grip.desktop
oocalc	/usr/share/applications/ooo645calc.desktop
oomath	/usr/share/applications/ooo645math.desktop
oopadmin	/usr/share/applications/ooo645printeradmin.desktop
oodraw	/usr/share/applications/ooo645draw.desktop
ooffice	/usr/share/applications/ooo645template.desktop
gmfsk	/usr/share/applications/gmfsk.desktop
tsclient	/usr/share/applications/tsclient.desktop
blender	/usr/share/applications/blender.desktop
mlv	/usr/share/applications/mlview.desktop
nautilus	/usr/share/applications/nautilus-home.desktop
nautilus	/usr/share/applications/nautilus-computer.desktop
mozilla-thunderbird	/usr/share/applications/mozilla-thunderbird-pm.desktop
mozilla-thunderbird	/usr/share/applications/mozilla-thunderbird.desktop
amule	/usr/share/applications/amule.desktop
scribus	/usr/share/applications/scribus.desktop
gksuexec	/usr/share/applications/gksuexec.desktop
firefox	/usr/share/applications/mozilla-firefox.desktop
gmplayer	/usr/share/applications/mplayer.desktop
slix-central	/usr/share/applications/slix-central.desktop
gv4l	/usr/share/applications/gnome-gv4l.desktop
cyca-central	/usr/share/applications/cyca-central.desktop
\.


--
-- Data for TOC entry 582 (OID 2071468)
-- Name: project; Type: TABLE DATA; Schema: public; Owner: postgres
--

COPY project (projectname_short, projectname_full, desc_short, desc_full, latest_release_version, latest_release_date, app, home, freshmeat, forge, package) FROM stdin;
blender	Blender	A very fast and versatile 3D graphics creation suite.	Blender is a fully integrated 3D graphics creation suite allowing modeling, animation, rendering, post-production, real-time interactive 3D, and game creation and playback with cross-platform compatibility.	2.34	2004-08-05	\N	\N	\N	\N	\N
scribus	Scribus	A DTP-Program for Linux using the Qt-Library	Scribus is a DTP program for Linux. Its goal is to provide an\neasy-to-use tool for simple Desktop Publishing. It tries be as\nprofessional as possible.\n	1.0.1	2003-08-08	\N	\N	\N	\N	\N
mozilla	Mozilla	A Web browser for X11.	Mozilla is a Web browser that is being developed by the Free Software Community with the cooperation and support of Netscape. The current Mozilla is a completely new software based on the &quot;NGLayout&quot; layout engine and runs on almost all current operating systems. Mozilla's user interface is written on top of NGLayout using XUL and JavaScript.  The Mozilla project only develops and tests the source code for other projects / companies to use. Netscape 6 (the Web browser from Netscape) and Beonex Communicator (an open-source project to make a Mozilla for end-users) are directly based on Mozilla. Many other projects use/embed Mozilla's rendering engine (e.g., Galeon).\n	1.4	2003-07-01	\N	\N	\N	\N	\N
texmacs	GNU TeXmacs	A structured &quot;wysiwyg&quot; technical text editor.	GNU TeXmacs is a free scientific text editor, which was inspired by both TeX and GNU Emacs. The editor allows you to write structured documents via a &quot;wysiwyg&quot; and user friendly interface. The program implements high quality typesetting algorithms and TeX fonts. It is also possible to use TeXmacs as an interface to computer algebra systems. Finally, TeXmacs supports the Guile/Scheme extension language, which makes it possible to adapt the user interface to specific needs, and even to extend the editor.	1.0.4.1	2004-08-09	\N	\N	\N	\N	\N
inkscape	Inkscape	An SVG-based vector drawing application.	Inkscape is an SVG-based graphics editor featuring alpha \nblending, node editing, SVG to PNG export, and more. Its \ngoal is for features similar to Illustrator, CorelDraw, Visio, \netc.	0.39	2004-07-20	\N	\N	\N	\N	\N
openoffice	OpenOffice.org	An Open Source version of StarOffice.	OpenOffice.org is the Open Source project through which Sun Microsystems is releasing the technology for the popular StarOffice productivity suite.	1.1.2	2004-07-31	\N	\N	\N	\N	\N
staroffice	StarOffice	A cross-platform office suite.	StarOffice is an integrated Microsoft Office-compatible suite of productivity applications. It provides word processing, spreadsheet, presentation, charting, and graphics applications.	7	2003-09-21	\N	\N	\N	\N	\N
dia	Dia	A GTK2-based diagram drawing program, similar to Visio.	Dia is a program for creating diagrams of all kinds. The current version can do UML class diagrams, Entity-Relationship modeling, network diagrams, and much more. The engine is very flexible and dynamically loads diagram-types from disk. It can currently export to PostScript and load/save in an XML format.\n	0.93	2004-05-04	\N	\N	\N	\N	\N
tetex	teTeX	A TeX distribution for Unix.	teTeX is the de facto standard TeX distribution\nfor a wide range of Unix-type operating systems,\nand serves as a building block for others. It's\neasy to install and customize.\n	2.0.2	2003-03-08	\N	\N	\N	\N	\N
latex	LaTeX	A high-quality typesetting system based on TeX.	LaTeX is a document preparation system for\nhigh-quality typesetting based on TeX. It is most\noften used for medium-to-large technical or\nscientific documents, but it can be used for\nalmost any form of publishing. It is not a word\nprocessor; instead, it encourages authors not to\nworry too much about the appearance of their\ndocuments, but to concentrate on getting the right\ncontent. 	2003/12/01	2004-05-13	\N	\N	\N	\N	\N
kile	Kile	An integrated LaTeX development environment for KDE 3.	Kile is a LaTeX source editor, TeX shell, and gnuplot frontend for KDE 3.\n	1.6.3	2004-05-12	\N	\N	\N	\N	\N
graphviz	graphviz	Graph drawing utilities with web and graphical interfaces.	graphviz is a set of graph drawing tools and libraries. It supports hierarchical and mass-spring drawings; although the tools are scalable, their emphasis is on making very good drawings of reasonably-sized graphs. Package components include batch layout filters and interactive editors for X11, Java, and a TCL/tk extension. The batch filters can be configured as a web visualization service (using GIF and click-maps). A generic ActiveX client-server component is a recent addition to this package. Typical applications include display of finite state machines, software diagrams, database schemas, and communication networks.  This package contains the layout commands dot, neato, and twopi, the interactive tools lefty, dotty, lneato, tcldot, and gpr, and the graph stream processors gpr, ccomps, colorize, gc, nop, prune, sccmap, tred, and unflatten. The Java graph display client is named Grappa and is available as a separate package.	1.8.10	2002-12-27	\N	\N	\N	\N	\N
audacity	Audacity	A cross-platform multitrack audio editor.	Audacity is a cross-platform multitrack audio editor. It allows you to record sounds directly or to import Ogg, WAV, AIFF, AU, IRCAM, or MP3 files. It features a few simple effects, all of the editing features you should need, and unlimited undo. The GUI was built with wxWindows and the audio I/O currently uses OSS under Linux. Audacity runs on Linux/*BSD, MacOS, and Windows. 	1.2.1	2004-05-09	\N	\N	\N	\N	\N
hugin	hugin	A  tool for creating panoramas.	hugin is a tool for assembling a mosaic of\nphotographs into a complete immersive panorama by\nstitching any series of overlapping pictures. It\nuses the powerful but difficult to use Panorama\nTools as its backend.\n	0.4b	2004-03-13	\N	\N	\N	\N	\N
streamtuner	streamtuner	A GTK+ 2.0 stream directory browser.	streamtuner is a stream directory browser. Through\nthe use of a plugin system, it offers an intuitive\nGTK+ 2.0 interface to Internet radio directories\nsuch as SHOUTcast and Live365.	0.12.5	2004-08-09	\N	\N	\N	\N	\N
akregator	aKregator	A KDE RSS aggregator.	aKregator is a KDE RSS aggregator. It supports the\nbest known metaphors from existing aggregators. It\nalso facilitates good integration with KDE by\nmaintaining an interface similar to Konqueror and\nKMail.	1.0-beta5	2004-07-18	\N	\N	\N	\N	\N
\.


--
-- TOC entry 109 (OID 173239)
-- Name: links_url_idx; Type: INDEX; Schema: public; Owner: postgres
--

CREATE UNIQUE INDEX links_url_idx ON links USING btree (url);


--
-- TOC entry 111 (OID 173274)
-- Name: zip_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY zip
    ADD CONSTRAINT zip_pkey PRIMARY KEY (zip);

ALTER TABLE zip CLUSTER ON zip_pkey;


--
-- TOC entry 108 (OID 173374)
-- Name: links_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY links
    ADD CONSTRAINT links_pkey PRIMARY KEY (id);


--
-- TOC entry 112 (OID 173432)
-- Name: mime_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY mime
    ADD CONSTRAINT mime_pkey PRIMARY KEY ("type");

ALTER TABLE mime CLUSTER ON mime_pkey;


--
-- TOC entry 113 (OID 184714)
-- Name: turba_objects_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY turba_objects
    ADD CONSTRAINT turba_objects_pkey PRIMARY KEY (object_id);


--
-- TOC entry 114 (OID 1867210)
-- Name: pg_ts_dict_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY pg_ts_dict
    ADD CONSTRAINT pg_ts_dict_pkey PRIMARY KEY (dict_name);


--
-- TOC entry 115 (OID 1867236)
-- Name: pg_ts_parser_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY pg_ts_parser
    ADD CONSTRAINT pg_ts_parser_pkey PRIMARY KEY (prs_name);


--
-- TOC entry 116 (OID 1867261)
-- Name: pg_ts_cfg_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY pg_ts_cfg
    ADD CONSTRAINT pg_ts_cfg_pkey PRIMARY KEY (ts_name);


--
-- TOC entry 117 (OID 1867268)
-- Name: pg_ts_cfgmap_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY pg_ts_cfgmap
    ADD CONSTRAINT pg_ts_cfgmap_pkey PRIMARY KEY (ts_name, tok_alias);


--
-- TOC entry 110 (OID 1925518)
-- Name: links_url_key; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY links
    ADD CONSTRAINT links_url_key UNIQUE (url);


--
-- TOC entry 107 (OID 1925520)
-- Name: links_name_key; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY links
    ADD CONSTRAINT links_name_key UNIQUE (name);


--
-- TOC entry 118 (OID 2051527)
-- Name: globs_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY globs
    ADD CONSTRAINT globs_pkey PRIMARY KEY (pattern, "type");

ALTER TABLE globs CLUSTER ON globs_pkey;


--
-- TOC entry 119 (OID 2054694)
-- Name: apps_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY apps
    ADD CONSTRAINT apps_pkey PRIMARY KEY (fname);

ALTER TABLE apps CLUSTER ON apps_pkey;


--
-- TOC entry 120 (OID 2061970)
-- Name: app_input_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY app_mime
    ADD CONSTRAINT app_input_pkey PRIMARY KEY (app, mime);


--
-- TOC entry 121 (OID 2062801)
-- Name: app_categories_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY app_category
    ADD CONSTRAINT app_categories_pkey PRIMARY KEY (app, category);


--
-- TOC entry 122 (OID 2063951)
-- Name: configuration_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY configuration
    ADD CONSTRAINT configuration_pkey PRIMARY KEY (configuration);


--
-- TOC entry 123 (OID 2063967)
-- Name: app_configuration_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY app_configuration
    ADD CONSTRAINT app_configuration_pkey PRIMARY KEY (app, configuration);


--
-- TOC entry 124 (OID 2064012)
-- Name: app_exec_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY app_exec
    ADD CONSTRAINT app_exec_pkey PRIMARY KEY (app, exec);


--
-- TOC entry 125 (OID 2068218)
-- Name: action_verb_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY action_verb
    ADD CONSTRAINT action_verb_pkey PRIMARY KEY (name);


--
-- TOC entry 126 (OID 2068324)
-- Name: icon_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY icon
    ADD CONSTRAINT icon_pkey PRIMARY KEY (icon);


--
-- TOC entry 128 (OID 2068341)
-- Name: app_registry_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY app_registry
    ADD CONSTRAINT app_registry_pkey PRIMARY KEY (app, registry);


--
-- TOC entry 127 (OID 2069901)
-- Name: app_icon_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY app_icon
    ADD CONSTRAINT app_icon_pkey PRIMARY KEY (app, icon);


--
-- TOC entry 129 (OID 2071476)
-- Name: project_pkey; Type: CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY project
    ADD CONSTRAINT project_pkey PRIMARY KEY (projectname_full);


--
-- TOC entry 584 (OID 2051509)
-- Name: $1; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY mime
    ADD CONSTRAINT "$1" FOREIGN KEY (aliasfor) REFERENCES mime("type");


--
-- TOC entry 585 (OID 2054562)
-- Name: $1; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY globs
    ADD CONSTRAINT "$1" FOREIGN KEY ("type") REFERENCES mime("type") ON UPDATE CASCADE ON DELETE CASCADE;


--
-- TOC entry 591 (OID 2061962)
-- Name: $1; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY app_mime
    ADD CONSTRAINT "$1" FOREIGN KEY (app) REFERENCES apps(fname);


--
-- TOC entry 590 (OID 2061966)
-- Name: $2; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY app_mime
    ADD CONSTRAINT "$2" FOREIGN KEY (mime) REFERENCES mime("type");


--
-- TOC entry 592 (OID 2062797)
-- Name: $1; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY app_category
    ADD CONSTRAINT "$1" FOREIGN KEY (app) REFERENCES apps(fname);


--
-- TOC entry 595 (OID 2063955)
-- Name: $1; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY app_configuration
    ADD CONSTRAINT "$1" FOREIGN KEY (app) REFERENCES apps(fname);


--
-- TOC entry 594 (OID 2063959)
-- Name: $2; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY app_configuration
    ADD CONSTRAINT "$2" FOREIGN KEY (configuration) REFERENCES configuration(configuration);


--
-- TOC entry 596 (OID 2064008)
-- Name: $1; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY app_exec
    ADD CONSTRAINT "$1" FOREIGN KEY (app) REFERENCES apps(fname);


--
-- TOC entry 583 (OID 2064784)
-- Name: $2; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY mime
    ADD CONSTRAINT "$2" FOREIGN KEY (isa) REFERENCES mime("type");


--
-- TOC entry 589 (OID 2068223)
-- Name: $3; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY app_mime
    ADD CONSTRAINT "$3" FOREIGN KEY ("action") REFERENCES action_verb(name);


--
-- TOC entry 597 (OID 2068328)
-- Name: $1; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY app_icon
    ADD CONSTRAINT "$1" FOREIGN KEY (app) REFERENCES apps(fname);


--
-- TOC entry 598 (OID 2068337)
-- Name: $1; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY app_registry
    ADD CONSTRAINT "$1" FOREIGN KEY (app) REFERENCES apps(fname);


--
-- TOC entry 588 (OID 2071977)
-- Name: $1; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY apps
    ADD CONSTRAINT "$1" FOREIGN KEY (project) REFERENCES project(projectname_full);


--
-- TOC entry 593 (OID 2072025)
-- Name: $1; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY configuration
    ADD CONSTRAINT "$1" FOREIGN KEY (extends) REFERENCES configuration(configuration);


--
-- TOC entry 587 (OID 2072066)
-- Name: $2; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY apps
    ADD CONSTRAINT "$2" FOREIGN KEY (plugin_for) REFERENCES apps(fname);


--
-- TOC entry 586 (OID 2072070)
-- Name: $3; Type: FK CONSTRAINT; Schema: public; Owner: postgres
--

ALTER TABLE ONLY apps
    ADD CONSTRAINT "$3" FOREIGN KEY (gui_for) REFERENCES apps(fname);


--
-- TOC entry 599 (OID 1925683)
-- Name: WDBI_before_insert; Type: TRIGGER; Schema: public; Owner: postgres
--

CREATE TRIGGER "WDBI_before_insert"
    BEFORE INSERT ON links
    FOR EACH ROW
    EXECUTE PROCEDURE links_constuct();


--
-- TOC entry 600 (OID 2054612)
-- Name: 0010_mime_touch; Type: TRIGGER; Schema: public; Owner: postgres
--

CREATE TRIGGER "0010_mime_touch"
    BEFORE INSERT OR UPDATE ON mime
    FOR EACH ROW
    EXECUTE PROCEDURE mime_touch();


--
-- TOC entry 601 (OID 2057226)
-- Name: 0010_apps_touch; Type: TRIGGER; Schema: public; Owner: postgres
--

CREATE TRIGGER "0010_apps_touch"
    BEFORE INSERT OR UPDATE ON apps
    FOR EACH ROW
    EXECUTE PROCEDURE apps_touch();


--
-- TOC entry 602 (OID 2064808)
-- Name: 0010_app_input_touch; Type: TRIGGER; Schema: public; Owner: postgres
--

CREATE TRIGGER "0010_app_input_touch"
    BEFORE INSERT OR UPDATE ON app_mime
    FOR EACH ROW
    EXECUTE PROCEDURE app_input_touch();


--
-- TOC entry 603 (OID 2029040)
-- Name: synonym_insert_rule; Type: RULE; Schema: public; Owner: postgres
--

CREATE RULE synonym_insert_rule AS ON INSERT TO zip2 DO INSTEAD INSERT INTO zip (city, zip) VALUES (new.city, new.zip);


--
-- TOC entry 604 (OID 2029041)
-- Name: synonym_update_rule; Type: RULE; Schema: public; Owner: postgres
--

CREATE RULE synonym_update_rule AS ON UPDATE TO zip2 DO INSTEAD UPDATE zip SET city = new.city, zip = new.zip WHERE (zip.zip = old.zip);


--
-- TOC entry 605 (OID 2029042)
-- Name: synonym_delete_rule; Type: RULE; Schema: public; Owner: postgres
--

CREATE RULE synonym_delete_rule AS ON DELETE TO zip2 DO INSTEAD DELETE FROM zip WHERE (zip.zip = old.zip);


--
-- TOC entry 42 (OID 166024)
-- Name: users_id_seq; Type: SEQUENCE SET; Schema: public; Owner: postgres
--

SELECT pg_catalog.setval('users_id_seq', 1064, true);


--
-- TOC entry 44 (OID 1925012)
-- Name: id_seq; Type: SEQUENCE SET; Schema: public; Owner: postgres
--

SELECT pg_catalog.setval('id_seq', 119150, true);


--
-- TOC entry 3 (OID 2200)
-- Name: SCHEMA public; Type: COMMENT; Schema: -; Owner: postgres
--

COMMENT ON SCHEMA public IS 'Standard public schema';


--
-- TOC entry 6 (OID 165765)
-- Name: DOMAIN euro; Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON DOMAIN euro IS 'European dollar EUR';


--
-- TOC entry 136 (OID 165766)
-- Name: FUNCTION firstword(text); Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON FUNCTION firstword(text) IS 'Return first subword';


--
-- TOC entry 138 (OID 165767)
-- Name: FUNCTION makename(text); Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON FUNCTION makename(text) IS 'Convert to a name';


--
-- TOC entry 144 (OID 165772)
-- Name: FUNCTION path_indent(text, text); Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON FUNCTION path_indent(text, text) IS 'Count the occurences of second string in first';


--
-- TOC entry 146 (OID 165773)
-- Name: FUNCTION path_indent(text); Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON FUNCTION path_indent(text) IS 'Prepend path with nbspaces, no label';


--
-- TOC entry 149 (OID 165775)
-- Name: FUNCTION count_substrings(text, text); Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON FUNCTION count_substrings(text, text) IS 'Count the occurences of second string in first';


--
-- TOC entry 153 (OID 165778)
-- Name: FUNCTION str_repeat(text, integer); Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON FUNCTION str_repeat(text, integer) IS 'repeat a string';


--
-- TOC entry 156 (OID 165780)
-- Name: FUNCTION run_add(text, text); Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON FUNCTION run_add(text, text) IS 'This function adds $1 to global perl var $kiki::run[$1] and returns result. For running totals and such.';


--
-- TOC entry 160 (OID 165783)
-- Name: FUNCTION kiki_stamp(); Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON FUNCTION kiki_stamp() IS 'Before insert/update trigger on nodes';


--
-- TOC entry 162 (OID 165784)
-- Name: FUNCTION kiki_stamp_children(); Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON FUNCTION kiki_stamp_children() IS 'After update trigger children of node';


--
-- TOC entry 164 (OID 165785)
-- Name: FUNCTION kiki_insert(text, text); Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON FUNCTION kiki_insert(text, text) IS 'Insert a new node';


--
-- TOC entry 166 (OID 165786)
-- Name: FUNCTION sitemap_insert(text, text); Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON FUNCTION sitemap_insert(text, text) IS 'Insert a new node';


--
-- TOC entry 168 (OID 165787)
-- Name: FUNCTION kiki_ordung(); Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON FUNCTION kiki_ordung() IS 'After insert trigger on nodes';


--
-- TOC entry 170 (OID 165788)
-- Name: FUNCTION log_trigger(); Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON FUNCTION log_trigger() IS 'Trigger function used for logging';


--
-- TOC entry 173 (OID 165790)
-- Name: FUNCTION kiki_subclass(text, text); Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON FUNCTION kiki_subclass(text, text) IS 'Subclass a table';


--
-- TOC entry 175 (OID 165791)
-- Name: FUNCTION kiki_add_triggers(text); Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON FUNCTION kiki_add_triggers(text) IS 'Create necessary triggers on specified kiki table';


--
-- TOC entry 47 (OID 165917)
-- Name: TABLE links; Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON TABLE links IS 'Web Links';


--
-- TOC entry 50 (OID 165940)
-- Name: TABLE zip; Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON TABLE zip IS 'Postal codes';


--
-- TOC entry 177 (OID 166041)
-- Name: FUNCTION wdbi_atom(text); Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON FUNCTION wdbi_atom(text) IS 'find or create atom in table wdbi_atoms';


--
-- TOC entry 181 (OID 166099)
-- Name: FUNCTION sec_to_time(text); Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON FUNCTION sec_to_time(text) IS 'Format time (mysql)';


--
-- TOC entry 53 (OID 167301)
-- Name: TABLE mime; Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON TABLE mime IS 'MIME types';


--
-- TOC entry 14 (OID 173676)
-- Name: DOMAIN xml; Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON DOMAIN xml IS 'Syntactically correct XML';


--
-- TOC entry 12 (OID 1867128)
-- Name: TYPE issn; Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON TYPE issn IS 'International Standard Serial Number';


--
-- TOC entry 16 (OID 1867146)
-- Name: TYPE isbn; Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON TYPE isbn IS 'International Standard Book Number';


--
-- TOC entry 24 (OID 1867333)
-- Name: TYPE tsvector; Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON TYPE tsvector IS 'Tsearch2 word vector';


--
-- TOC entry 375 (OID 1867353)
-- Name: FUNCTION exectsq(tsvector, tsquery); Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON FUNCTION exectsq(tsvector, tsquery) IS 'boolean operation with text index';


--
-- TOC entry 377 (OID 1867354)
-- Name: FUNCTION rexectsq(tsquery, tsvector); Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON FUNCTION rexectsq(tsquery, tsvector) IS 'boolean operation with text index';


--
-- TOC entry 30 (OID 1867394)
-- Name: TYPE chkpass; Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON TYPE chkpass IS 'password type with checks';


--
-- TOC entry 64 (OID 1867533)
-- Name: VIEW dual; Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON VIEW dual IS 'Oracle like dual';


--
-- TOC entry 10 (OID 1912360)
-- Name: DOMAIN shell; Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON DOMAIN shell IS 'UNIX shell executable';


--
-- TOC entry 38 (OID 1923125)
-- Name: DOMAIN textarea; Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON DOMAIN textarea IS 'Text area';


--
-- TOC entry 78 (OID 2054634)
-- Name: TABLE apps; Type: COMMENT; Schema: public; Owner: postgres
--

COMMENT ON TABLE apps IS 'Desktop applications';


